(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    557510,      13545]
NotebookOptionsPosition[    525722,      13006]
NotebookOutlinePosition[    531317,      13125]
CellTagsIndexPosition[    531274,      13122]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This Mathematica notebook (CircuitsAndFormulas.nb) accompanies the article \
\[OpenCurlyDoubleQuote]Chemical Reaction Networks and Stochastic Local Search\
\[CloseCurlyDoubleQuote] (DNA 25, LNCS vol 11648, pp 1-20, 2019) by Erik \
Winfree, who is also the author of the notebook.   

The CRN simulator used here is a modification of David Soloveichik\
\[CloseCurlyQuote]s software \
(http://users.ece.utexas.edu/~soloveichik/crnsimulator.html, CRNSimulator.m, \
CRNSimulatorExtensions.m, CRNSimulatorSSA.m, Examples.nb, ExamplesSSA.nb, \
downloaded June 5, 2016) that improves performance of SSA simulation for \
large CRNs (CRNSimulatorSSA5.m).  The new features are not fully documented \
here, but will be in a future release that integrates better with the 2017 \
release of Soloveichik\[CloseCurlyQuote]s code.

This notebook is organized with critical definitions as (grey) Initialization \
Cells, so if you execute one, you will be asked if all should be executed.  \
Say yes. Interspersed are example invocations that help explain how the \
definitions can be used.\
\>", "Text",
 CellChangeTimes->{{3.7731345194022903`*^9, 3.7731346761403522`*^9}, {
  3.773134715066553*^9, 3.77313475194668*^9}, {3.773165491221787*^9, 
  3.7731656627009563`*^9}, {3.773165781403113*^9, 3.773165926870805*^9}, {
  3.773165958446312*^9, 3.773165987968218*^9}, {3.773166098232452*^9, 
  3.773166116149541*^9}, {3.773166153960567*^9, 3.7731661678560467`*^9}, {
  3.7733259189541407`*^9, 3.77332599232587*^9}, {3.773549221010396*^9, 
  3.7735492218740683`*^9}, {3.773669458348291*^9, 3.7736694602222643`*^9}, {
  3.7736747804097357`*^9, 3.7736747808324947`*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"51a0b4e7-203e-4187-a88e-2aad3c6dffb7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Get", "[", "\"\<CRNSimulator.m\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Get", "[", "\"\<CRNSimulatorSSA5.m\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Needs", "[", "\"\<ErrorBarPlots`\>\"", "]"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773135713074634*^9, 3.773135736155792*^9}, {
  3.7731357702229548`*^9, 3.7731357779550047`*^9}, {3.773499055121832*^9, 
  3.773499055361959*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"b171f188-5f30-4a33-9b94-e0e5eec7e0de"],

Cell[CellGroupData[{

Cell["Boolean Circuit Evaluation", "Section",
 CellChangeTimes->{{3.7731353585432863`*^9, 
  3.773135367944931*^9}},ExpressionUUID->"f77d9965-b86d-43af-9533-\
588f8d769478"],

Cell["\<\
Here is a natural symbolic representation of  a Boolean logic circuit.  This \
particular circuit is the one from Figure 7 of \
\[OpenCurlyDoubleQuote]Reversible Computation Using Swap Reactions on a \
Surface\[CloseCurlyDoubleQuote] in this volume.  It computes the 2-bit floor \
of the square root of a 4-bit input.  Symbolic replacement rules are used to \
replace variables representing input, gates, and output by the values that \
they should compute.\
\>", "Text",
 CellChangeTimes->{{3.7731345194022903`*^9, 3.7731346761403522`*^9}, {
  3.773134715066553*^9, 3.77313475194668*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"e0695cca-c69a-4341-8581-b1c5e8e8e655"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sqrtcircuit", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"out1", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"in1", " ", "||", " ", "in2"}], ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"out2", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"g1", " ", "||", " ", "g4"}], ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"g1", " ", "\[Rule]", " ", 
      RowBox[{"(", 
       RowBox[{"in1", " ", "&&", " ", "in2"}], ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"g2", " ", "\[Rule]", " ", 
      RowBox[{"(", 
       RowBox[{"!", "in2"}], ")"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"g3", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"in3", " ", "||", " ", "in4"}], ")"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"g4", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"g2", "&&", "g3"}], ")"}]}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773131357952937*^9, 3.773131425218872*^9}, {
  3.7731316377867928`*^9, 3.7731317348364553`*^9}, {3.773138340669475*^9, 
  3.773138346273397*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"489e8fe5-19e0-4fbb-9cab-ba96949bbccd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"inputs", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"in1", "\[Rule]", "0"}], ",", 
     RowBox[{"in2", "\[Rule]", "1"}], ",", 
     RowBox[{"in3", "\[Rule]", "0"}], ",", 
     RowBox[{"in4", "\[Rule]", "1"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.773131741813983*^9, 3.773131771109714*^9}, {
  3.773138475290058*^9, 3.773138475979993*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"1f1bf884-ae4e-48aa-a6cf-8f0ca074fdd3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"out2", ",", "out1"}], "}"}], "//.", "sqrtcircuit"}], "//.", 
   "inputs"}], "//.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"0", "\[Rule]", "False"}], ",", 
    RowBox[{"1", "\[Rule]", "True"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.773131780590714*^9, 3.773131806051477*^9}, {
  3.77313835530311*^9, 3.773138358141542*^9}, {3.773138478696314*^9, 
  3.7731384793844843`*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"51f4137a-49a2-4cbb-a2b7-0018cc62720d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"False", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.773131808122478*^9, 3.773138366710219*^9, 
  3.773138483700913*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"70e76aa0-761a-4f8f-8583-d9ee0ce19d1c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"CircuitEvaluation", "[", 
   RowBox[{"circuit_", ",", "inputs_", ",", "outputs_"}], "]"}], ":=", 
  RowBox[{"Boole", "[", 
   RowBox[{"outputs", "//.", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"circuit", "/.", "inputs"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0", "\[Rule]", "False"}], ",", 
        RowBox[{"1", "\[Rule]", "True"}]}], "}"}]}], ")"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773132006986058*^9, 3.773132066851809*^9}, {
  3.773138372478677*^9, 3.773138386617721*^9}, {3.773268326636455*^9, 
  3.773268358598117*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"8e33f8b3-9525-424d-bea9-5ed4b855ba37"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"inputs", ",", "outputs"}], "}"}], ",", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"inputs", "=", 
        RowBox[{"MapThread", "[", 
         RowBox[{"Rule", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"in1", ",", "in2", ",", "in3", ",", "in4"}], "}"}], ",", 
            
            RowBox[{"IntegerDigits", "[", 
             RowBox[{"n", ",", "2", ",", "4"}], "]"}]}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"outputs", "=", 
        RowBox[{"{", 
         RowBox[{"out1", ",", "out2"}], "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"IntegerDigits", "[", 
          RowBox[{"n", ",", "2", ",", "4"}], "]"}], ",", 
         RowBox[{"{", "\"\<=\>\"", "}"}], ",", 
         RowBox[{"CircuitEvaluation", "[", 
          RowBox[{"sqrtcircuit", ",", "inputs", ",", "outputs"}], "]"}]}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"n", ",", "0", ",", "15"}], "}"}]}], "]"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773132097630651*^9, 3.773132186211377*^9}, {
  3.773132496144418*^9, 3.773132568887961*^9}, {3.7731326273650627`*^9, 
  3.7731326416533327`*^9}, {3.773133235307767*^9, 3.773133239380115*^9}, {
  3.773133284296085*^9, 3.773133287060564*^9}, {3.7731384087548733`*^9, 
  3.773138460067658*^9}},
 CellLabel->
  "In[430]:=",ExpressionUUID->"29165b4f-e020-4278-a21a-697bc063ce45"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0", "\<\"=\"\>", "0", "0"},
     {"0", "0", "0", "1", "\<\"=\"\>", "0", "1"},
     {"0", "0", "1", "0", "\<\"=\"\>", "0", "1"},
     {"0", "0", "1", "1", "\<\"=\"\>", "0", "1"},
     {"0", "1", "0", "0", "\<\"=\"\>", "1", "0"},
     {"0", "1", "0", "1", "\<\"=\"\>", "1", "0"},
     {"0", "1", "1", "0", "\<\"=\"\>", "1", "0"},
     {"0", "1", "1", "1", "\<\"=\"\>", "1", "0"},
     {"1", "0", "0", "0", "\<\"=\"\>", "1", "0"},
     {"1", "0", "0", "1", "\<\"=\"\>", "1", "1"},
     {"1", "0", "1", "0", "\<\"=\"\>", "1", "1"},
     {"1", "0", "1", "1", "\<\"=\"\>", "1", "1"},
     {"1", "1", "0", "0", "\<\"=\"\>", "1", "1"},
     {"1", "1", "0", "1", "\<\"=\"\>", "1", "1"},
     {"1", "1", "1", "0", "\<\"=\"\>", "1", "1"},
     {"1", "1", "1", "1", "\<\"=\"\>", "1", "1"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.773132109035987*^9, 3.773132113505072*^9}, 
   3.773132569553684*^9, {3.773132637537093*^9, 3.773132642101725*^9}, 
   3.773133240081705*^9, 3.7731332875984163`*^9, 3.773138460718711*^9, 
   3.773268363682626*^9, 3.773346667080791*^9},
 CellLabel->
  "Out[430]//MatrixForm=",ExpressionUUID->"6ccd3d6c-d813-46d2-9530-\
12ce51101e5b"]
}, Open  ]],

Cell["\<\
A more general-purpose construction (with arbitrary gates) could easily be \
implemented here, but to make the construction absolutely transparent, we \
just hard-code the construction for AND, OR, NOT, and XOR gate circuits.
(You can type the XOR symbol as (esc) xor (esc).)\
\>", "Text",
 CellChangeTimes->{{3.773135391887474*^9, 3.773135408606073*^9}, {
  3.773135500167407*^9, 3.773135571723969*^9}, {3.773196147034535*^9, 
  3.7731961720190363`*^9}, {3.7731962712801857`*^9, 3.77319627640628*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"88051b51-c25d-4abb-8d1f-136195ec2549"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Xor", "[", 
  RowBox[{"A", ",", "B"}], "]"}]], "Input",
 CellChangeTimes->{{3.773196059919693*^9, 3.773196065191615*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"7cc25c2f-90d1-4fac-9932-72bbd3f0f473"],

Cell[BoxData[
 RowBox[{"A", "\[Xor]", "B"}]], "Output",
 CellChangeTimes->{3.7731960656631527`*^9},
 CellLabel->"Out[94]=",ExpressionUUID->"c29b2730-3ae2-4392-9927-6aa7461d8d78"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"CircuitEvaluationCRN", "[", "circuit_", "]"}], ":=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{"circuit", "/.", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Rule", "[", 
        RowBox[{"gate_", ",", 
         RowBox[{"(", 
          RowBox[{"in1_", " ", "||", " ", "in2_"}], ")"}]}], "]"}], 
       "\[RuleDelayed]", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Rule", "[", 
        RowBox[{"gate_", ",", 
         RowBox[{"(", 
          RowBox[{"in1_", " ", "&&", " ", "in2_"}], ")"}]}], "]"}], 
       "\[RuleDelayed]", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Rule", "[", 
        RowBox[{"gate_", ",", 
         RowBox[{"(", 
          RowBox[{"in1_", " ", "\[Xor]", " ", "in2_"}], ")"}]}], "]"}], 
       "\[RuleDelayed]", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Rule", "[", 
        RowBox[{"gate_", ",", 
         RowBox[{"(", 
          RowBox[{"!", "in_"}], ")"}]}], "]"}], "\[RuleDelayed]", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in", "[", "1", "]"}]}], ",", "1"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Rule", "[", 
        RowBox[{"gate_", ",", "value_Integer"}], "]"}], "\[RuleDelayed]", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{"rxn", "[", 
         RowBox[{
          RowBox[{"gate", "[", 
           RowBox[{"1", "-", "value"}], "]"}], ",", 
          RowBox[{"gate", "[", "value", "]"}], ",", "10"}], "]"}], 
        "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "}"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7731336380545797`*^9, 3.773133647747416*^9}, {
  3.7731337238127823`*^9, 3.7731337803106747`*^9}, {3.773133816403913*^9, 
  3.7731339870988913`*^9}, {3.7731349997515917`*^9, 3.773135115025382*^9}, {
  3.773135147109956*^9, 3.773135157144483*^9}, {3.773136163821723*^9, 
  3.7731361693559713`*^9}, {3.773138508747334*^9, 3.7731385119601192`*^9}, {
  3.773196184917919*^9, 3.77319621636522*^9}, {3.773279789326082*^9, 
  3.773279832340464*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"549d7aec-4465-4ec9-a82e-0ee873e30bf0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CircuitEvaluationCRN", "[", "sqrtcircuit", "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773135124709772*^9, 3.77313514000208*^9}, {
  3.77313851858514*^9, 3.773138521731555*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"b23b9c00-2efa-440a-9609-1d5b3d1fd613"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"out1", "[", "1", "]"}], "+", 
         RowBox[{"in1", "[", "0", "]"}], "+", 
         RowBox[{"in2", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"out1", "[", "0", "]"}], "+", 
         RowBox[{"in1", "[", "0", "]"}], "+", 
         RowBox[{"in2", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"out1", "[", "0", "]"}], "+", 
         RowBox[{"in1", "[", "0", "]"}], "+", 
         RowBox[{"in2", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"out1", "[", "1", "]"}], "+", 
         RowBox[{"in1", "[", "0", "]"}], "+", 
         RowBox[{"in2", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"out1", "[", "0", "]"}], "+", 
         RowBox[{"in1", "[", "1", "]"}], "+", 
         RowBox[{"in2", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"out1", "[", "1", "]"}], "+", 
         RowBox[{"in1", "[", "1", "]"}], "+", 
         RowBox[{"in2", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"out1", "[", "0", "]"}], "+", 
         RowBox[{"in1", "[", "1", "]"}], "+", 
         RowBox[{"in2", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"out1", "[", "1", "]"}], "+", 
         RowBox[{"in1", "[", "1", "]"}], "+", 
         RowBox[{"in2", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"out2", "[", "1", "]"}], "+", 
         RowBox[{"g1", "[", "0", "]"}], "+", 
         RowBox[{"g4", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"out2", "[", "0", "]"}], "+", 
         RowBox[{"g1", "[", "0", "]"}], "+", 
         RowBox[{"g4", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"out2", "[", "0", "]"}], "+", 
         RowBox[{"g1", "[", "0", "]"}], "+", 
         RowBox[{"g4", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"out2", "[", "1", "]"}], "+", 
         RowBox[{"g1", "[", "0", "]"}], "+", 
         RowBox[{"g4", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"out2", "[", "0", "]"}], "+", 
         RowBox[{"g1", "[", "1", "]"}], "+", 
         RowBox[{"g4", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"out2", "[", "1", "]"}], "+", 
         RowBox[{"g1", "[", "1", "]"}], "+", 
         RowBox[{"g4", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"out2", "[", "0", "]"}], "+", 
         RowBox[{"g1", "[", "1", "]"}], "+", 
         RowBox[{"g4", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"out2", "[", "1", "]"}], "+", 
         RowBox[{"g1", "[", "1", "]"}], "+", 
         RowBox[{"g4", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g1", "[", "1", "]"}], "+", 
         RowBox[{"in1", "[", "0", "]"}], "+", 
         RowBox[{"in2", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g1", "[", "0", "]"}], "+", 
         RowBox[{"in1", "[", "0", "]"}], "+", 
         RowBox[{"in2", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g1", "[", "1", "]"}], "+", 
         RowBox[{"in1", "[", "0", "]"}], "+", 
         RowBox[{"in2", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g1", "[", "0", "]"}], "+", 
         RowBox[{"in1", "[", "0", "]"}], "+", 
         RowBox[{"in2", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g1", "[", "1", "]"}], "+", 
         RowBox[{"in1", "[", "1", "]"}], "+", 
         RowBox[{"in2", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g1", "[", "0", "]"}], "+", 
         RowBox[{"in1", "[", "1", "]"}], "+", 
         RowBox[{"in2", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g1", "[", "0", "]"}], "+", 
         RowBox[{"in1", "[", "1", "]"}], "+", 
         RowBox[{"in2", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g1", "[", "1", "]"}], "+", 
         RowBox[{"in1", "[", "1", "]"}], "+", 
         RowBox[{"in2", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g2", "[", "0", "]"}], "+", 
         RowBox[{"in2", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g2", "[", "1", "]"}], "+", 
         RowBox[{"in2", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g2", "[", "1", "]"}], "+", 
         RowBox[{"in2", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g2", "[", "0", "]"}], "+", 
         RowBox[{"in2", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g3", "[", "1", "]"}], "+", 
         RowBox[{"in3", "[", "0", "]"}], "+", 
         RowBox[{"in4", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g3", "[", "0", "]"}], "+", 
         RowBox[{"in3", "[", "0", "]"}], "+", 
         RowBox[{"in4", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g3", "[", "0", "]"}], "+", 
         RowBox[{"in3", "[", "0", "]"}], "+", 
         RowBox[{"in4", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g3", "[", "1", "]"}], "+", 
         RowBox[{"in3", "[", "0", "]"}], "+", 
         RowBox[{"in4", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g3", "[", "0", "]"}], "+", 
         RowBox[{"in3", "[", "1", "]"}], "+", 
         RowBox[{"in4", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g3", "[", "1", "]"}], "+", 
         RowBox[{"in3", "[", "1", "]"}], "+", 
         RowBox[{"in4", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g3", "[", "0", "]"}], "+", 
         RowBox[{"in3", "[", "1", "]"}], "+", 
         RowBox[{"in4", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g3", "[", "1", "]"}], "+", 
         RowBox[{"in3", "[", "1", "]"}], "+", 
         RowBox[{"in4", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g4", "[", "1", "]"}], "+", 
         RowBox[{"g2", "[", "0", "]"}], "+", 
         RowBox[{"g3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g4", "[", "0", "]"}], "+", 
         RowBox[{"g2", "[", "0", "]"}], "+", 
         RowBox[{"g3", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g4", "[", "1", "]"}], "+", 
         RowBox[{"g2", "[", "0", "]"}], "+", 
         RowBox[{"g3", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g4", "[", "0", "]"}], "+", 
         RowBox[{"g2", "[", "0", "]"}], "+", 
         RowBox[{"g3", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g4", "[", "1", "]"}], "+", 
         RowBox[{"g2", "[", "1", "]"}], "+", 
         RowBox[{"g3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g4", "[", "0", "]"}], "+", 
         RowBox[{"g2", "[", "1", "]"}], "+", 
         RowBox[{"g3", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"g4", "[", "0", "]"}], "+", 
         RowBox[{"g2", "[", "1", "]"}], "+", 
         RowBox[{"g3", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"g4", "[", "1", "]"}], "+", 
         RowBox[{"g2", "[", "1", "]"}], "+", 
         RowBox[{"g3", "[", "1", "]"}]}], " "}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.773135132257275*^9, 3.7731351597495623`*^9}, 
   3.773135884494416*^9, 3.773136935430277*^9, 3.773138522258976*^9},
 CellLabel->
  "Out[45]//MatrixForm=",ExpressionUUID->"dcf68cda-6ecd-4866-84b7-\
8fc87bc9aedc"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClampCRN", "[", "inputs_", "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"inputs", "/.", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Rule", "[", 
       RowBox[{"input_", ",", "value_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"rxn", "[", 
       RowBox[{
        RowBox[{"input", "[", 
         RowBox[{"1", "-", "value"}], "]"}], ",", 
        RowBox[{"input", "[", "value", "]"}], ",", "10"}], "]"}]}], 
     "\[IndentingNewLine]", "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773136345805603*^9, 3.773136428383919*^9}, {
   3.7731364916480017`*^9, 3.773136499490492*^9}, 3.773139822221539*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"64d51fbe-72a9-4523-90f9-531f92a0c487"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ClampCRN", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"in1", "\[Rule]", "0"}], ",", 
    RowBox[{"in2", "\[Rule]", "1"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.773136621888695*^9, 3.773136633074936*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"c041d904-78b5-4744-abbb-bda3d8f2708a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"in1", "[", "1", "]"}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "10", " "}]], " ", 
    RowBox[{"in1", "[", "0", "]"}]}], " ", ",", 
   RowBox[{
    RowBox[{"in2", "[", "0", "]"}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "10", " "}]], " ", 
    RowBox[{"in2", "[", "1", "]"}]}]}], " ", "}"}]], "Output",
 CellChangeTimes->{3.773136633638302*^9, 3.773139825149781*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"48c68c4f-a2d3-44d8-8ec7-afd25f0ca096"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DualRailInitialState", "[", "crn_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"conc", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"RandomChoice", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], "]"}], "]"}], ",", "1"}], "]"}], 
     ")"}], "&"}], "/@", 
   RowBox[{"Union", "[", 
    RowBox[{"Head", "/@", 
     RowBox[{"SpeciesInRxnsys", "[", "crn", "]"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7731365246339827`*^9, 3.773136611963578*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"acd7cd05-7a7c-48bf-b8dd-da707616f7d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DualRailInitialState", "[", 
  RowBox[{"CircuitEvaluationCRN", "[", "sqrtcircuit", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.773136237521006*^9, 3.773136251412196*^9}, {
  3.773136292706235*^9, 3.773136301051996*^9}, {3.773136658820594*^9, 
  3.7731366656855717`*^9}, {3.773138530561905*^9, 3.773138532977006*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"66081b91-0e37-4b88-93b4-fe193a976dc4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"conc", "[", 
    RowBox[{
     RowBox[{"g1", "[", "1", "]"}], ",", "1"}], "]"}], ",", 
   RowBox[{"conc", "[", 
    RowBox[{
     RowBox[{"g2", "[", "0", "]"}], ",", "1"}], "]"}], ",", 
   RowBox[{"conc", "[", 
    RowBox[{
     RowBox[{"g3", "[", "0", "]"}], ",", "1"}], "]"}], ",", 
   RowBox[{"conc", "[", 
    RowBox[{
     RowBox[{"g4", "[", "1", "]"}], ",", "1"}], "]"}], ",", 
   RowBox[{"conc", "[", 
    RowBox[{
     RowBox[{"in1", "[", "1", "]"}], ",", "1"}], "]"}], ",", 
   RowBox[{"conc", "[", 
    RowBox[{
     RowBox[{"in2", "[", "0", "]"}], ",", "1"}], "]"}], ",", 
   RowBox[{"conc", "[", 
    RowBox[{
     RowBox[{"in3", "[", "1", "]"}], ",", "1"}], "]"}], ",", 
   RowBox[{"conc", "[", 
    RowBox[{
     RowBox[{"in4", "[", "1", "]"}], ",", "1"}], "]"}], ",", 
   RowBox[{"conc", "[", 
    RowBox[{
     RowBox[{"out1", "[", "0", "]"}], ",", "1"}], "]"}], ",", 
   RowBox[{"conc", "[", 
    RowBox[{
     RowBox[{"out2", "[", "0", "]"}], ",", "1"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773136252234207*^9, {3.773136294941647*^9, 3.773136301588888*^9}, 
   3.773136666477545*^9, {3.773136966310585*^9, 3.773136968433703*^9}, 
   3.773138533821628*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"eceef750-f502-42e1-9684-c6b86f6bc73e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RunCircuitEvaluationCRN", "[", 
   RowBox[{"circuit_", ",", "inputs_", ",", "outputs_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "crn", ",", "rsys", ",", "times", ",", "data", ",", "finishconcs", ",", 
      "results"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"crn", "=", 
      RowBox[{"CircuitEvaluationCRN", "[", "circuit", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rsys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"crn", ",", 
        RowBox[{"ClampCRN", "[", "inputs", "]"}], ",", 
        RowBox[{"DualRailInitialState", "[", "crn", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"times", ",", "data"}], "}"}], "=", 
      RowBox[{"SimulateRxnsysSSA", "[", 
       RowBox[{"rsys", ",", "Infinity", ",", 
        RowBox[{"Output", "\[Rule]", "\"\<State\>\""}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"finishconcs", "=", 
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}], ",", 
          RowBox[{"Last", "[", "data", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"results", "=", 
      RowBox[{"Cases", "[", 
       RowBox[{"finishconcs", ",", 
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{
           RowBox[{"s_", "[", "t_", "]"}], ",", 
           RowBox[{"_", "?", "Positive"}]}], "]"}], "\[RuleDelayed]", 
         RowBox[{"(", 
          RowBox[{"s", "\[Rule]", "t"}], ")"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"outputs", "/.", "results"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.68021565999244*^9, 3.680215750241291*^9}, {
  3.6802158052863903`*^9, 3.6802158385740547`*^9}, {3.773136058908334*^9, 
  3.773136129428895*^9}, {3.773136200951747*^9, 3.773136220896125*^9}, {
  3.7731367033385553`*^9, 3.773136728021192*^9}, {3.773136827472237*^9, 
  3.773136847838519*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"e61078bd-1a8c-4fd7-b73c-7c4139fe05b4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunCircuitEvaluationCRN", "[", 
  RowBox[{"sqrtcircuit", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"in1", "\[Rule]", "1"}], ",", 
     RowBox[{"in2", "\[Rule]", "0"}], ",", 
     RowBox[{"in3", "\[Rule]", "0"}], ",", 
     RowBox[{"in4", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"out1", ",", "out2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773136761388607*^9, 3.773136801393516*^9}, {
  3.77313701910323*^9, 3.773137043140489*^9}, {3.7731385398286963`*^9, 
  3.773138541917984*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"c65795a7-f48b-4604-abfa-d0bfe5fdebb9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7731368035986423`*^9, 3.773136852850195*^9, {3.773137023526898*^9, 
   3.773137044840991*^9}, 3.77313854468293*^9, 3.773139835705007*^9, 
   3.7731663837807198`*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"3190fdf5-d498-4fbb-b8c7-288fcb58eeb8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"inputs", ",", "outputs"}], "}"}], ",", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"inputs", "=", 
        RowBox[{"MapThread", "[", 
         RowBox[{"Rule", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"in1", ",", "in2", ",", "in3", ",", "in4"}], "}"}], ",", 
            
            RowBox[{"IntegerDigits", "[", 
             RowBox[{"n", ",", "2", ",", "4"}], "]"}]}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"outputs", "=", 
        RowBox[{"{", 
         RowBox[{"out1", ",", "out2"}], "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"IntegerDigits", "[", 
          RowBox[{"n", ",", "2", ",", "4"}], "]"}], ",", 
         RowBox[{"{", "\"\<=\>\"", "}"}], ",", 
         RowBox[{"RunCircuitEvaluationCRN", "[", 
          RowBox[{"sqrtcircuit", ",", "inputs", ",", "outputs"}], "]"}]}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"n", ",", "0", ",", "15"}], "}"}]}], "]"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773132097630651*^9, 3.773132186211377*^9}, {
  3.773132496144418*^9, 3.773132568887961*^9}, {3.7731326273650627`*^9, 
  3.7731326416533327`*^9}, {3.773133235307767*^9, 3.773133239380115*^9}, {
  3.773133284296085*^9, 3.773133287060564*^9}, {3.773136879633527*^9, 
  3.773136883233589*^9}, {3.773138552372662*^9, 3.773138581985327*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"44abeccf-05d9-4ae8-9200-74a881209702"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0", "\<\"=\"\>", "0", "0"},
     {"0", "0", "0", "1", "\<\"=\"\>", "0", "1"},
     {"0", "0", "1", "0", "\<\"=\"\>", "0", "1"},
     {"0", "0", "1", "1", "\<\"=\"\>", "0", "1"},
     {"0", "1", "0", "0", "\<\"=\"\>", "1", "0"},
     {"0", "1", "0", "1", "\<\"=\"\>", "1", "0"},
     {"0", "1", "1", "0", "\<\"=\"\>", "1", "0"},
     {"0", "1", "1", "1", "\<\"=\"\>", "1", "0"},
     {"1", "0", "0", "0", "\<\"=\"\>", "1", "0"},
     {"1", "0", "0", "1", "\<\"=\"\>", "1", "1"},
     {"1", "0", "1", "0", "\<\"=\"\>", "1", "1"},
     {"1", "0", "1", "1", "\<\"=\"\>", "1", "1"},
     {"1", "1", "0", "0", "\<\"=\"\>", "1", "1"},
     {"1", "1", "0", "1", "\<\"=\"\>", "1", "1"},
     {"1", "1", "1", "0", "\<\"=\"\>", "1", "1"},
     {"1", "1", "1", "1", "\<\"=\"\>", "1", "1"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.773136895611417*^9, {3.7731370535023117`*^9, 3.773137076752575*^9}, 
   3.7731385846038113`*^9, 3.773139840846806*^9, 3.77316639851782*^9},
 CellLabel->
  "Out[92]//MatrixForm=",ExpressionUUID->"89a850a9-a8f9-444c-8fff-\
5924992c8ab7"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Naive Boolean Circuit Satisfiability Solver", "Section",
 CellChangeTimes->{{3.7731353585432863`*^9, 3.773135367944931*^9}, {
  3.773137113731822*^9, 3.77313711827369*^9}, {3.773326022161957*^9, 
  3.773326022708658*^9}},ExpressionUUID->"a56e8c6f-c790-458b-b497-\
e1b6581a3113"],

Cell["\<\
We\[CloseCurlyQuote]ll go ahead and brute-force the construction for AND, OR, \
NOT, XOR circuits.  This construction is correct, and the resulting CRN is \
correct in the sense proved in the paper, i.e. it will eventually find a \
solution and halt if and only if a solution exists.  However, if you try it \
on circuits much larger than the square root circuit, the CRN may engage in \
an awful lot of useless meandering before arriving at the solution.  Remember \
that Mathematica can abort execution with Command-.\
\>", "Text",
 CellChangeTimes->{{3.7731345194022903`*^9, 3.7731346761403522`*^9}, {
  3.773134715066553*^9, 3.77313475194668*^9}, {3.773137458606723*^9, 
  3.773137486858985*^9}, {3.773139011708281*^9, 3.7731391622186317`*^9}, {
  3.773140039024252*^9, 3.773140082100349*^9}, {3.773196266803932*^9, 
  3.773196267304377*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"0714e2bd-0b23-4ac7-907f-d46fca36bf7b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CircuitSATCRN", "[", "circuit_", "]"}], ":=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{"circuit", "/.", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Rule", "[", 
        RowBox[{"gate_", ",", 
         RowBox[{"(", 
          RowBox[{"in1_", " ", "||", " ", "in2_"}], ")"}]}], "]"}], 
       "\[RuleDelayed]", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "output"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "input1"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "input2"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Rule", "[", 
        RowBox[{"gate_", ",", 
         RowBox[{"(", 
          RowBox[{"in1_", " ", "&&", " ", "in2_"}], ")"}]}], "]"}], 
       "\[RuleDelayed]", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "output"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "input1"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "input2"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Rule", "[", 
        RowBox[{"gate_", ",", 
         RowBox[{"(", 
          RowBox[{"in1_", " ", "\[Xor]", " ", "in2_"}], ")"}]}], "]"}], 
       "\[RuleDelayed]", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "output"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "input1"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "input2"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "0", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in1", "[", "1", "]"}], "+", 
            RowBox[{"in2", "[", "0", "]"}]}], ",", "1"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Rule", "[", 
        RowBox[{"gate_", ",", 
         RowBox[{"(", 
          RowBox[{"!", "in_"}], ")"}]}], "]"}], "\[RuleDelayed]", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in", "[", "0", "]"}]}], ",", "1"}], "]"}], ",", " ", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "output"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in", "[", "0", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "0", "]"}], "+", 
            RowBox[{"in", "[", "1", "]"}]}], ",", "1"}], "]"}], ",", " ", 
         RowBox[{"(*", " ", 
          RowBox[{"change", " ", "input"}], " ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in", "[", "1", "]"}]}], ",", 
           RowBox[{
            RowBox[{"gate", "[", "1", "]"}], "+", 
            RowBox[{"in", "[", "0", "]"}]}], ",", "1"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Rule", "[", 
        RowBox[{"gate_", ",", "value_Integer"}], "]"}], "\[RuleDelayed]", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{"rxn", "[", 
         RowBox[{
          RowBox[{"gate", "[", 
           RowBox[{"1", "-", "value"}], "]"}], ",", 
          RowBox[{"gate", "[", "value", "]"}], ",", "10"}], "]"}], 
        "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "}"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7731336380545797`*^9, 3.773133647747416*^9}, {
   3.7731337238127823`*^9, 3.7731337803106747`*^9}, {3.773133816403913*^9, 
   3.7731339870988913`*^9}, {3.7731349997515917`*^9, 3.773135115025382*^9}, {
   3.773135147109956*^9, 3.773135157144483*^9}, {3.773136163821723*^9, 
   3.7731361693559713`*^9}, {3.773137491728619*^9, 3.7731375439497643`*^9}, {
   3.7731375969195347`*^9, 3.7731377414325953`*^9}, {3.7731377810553493`*^9, 
   3.773137805456997*^9}, {3.773196257905251*^9, 3.7731964085406237`*^9}, 
   3.773280159508107*^9, {3.773345375230547*^9, 3.7733453754077377`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"0099d88b-d5a3-4220-973c-0ad5a499b6ce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RunCircuitSATCRN", "[", 
   RowBox[{"circuit_", ",", "known_", ",", "desired_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "crn", ",", "rsys", ",", "times", ",", "data", ",", "finishconcs", ",", 
      "results"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"crn", "=", 
      RowBox[{"CircuitSATCRN", "[", "circuit", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rsys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"crn", ",", 
        RowBox[{"ClampCRN", "[", "known", "]"}], ",", 
        RowBox[{"DualRailInitialState", "[", "crn", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"times", ",", "data"}], "}"}], "=", 
      RowBox[{"SimulateRxnsysSSA", "[", 
       RowBox[{"rsys", ",", "Infinity", ",", 
        RowBox[{"Output", "\[Rule]", "\"\<State\>\""}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"finishconcs", "=", 
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}], ",", 
          RowBox[{"Last", "[", "data", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"results", "=", 
      RowBox[{"Cases", "[", 
       RowBox[{"finishconcs", ",", 
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{
           RowBox[{"s_", "[", "t_", "]"}], ",", 
           RowBox[{"_", "?", "Positive"}]}], "]"}], "\[RuleDelayed]", 
         RowBox[{"(", 
          RowBox[{"s", "\[Rule]", "t"}], ")"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"desired", "/.", "results"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.68021565999244*^9, 3.680215750241291*^9}, {
  3.6802158052863903`*^9, 3.6802158385740547`*^9}, {3.773136058908334*^9, 
  3.773136129428895*^9}, {3.773136200951747*^9, 3.773136220896125*^9}, {
  3.7731367033385553`*^9, 3.773136728021192*^9}, {3.773136827472237*^9, 
  3.773136847838519*^9}, {3.7731378382659616`*^9, 3.773137844146751*^9}, {
  3.7731378785932217`*^9, 3.773137886692079*^9}, {3.773137999129963*^9, 
  3.773138017053162*^9}, {3.773139783824836*^9, 3.7731397890753393`*^9}, {
  3.773139890729321*^9, 3.773139903448102*^9}, {3.773280197937496*^9, 
  3.773280211920089*^9}, {3.7733453849612217`*^9, 3.7733453892668533`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"c2e3fc8a-a646-46ab-88d7-f7295c0d01f0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunCircuitSATCRN", "[", 
  RowBox[{"sqrtcircuit", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"out1", "\[Rule]", "1"}], ",", 
     RowBox[{"out2", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"in1", ",", "in2", ",", "in3", ",", "in4"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
  3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
  3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
  3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
  3.773166458472303*^9}, {3.773280234288148*^9, 3.773280252028183*^9}, {
  3.773280304844215*^9, 3.7732803306111727`*^9}, {3.773345412060792*^9, 
  3.773345412390747*^9}},
 CellLabel->
  "In[410]:=",ExpressionUUID->"a9eebed0-2ea2-42a0-bcb6-b0ac09750617"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.773138049033792*^9, {3.7731382852593927`*^9, 3.773138291002398*^9}, 
   3.773138667428905*^9, {3.773139748572077*^9, 3.773139794982086*^9}, 
   3.773139854611534*^9, {3.773139907046414*^9, 3.7731399345977077`*^9}, {
   3.773139973510147*^9, 3.773139993703556*^9}, 3.773166459116466*^9, 
   3.773196452277845*^9, {3.773280255270053*^9, 3.773280271366089*^9}, {
   3.773280308901577*^9, 3.773280355577343*^9}, {3.7733454134745007`*^9, 
   3.773345429951271*^9}},
 CellLabel->
  "Out[410]=",ExpressionUUID->"5120d0a3-8481-4d4f-9523-5acded815a45"]
}, Open  ]],

Cell["\<\
The square root circuit is not a particularly interesting circuit to invert.  \
A more delightful example would be an N-bit multiplication circuit, where \
solving circuit satisfiability is equivalent to factoring.  As 4-bit \
multiplication produces an 8-bit output, N=4 would allow us to factor 8-bit \
numbers.  That might be interesting.  Not practical, but illustrative.

Our convention for building modular circuits will be to let Mathematica \
provide unique variable names for new gates introduced inside a module.  \
Building and evaluating modular circuits is fine, but... factoring by the \
circuit satisfaction CRN is alas beyond painfully slow.\
\>", "Text",
 CellChangeTimes->{{3.7731345194022903`*^9, 3.7731346761403522`*^9}, {
  3.773134715066553*^9, 3.77313475194668*^9}, {3.773137458606723*^9, 
  3.773137486858985*^9}, {3.773139011708281*^9, 3.7731391622186317`*^9}, {
  3.773140039024252*^9, 3.773140082100349*^9}, {3.7731947456507797`*^9, 
  3.7731948466226263`*^9}, {3.773258477776392*^9, 3.773258483339511*^9}, {
  3.7732587358765182`*^9, 3.773258767060913*^9}, {3.773259643688278*^9, 
  3.773259659401154*^9}, {3.773284472767356*^9, 3.773284527419499*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"a111e14a-9836-4143-99f5-531e7e36ae24"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullAdder", "[", 
   RowBox[{"A_", ",", "B_", ",", "Cin_", ",", "Out_", ",", "Cout_"}], "]"}], ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"g1", ",", "g2", ",", "g3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"g1", "\[Rule]", 
       RowBox[{"A", "\[Xor]", "B"}]}], ",", 
      RowBox[{"Out", "\[Rule]", 
       RowBox[{"Cin", "\[Xor]", "g1"}]}], ",", " ", 
      RowBox[{"g2", "\[Rule]", 
       RowBox[{"Cin", "&&", "g1"}]}], ",", 
      RowBox[{"g3", "\[Rule]", 
       RowBox[{"A", "&&", "B"}]}], ",", 
      RowBox[{"Cout", "\[Rule]", 
       RowBox[{"g2", "||", "g3"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.773258613375505*^9, 3.773258655425783*^9}, {
  3.773258718696567*^9, 3.773258720313353*^9}, {3.773258772658247*^9, 
  3.7732588383047123`*^9}, {3.773259005864904*^9, 3.7732592573212957`*^9}, {
  3.773259663670514*^9, 3.773259673940139*^9}, {3.773260143917165*^9, 
  3.773260145068316*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"25cd4c20-b6de-47fa-ac02-4350e5f9d404"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullAdder", "[", 
  RowBox[{"A0", ",", "B0", ",", "C0in", ",", "Out0", ",", "C0out"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.773259264745452*^9, 3.7732593515617123`*^9}, {
  3.7732601476007833`*^9, 3.773260148541965*^9}},
 CellLabel->
  "In[113]:=",ExpressionUUID->"91035f16-3e19-4e12-9bbf-3ceded792160"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"g1$149441", "\[Rule]", 
    RowBox[{"A0", "\[Xor]", "B0"}]}], ",", 
   RowBox[{"Out0", "\[Rule]", 
    RowBox[{"C0in", "\[Xor]", "g1$149441"}]}], ",", 
   RowBox[{"g2$149441", "\[Rule]", 
    RowBox[{"C0in", "&&", "g1$149441"}]}], ",", 
   RowBox[{"g3$149441", "\[Rule]", 
    RowBox[{"A0", "&&", "B0"}]}], ",", 
   RowBox[{"C0out", "\[Rule]", 
    RowBox[{"g2$149441", "||", "g3$149441"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7732593404358873`*^9, 3.773259355940085*^9}, {
   3.773259679757811*^9, 3.7732596842195787`*^9}, 3.7732601542186947`*^9},
 CellLabel->
  "Out[113]=",ExpressionUUID->"0865c0b5-e765-4dd0-a214-fe77c669e42f"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"NBitAdder", "[", 
   RowBox[{"a_List", ",", "b_List", ",", "C_", ",", "S_List"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Cout", ",", "Cs"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Length", "[", "a", "]"}], "\[Equal]", 
       RowBox[{"Length", "[", "b", "]"}], "\[Equal]", 
       RowBox[{"Length", "[", "S", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Cs", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Unique", "[", "Cout", "]"}], ",", 
            RowBox[{"Length", "[", "a", "]"}]}], "]"}], ",", 
          RowBox[{"{", "C", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Cs", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", "0"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"FullAdder", "[", 
             RowBox[{
              RowBox[{"a", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"b", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"Cs", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"S", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"Cs", "[", 
               RowBox[{"[", 
                RowBox[{"i", "+", "1"}], "]"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Length", "[", "a", "]"}]}], "}"}]}], "]"}]}], "}"}], 
        "\[IndentingNewLine]", "]"}]}], ",", " ", 
      "\"\<NBitAdder requires a, b, S to be same length.\>\""}], "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7732594047358427`*^9, 3.773259456694578*^9}, {
   3.773259550067439*^9, 3.773259576139203*^9}, {3.773259732021762*^9, 
   3.773259732698781*^9}, {3.773259812665206*^9, 3.77325982735465*^9}, 
   3.773259867046883*^9, {3.773260042646862*^9, 3.7732600849431887`*^9}, {
   3.773260118683569*^9, 3.773260178467762*^9}, {3.773260288099164*^9, 
   3.773260358418344*^9}, {3.773260472616086*^9, 3.77326048941464*^9}, {
   3.773260526518694*^9, 3.773260553412141*^9}, {3.773260590982945*^9, 
   3.773260611211293*^9}, {3.7732606792822742`*^9, 3.773260805643147*^9}, {
   3.773260874795273*^9, 3.773260878675448*^9}, {3.773266932354085*^9, 
   3.773266983558867*^9}},
 CellLabel->
  "In[143]:=",ExpressionUUID->"cb97aa93-1087-4b40-9bc9-73b95ad97fcf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"add4", "=", 
  RowBox[{"NBitAdder", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"A0", ",", "A1", ",", "A2", ",", "A3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"B0", ",", "B1", ",", "B2", ",", "B3"}], "}"}], ",", "Cout", ",", 
    RowBox[{"{", 
     RowBox[{"S0", ",", "S1", ",", "S2", ",", "S3"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.773260813207995*^9, 3.7732608446781588`*^9}, {
  3.7732609221822166`*^9, 3.7732609223181067`*^9}, {3.773345477211648*^9, 
  3.773345484996409*^9}},
 CellLabel->
  "In[412]:=",ExpressionUUID->"69d6064b-fea9-4c1e-a19d-913eb6815b23"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Cout$818178$818179", "\[Rule]", "0"}], ",", 
   RowBox[{"g1$818183", "\[Rule]", 
    RowBox[{"A0", "\[Xor]", "B0"}]}], ",", 
   RowBox[{"S0", "\[Rule]", 
    RowBox[{"Cout$818178$818179", "\[Xor]", "g1$818183"}]}], ",", 
   RowBox[{"g2$818183", "\[Rule]", 
    RowBox[{"Cout$818178$818179", "&&", "g1$818183"}]}], ",", 
   RowBox[{"g3$818183", "\[Rule]", 
    RowBox[{"A0", "&&", "B0"}]}], ",", 
   RowBox[{"Cout$818178$818180", "\[Rule]", 
    RowBox[{"g2$818183", "||", "g3$818183"}]}], ",", 
   RowBox[{"g1$818184", "\[Rule]", 
    RowBox[{"A1", "\[Xor]", "B1"}]}], ",", 
   RowBox[{"S1", "\[Rule]", 
    RowBox[{"Cout$818178$818180", "\[Xor]", "g1$818184"}]}], ",", 
   RowBox[{"g2$818184", "\[Rule]", 
    RowBox[{"Cout$818178$818180", "&&", "g1$818184"}]}], ",", 
   RowBox[{"g3$818184", "\[Rule]", 
    RowBox[{"A1", "&&", "B1"}]}], ",", 
   RowBox[{"Cout$818178$818181", "\[Rule]", 
    RowBox[{"g2$818184", "||", "g3$818184"}]}], ",", 
   RowBox[{"g1$818185", "\[Rule]", 
    RowBox[{"A2", "\[Xor]", "B2"}]}], ",", 
   RowBox[{"S2", "\[Rule]", 
    RowBox[{"Cout$818178$818181", "\[Xor]", "g1$818185"}]}], ",", 
   RowBox[{"g2$818185", "\[Rule]", 
    RowBox[{"Cout$818178$818181", "&&", "g1$818185"}]}], ",", 
   RowBox[{"g3$818185", "\[Rule]", 
    RowBox[{"A2", "&&", "B2"}]}], ",", 
   RowBox[{"Cout$818178$818182", "\[Rule]", 
    RowBox[{"g2$818185", "||", "g3$818185"}]}], ",", 
   RowBox[{"g1$818186", "\[Rule]", 
    RowBox[{"A3", "\[Xor]", "B3"}]}], ",", 
   RowBox[{"S3", "\[Rule]", 
    RowBox[{"Cout$818178$818182", "\[Xor]", "g1$818186"}]}], ",", 
   RowBox[{"g2$818186", "\[Rule]", 
    RowBox[{"Cout$818178$818182", "&&", "g1$818186"}]}], ",", 
   RowBox[{"g3$818186", "\[Rule]", 
    RowBox[{"A3", "&&", "B3"}]}], ",", 
   RowBox[{"Cout", "\[Rule]", 
    RowBox[{"g2$818186", "||", "g3$818186"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.773260847850889*^9, 3.773260881561014*^9, 
  3.773260923919571*^9, 3.773266995207451*^9, 3.773345450727298*^9, 
  3.773345486717894*^9},
 CellLabel->
  "Out[412]=",ExpressionUUID->"80f56fd2-98fd-42ab-a4ec-9a7f38e08686"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CircuitEvaluation", "[", 
  RowBox[{"add4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A3", "\[Rule]", "1"}], ",", 
     RowBox[{"A2", "\[Rule]", "1"}], ",", 
     RowBox[{"A1", "\[Rule]", "0"}], ",", 
     RowBox[{"A0", "\[Rule]", "1"}], ",", 
     RowBox[{"B3", "\[Rule]", "1"}], ",", 
     RowBox[{"B2", "\[Rule]", "0"}], ",", 
     RowBox[{"B1", "\[Rule]", "1"}], ",", 
     RowBox[{"B0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Cout", ",", "S3", ",", "S2", ",", "S1", ",", "S0"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.77326092678153*^9, 3.7732610319592237`*^9}, {
  3.7733454909243107`*^9, 3.7733454947212553`*^9}},
 CellLabel->
  "In[413]:=",ExpressionUUID->"403e1937-7d4e-436d-b7cf-442e6cf8d56b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.773261032756998*^9, 3.773267018203594*^9, 
  3.773345495417962*^9},
 CellLabel->
  "Out[413]=",ExpressionUUID->"a69dcbb3-bc75-4f82-b6fe-b0ae1f72ee0b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"test", " ", "all", " ", "4"}], "-", 
    RowBox[{
    "bit", " ", "additions", " ", "and", " ", "check", " ", "them", " ", "by",
      " ", "eye"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "n", ",", "x", ",", "z"}], "}"}], ",", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "=", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"IntegerDigits", "[", 
            RowBox[{"n", ",", "2", ",", "8"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "4"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"b", "=", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"IntegerDigits", "[", 
            RowBox[{"n", ",", "2", ",", "8"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "8"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"x", "=", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"MapThread", "[", 
            RowBox[{"Rule", ",", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"A3", ",", "A2", ",", "A1", ",", "A0"}], "}"}], ",", 
               "a"}], "}"}]}], "]"}], ",", 
           RowBox[{"MapThread", "[", 
            RowBox[{"Rule", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"B3", ",", "B2", ",", "B1", ",", "B0"}], "}"}], ",", 
               "b"}], "}"}]}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"z", "=", 
         RowBox[{"{", 
          RowBox[{"Cout", ",", "S3", ",", "S2", ",", "S1", ",", "S0"}], 
          "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"FromDigits", "[", 
             RowBox[{"a", ",", "2"}], "]"}], "+", 
            RowBox[{"FromDigits", "[", 
             RowBox[{"b", ",", "2"}], "]"}]}], "=!=", 
           RowBox[{"FromDigits", "[", " ", 
            RowBox[{
             RowBox[{"CircuitEvaluation", "[", 
              RowBox[{"add4", ",", "x", ",", "z"}], "]"}], ",", "2"}], 
            "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Print", "[", 
           RowBox[{
           "a", ",", "\"\< plus \>\"", ",", " ", "b", ",", " ", 
            "\"\< does not equal \>\"", ",", " ", 
            RowBox[{"CircuitEvaluation", "[", 
             RowBox[{"add4", ",", "x", ",", "z"}], "]"}]}], "]"}]}], "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"Join", "[", 
         RowBox[{"a", ",", "b", ",", 
          RowBox[{"{", "\"\<=\>\"", "}"}], ",", 
          RowBox[{"CircuitEvaluation", "[", 
           RowBox[{"add4", ",", "x", ",", "z"}], "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "255"}], "}"}]}], "]"}]}], "]"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.773261108091681*^9, 3.773261361448718*^9}, {
  3.773266150833281*^9, 3.7732661699149323`*^9}, {3.7733455042232656`*^9, 
  3.773345568350309*^9}},
 CellLabel->
  "In[415]:=",ExpressionUUID->"475f4beb-a00c-4a43-bc8a-a9293776ca19"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0", "0", "0", "0", "0", "\<\"=\"\>", "0", "0", "0", "0",
       "0"},
     {"0", "0", "0", "0", "0", "0", "0", "1", "\<\"=\"\>", "0", "0", "0", "0",
       "1"},
     {"0", "0", "0", "0", "0", "0", "1", "0", "\<\"=\"\>", "0", "0", "0", "1",
       "0"},
     {"0", "0", "0", "0", "0", "0", "1", "1", "\<\"=\"\>", "0", "0", "0", "1",
       "1"},
     {"0", "0", "0", "0", "0", "1", "0", "0", "\<\"=\"\>", "0", "0", "1", "0",
       "0"},
     {"0", "0", "0", "0", "0", "1", "0", "1", "\<\"=\"\>", "0", "0", "1", "0",
       "1"},
     {"0", "0", "0", "0", "0", "1", "1", "0", "\<\"=\"\>", "0", "0", "1", "1",
       "0"},
     {"0", "0", "0", "0", "0", "1", "1", "1", "\<\"=\"\>", "0", "0", "1", "1",
       "1"},
     {"0", "0", "0", "0", "1", "0", "0", "0", "\<\"=\"\>", "0", "1", "0", "0",
       "0"},
     {"0", "0", "0", "0", "1", "0", "0", "1", "\<\"=\"\>", "0", "1", "0", "0",
       "1"},
     {"0", "0", "0", "0", "1", "0", "1", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"0", "0", "0", "0", "1", "0", "1", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"0", "0", "0", "0", "1", "1", "0", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"0", "0", "0", "0", "1", "1", "0", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"0", "0", "0", "0", "1", "1", "1", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"0", "0", "0", "0", "1", "1", "1", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"0", "0", "0", "1", "0", "0", "0", "0", "\<\"=\"\>", "0", "0", "0", "0",
       "1"},
     {"0", "0", "0", "1", "0", "0", "0", "1", "\<\"=\"\>", "0", "0", "0", "1",
       "0"},
     {"0", "0", "0", "1", "0", "0", "1", "0", "\<\"=\"\>", "0", "0", "0", "1",
       "1"},
     {"0", "0", "0", "1", "0", "0", "1", "1", "\<\"=\"\>", "0", "0", "1", "0",
       "0"},
     {"0", "0", "0", "1", "0", "1", "0", "0", "\<\"=\"\>", "0", "0", "1", "0",
       "1"},
     {"0", "0", "0", "1", "0", "1", "0", "1", "\<\"=\"\>", "0", "0", "1", "1",
       "0"},
     {"0", "0", "0", "1", "0", "1", "1", "0", "\<\"=\"\>", "0", "0", "1", "1",
       "1"},
     {"0", "0", "0", "1", "0", "1", "1", "1", "\<\"=\"\>", "0", "1", "0", "0",
       "0"},
     {"0", "0", "0", "1", "1", "0", "0", "0", "\<\"=\"\>", "0", "1", "0", "0",
       "1"},
     {"0", "0", "0", "1", "1", "0", "0", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"0", "0", "0", "1", "1", "0", "1", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"0", "0", "0", "1", "1", "0", "1", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"0", "0", "0", "1", "1", "1", "0", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"0", "0", "0", "1", "1", "1", "0", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"0", "0", "0", "1", "1", "1", "1", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"0", "0", "0", "1", "1", "1", "1", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"0", "0", "1", "0", "0", "0", "0", "0", "\<\"=\"\>", "0", "0", "0", "1",
       "0"},
     {"0", "0", "1", "0", "0", "0", "0", "1", "\<\"=\"\>", "0", "0", "0", "1",
       "1"},
     {"0", "0", "1", "0", "0", "0", "1", "0", "\<\"=\"\>", "0", "0", "1", "0",
       "0"},
     {"0", "0", "1", "0", "0", "0", "1", "1", "\<\"=\"\>", "0", "0", "1", "0",
       "1"},
     {"0", "0", "1", "0", "0", "1", "0", "0", "\<\"=\"\>", "0", "0", "1", "1",
       "0"},
     {"0", "0", "1", "0", "0", "1", "0", "1", "\<\"=\"\>", "0", "0", "1", "1",
       "1"},
     {"0", "0", "1", "0", "0", "1", "1", "0", "\<\"=\"\>", "0", "1", "0", "0",
       "0"},
     {"0", "0", "1", "0", "0", "1", "1", "1", "\<\"=\"\>", "0", "1", "0", "0",
       "1"},
     {"0", "0", "1", "0", "1", "0", "0", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"0", "0", "1", "0", "1", "0", "0", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"0", "0", "1", "0", "1", "0", "1", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"0", "0", "1", "0", "1", "0", "1", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"0", "0", "1", "0", "1", "1", "0", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"0", "0", "1", "0", "1", "1", "0", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"0", "0", "1", "0", "1", "1", "1", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"0", "0", "1", "0", "1", "1", "1", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"0", "0", "1", "1", "0", "0", "0", "0", "\<\"=\"\>", "0", "0", "0", "1",
       "1"},
     {"0", "0", "1", "1", "0", "0", "0", "1", "\<\"=\"\>", "0", "0", "1", "0",
       "0"},
     {"0", "0", "1", "1", "0", "0", "1", "0", "\<\"=\"\>", "0", "0", "1", "0",
       "1"},
     {"0", "0", "1", "1", "0", "0", "1", "1", "\<\"=\"\>", "0", "0", "1", "1",
       "0"},
     {"0", "0", "1", "1", "0", "1", "0", "0", "\<\"=\"\>", "0", "0", "1", "1",
       "1"},
     {"0", "0", "1", "1", "0", "1", "0", "1", "\<\"=\"\>", "0", "1", "0", "0",
       "0"},
     {"0", "0", "1", "1", "0", "1", "1", "0", "\<\"=\"\>", "0", "1", "0", "0",
       "1"},
     {"0", "0", "1", "1", "0", "1", "1", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"0", "0", "1", "1", "1", "0", "0", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"0", "0", "1", "1", "1", "0", "0", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"0", "0", "1", "1", "1", "0", "1", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"0", "0", "1", "1", "1", "0", "1", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"0", "0", "1", "1", "1", "1", "0", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"0", "0", "1", "1", "1", "1", "0", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"0", "0", "1", "1", "1", "1", "1", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"0", "0", "1", "1", "1", "1", "1", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"0", "1", "0", "0", "0", "0", "0", "0", "\<\"=\"\>", "0", "0", "1", "0",
       "0"},
     {"0", "1", "0", "0", "0", "0", "0", "1", "\<\"=\"\>", "0", "0", "1", "0",
       "1"},
     {"0", "1", "0", "0", "0", "0", "1", "0", "\<\"=\"\>", "0", "0", "1", "1",
       "0"},
     {"0", "1", "0", "0", "0", "0", "1", "1", "\<\"=\"\>", "0", "0", "1", "1",
       "1"},
     {"0", "1", "0", "0", "0", "1", "0", "0", "\<\"=\"\>", "0", "1", "0", "0",
       "0"},
     {"0", "1", "0", "0", "0", "1", "0", "1", "\<\"=\"\>", "0", "1", "0", "0",
       "1"},
     {"0", "1", "0", "0", "0", "1", "1", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"0", "1", "0", "0", "0", "1", "1", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"0", "1", "0", "0", "1", "0", "0", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"0", "1", "0", "0", "1", "0", "0", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"0", "1", "0", "0", "1", "0", "1", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"0", "1", "0", "0", "1", "0", "1", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"0", "1", "0", "0", "1", "1", "0", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"0", "1", "0", "0", "1", "1", "0", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"0", "1", "0", "0", "1", "1", "1", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"0", "1", "0", "0", "1", "1", "1", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"0", "1", "0", "1", "0", "0", "0", "0", "\<\"=\"\>", "0", "0", "1", "0",
       "1"},
     {"0", "1", "0", "1", "0", "0", "0", "1", "\<\"=\"\>", "0", "0", "1", "1",
       "0"},
     {"0", "1", "0", "1", "0", "0", "1", "0", "\<\"=\"\>", "0", "0", "1", "1",
       "1"},
     {"0", "1", "0", "1", "0", "0", "1", "1", "\<\"=\"\>", "0", "1", "0", "0",
       "0"},
     {"0", "1", "0", "1", "0", "1", "0", "0", "\<\"=\"\>", "0", "1", "0", "0",
       "1"},
     {"0", "1", "0", "1", "0", "1", "0", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"0", "1", "0", "1", "0", "1", "1", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"0", "1", "0", "1", "0", "1", "1", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"0", "1", "0", "1", "1", "0", "0", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"0", "1", "0", "1", "1", "0", "0", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"0", "1", "0", "1", "1", "0", "1", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"0", "1", "0", "1", "1", "0", "1", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"0", "1", "0", "1", "1", "1", "0", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"0", "1", "0", "1", "1", "1", "0", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"0", "1", "0", "1", "1", "1", "1", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"0", "1", "0", "1", "1", "1", "1", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"0", "1", "1", "0", "0", "0", "0", "0", "\<\"=\"\>", "0", "0", "1", "1",
       "0"},
     {"0", "1", "1", "0", "0", "0", "0", "1", "\<\"=\"\>", "0", "0", "1", "1",
       "1"},
     {"0", "1", "1", "0", "0", "0", "1", "0", "\<\"=\"\>", "0", "1", "0", "0",
       "0"},
     {"0", "1", "1", "0", "0", "0", "1", "1", "\<\"=\"\>", "0", "1", "0", "0",
       "1"},
     {"0", "1", "1", "0", "0", "1", "0", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"0", "1", "1", "0", "0", "1", "0", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"0", "1", "1", "0", "0", "1", "1", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"0", "1", "1", "0", "0", "1", "1", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"0", "1", "1", "0", "1", "0", "0", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"0", "1", "1", "0", "1", "0", "0", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"0", "1", "1", "0", "1", "0", "1", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"0", "1", "1", "0", "1", "0", "1", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"0", "1", "1", "0", "1", "1", "0", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"0", "1", "1", "0", "1", "1", "0", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"0", "1", "1", "0", "1", "1", "1", "0", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"0", "1", "1", "0", "1", "1", "1", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "1"},
     {"0", "1", "1", "1", "0", "0", "0", "0", "\<\"=\"\>", "0", "0", "1", "1",
       "1"},
     {"0", "1", "1", "1", "0", "0", "0", "1", "\<\"=\"\>", "0", "1", "0", "0",
       "0"},
     {"0", "1", "1", "1", "0", "0", "1", "0", "\<\"=\"\>", "0", "1", "0", "0",
       "1"},
     {"0", "1", "1", "1", "0", "0", "1", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"0", "1", "1", "1", "0", "1", "0", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"0", "1", "1", "1", "0", "1", "0", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"0", "1", "1", "1", "0", "1", "1", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"0", "1", "1", "1", "0", "1", "1", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"0", "1", "1", "1", "1", "0", "0", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"0", "1", "1", "1", "1", "0", "0", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"0", "1", "1", "1", "1", "0", "1", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"0", "1", "1", "1", "1", "0", "1", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"0", "1", "1", "1", "1", "1", "0", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"0", "1", "1", "1", "1", "1", "0", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"0", "1", "1", "1", "1", "1", "1", "0", "\<\"=\"\>", "1", "0", "1", "0",
       "1"},
     {"0", "1", "1", "1", "1", "1", "1", "1", "\<\"=\"\>", "1", "0", "1", "1",
       "0"},
     {"1", "0", "0", "0", "0", "0", "0", "0", "\<\"=\"\>", "0", "1", "0", "0",
       "0"},
     {"1", "0", "0", "0", "0", "0", "0", "1", "\<\"=\"\>", "0", "1", "0", "0",
       "1"},
     {"1", "0", "0", "0", "0", "0", "1", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"1", "0", "0", "0", "0", "0", "1", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"1", "0", "0", "0", "0", "1", "0", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"1", "0", "0", "0", "0", "1", "0", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"1", "0", "0", "0", "0", "1", "1", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"1", "0", "0", "0", "0", "1", "1", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"1", "0", "0", "0", "1", "0", "0", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"1", "0", "0", "0", "1", "0", "0", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"1", "0", "0", "0", "1", "0", "1", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"1", "0", "0", "0", "1", "0", "1", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"1", "0", "0", "0", "1", "1", "0", "0", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"1", "0", "0", "0", "1", "1", "0", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "1"},
     {"1", "0", "0", "0", "1", "1", "1", "0", "\<\"=\"\>", "1", "0", "1", "1",
       "0"},
     {"1", "0", "0", "0", "1", "1", "1", "1", "\<\"=\"\>", "1", "0", "1", "1",
       "1"},
     {"1", "0", "0", "1", "0", "0", "0", "0", "\<\"=\"\>", "0", "1", "0", "0",
       "1"},
     {"1", "0", "0", "1", "0", "0", "0", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"1", "0", "0", "1", "0", "0", "1", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"1", "0", "0", "1", "0", "0", "1", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"1", "0", "0", "1", "0", "1", "0", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"1", "0", "0", "1", "0", "1", "0", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"1", "0", "0", "1", "0", "1", "1", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"1", "0", "0", "1", "0", "1", "1", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"1", "0", "0", "1", "1", "0", "0", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"1", "0", "0", "1", "1", "0", "0", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"1", "0", "0", "1", "1", "0", "1", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"1", "0", "0", "1", "1", "0", "1", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"1", "0", "0", "1", "1", "1", "0", "0", "\<\"=\"\>", "1", "0", "1", "0",
       "1"},
     {"1", "0", "0", "1", "1", "1", "0", "1", "\<\"=\"\>", "1", "0", "1", "1",
       "0"},
     {"1", "0", "0", "1", "1", "1", "1", "0", "\<\"=\"\>", "1", "0", "1", "1",
       "1"},
     {"1", "0", "0", "1", "1", "1", "1", "1", "\<\"=\"\>", "1", "1", "0", "0",
       "0"},
     {"1", "0", "1", "0", "0", "0", "0", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "0"},
     {"1", "0", "1", "0", "0", "0", "0", "1", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"1", "0", "1", "0", "0", "0", "1", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"1", "0", "1", "0", "0", "0", "1", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"1", "0", "1", "0", "0", "1", "0", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"1", "0", "1", "0", "0", "1", "0", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"1", "0", "1", "0", "0", "1", "1", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"1", "0", "1", "0", "0", "1", "1", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"1", "0", "1", "0", "1", "0", "0", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"1", "0", "1", "0", "1", "0", "0", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"1", "0", "1", "0", "1", "0", "1", "0", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"1", "0", "1", "0", "1", "0", "1", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "1"},
     {"1", "0", "1", "0", "1", "1", "0", "0", "\<\"=\"\>", "1", "0", "1", "1",
       "0"},
     {"1", "0", "1", "0", "1", "1", "0", "1", "\<\"=\"\>", "1", "0", "1", "1",
       "1"},
     {"1", "0", "1", "0", "1", "1", "1", "0", "\<\"=\"\>", "1", "1", "0", "0",
       "0"},
     {"1", "0", "1", "0", "1", "1", "1", "1", "\<\"=\"\>", "1", "1", "0", "0",
       "1"},
     {"1", "0", "1", "1", "0", "0", "0", "0", "\<\"=\"\>", "0", "1", "0", "1",
       "1"},
     {"1", "0", "1", "1", "0", "0", "0", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"1", "0", "1", "1", "0", "0", "1", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"1", "0", "1", "1", "0", "0", "1", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"1", "0", "1", "1", "0", "1", "0", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"1", "0", "1", "1", "0", "1", "0", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"1", "0", "1", "1", "0", "1", "1", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"1", "0", "1", "1", "0", "1", "1", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"1", "0", "1", "1", "1", "0", "0", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"1", "0", "1", "1", "1", "0", "0", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"1", "0", "1", "1", "1", "0", "1", "0", "\<\"=\"\>", "1", "0", "1", "0",
       "1"},
     {"1", "0", "1", "1", "1", "0", "1", "1", "\<\"=\"\>", "1", "0", "1", "1",
       "0"},
     {"1", "0", "1", "1", "1", "1", "0", "0", "\<\"=\"\>", "1", "0", "1", "1",
       "1"},
     {"1", "0", "1", "1", "1", "1", "0", "1", "\<\"=\"\>", "1", "1", "0", "0",
       "0"},
     {"1", "0", "1", "1", "1", "1", "1", "0", "\<\"=\"\>", "1", "1", "0", "0",
       "1"},
     {"1", "0", "1", "1", "1", "1", "1", "1", "\<\"=\"\>", "1", "1", "0", "1",
       "0"},
     {"1", "1", "0", "0", "0", "0", "0", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "0"},
     {"1", "1", "0", "0", "0", "0", "0", "1", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"1", "1", "0", "0", "0", "0", "1", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"1", "1", "0", "0", "0", "0", "1", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"1", "1", "0", "0", "0", "1", "0", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"1", "1", "0", "0", "0", "1", "0", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"1", "1", "0", "0", "0", "1", "1", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"1", "1", "0", "0", "0", "1", "1", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"1", "1", "0", "0", "1", "0", "0", "0", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"1", "1", "0", "0", "1", "0", "0", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "1"},
     {"1", "1", "0", "0", "1", "0", "1", "0", "\<\"=\"\>", "1", "0", "1", "1",
       "0"},
     {"1", "1", "0", "0", "1", "0", "1", "1", "\<\"=\"\>", "1", "0", "1", "1",
       "1"},
     {"1", "1", "0", "0", "1", "1", "0", "0", "\<\"=\"\>", "1", "1", "0", "0",
       "0"},
     {"1", "1", "0", "0", "1", "1", "0", "1", "\<\"=\"\>", "1", "1", "0", "0",
       "1"},
     {"1", "1", "0", "0", "1", "1", "1", "0", "\<\"=\"\>", "1", "1", "0", "1",
       "0"},
     {"1", "1", "0", "0", "1", "1", "1", "1", "\<\"=\"\>", "1", "1", "0", "1",
       "1"},
     {"1", "1", "0", "1", "0", "0", "0", "0", "\<\"=\"\>", "0", "1", "1", "0",
       "1"},
     {"1", "1", "0", "1", "0", "0", "0", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"1", "1", "0", "1", "0", "0", "1", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"1", "1", "0", "1", "0", "0", "1", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"1", "1", "0", "1", "0", "1", "0", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"1", "1", "0", "1", "0", "1", "0", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"1", "1", "0", "1", "0", "1", "1", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"1", "1", "0", "1", "0", "1", "1", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"1", "1", "0", "1", "1", "0", "0", "0", "\<\"=\"\>", "1", "0", "1", "0",
       "1"},
     {"1", "1", "0", "1", "1", "0", "0", "1", "\<\"=\"\>", "1", "0", "1", "1",
       "0"},
     {"1", "1", "0", "1", "1", "0", "1", "0", "\<\"=\"\>", "1", "0", "1", "1",
       "1"},
     {"1", "1", "0", "1", "1", "0", "1", "1", "\<\"=\"\>", "1", "1", "0", "0",
       "0"},
     {"1", "1", "0", "1", "1", "1", "0", "0", "\<\"=\"\>", "1", "1", "0", "0",
       "1"},
     {"1", "1", "0", "1", "1", "1", "0", "1", "\<\"=\"\>", "1", "1", "0", "1",
       "0"},
     {"1", "1", "0", "1", "1", "1", "1", "0", "\<\"=\"\>", "1", "1", "0", "1",
       "1"},
     {"1", "1", "0", "1", "1", "1", "1", "1", "\<\"=\"\>", "1", "1", "1", "0",
       "0"},
     {"1", "1", "1", "0", "0", "0", "0", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "0"},
     {"1", "1", "1", "0", "0", "0", "0", "1", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"1", "1", "1", "0", "0", "0", "1", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"1", "1", "1", "0", "0", "0", "1", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"1", "1", "1", "0", "0", "1", "0", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"1", "1", "1", "0", "0", "1", "0", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"1", "1", "1", "0", "0", "1", "1", "0", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"1", "1", "1", "0", "0", "1", "1", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "1"},
     {"1", "1", "1", "0", "1", "0", "0", "0", "\<\"=\"\>", "1", "0", "1", "1",
       "0"},
     {"1", "1", "1", "0", "1", "0", "0", "1", "\<\"=\"\>", "1", "0", "1", "1",
       "1"},
     {"1", "1", "1", "0", "1", "0", "1", "0", "\<\"=\"\>", "1", "1", "0", "0",
       "0"},
     {"1", "1", "1", "0", "1", "0", "1", "1", "\<\"=\"\>", "1", "1", "0", "0",
       "1"},
     {"1", "1", "1", "0", "1", "1", "0", "0", "\<\"=\"\>", "1", "1", "0", "1",
       "0"},
     {"1", "1", "1", "0", "1", "1", "0", "1", "\<\"=\"\>", "1", "1", "0", "1",
       "1"},
     {"1", "1", "1", "0", "1", "1", "1", "0", "\<\"=\"\>", "1", "1", "1", "0",
       "0"},
     {"1", "1", "1", "0", "1", "1", "1", "1", "\<\"=\"\>", "1", "1", "1", "0",
       "1"},
     {"1", "1", "1", "1", "0", "0", "0", "0", "\<\"=\"\>", "0", "1", "1", "1",
       "1"},
     {"1", "1", "1", "1", "0", "0", "0", "1", "\<\"=\"\>", "1", "0", "0", "0",
       "0"},
     {"1", "1", "1", "1", "0", "0", "1", "0", "\<\"=\"\>", "1", "0", "0", "0",
       "1"},
     {"1", "1", "1", "1", "0", "0", "1", "1", "\<\"=\"\>", "1", "0", "0", "1",
       "0"},
     {"1", "1", "1", "1", "0", "1", "0", "0", "\<\"=\"\>", "1", "0", "0", "1",
       "1"},
     {"1", "1", "1", "1", "0", "1", "0", "1", "\<\"=\"\>", "1", "0", "1", "0",
       "0"},
     {"1", "1", "1", "1", "0", "1", "1", "0", "\<\"=\"\>", "1", "0", "1", "0",
       "1"},
     {"1", "1", "1", "1", "0", "1", "1", "1", "\<\"=\"\>", "1", "0", "1", "1",
       "0"},
     {"1", "1", "1", "1", "1", "0", "0", "0", "\<\"=\"\>", "1", "0", "1", "1",
       "1"},
     {"1", "1", "1", "1", "1", "0", "0", "1", "\<\"=\"\>", "1", "1", "0", "0",
       "0"},
     {"1", "1", "1", "1", "1", "0", "1", "0", "\<\"=\"\>", "1", "1", "0", "0",
       "1"},
     {"1", "1", "1", "1", "1", "0", "1", "1", "\<\"=\"\>", "1", "1", "0", "1",
       "0"},
     {"1", "1", "1", "1", "1", "1", "0", "0", "\<\"=\"\>", "1", "1", "0", "1",
       "1"},
     {"1", "1", "1", "1", "1", "1", "0", "1", "\<\"=\"\>", "1", "1", "1", "0",
       "0"},
     {"1", "1", "1", "1", "1", "1", "1", "0", "\<\"=\"\>", "1", "1", "1", "0",
       "1"},
     {"1", "1", "1", "1", "1", "1", "1", "1", "\<\"=\"\>", "1", "1", "1", "1",
       "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.773261362357733*^9, 3.773266171365046*^9, 
  3.773267038432008*^9, 3.773345511013585*^9, 3.7733455693176003`*^9},
 CellLabel->
  "Out[415]//MatrixForm=",ExpressionUUID->"a51c8d87-f760-4173-b3b6-\
cb5eb594a8f2"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"NBitMultiplier", "[", 
   RowBox[{"a_List", ",", "b_List", ",", "p_List"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "a", "]"}]}], ",", "g", ",", "c", ",", "s", ",",
       " ", "gs", ",", "cs", ",", "ss", ",", "gr", ",", "cr", ",", "sr"}], 
     "}"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "a", "]"}], "\[Equal]", 
        RowBox[{"Length", "[", "b", "]"}]}], "&&", 
       RowBox[{
        RowBox[{"Length", "[", "p", "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{"Length", "[", "a", "]"}], "+", 
         RowBox[{"Length", "[", "b", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"gs", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Unique", "[", "g", "]"}], ",", 
          RowBox[{"Length", "[", "a", "]"}], ",", 
          RowBox[{"Length", "[", "a", "]"}]}], "]"}]}], ";", " ", 
       RowBox[{
        RowBox[{"gs", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], "=", 
        RowBox[{"First", "[", "p", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"cs", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Unique", "[", "c", "]"}], ",", "n"}], "]"}]}], ";", 
       RowBox[{
        RowBox[{"cs", "[", 
         RowBox[{"[", 
          RowBox[{"-", "1"}], "]"}], "]"}], "=", 
        RowBox[{"Last", "[", "p", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ss", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"p", "[", 
              RowBox[{"[", 
               RowBox[{"i", "+", "1"}], "]"}], "]"}], "}"}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Unique", "[", "s", "]"}], ",", 
              RowBox[{"n", "-", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"cs", "[", 
              RowBox[{"[", 
               RowBox[{"i", "+", "1"}], "]"}], "]"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ss", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"n", "-", "1"}], ",", 
           RowBox[{"Range", "[", 
            RowBox[{"2", ",", "n"}], "]"}]}], "]"}], "]"}], "=", 
        RowBox[{"p", "[", 
         RowBox[{"[", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"n", "+", "1"}], ",", 
            RowBox[{
             RowBox[{"2", "n"}], "-", "1"}]}], "]"}], "]"}], "]"}]}], ";", 
       RowBox[{"gr", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"gs", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"a", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "&&", 
            RowBox[{"b", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "n"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"cr", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"First", "[", "cs", "]"}], "\[Rule]", "0"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sr", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"NBitAdder", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"gs", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"i", "\[Equal]", "1"}], ",", 
              RowBox[{"Join", "[", 
               RowBox[{
                RowBox[{"Rest", "[", 
                 RowBox[{"gs", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"First", "[", "cs", "]"}], "}"}]}], "]"}], ",", 
              RowBox[{"Rest", "[", 
               RowBox[{"ss", "[", 
                RowBox[{"[", 
                 RowBox[{"i", "-", "1"}], "]"}], "]"}], "]"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"cs", "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Drop", "[", 
             RowBox[{
              RowBox[{"ss", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"-", "1"}]}], "]"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{"cr", ",", "gr", ",", " ", "sr"}], "}"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      "\"\<NBitMultiplier requires a and b to be same length and p to be \
their sum.\>\""}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7732614343903*^9, 3.773261590988966*^9}, {
   3.773261668220386*^9, 3.773261687085017*^9}, {3.773261858732727*^9, 
   3.77326188776857*^9}, {3.7732626060288267`*^9, 3.773262621315063*^9}, {
   3.773262700885662*^9, 3.773262716642276*^9}, {3.77326291294598*^9, 
   3.773262990288567*^9}, {3.77326313262007*^9, 3.773263280391664*^9}, 
   3.773263336281225*^9, {3.773263366309833*^9, 3.773263379241774*^9}, {
   3.773263424681778*^9, 3.7732636151223717`*^9}, {3.773263672772709*^9, 
   3.773263690388932*^9}, {3.773263727401116*^9, 3.7732637448974543`*^9}, {
   3.773263966062723*^9, 3.773263982633659*^9}, {3.773264012973695*^9, 
   3.773264059035531*^9}, {3.773264108334138*^9, 3.773264202397546*^9}, {
   3.773264587692984*^9, 3.773264708679613*^9}, {3.773265199236025*^9, 
   3.77326527490751*^9}, 3.773265371224945*^9, {3.773265414258031*^9, 
   3.7732655157519503`*^9}, {3.773265615378725*^9, 3.773265628467782*^9}, {
   3.773265965029654*^9, 3.773265976745919*^9}, {3.7732670682832203`*^9, 
   3.773267094970262*^9}, {3.773267204918002*^9, 3.773267257291629*^9}, {
   3.773267579343667*^9, 3.773267588844144*^9}, {3.773267622001088*^9, 
   3.773267628743271*^9}, {3.7732676655494757`*^9, 3.77326767183632*^9}, {
   3.77326972831639*^9, 3.773269730590448*^9}, {3.7732704077782593`*^9, 
   3.7732704368329163`*^9}, {3.7732721814857807`*^9, 3.773272181719871*^9}, {
   3.773272536227982*^9, 3.7732725362581882`*^9}, 3.77327267514081*^9},
 CellLabel->
  "In[416]:=",ExpressionUUID->"17785053-f44a-4eeb-bdec-bfa49b744892"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mult4", "=", 
  RowBox[{"NBitMultiplier", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"A0", ",", "A1", ",", "A2", ",", "A3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"B0", ",", "B1", ",", "B2", ",", "B3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "P0", ",", "P1", ",", "P2", ",", "P3", ",", "P4", ",", "P5", ",", "P6", 
      ",", "P7"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.773265521179862*^9, 3.773265569838831*^9}, {
   3.773267721979039*^9, 3.773267722349531*^9}, 3.773269908109679*^9, {
   3.773272679884791*^9, 3.773272689768237*^9}},
 CellLabel->
  "In[417]:=",ExpressionUUID->"d1bed4a5-79d9-43ac-aa5e-f376332a48c8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"c$819102$819119", "\[Rule]", "0"}], ",", 
   RowBox[{"P0", "\[Rule]", 
    RowBox[{"A0", "&&", "B0"}]}], ",", 
   RowBox[{"g$819102$819104", "\[Rule]", 
    RowBox[{"A1", "&&", "B0"}]}], ",", 
   RowBox[{"g$819102$819105", "\[Rule]", 
    RowBox[{"A2", "&&", "B0"}]}], ",", 
   RowBox[{"g$819102$819106", "\[Rule]", 
    RowBox[{"A3", "&&", "B0"}]}], ",", 
   RowBox[{"g$819102$819107", "\[Rule]", 
    RowBox[{"A0", "&&", "B1"}]}], ",", 
   RowBox[{"g$819102$819108", "\[Rule]", 
    RowBox[{"A1", "&&", "B1"}]}], ",", 
   RowBox[{"g$819102$819109", "\[Rule]", 
    RowBox[{"A2", "&&", "B1"}]}], ",", 
   RowBox[{"g$819102$819110", "\[Rule]", 
    RowBox[{"A3", "&&", "B1"}]}], ",", 
   RowBox[{"g$819102$819111", "\[Rule]", 
    RowBox[{"A0", "&&", "B2"}]}], ",", 
   RowBox[{"g$819102$819112", "\[Rule]", 
    RowBox[{"A1", "&&", "B2"}]}], ",", 
   RowBox[{"g$819102$819113", "\[Rule]", 
    RowBox[{"A2", "&&", "B2"}]}], ",", 
   RowBox[{"g$819102$819114", "\[Rule]", 
    RowBox[{"A3", "&&", "B2"}]}], ",", 
   RowBox[{"g$819102$819115", "\[Rule]", 
    RowBox[{"A0", "&&", "B3"}]}], ",", 
   RowBox[{"g$819102$819116", "\[Rule]", 
    RowBox[{"A1", "&&", "B3"}]}], ",", 
   RowBox[{"g$819102$819117", "\[Rule]", 
    RowBox[{"A2", "&&", "B3"}]}], ",", 
   RowBox[{"g$819102$819118", "\[Rule]", 
    RowBox[{"A3", "&&", "B3"}]}], ",", 
   RowBox[{"Cout$819132$819133", "\[Rule]", "0"}], ",", 
   RowBox[{"g1$819137", "\[Rule]", 
    RowBox[{"g$819102$819104", "\[Xor]", "g$819102$819107"}]}], ",", 
   RowBox[{"P1", "\[Rule]", 
    RowBox[{"Cout$819132$819133", "\[Xor]", "g1$819137"}]}], ",", 
   RowBox[{"g2$819137", "\[Rule]", 
    RowBox[{"Cout$819132$819133", "&&", "g1$819137"}]}], ",", 
   RowBox[{"g3$819137", "\[Rule]", 
    RowBox[{"g$819102$819107", "&&", "g$819102$819104"}]}], ",", 
   RowBox[{"Cout$819132$819134", "\[Rule]", 
    RowBox[{"g2$819137", "||", "g3$819137"}]}], ",", 
   RowBox[{"g1$819138", "\[Rule]", 
    RowBox[{"g$819102$819105", "\[Xor]", "g$819102$819108"}]}], ",", 
   RowBox[{"s$819102$819123", "\[Rule]", 
    RowBox[{"Cout$819132$819134", "\[Xor]", "g1$819138"}]}], ",", 
   RowBox[{"g2$819138", "\[Rule]", 
    RowBox[{"Cout$819132$819134", "&&", "g1$819138"}]}], ",", 
   RowBox[{"g3$819138", "\[Rule]", 
    RowBox[{"g$819102$819108", "&&", "g$819102$819105"}]}], ",", 
   RowBox[{"Cout$819132$819135", "\[Rule]", 
    RowBox[{"g2$819138", "||", "g3$819138"}]}], ",", 
   RowBox[{"g1$819139", "\[Rule]", 
    RowBox[{"g$819102$819106", "\[Xor]", "g$819102$819109"}]}], ",", 
   RowBox[{"s$819102$819124", "\[Rule]", 
    RowBox[{"Cout$819132$819135", "\[Xor]", "g1$819139"}]}], ",", 
   RowBox[{"g2$819139", "\[Rule]", 
    RowBox[{"Cout$819132$819135", "&&", "g1$819139"}]}], ",", 
   RowBox[{"g3$819139", "\[Rule]", 
    RowBox[{"g$819102$819109", "&&", "g$819102$819106"}]}], ",", 
   RowBox[{"Cout$819132$819136", "\[Rule]", 
    RowBox[{"g2$819139", "||", "g3$819139"}]}], ",", 
   RowBox[{"g1$819140", "\[Rule]", 
    RowBox[{"c$819102$819119", "\[Xor]", "g$819102$819110"}]}], ",", 
   RowBox[{"s$819102$819125", "\[Rule]", 
    RowBox[{"Cout$819132$819136", "\[Xor]", "g1$819140"}]}], ",", 
   RowBox[{"g2$819140", "\[Rule]", 
    RowBox[{"Cout$819132$819136", "&&", "g1$819140"}]}], ",", 
   RowBox[{"g3$819140", "\[Rule]", 
    RowBox[{"g$819102$819110", "&&", "c$819102$819119"}]}], ",", 
   RowBox[{"c$819102$819120", "\[Rule]", 
    RowBox[{"g2$819140", "||", "g3$819140"}]}], ",", 
   RowBox[{"Cout$819141$819142", "\[Rule]", "0"}], ",", 
   RowBox[{"g1$819146", "\[Rule]", 
    RowBox[{"g$819102$819111", "\[Xor]", "s$819102$819123"}]}], ",", 
   RowBox[{"P2", "\[Rule]", 
    RowBox[{"Cout$819141$819142", "\[Xor]", "g1$819146"}]}], ",", 
   RowBox[{"g2$819146", "\[Rule]", 
    RowBox[{"Cout$819141$819142", "&&", "g1$819146"}]}], ",", 
   RowBox[{"g3$819146", "\[Rule]", 
    RowBox[{"g$819102$819111", "&&", "s$819102$819123"}]}], ",", 
   RowBox[{"Cout$819141$819143", "\[Rule]", 
    RowBox[{"g2$819146", "||", "g3$819146"}]}], ",", 
   RowBox[{"g1$819147", "\[Rule]", 
    RowBox[{"g$819102$819112", "\[Xor]", "s$819102$819124"}]}], ",", 
   RowBox[{"s$819102$819126", "\[Rule]", 
    RowBox[{"Cout$819141$819143", "\[Xor]", "g1$819147"}]}], ",", 
   RowBox[{"g2$819147", "\[Rule]", 
    RowBox[{"Cout$819141$819143", "&&", "g1$819147"}]}], ",", 
   RowBox[{"g3$819147", "\[Rule]", 
    RowBox[{"g$819102$819112", "&&", "s$819102$819124"}]}], ",", 
   RowBox[{"Cout$819141$819144", "\[Rule]", 
    RowBox[{"g2$819147", "||", "g3$819147"}]}], ",", 
   RowBox[{"g1$819148", "\[Rule]", 
    RowBox[{"g$819102$819113", "\[Xor]", "s$819102$819125"}]}], ",", 
   RowBox[{"s$819102$819127", "\[Rule]", 
    RowBox[{"Cout$819141$819144", "\[Xor]", "g1$819148"}]}], ",", 
   RowBox[{"g2$819148", "\[Rule]", 
    RowBox[{"Cout$819141$819144", "&&", "g1$819148"}]}], ",", 
   RowBox[{"g3$819148", "\[Rule]", 
    RowBox[{"g$819102$819113", "&&", "s$819102$819125"}]}], ",", 
   RowBox[{"Cout$819141$819145", "\[Rule]", 
    RowBox[{"g2$819148", "||", "g3$819148"}]}], ",", 
   RowBox[{"g1$819149", "\[Rule]", 
    RowBox[{"c$819102$819120", "\[Xor]", "g$819102$819114"}]}], ",", 
   RowBox[{"s$819102$819128", "\[Rule]", 
    RowBox[{"Cout$819141$819145", "\[Xor]", "g1$819149"}]}], ",", 
   RowBox[{"g2$819149", "\[Rule]", 
    RowBox[{"Cout$819141$819145", "&&", "g1$819149"}]}], ",", 
   RowBox[{"g3$819149", "\[Rule]", 
    RowBox[{"g$819102$819114", "&&", "c$819102$819120"}]}], ",", 
   RowBox[{"c$819102$819121", "\[Rule]", 
    RowBox[{"g2$819149", "||", "g3$819149"}]}], ",", 
   RowBox[{"Cout$819150$819151", "\[Rule]", "0"}], ",", 
   RowBox[{"g1$819155", "\[Rule]", 
    RowBox[{"g$819102$819115", "\[Xor]", "s$819102$819126"}]}], ",", 
   RowBox[{"P3", "\[Rule]", 
    RowBox[{"Cout$819150$819151", "\[Xor]", "g1$819155"}]}], ",", 
   RowBox[{"g2$819155", "\[Rule]", 
    RowBox[{"Cout$819150$819151", "&&", "g1$819155"}]}], ",", 
   RowBox[{"g3$819155", "\[Rule]", 
    RowBox[{"g$819102$819115", "&&", "s$819102$819126"}]}], ",", 
   RowBox[{"Cout$819150$819152", "\[Rule]", 
    RowBox[{"g2$819155", "||", "g3$819155"}]}], ",", 
   RowBox[{"g1$819156", "\[Rule]", 
    RowBox[{"g$819102$819116", "\[Xor]", "s$819102$819127"}]}], ",", 
   RowBox[{"P4", "\[Rule]", 
    RowBox[{"Cout$819150$819152", "\[Xor]", "g1$819156"}]}], ",", 
   RowBox[{"g2$819156", "\[Rule]", 
    RowBox[{"Cout$819150$819152", "&&", "g1$819156"}]}], ",", 
   RowBox[{"g3$819156", "\[Rule]", 
    RowBox[{"g$819102$819116", "&&", "s$819102$819127"}]}], ",", 
   RowBox[{"Cout$819150$819153", "\[Rule]", 
    RowBox[{"g2$819156", "||", "g3$819156"}]}], ",", 
   RowBox[{"g1$819157", "\[Rule]", 
    RowBox[{"g$819102$819117", "\[Xor]", "s$819102$819128"}]}], ",", 
   RowBox[{"P5", "\[Rule]", 
    RowBox[{"Cout$819150$819153", "\[Xor]", "g1$819157"}]}], ",", 
   RowBox[{"g2$819157", "\[Rule]", 
    RowBox[{"Cout$819150$819153", "&&", "g1$819157"}]}], ",", 
   RowBox[{"g3$819157", "\[Rule]", 
    RowBox[{"g$819102$819117", "&&", "s$819102$819128"}]}], ",", 
   RowBox[{"Cout$819150$819154", "\[Rule]", 
    RowBox[{"g2$819157", "||", "g3$819157"}]}], ",", 
   RowBox[{"g1$819158", "\[Rule]", 
    RowBox[{"c$819102$819121", "\[Xor]", "g$819102$819118"}]}], ",", 
   RowBox[{"P6", "\[Rule]", 
    RowBox[{"Cout$819150$819154", "\[Xor]", "g1$819158"}]}], ",", 
   RowBox[{"g2$819158", "\[Rule]", 
    RowBox[{"Cout$819150$819154", "&&", "g1$819158"}]}], ",", 
   RowBox[{"g3$819158", "\[Rule]", 
    RowBox[{"g$819102$819118", "&&", "c$819102$819121"}]}], ",", 
   RowBox[{"P7", "\[Rule]", 
    RowBox[{"g2$819158", "||", "g3$819158"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773272681456814*^9, 3.7732726914064083`*^9}, 
   3.773345584612177*^9},
 CellLabel->
  "Out[417]=",ExpressionUUID->"23995361-1b42-4a50-afc4-bb5c089e3017"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CircuitEvaluation", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A3", "\[Rule]", "1"}], ",", 
     RowBox[{"A2", "\[Rule]", "1"}], ",", 
     RowBox[{"A1", "\[Rule]", "0"}], ",", 
     RowBox[{"A0", "\[Rule]", "1"}], ",", 
     RowBox[{"B3", "\[Rule]", "1"}], ",", 
     RowBox[{"B2", "\[Rule]", "0"}], ",", 
     RowBox[{"B1", "\[Rule]", "1"}], ",", 
     RowBox[{"B0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "P7", ",", "P6", ",", "P5", ",", "P4", ",", "P3", ",", "P2", ",", "P1", 
     ",", "P0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.77326092678153*^9, 3.7732610319592237`*^9}, {
  3.773267753242972*^9, 3.773267763571062*^9}, {3.773267796042349*^9, 
  3.773267798734644*^9}, {3.773267901691452*^9, 3.773267904668077*^9}, {
  3.773272700234758*^9, 3.7732727013055477`*^9}, {3.773272756652507*^9, 
  3.773272758460618*^9}},
 CellLabel->
  "In[418]:=",ExpressionUUID->"932cdb9f-3605-463f-8ab4-292cb0905446"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "1", ",", "1"}],
   "}"}]], "Output",
 CellChangeTimes->{{3.7732677831161327`*^9, 3.773267801109716*^9}, 
   3.773267914303712*^9, 3.773269769978713*^9, 3.773270570831455*^9, 
   3.773272268827922*^9, 3.77327255202868*^9, 3.773272703089315*^9, 
   3.77327275938489*^9, 3.773279767500331*^9, 3.7733455904390173`*^9},
 CellLabel->
  "Out[418]=",ExpressionUUID->"a331f6ee-bef9-4db6-a2e1-f45ff85f0767"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"test", " ", "all", " ", "4"}], "-", 
    RowBox[{
    "bit", " ", "multiplications", " ", "and", " ", "check", " ", "them", " ",
      "automatically"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "n", ",", "x", ",", "z"}], "}"}], ",", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "=", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"IntegerDigits", "[", 
            RowBox[{"n", ",", "2", ",", "8"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "4"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"b", "=", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"IntegerDigits", "[", 
            RowBox[{"n", ",", "2", ",", "8"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"5", ",", "8"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"x", "=", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"MapThread", "[", 
            RowBox[{"Rule", ",", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"A3", ",", "A2", ",", "A1", ",", "A0"}], "}"}], ",", 
               "a"}], "}"}]}], "]"}], ",", 
           RowBox[{"MapThread", "[", 
            RowBox[{"Rule", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"B3", ",", "B2", ",", "B1", ",", "B0"}], "}"}], ",", 
               "b"}], "}"}]}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"z", "=", 
         RowBox[{"{", 
          RowBox[{
          "P7", ",", "P6", ",", "P5", ",", "P4", ",", "P3", ",", "P2", ",", 
           "P1", ",", "P0"}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"FromDigits", "[", 
             RowBox[{"a", ",", "2"}], "]"}], "*", 
            RowBox[{"FromDigits", "[", 
             RowBox[{"b", ",", "2"}], "]"}]}], "=!=", 
           RowBox[{"FromDigits", "[", " ", 
            RowBox[{
             RowBox[{"CircuitEvaluation", "[", 
              RowBox[{"mult4", ",", "x", ",", "z"}], "]"}], ",", "2"}], 
            "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Print", "[", 
           RowBox[{
           "a", ",", "\"\< times \>\"", ",", " ", "b", ",", " ", 
            "\"\< does not equal \>\"", ",", " ", 
            RowBox[{"CircuitEvaluation", "[", 
             RowBox[{"mult4", ",", "x", ",", "z"}], "]"}]}], "]"}]}], "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"Join", "[", 
         RowBox[{"a", ",", 
          RowBox[{"{", "\"\< * \>\"", "}"}], ",", "b", ",", 
          RowBox[{"{", "\"\< = \>\"", "}"}], ",", 
          RowBox[{"CircuitEvaluation", "[", 
           RowBox[{"mult4", ",", "x", ",", "z"}], "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "255"}], "}"}]}], "]"}]}], "]"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.773261108091681*^9, 3.773261361448718*^9}, {
  3.773266150833281*^9, 3.7732661699149323`*^9}, {3.773272731420412*^9, 
  3.773272788143426*^9}, {3.773272827628983*^9, 3.773273010632653*^9}},
 CellLabel->
  "In[419]:=",ExpressionUUID->"2652cdb2-b366-4846-92f2-99adc4a12feb"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "1", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "1", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "1"},
     {"0", "0", "0", "1", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "1", "0"},
     {"0", "0", "0", "1", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "1", "1"},
     {"0", "0", "0", "1", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "0", "0"},
     {"0", "0", "0", "1", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "0", "1"},
     {"0", "0", "0", "1", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "1", "0"},
     {"0", "0", "0", "1", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "1", "1"},
     {"0", "0", "0", "1", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "0", "0"},
     {"0", "0", "0", "1", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "0", "1"},
     {"0", "0", "0", "1", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "1", "0"},
     {"0", "0", "0", "1", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "1", "1"},
     {"0", "0", "0", "1", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "0", "0"},
     {"0", "0", "0", "1", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "0", "1"},
     {"0", "0", "0", "1", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "1", "0"},
     {"0", "0", "0", "1", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "1", "1"},
     {"0", "0", "1", "0", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "1", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "0", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "1", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "0", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "1", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "0", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "1", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "0", "0", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "0", "1", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "1", "0", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "1", "1", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "0", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "1", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "1", "0", "0"},
     {"0", "0", "1", "0", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "1", "1", "0"},
     {"0", "0", "1", "1", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "1", "1", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "1", "1"},
     {"0", "0", "1", "1", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "1", "0"},
     {"0", "0", "1", "1", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "0", "1"},
     {"0", "0", "1", "1", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "0", "0"},
     {"0", "0", "1", "1", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "1", "1"},
     {"0", "0", "1", "1", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "0", "1", "0"},
     {"0", "0", "1", "1", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "1", "0", "1"},
     {"0", "0", "1", "1", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "0", "0"},
     {"0", "0", "1", "1", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "1", "1"},
     {"0", "0", "1", "1", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "1", "1", "0"},
     {"0", "0", "1", "1", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "0", "0", "1"},
     {"0", "0", "1", "1", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "1", "0", "0"},
     {"0", "0", "1", "1", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "1", "1", "1"},
     {"0", "0", "1", "1", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "0", "1", "0"},
     {"0", "0", "1", "1", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "1", "0", "1"},
     {"0", "1", "0", "0", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "0", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "1", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "1", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "0", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "1", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "0", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "1", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "0", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "1", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "0", "0", "0"},
     {"0", "1", "0", "0", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "1", "0", "0"},
     {"0", "1", "0", "1", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "1", "0", "1", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "0", "1"},
     {"0", "1", "0", "1", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "1", "0"},
     {"0", "1", "0", "1", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "1", "1"},
     {"0", "1", "0", "1", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "1", "0", "0"},
     {"0", "1", "0", "1", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "0", "1"},
     {"0", "1", "0", "1", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "1", "1", "0"},
     {"0", "1", "0", "1", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "0", "1", "1"},
     {"0", "1", "0", "1", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "0", "0", "0"},
     {"0", "1", "0", "1", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "1", "0", "1"},
     {"0", "1", "0", "1", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "0", "1", "0"},
     {"0", "1", "0", "1", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "1", "1", "1"},
     {"0", "1", "0", "1", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "1", "0", "0"},
     {"0", "1", "0", "1", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "0", "0", "0", "1"},
     {"0", "1", "0", "1", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "0", "1", "0", "0", "0", "1", "1", "0"},
     {"0", "1", "0", "1", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "1", "0", "1", "1"},
     {"0", "1", "1", "0", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "1", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "0", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "0", "1", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "0", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "1", "1", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "1", "0", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "0", "1", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "0", "0", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "1", "1", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "1", "0", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "0", "0", "1", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "1", "0", "0", "1", "0", "0", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "1", "1", "1", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "0", "1", "0", "1", "0", "1", "0", "0"},
     {"0", "1", "1", "0", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "0", "1", "0", "1", "1", "0", "1", "0"},
     {"0", "1", "1", "1", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "1", "1", "1", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "1", "1", "1"},
     {"0", "1", "1", "1", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "1", "0"},
     {"0", "1", "1", "1", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "1", "0", "1"},
     {"0", "1", "1", "1", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "1", "0", "0"},
     {"0", "1", "1", "1", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "0", "1", "1"},
     {"0", "1", "1", "1", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "0", "1", "0"},
     {"0", "1", "1", "1", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "0", "0", "1"},
     {"0", "1", "1", "1", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "0", "0", "0"},
     {"0", "1", "1", "1", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "1", "1", "1"},
     {"0", "1", "1", "1", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "1", "0", "0", "0", "1", "1", "0"},
     {"0", "1", "1", "1", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "1", "1", "0", "1"},
     {"0", "1", "1", "1", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "1", "0", "1", "0", "1", "0", "0"},
     {"0", "1", "1", "1", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "0", "1", "0", "1", "1", "0", "1", "1"},
     {"0", "1", "1", "1", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "0", "1", "1", "0", "0", "0", "1", "0"},
     {"0", "1", "1", "1", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "0", "1", "1", "0", "1", "0", "0", "1"},
     {"1", "0", "0", "0", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "1", "0", "0", "0", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "1", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "1", "0", "1", "0", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "1", "0", "1", "1", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "1", "1", "0", "0", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "0", "1", "1", "0", "1", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "0", "1", "1", "1", "0", "0", "0", "0"},
     {"1", "0", "0", "0", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "0", "1", "1", "1", "1", "0", "0", "0"},
     {"1", "0", "0", "1", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"1", "0", "0", "1", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "0", "1"},
     {"1", "0", "0", "1", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "0", "1", "0"},
     {"1", "0", "0", "1", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "1", "1"},
     {"1", "0", "0", "1", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "1", "0", "0"},
     {"1", "0", "0", "1", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "1", "0", "1"},
     {"1", "0", "0", "1", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "1", "1", "0"},
     {"1", "0", "0", "1", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "1", "1", "1"},
     {"1", "0", "0", "1", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "1", "0", "0", "1", "0", "0", "0"},
     {"1", "0", "0", "1", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "1", "0", "1", "0", "0", "0", "1"},
     {"1", "0", "0", "1", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "1", "0", "1", "1", "0", "1", "0"},
     {"1", "0", "0", "1", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "1", "1", "0", "0", "0", "1", "1"},
     {"1", "0", "0", "1", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "1", "1", "0", "1", "1", "0", "0"},
     {"1", "0", "0", "1", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "0", "1", "1", "1", "0", "1", "0", "1"},
     {"1", "0", "0", "1", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "0", "1", "1", "1", "1", "1", "1", "0"},
     {"1", "0", "0", "1", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "1", "0", "0", "0", "0", "1", "1", "1"},
     {"1", "0", "1", "0", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "1", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "1", "0", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "1", "1", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "0", "0", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "0", "1", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "1", "0", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "0", "1", "1", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "1", "0", "1", "0", "0", "0", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "1", "0", "1", "1", "0", "1", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "1", "1", "0", "0", "1", "0", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "1", "1", "0", "1", "1", "1", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "0", "1", "1", "1", "1", "0", "0", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "1", "0", "0", "0", "0", "0", "1", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "1", "0", "0", "0", "1", "1", "0", "0"},
     {"1", "0", "1", "0", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "1", "0", "0", "1", "0", "1", "1", "0"},
     {"1", "0", "1", "1", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"1", "0", "1", "1", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "0", "1", "1"},
     {"1", "0", "1", "1", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "0", "1", "1", "0"},
     {"1", "0", "1", "1", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "0", "0", "1"},
     {"1", "0", "1", "1", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "1", "0", "0"},
     {"1", "0", "1", "1", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "1", "1", "1"},
     {"1", "0", "1", "1", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "1", "0", "0", "0", "0", "1", "0"},
     {"1", "0", "1", "1", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "1", "1", "0", "1"},
     {"1", "0", "1", "1", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "1", "0", "1", "1", "0", "0", "0"},
     {"1", "0", "1", "1", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "1", "1", "0", "0", "0", "1", "1"},
     {"1", "0", "1", "1", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "1", "1", "0", "1", "1", "1", "0"},
     {"1", "0", "1", "1", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "0", "1", "1", "1", "1", "0", "0", "1"},
     {"1", "0", "1", "1", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "1", "0", "0", "0", "0", "1", "0", "0"},
     {"1", "0", "1", "1", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "1", "0", "0", "0", "1", "1", "1", "1"},
     {"1", "0", "1", "1", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "1", "0", "0", "1", "1", "0", "1", "0"},
     {"1", "0", "1", "1", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "1", "0", "1", "0", "0", "1", "0", "1"},
     {"1", "1", "0", "0", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "1", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "0", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "1", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "1", "0", "0", "1", "0", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "1", "0", "1", "0", "1", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "1", "1", "0", "0", "0", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "1", "1", "0", "1", "1", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "0", "1", "1", "1", "1", "0", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "1", "0", "0", "0", "0", "1", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "1", "0", "0", "1", "0", "0", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "1", "0", "0", "1", "1", "1", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "1", "0", "1", "0", "1", "0", "0", "0"},
     {"1", "1", "0", "0", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "1", "0", "1", "1", "0", "1", "0", "0"},
     {"1", "1", "0", "1", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"1", "1", "0", "1", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "0", "1"},
     {"1", "1", "0", "1", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "0", "1", "0"},
     {"1", "1", "0", "1", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "0", "1", "1", "1"},
     {"1", "1", "0", "1", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "0", "1", "0", "0"},
     {"1", "1", "0", "1", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "0", "0", "0", "1"},
     {"1", "1", "0", "1", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "1", "0", "0", "1", "1", "1", "0"},
     {"1", "1", "0", "1", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "1", "0", "1", "1", "0", "1", "1"},
     {"1", "1", "0", "1", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "1", "1", "0", "1", "0", "0", "0"},
     {"1", "1", "0", "1", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "1", "1", "1", "0", "1", "0", "1"},
     {"1", "1", "0", "1", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "1", "0", "0", "0", "0", "0", "1", "0"},
     {"1", "1", "0", "1", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "1", "0", "0", "0", "1", "1", "1", "1"},
     {"1", "1", "0", "1", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "1", "0", "0", "1", "1", "1", "0", "0"},
     {"1", "1", "0", "1", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "1", "0", "1", "0", "1", "0", "0", "1"},
     {"1", "1", "0", "1", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "1", "0", "1", "1", "0", "1", "1", "0"},
     {"1", "1", "0", "1", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "1", "1", "0", "0", "0", "0", "1", "1"},
     {"1", "1", "1", "0", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "1", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "1", "0", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "0", "1", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "0", "0", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "0", "1", "1", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "1", "0", "1", "0", "1", "0", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "1", "1", "0", "0", "0", "1", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "1", "1", "1", "0", "0", "0", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "0", "1", "1", "1", "1", "1", "1", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "1", "0", "0", "0", "1", "1", "0", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "1", "0", "0", "1", "1", "0", "1", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "1", "0", "1", "0", "1", "0", "0", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "1", "0", "1", "1", "0", "1", "1", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "1", "1", "0", "0", "0", "1", "0", "0"},
     {"1", "1", "1", "0", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "1", "1", "0", "1", "0", "0", "1", "0"},
     {"1", "1", "1", "1", "\<\" * \"\>", "0", "0", "0", "0", "\<\" = \"\>", 
      "0", "0", "0", "0", "0", "0", "0", "0"},
     {"1", "1", "1", "1", "\<\" * \"\>", "0", "0", "0", "1", "\<\" = \"\>", 
      "0", "0", "0", "0", "1", "1", "1", "1"},
     {"1", "1", "1", "1", "\<\" * \"\>", "0", "0", "1", "0", "\<\" = \"\>", 
      "0", "0", "0", "1", "1", "1", "1", "0"},
     {"1", "1", "1", "1", "\<\" * \"\>", "0", "0", "1", "1", "\<\" = \"\>", 
      "0", "0", "1", "0", "1", "1", "0", "1"},
     {"1", "1", "1", "1", "\<\" * \"\>", "0", "1", "0", "0", "\<\" = \"\>", 
      "0", "0", "1", "1", "1", "1", "0", "0"},
     {"1", "1", "1", "1", "\<\" * \"\>", "0", "1", "0", "1", "\<\" = \"\>", 
      "0", "1", "0", "0", "1", "0", "1", "1"},
     {"1", "1", "1", "1", "\<\" * \"\>", "0", "1", "1", "0", "\<\" = \"\>", 
      "0", "1", "0", "1", "1", "0", "1", "0"},
     {"1", "1", "1", "1", "\<\" * \"\>", "0", "1", "1", "1", "\<\" = \"\>", 
      "0", "1", "1", "0", "1", "0", "0", "1"},
     {"1", "1", "1", "1", "\<\" * \"\>", "1", "0", "0", "0", "\<\" = \"\>", 
      "0", "1", "1", "1", "1", "0", "0", "0"},
     {"1", "1", "1", "1", "\<\" * \"\>", "1", "0", "0", "1", "\<\" = \"\>", 
      "1", "0", "0", "0", "0", "1", "1", "1"},
     {"1", "1", "1", "1", "\<\" * \"\>", "1", "0", "1", "0", "\<\" = \"\>", 
      "1", "0", "0", "1", "0", "1", "1", "0"},
     {"1", "1", "1", "1", "\<\" * \"\>", "1", "0", "1", "1", "\<\" = \"\>", 
      "1", "0", "1", "0", "0", "1", "0", "1"},
     {"1", "1", "1", "1", "\<\" * \"\>", "1", "1", "0", "0", "\<\" = \"\>", 
      "1", "0", "1", "1", "0", "1", "0", "0"},
     {"1", "1", "1", "1", "\<\" * \"\>", "1", "1", "0", "1", "\<\" = \"\>", 
      "1", "1", "0", "0", "0", "0", "1", "1"},
     {"1", "1", "1", "1", "\<\" * \"\>", "1", "1", "1", "0", "\<\" = \"\>", 
      "1", "1", "0", "1", "0", "0", "1", "0"},
     {"1", "1", "1", "1", "\<\" * \"\>", "1", "1", "1", "1", "\<\" = \"\>", 
      "1", "1", "1", "0", "0", "0", "0", "1"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.773273015804557*^9, 3.773345597377405*^9},
 CellLabel->
  "Out[419]//MatrixForm=",ExpressionUUID->"3df92b44-b39f-41b7-b01c-\
4f67370b2191"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunCircuitEvaluationCRN", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A3", "\[Rule]", "1"}], ",", 
     RowBox[{"A2", "\[Rule]", "1"}], ",", 
     RowBox[{"A1", "\[Rule]", "0"}], ",", 
     RowBox[{"A0", "\[Rule]", "1"}], ",", 
     RowBox[{"B3", "\[Rule]", "1"}], ",", 
     RowBox[{"B2", "\[Rule]", "0"}], ",", 
     RowBox[{"B1", "\[Rule]", "1"}], ",", 
     RowBox[{"B0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "P7", ",", "P6", ",", "P5", ",", "P4", ",", "P3", ",", "P2", ",", "P1", 
     ",", "P0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773136761388607*^9, 3.773136801393516*^9}, {
  3.77313701910323*^9, 3.773137043140489*^9}, {3.7731385398286963`*^9, 
  3.773138541917984*^9}, {3.773279735113558*^9, 3.773279747235894*^9}},
 CellLabel->
  "In[420]:=",ExpressionUUID->"db194095-ce19-420b-b2b8-a4218a3e2efa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "1", ",", "1"}],
   "}"}]], "Output",
 CellChangeTimes->{{3.7732797534891157`*^9, 3.773279759295453*^9}, {
   3.773279858679227*^9, 3.7732798632681923`*^9}, 3.773284569960329*^9, 
   3.7733456039449244`*^9},
 CellLabel->
  "Out[420]=",ExpressionUUID->"f3c170ff-e34f-4f1f-98a2-33d52c958edc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "mult4", "]"}]], "Input",
 CellChangeTimes->{{3.773326614622122*^9, 3.7733266172082*^9}},
 CellLabel->
  "In[293]:=",ExpressionUUID->"712a2506-bf0e-43b6-a778-88cf838f687c"],

Cell[BoxData["80"], "Output",
 CellChangeTimes->{3.773326617805492*^9},
 CellLabel->
  "Out[293]=",ExpressionUUID->"a76f1a9b-62f8-4a49-b76b-8f9477e95b0b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"_", "[", 
    RowBox[{"_Symbol", ",", "_Integer"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773326647108151*^9, 3.773326723270256*^9}},
 CellLabel->
  "In[296]:=",ExpressionUUID->"fde378a9-0931-49b0-aedf-0de713138c23"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"c$169625$169642", "\[Rule]", "0"}], ",", 
   RowBox[{"Cout$169655$169656", "\[Rule]", "0"}], ",", 
   RowBox[{"Cout$169664$169665", "\[Rule]", "0"}], ",", 
   RowBox[{"Cout$169673$169674", "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773326660634528*^9, 3.773326684310087*^9}, 
   3.773326723878745*^9},
 CellLabel->
  "Out[296]=",ExpressionUUID->"a915b64e-dda8-4db1-8623-0a7734840cd0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"CircuitEvaluationCRN", "[", "mult4", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.773326513480752*^9, 3.773326553074546*^9}},
 CellLabel->
  "In[292]:=",ExpressionUUID->"46aa7a3f-1b13-4f94-a3bf-256125506ba8"],

Cell[BoxData["308"], "Output",
 CellChangeTimes->{3.773326531900444*^9, 3.77332659175725*^9},
 CellLabel->
  "Out[292]=",ExpressionUUID->"3b7625e0-90cd-42f6-8e73-2b11e9fab780"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"CircuitSATCRN", "[", "mult4", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.773326513480752*^9, 3.773326553074546*^9}, {
  3.77332678709112*^9, 3.773326788886126*^9}, {3.773345610903345*^9, 
  3.7733456111283712`*^9}},
 CellLabel->
  "In[421]:=",ExpressionUUID->"ef574283-f484-450b-8c63-a75242c9b5f4"],

Cell[BoxData["916"], "Output",
 CellChangeTimes->{3.773326531900444*^9, 3.77332659175725*^9, 
  3.773326789941979*^9, 3.773345612128821*^9},
 CellLabel->
  "Out[421]=",ExpressionUUID->"f28564e7-db34-4697-8b45-caf7efaf55fe"]
}, Open  ]],

Cell["\<\
The 4-bit multiplication circuit has 80 gates (including 4 constant values), \
and the corresponding circuit evaluation CRN has 308 reactions.   The circuit \
satisfiability CRN has 916 reactions; let\[CloseCurlyQuote]s see what that \
gets you.

If you clamp the inputs, it will calculate forward and you can read the \
output: it performs multiplication.  13 * 11 = 143.\
\>", "Text",
 CellChangeTimes->{{3.773284587135214*^9, 3.7732846402428226`*^9}, {
  3.7733266333981256`*^9, 3.773326645005114*^9}, {3.773326732398467*^9, 
  3.773326813384766*^9}, {3.773326971379553*^9, 3.773327027581431*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"ca27e3e7-2597-4442-88b2-63103944f43a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunCircuitSATCRN", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A3", "\[Rule]", "1"}], ",", 
     RowBox[{"A2", "\[Rule]", "1"}], ",", 
     RowBox[{"A1", "\[Rule]", "0"}], ",", 
     RowBox[{"A0", "\[Rule]", "1"}], ",", 
     RowBox[{"B3", "\[Rule]", "1"}], ",", 
     RowBox[{"B2", "\[Rule]", "0"}], ",", 
     RowBox[{"B1", "\[Rule]", "1"}], ",", 
     RowBox[{"B0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "P7", ",", "P6", ",", "P5", ",", "P4", ",", "P3", ",", "P2", ",", "P1", 
     ",", "P0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.773326072795823*^9, {3.773326823943169*^9, 3.773326856287869*^9}, {
   3.773326892216467*^9, 3.7733268943383827`*^9}, 3.773327032639454*^9, {
   3.773345634748732*^9, 3.773345636808978*^9}},
 CellLabel->
  "In[422]:=",ExpressionUUID->"047236e6-efa1-40f9-949f-704946100446"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "1", ",", "1"}],
   "}"}]], "Output",
 CellChangeTimes->{3.773326078999913*^9, 3.773327078181176*^9, 
  3.7733456407284927`*^9},
 CellLabel->
  "Out[422]=",ExpressionUUID->"a8380801-aa18-43eb-8cff-4d3bec878d55"]
}, Open  ]],

Cell["\<\
If you clamp the output and one input, it will calculate sideways and you can \
read the other input: it performs division . 143/13 = 11.\
\>", "Text",
 CellChangeTimes->{{3.773284587135214*^9, 3.7732846402428226`*^9}, {
  3.7733266333981256`*^9, 3.773326645005114*^9}, {3.773326732398467*^9, 
  3.773326813384766*^9}, {3.773326971379553*^9, 3.7733270687368097`*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"1729763d-471c-438d-9079-4c9b1a8a51cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunCircuitSATCRN", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A3", "\[Rule]", "1"}], ",", 
     RowBox[{"A2", "\[Rule]", "1"}], ",", 
     RowBox[{"A1", "\[Rule]", "0"}], ",", 
     RowBox[{"A0", "\[Rule]", "1"}], ",", 
     RowBox[{"P7", "\[Rule]", "1"}], ",", 
     RowBox[{"P6", "\[Rule]", "0"}], ",", 
     RowBox[{"P5", "\[Rule]", "0"}], ",", 
     RowBox[{"P4", "\[Rule]", "0"}], ",", 
     RowBox[{"P3", "\[Rule]", "1"}], ",", 
     RowBox[{"P2", "\[Rule]", "1"}], ",", 
     RowBox[{"P1", "\[Rule]", "1"}], ",", 
     RowBox[{"P0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"B3", ",", "B2", ",", "B1", ",", "B0"}], "}"}]}], "]"}]], "Input",\

 CellChangeTimes->{
  3.773326072795823*^9, {3.7733261335349627`*^9, 3.773326165005332*^9}, {
   3.773326864729732*^9, 3.7733269113451633`*^9}, 3.7733270726597967`*^9, {
   3.773345644654078*^9, 3.7733456448224163`*^9}},
 CellLabel->
  "In[423]:=",ExpressionUUID->"1a3cf362-cd72-400c-80ee-7714857645d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.773326169120125*^9, 3.773327085846754*^9, 
  3.773345647796536*^9},
 CellLabel->
  "Out[423]=",ExpressionUUID->"7d3e06df-6423-47af-ae59-e4831a6f1f00"]
}, Open  ]],

Cell["\<\
If you clamp the output, it will calculate backward and you can read the \
inputs: it performs factorization.  Factors of 143 include 13 and 11.\
\>", "Text",
 CellChangeTimes->{{3.773284587135214*^9, 3.7732846402428226`*^9}, {
  3.7733266333981256`*^9, 3.773326645005114*^9}, {3.773326732398467*^9, 
  3.773326813384766*^9}, {3.773326971379553*^9, 3.7733270687368097`*^9}, {
  3.773327101853036*^9, 3.773327142114811*^9}, {3.7733456692459793`*^9, 
  3.773345671126664*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"6402d316-4f4f-4abb-a04a-c22231d6d7a8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunCircuitSATCRN", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P7", "\[Rule]", "1"}], ",", 
     RowBox[{"P6", "\[Rule]", "0"}], ",", 
     RowBox[{"P5", "\[Rule]", "0"}], ",", 
     RowBox[{"P4", "\[Rule]", "0"}], ",", 
     RowBox[{"P3", "\[Rule]", "1"}], ",", 
     RowBox[{"P2", "\[Rule]", "1"}], ",", 
     RowBox[{"P1", "\[Rule]", "1"}], ",", 
     RowBox[{"P0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", "B1", 
     ",", "B0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
   3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
   3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
   3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
   3.773166458472303*^9}, {3.77327988361902*^9, 3.773279911979558*^9}, {
   3.773280057199664*^9, 3.773280128264084*^9}, {3.7733262156521378`*^9, 
   3.773326221916224*^9}, {3.773326916728631*^9, 3.773326934196891*^9}, 
   3.77332709817653*^9, 3.773327144762494*^9, {3.773345652241632*^9, 
   3.773345652423212*^9}},
 CellLabel->
  "In[424]:=",ExpressionUUID->"335f3aef-2f8a-41e1-b211-84449664db25"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "0", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0", ",", "1"}],
   "}"}]], "Output",
 CellChangeTimes->{3.773326235034787*^9, 3.773326951215279*^9, 
  3.773327161467757*^9, 3.77334571898958*^9},
 CellLabel->
  "Out[424]=",ExpressionUUID->"133bbb51-1c1c-4e66-be4b-62d2a8c0c3d2"]
}, Open  ]],

Cell["\<\
It doesn\[CloseCurlyQuote]t need to be so neat: if you provide valid clues \
about input, output, and/or intermediate gates, that may well be enough for \
the CRN to play Sherlock and sort out everything else.  (There may be \
multiple possible solutions, if not enough clues were given...)

The code below rather awkwardly chooses random awkwardly-named intermediate \
gates (from when the circuit mult4 was built... their names will be different \
every-time one re-runs the code to build mult4) and does a calculation to \
find values for those intermediate gates that are consistent with the given \
inputs.   The circuit SAT solver is run for partial inputs, outputs, and \
intermediate gates, then the solution that it found is tested to make sure it \
works.  It does.\
\>", "Text",
 CellChangeTimes->{{3.773284587135214*^9, 3.7732846402428226`*^9}, {
  3.7733266333981256`*^9, 3.773326645005114*^9}, {3.773326732398467*^9, 
  3.773326813384766*^9}, {3.773326971379553*^9, 3.7733270687368097`*^9}, {
  3.773327101853036*^9, 3.773327142114811*^9}, {3.773327934957101*^9, 
  3.7733279474065228`*^9}, {3.773328000488317*^9, 3.7733280338047*^9}, {
  3.773328215490341*^9, 3.773328241184587*^9}, {3.773346130863179*^9, 
  3.773346153441534*^9}, {3.773346236605054*^9, 3.77334624584975*^9}, {
  3.7733464452453947`*^9, 3.773346562903161*^9}, {3.773347033799334*^9, 
  3.7733470858053303`*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"853b8345-5510-4b61-97ee-15305c5f6e9c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"randomgate1", "=", 
  RowBox[{"Head", "[", 
   RowBox[{"RandomChoice", "[", 
    RowBox[{"SpeciesInRxnsys", "[", 
     RowBox[{"CircuitSATCRN", "[", "mult4", "]"}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.773327797466775*^9, 3.7733278809599133`*^9}, {
  3.773327961174727*^9, 3.773327962300439*^9}, {3.773345687201305*^9, 
  3.77334568749969*^9}},
 CellLabel->
  "In[426]:=",ExpressionUUID->"9a14e253-7325-4049-b35e-132cdd433d23"],

Cell[BoxData["Cout$819141$819145"], "Output",
 CellChangeTimes->{
  3.773327820425539*^9, {3.773327866478899*^9, 3.773327881814152*^9}, 
   3.773327975213485*^9, 3.7733283563516607`*^9, 3.773345746986005*^9, 
   3.773346157206723*^9},
 CellLabel->
  "Out[426]=",ExpressionUUID->"48c04e27-162c-4536-8b3f-54c6abe1aad4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"randomgate2", "=", 
  RowBox[{"Head", "[", 
   RowBox[{"RandomChoice", "[", 
    RowBox[{"SpeciesInRxnsys", "[", 
     RowBox[{"CircuitSATCRN", "[", "mult4", "]"}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.773327797466775*^9, 3.7733278809599133`*^9}, {
  3.773327961174727*^9, 3.77332797341635*^9}, {3.773345692354827*^9, 
  3.77334569265832*^9}},
 CellLabel->
  "In[427]:=",ExpressionUUID->"236fe45a-0d21-4af5-9c29-348670e46ea9"],

Cell[BoxData["g$819102$819112"], "Output",
 CellChangeTimes->{3.773327977716701*^9, 3.7733283581622143`*^9, 
  3.773346161645279*^9},
 CellLabel->
  "Out[427]=",ExpressionUUID->"9a2ca045-13e5-4f9b-84b1-8163316a3cb4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"valid", "=", 
  RowBox[{"CircuitEvaluation", "[", 
   RowBox[{"mult4", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A3", "\[Rule]", "1"}], ",", 
      RowBox[{"A2", "\[Rule]", "1"}], ",", 
      RowBox[{"A1", "\[Rule]", "0"}], ",", 
      RowBox[{"A0", "\[Rule]", "1"}], ",", 
      RowBox[{"B3", "\[Rule]", "1"}], ",", 
      RowBox[{"B2", "\[Rule]", "0"}], ",", 
      RowBox[{"B1", "\[Rule]", "1"}], ",", 
      RowBox[{"B0", "\[Rule]", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "P7", ",", "P6", ",", "P5", ",", "P4", ",", "P3", ",", "P2", ",", "P1", 
      ",", "P0", ",", "randomgate1", ",", "randomgate2"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.773326072795823*^9, {3.773326823943169*^9, 3.773326856287869*^9}, {
   3.773326892216467*^9, 3.7733268943383827`*^9}, 3.773327032639454*^9, {
   3.773327908788611*^9, 3.7733279102427797`*^9}, {3.773327983122484*^9, 
   3.773327985956992*^9}, {3.773328106278913*^9, 3.773328106797048*^9}, {
   3.773345698714889*^9, 3.7733456990413513`*^9}, {3.7733466007104273`*^9, 
   3.773346602757691*^9}},
 CellLabel->
  "In[444]:=",ExpressionUUID->"cba80840-8cb7-44ae-915e-004902eb6120"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.773327915165174*^9, 3.773327990049189*^9, 3.7733281098890057`*^9, 
   3.773328362120267*^9, 3.773346225955324*^9, {3.773346889861135*^9, 
   3.773346899905384*^9}},
 CellLabel->
  "Out[444]=",ExpressionUUID->"450d3285-8132-4197-89f6-010cda1c33ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"RunCircuitSATCRN", "[", 
   RowBox[{"mult4", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A3", "\[Rule]", "1"}], ",", 
      RowBox[{"A0", "\[Rule]", "1"}], ",", 
      RowBox[{"B1", "\[Rule]", "1"}], ",", 
      RowBox[{"B0", "\[Rule]", "1"}], ",", 
      RowBox[{"P6", "\[Rule]", "0"}], ",", 
      RowBox[{"P3", "\[Rule]", "1"}], ",", 
      RowBox[{"P2", "\[Rule]", "1"}], ",", 
      RowBox[{"randomgate1", "\[Rule]", 
       RowBox[{"valid", "[", 
        RowBox[{"[", 
         RowBox[{"-", "2"}], "]"}], "]"}]}], ",", 
      RowBox[{"randomgate2", "\[Rule]", 
       RowBox[{"valid", "[", 
        RowBox[{"[", 
         RowBox[{"-", "1"}], "]"}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", "B1", 
      ",", "B0", ",", "P7", ",", "P6", ",", "P5", ",", "P4", ",", "P3", ",", 
      "P2", ",", "P1", ",", "P0"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.773326072795823*^9, {3.773326823943169*^9, 3.773326856287869*^9}, {
   3.773326892216467*^9, 3.7733268943383827`*^9}, 3.773327032639454*^9, {
   3.773327908788611*^9, 3.7733279102427797`*^9}, {3.773327983122484*^9, 
   3.773327985956992*^9}, {3.773328051259577*^9, 3.773328176883068*^9}, {
   3.773345704378257*^9, 3.773345704660087*^9}, {3.773346070398695*^9, 
   3.773346072133315*^9}, {3.77334691482241*^9, 3.773346917658342*^9}, {
   3.773346966795281*^9, 3.773346974106872*^9}},
 CellLabel->
  "In[445]:=",ExpressionUUID->"044e269b-47bd-4d5e-a6fc-ce4ca6274f0f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "1", ",", "1", ",", "0", ",", "0", ",", "1", ",", "1", 
   ",", "0", ",", "0", ",", "1", ",", "0", ",", "1", ",", "1", ",", "0", ",", 
   "1"}], "}"}]], "Output",
 CellChangeTimes->{{3.773328156894939*^9, 3.7733281802272387`*^9}, {
   3.773328246803652*^9, 3.773328256378813*^9}, 3.773328367675702*^9, 
   3.773346650253798*^9, 3.773346990277154*^9},
 CellLabel->
  "Out[445]=",ExpressionUUID->"d5f5366d-3526-4b32-a43d-4fd5466a9750"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CircuitEvaluation", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"MapThread", "[", 
    RowBox[{"Rule", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", 
         "B1", ",", "B0"}], "}"}], ",", 
       RowBox[{"Take", "[", 
        RowBox[{"sol", ",", "8"}], "]"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "P7", ",", "P6", ",", "P5", ",", "P4", ",", "P3", ",", "P2", ",", "P1", 
     ",", "P0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.773326072795823*^9, {3.773326823943169*^9, 3.773326856287869*^9}, {
   3.773326892216467*^9, 3.7733268943383827`*^9}, 3.773327032639454*^9, {
   3.773327908788611*^9, 3.7733279102427797`*^9}, {3.773327983122484*^9, 
   3.773327985956992*^9}, {3.773328106278913*^9, 3.773328106797048*^9}, {
   3.7733283163848658`*^9, 3.773328335057529*^9}, {3.773328383278709*^9, 
   3.773328453286091*^9}, {3.7733457097003307`*^9, 3.773345710014954*^9}, {
   3.773347011801544*^9, 3.7733470164918756`*^9}},
 CellLabel->
  "In[446]:=",ExpressionUUID->"088735be-5039-4d98-9660-079b4648cce3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "1", ",", "0", ",", "1", ",", "1", ",", "0", ",", "1"}],
   "}"}]], "Output",
 CellChangeTimes->{3.773328457385765*^9, 3.7733470198340397`*^9},
 CellLabel->
  "Out[446]=",ExpressionUUID->"a9078277-d364-4b17-97d4-968e41e47ec9"]
}, Open  ]],

Cell["\<\
But not all is good.   If we try to factor 85 or 236,  the CRN bounces around \
between incomplete partial solutions for so long that we loose patience...\
\>", "Text",
 CellChangeTimes->{{3.773284587135214*^9, 3.7732846402428226`*^9}, {
  3.7733266333981256`*^9, 3.773326645005114*^9}, {3.773326732398467*^9, 
  3.773326813384766*^9}, {3.773326971379553*^9, 3.7733270687368097`*^9}, {
  3.773327101853036*^9, 3.773327142114811*^9}, {3.7733271744750566`*^9, 
  3.773327255205567*^9}, {3.773327308281427*^9, 3.7733273374016247`*^9}, {
  3.773327695256754*^9, 3.773327718561523*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"7e7743bf-6e0f-4d77-b860-6885af8aa1ce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IntegerDigits", "[", 
  RowBox[{
   RowBox[{"17", "*", "5"}], ",", "2", ",", "8"}], "]"}]], "Input",
 CellChangeTimes->{{3.773280086155188*^9, 3.7732800998310127`*^9}, {
  3.773327376694656*^9, 3.773327378867056*^9}},
 CellLabel->
  "In[302]:=",ExpressionUUID->"0bac5d1a-13af-4419-8e69-bad74c3a0477"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "1", ",", "0", ",", "1", ",", "0", ",", "1", ",", "0", ",", "1"}],
   "}"}]], "Output",
 CellChangeTimes->{3.773327383498763*^9},
 CellLabel->
  "Out[302]=",ExpressionUUID->"0020dac4-aa74-4124-82fc-fc9817867207"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunCircuitSATCRN", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P7", "\[Rule]", "0"}], ",", 
     RowBox[{"P6", "\[Rule]", "1"}], ",", 
     RowBox[{"P5", "\[Rule]", "0"}], ",", 
     RowBox[{"P4", "\[Rule]", "1"}], ",", 
     RowBox[{"P3", "\[Rule]", "0"}], ",", 
     RowBox[{"P2", "\[Rule]", "1"}], ",", 
     RowBox[{"P1", "\[Rule]", "0"}], ",", 
     RowBox[{"P0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", "B1", 
     ",", "B0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
   3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
   3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
   3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
   3.773166458472303*^9}, {3.77327988361902*^9, 3.773279911979558*^9}, {
   3.773280057199664*^9, 3.773280128264084*^9}, {3.7733262156521378`*^9, 
   3.773326221916224*^9}, {3.773326916728631*^9, 3.773326934196891*^9}, 
   3.77332709817653*^9, 3.773327144762494*^9, {3.77332738664828*^9, 
   3.77332740261819*^9}, {3.773345717121467*^9, 3.7733457227248583`*^9}},
 CellLabel->
  "In[447]:=",ExpressionUUID->"d6977147-1323-4c65-8487-7484c353a85b"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.773326235034787*^9, 3.773326951215279*^9, 
  3.773327161467757*^9, 3.773327683609096*^9, 3.7733285269073143`*^9, 
  3.773347326219266*^9},
 CellLabel->
  "Out[447]=",ExpressionUUID->"eacdb752-195f-4fd7-a057-d0b0295707a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IntegerDigits", "[", 
  RowBox[{"236", ",", "2", ",", "8"}], "]"}]], "Input",
 CellChangeTimes->{{3.773280086155188*^9, 3.7732800998310127`*^9}},
 CellLabel->
  "In[252]:=",ExpressionUUID->"71bb9780-5c63-45eb-ab16-37bbb497dce3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "1", ",", "0", ",", "1", ",", "1", ",", "0", ",", "0"}],
   "}"}]], "Output",
 CellChangeTimes->{{3.773280094529801*^9, 3.7732801002672443`*^9}},
 CellLabel->
  "Out[252]=",ExpressionUUID->"399b11c4-4423-4f78-9850-ba36baf54881"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunCircuitSATCRN", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P7", "\[Rule]", "1"}], ",", 
     RowBox[{"P6", "\[Rule]", "1"}], ",", 
     RowBox[{"P5", "\[Rule]", "1"}], ",", 
     RowBox[{"P4", "\[Rule]", "0"}], ",", 
     RowBox[{"P3", "\[Rule]", "1"}], ",", 
     RowBox[{"P2", "\[Rule]", "1"}], ",", 
     RowBox[{"P1", "\[Rule]", "0"}], ",", 
     RowBox[{"P0", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", "B1", 
     ",", "B0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
  3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
  3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
  3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
  3.773166458472303*^9}, {3.77327988361902*^9, 3.773279911979558*^9}, {
  3.773280057199664*^9, 3.773280128264084*^9}, {3.773347344526004*^9, 
  3.773347347630453*^9}},
 CellLabel->
  "In[448]:=",ExpressionUUID->"74e92b25-5712-4b17-8445-fc19bdf2d0bf"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{
  3.773138049033792*^9, {3.7731382852593927`*^9, 3.773138291002398*^9}, 
   3.773138667428905*^9, {3.773139748572077*^9, 3.773139794982086*^9}, 
   3.773139854611534*^9, {3.773139907046414*^9, 3.7731399345977077`*^9}, {
   3.773139973510147*^9, 3.773139993703556*^9}, 3.773166459116466*^9, 
   3.773196452277845*^9, 3.773280874142686*^9, 3.773347563409141*^9},
 CellLabel->
  "Out[448]=",ExpressionUUID->"bbd08b6b-a505-4c62-9d7a-6c380e7ddd73"]
}, Open  ]],

Cell["\<\
There seems to be motivation to make solving satisfiability problems at least \
a little bit more efficient...\
\>", "Text",
 CellChangeTimes->{{3.773284587135214*^9, 3.7732846402428226`*^9}, 
   3.77332734718438*^9, {3.773347579608418*^9, 3.7733475842054567`*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"893e883c-7bde-4ffb-90dd-874dcab9a5e3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Naive Boolean Formula Satisfiability Solver", "Section",
 CellChangeTimes->{{3.7731353585432863`*^9, 3.773135367944931*^9}, {
  3.773137113731822*^9, 3.77313711827369*^9}, {3.773326022161957*^9, 
  3.773326022708658*^9}, {3.773329079022523*^9, 
  3.7733290797123623`*^9}},ExpressionUUID->"62e41cfb-bf1e-4528-8dff-\
d7cf41579d46"],

Cell["\<\
This CRN still won\[CloseCurlyQuote]t be efficient, but it will be a stepping \
stone toward the more efficient WalkSATCRN.  First, we\[CloseCurlyQuote]ll \
need a representation for Boolean formulas.  We\[CloseCurlyQuote]ll use \
standard Mathematica Boolean expressions, and assume that they consist of a \
conjunction of clauses.   (What\[CloseCurlyQuote]s inside the clauses could \
be standard disjunctions, as when our expression is in conjunctive normal \
form, but our code will actually be OK with arbitrary subexpressions within \
each clause -- just, in that case, the number of CRN reactions related to the \
clause may scale exponentially with the number of variables in the clause.)  \
Mathematica has a variety of built-in functions to work with this \
representation, which is convenient.\
\>", "Text",
 CellChangeTimes->{{3.7731345194022903`*^9, 3.7731346761403522`*^9}, {
   3.773134715066553*^9, 3.77313475194668*^9}, {3.773137458606723*^9, 
   3.773137486858985*^9}, {3.773139011708281*^9, 3.7731391622186317`*^9}, {
   3.773140039024252*^9, 3.773140082100349*^9}, {3.773196266803932*^9, 
   3.773196267304377*^9}, 3.7733290832963943`*^9, {3.773336599123534*^9, 
   3.773336628856786*^9}, {3.773340030748124*^9, 3.7733400560896873`*^9}, {
   3.7733415481305513`*^9, 3.7733417065521183`*^9}, {3.7733422950884953`*^9, 
   3.773342296503228*^9}, {3.773342748459626*^9, 3.773342768392971*^9}, {
   3.773343140295533*^9, 3.773343161161839*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"2288d7c7-daec-4289-befc-122a82a2b65f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AdlemanSAT", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x03"}], " ", "||", " ", 
      RowBox[{"!", "x16"}], " ", "||", " ", "x18"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x05", "||", "x12", "||", 
      RowBox[{"!", "x09"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x13"}], "||", 
      RowBox[{"!", "x02"}], "||", "x20"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x12", "||", 
      RowBox[{"!", "x09"}], "||", 
      RowBox[{"!", "x05"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x19", "||", 
      RowBox[{"!", "x04"}], "||", "x06"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x09", "||", "x12", "||", 
      RowBox[{"!", "x05"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x01"}], "||", "x04", "||", 
      RowBox[{"!", "x11"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x13", "||", 
      RowBox[{"!", "x02"}], "||", 
      RowBox[{"!", "x19"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x05", "||", "x17", "||", "x09"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x15", "||", "x09", "||", 
      RowBox[{"!", "x17"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x05"}], "||", 
      RowBox[{"!", "x09"}], "||", 
      RowBox[{"!", "x12"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x06", "||", "x11", "||", "x04"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x15"}], "||", 
      RowBox[{"!", "x17"}], "||", "x07"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x06"}], "||", "x19", "||", "x13"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x12"}], "||", 
      RowBox[{"!", "x09"}], "||", "x05"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x12", "||", "x01", "||", "x14"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x20", "||", "x03", "||", "x02"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x10", "||", 
      RowBox[{"!", "x07"}], "||", 
      RowBox[{"!", "x08"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x05"}], "||", "x09", "||", 
      RowBox[{"!", "x12"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x18", "||", 
      RowBox[{"!", "x20"}], "||", "x03"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x10"}], "||", 
      RowBox[{"!", "x18"}], "||", 
      RowBox[{"!", "x16"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x01", "||", 
      RowBox[{"!", "x11"}], "||", 
      RowBox[{"!", "x14"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x08", "||", 
      RowBox[{"!", "x07"}], "||", 
      RowBox[{"!", "x15"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x08"}], "||", "x16", "||", 
      RowBox[{"!", "x10"}]}], ")"}]}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.680215895381444*^9, 3.680215903814577*^9}, {
   3.680216123067609*^9, 3.680216162633552*^9}, {3.6802170099454727`*^9, 
   3.680217026457756*^9}, {3.680217561902968*^9, 3.680217687187366*^9}, {
   3.680217775640882*^9, 3.6802178516039047`*^9}, {3.680217897924828*^9, 
   3.680218069619013*^9}, {3.683730619383401*^9, 3.68373069916354*^9}, 
   3.683730795775299*^9, {3.773340408178934*^9, 3.773340689996361*^9}, {
   3.7733407400606403`*^9, 3.773340774387685*^9}, {3.773340813196026*^9, 
   3.7733408707253437`*^9}, {3.773340902304175*^9, 3.773341016699072*^9}, {
   3.7733424123280497`*^9, 3.7733424181644993`*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"7c9289ec-ab0e-4bcf-b6de-efed6f5a86ed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BooleanVariables", "[", "AdlemanSAT", "]"}]], "Input",
 CellChangeTimes->{{3.773341243051072*^9, 3.7733412482699327`*^9}},
 CellLabel->
  "In[343]:=",ExpressionUUID->"b4126a2c-5a89-49bd-843b-9737653fc2b9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "x01", ",", "x02", ",", "x03", ",", "x04", ",", "x05", ",", "x06", ",", 
   "x07", ",", "x08", ",", "x09", ",", "x10", ",", "x11", ",", "x12", ",", 
   "x13", ",", "x14", ",", "x15", ",", "x16", ",", "x17", ",", "x18", ",", 
   "x19", ",", "x20"}], "}"}]], "Output",
 CellChangeTimes->{3.7733412488305893`*^9, 3.773342428752758*^9},
 CellLabel->
  "Out[343]=",ExpressionUUID->"c3a81515-7976-46c2-b342-7cf59f4e8495"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatisfiabilityInstances", "[", 
  RowBox[{"AdlemanSAT", ",", "AdlemanVars"}], "]"}]], "Input",
 CellChangeTimes->{{3.773341022199188*^9, 3.773341036939272*^9}, {
  3.7733410869186983`*^9, 3.773341102774674*^9}, {3.7733412665386343`*^9, 
  3.773341268540339*^9}},
 CellLabel->
  "In[345]:=",ExpressionUUID->"57665152-9652-4aa0-a6f9-6dae687939bc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
   "False", ",", "True", ",", "False", ",", "False", ",", "False", ",", 
    "False", ",", "True", ",", "True", ",", "False", ",", "True", ",", "True",
     ",", "True", ",", "False", ",", "False", ",", "True", ",", "True", ",", 
    "True", ",", "False", ",", "False", ",", "False"}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.773341066023781*^9, 3.77334126982985*^9, 
  3.773342430347219*^9, 3.773343178275301*^9},
 CellLabel->
  "Out[345]=",ExpressionUUID->"46b1cc4f-9654-4389-bc77-779d1808e749"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"NaiveClauseReactions", "[", "clause_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vars", ",", "n", ",", "unsat"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vars", "=", 
      RowBox[{"BooleanVariables", "[", "clause", "]"}]}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "vars", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"unsat", "=", 
      RowBox[{"Boole", "[", 
       RowBox[{"SatisfiabilityInstances", "[", 
        RowBox[{
         RowBox[{"!", "clause"}], ",", "vars", ",", 
         RowBox[{"2", "^", "n"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "watch", " ", "out", " ", "that", " ", "rxn", " ", "uses", " ", 
         "HoldAll"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"rxn", "@@", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Plus", "@@", 
            RowBox[{"MapThread", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"#1", "[", "#2", "]"}], "&"}], ",", 
              RowBox[{"{", 
               RowBox[{"vars", ",", "case"}], "}"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Plus", "@@", 
            RowBox[{"MapThread", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"#1", "[", "#2", "]"}], "&"}], ",", 
              RowBox[{"{", 
               RowBox[{"vars", ",", 
                RowBox[{"Mod", "[", 
                 RowBox[{
                  RowBox[{"case", "+", 
                   RowBox[{"UnitVector", "[", 
                    RowBox[{"n", ",", "var"}], "]"}]}], ",", "2"}], "]"}]}], 
               "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", "1"}], "}"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"case", ",", "unsat"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"var", ",", "n"}], "}"}]}], "\[IndentingNewLine]", "]"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.77334261243182*^9, 3.773342728828231*^9}, {
   3.7733431055806026`*^9, 3.773343191889161*^9}, {3.773343236919108*^9, 
   3.773343401403895*^9}, {3.7733436082507887`*^9, 3.7733436790628033`*^9}, {
   3.7733437625699587`*^9, 3.773343787909876*^9}, {3.77334385756599*^9, 
   3.773343858701167*^9}, {3.7733441097439957`*^9, 3.773344145630681*^9}, {
   3.773344250074697*^9, 3.773344281477072*^9}, {3.773344477676824*^9, 
   3.77334449995581*^9}, {3.7733446198526917`*^9, 3.773344622665374*^9}, {
   3.773344715209586*^9, 3.773344724570692*^9}, 3.7733447606741257`*^9, {
   3.7733449095711737`*^9, 3.7733449568079243`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"8639ca1b-0889-4de5-ba6e-50cfb1b27856"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"NaiveClauseReactions", "[", 
   RowBox[{
    RowBox[{"x1", "&&", "x2"}], "||", "x3"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773343707720828*^9, 3.7733437486371*^9}, {
  3.773344520175383*^9, 3.773344597328124*^9}, {3.773344646734956*^9, 
  3.773344646973575*^9}, {3.773345177118174*^9, 3.773345210837031*^9}},
 CellLabel->
  "In[398]:=",ExpressionUUID->"57105204-eeea-4bbe-a786-961d65fca50d"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"x1", "[", "1", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x1", "[", "1", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x1", "[", "1", "]"}], "+", 
         RowBox[{"x2", "[", "1", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x1", "[", "1", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x1", "[", "1", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "1", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x1", "[", "1", "]"}], "+", 
         RowBox[{"x2", "[", "1", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "1", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "1", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "1", "]"}], "+", 
         RowBox[{"x3", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x1", "[", "1", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "1", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x1", "[", "0", "]"}], "+", 
         RowBox[{"x2", "[", "0", "]"}], "+", 
         RowBox[{"x3", "[", "1", "]"}]}], " "}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.773343738687387*^9, 3.773343749177417*^9}, {
   3.773344552044032*^9, 3.77334459789979*^9}, {3.773344628632058*^9, 
   3.773344654326123*^9}, 3.773344743811968*^9, {3.7733451504770193`*^9, 
   3.7733451794683437`*^9}, 3.773345211249634*^9},
 CellLabel->
  "Out[398]//MatrixForm=",ExpressionUUID->"5c314db2-247b-4e34-919f-\
49334102e6f4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"NaiveClauseReactions", "[", 
   RowBox[{"AdlemanSAT", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773343682922858*^9, 3.773343694868966*^9}, {
  3.773344213026849*^9, 3.7733442131198483`*^9}, {3.7733452991496067`*^9, 
  3.773345300847039*^9}},
 CellLabel->
  "In[399]:=",ExpressionUUID->"7a815e52-6622-4979-8871-acb23154fae2"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7733436959313707`*^9, 3.7733437951108637`*^9, {3.773344116994277*^9, 
   3.773344148780796*^9}, 3.773344213846497*^9, 3.773344261181858*^9, 
   3.773344495392909*^9, 3.773344625575479*^9, 3.7733451529056463`*^9, 
   3.773345301214098*^9},
 CellLabel->
  "Out[399]//MatrixForm=",ExpressionUUID->"2cd20336-52a4-4789-8ebd-\
22a1cc6767ed"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"FormulaSATCRN", "[", "expr_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", "expr", "]"}], "===", "And"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Flatten", "[", 
     RowBox[{"NaiveClauseReactions", "/@", 
      RowBox[{"(", 
       RowBox[{"List", "@@", "expr"}], ")"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"NaiveClauseReactions", "[", "expr", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773347401609867*^9, 3.7733474842970552`*^9}, {
  3.773347651716776*^9, 3.773347680296624*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"8bf513d9-c4b4-4fb7-9d6b-48b22ec3156e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RunFormulaSATCRN", "[", "expr_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "crn", ",", "rsys", ",", "times", ",", "data", ",", "finishconcs", ",", 
      "results"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"crn", "=", 
      RowBox[{"FormulaSATCRN", "[", "expr", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rsys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"crn", ",", 
        RowBox[{"DualRailInitialState", "[", "crn", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"times", ",", "data"}], "}"}], "=", 
      RowBox[{"SimulateRxnsysSSA", "[", 
       RowBox[{"rsys", ",", "Infinity", ",", 
        RowBox[{"Output", "\[Rule]", "\"\<State\>\""}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"finishconcs", "=", 
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}], ",", 
          RowBox[{"Last", "[", "data", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"results", "=", 
      RowBox[{
       RowBox[{"Cases", "[", 
        RowBox[{"finishconcs", ",", 
         RowBox[{
          RowBox[{"conc", "[", 
           RowBox[{
            RowBox[{"s_", "[", "t_", "]"}], ",", 
            RowBox[{"_", "?", "Positive"}]}], "]"}], "\[RuleDelayed]", 
          RowBox[{"(", 
           RowBox[{"s", "\[Rule]", "t"}], ")"}]}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0", "\[Rule]", "False"}], ",", 
         RowBox[{"1", "\[Rule]", "True"}]}], "}"}]}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.68021565999244*^9, 3.680215750241291*^9}, {
   3.6802158052863903`*^9, 3.6802158385740547`*^9}, {3.773136058908334*^9, 
   3.773136129428895*^9}, {3.773136200951747*^9, 3.773136220896125*^9}, {
   3.7731367033385553`*^9, 3.773136728021192*^9}, {3.773136827472237*^9, 
   3.773136847838519*^9}, {3.7731378382659616`*^9, 3.773137844146751*^9}, {
   3.7731378785932217`*^9, 3.773137886692079*^9}, {3.773137999129963*^9, 
   3.773138017053162*^9}, {3.773139783824836*^9, 3.7731397890753393`*^9}, {
   3.773139890729321*^9, 3.773139903448102*^9}, {3.773280197937496*^9, 
   3.773280211920089*^9}, {3.7733453849612217`*^9, 3.7733453892668533`*^9}, {
   3.77334751343707*^9, 3.773347545687004*^9}, {3.773347847280039*^9, 
   3.773347866100006*^9}, {3.773347945836709*^9, 3.773347952150361*^9}, 
   3.77334825368139*^9},
 CellLabel->"In[15]:=",ExpressionUUID->"490bc627-b582-4087-af95-de5220a5f6fd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FormulaSATCRN", "[", "AdlemanSAT", "]"}]], "Input",
 CellChangeTimes->{{3.7733476138064938`*^9, 3.773347627053453*^9}, 
   3.773347983176874*^9},ExpressionUUID->"1fd8813c-c36f-4da7-95bc-\
3053fe5dd21e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x03", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x03", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x03", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "0", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x03", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x03", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "1", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x02", "[", "0", "]"}], "+", 
     RowBox[{"x13", "[", "1", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "1", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "1", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "1", "]"}], "+", 
     RowBox[{"x20", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x04", "[", "1", "]"}], "+", 
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x04", "[", "1", "]"}], "+", 
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x04", "[", "1", "]"}], "+", 
     RowBox[{"x06", "[", "1", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x04", "[", "1", "]"}], "+", 
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x04", "[", "1", "]"}], "+", 
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x01", "[", "1", "]"}], "+", 
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x01", "[", "1", "]"}], "+", 
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x01", "[", "1", "]"}], "+", 
     RowBox[{"x04", "[", "1", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x01", "[", "1", "]"}], "+", 
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x01", "[", "1", "]"}], "+", 
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x02", "[", "0", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "1", "]"}], "+", 
     RowBox[{"x19", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x17", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x15", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x04", "[", "1", "]"}], "+", 
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x06", "[", "1", "]"}], "+", 
     RowBox[{"x11", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x04", "[", "0", "]"}], "+", 
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x07", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x07", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x07", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "0", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x07", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}], "+", 
     RowBox[{"x17", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x07", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}], "+", 
     RowBox[{"x17", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x06", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x06", "[", "0", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x06", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x06", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "1", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x06", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x06", "[", "1", "]"}], "+", 
     RowBox[{"x13", "[", "0", "]"}], "+", 
     RowBox[{"x19", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}], "+", 
     RowBox[{"x14", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x01", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}], "+", 
     RowBox[{"x14", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}], "+", 
     RowBox[{"x14", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}], "+", 
     RowBox[{"x14", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}], "+", 
     RowBox[{"x14", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}], "+", 
     RowBox[{"x14", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x02", "[", "0", "]"}], "+", 
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x02", "[", "1", "]"}], "+", 
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x02", "[", "0", "]"}], "+", 
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x02", "[", "0", "]"}], "+", 
     RowBox[{"x03", "[", "1", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x02", "[", "0", "]"}], "+", 
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x02", "[", "0", "]"}], "+", 
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x10", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x07", "[", "0", "]"}], "+", 
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x10", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x10", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x08", "[", "0", "]"}], "+", 
     RowBox[{"x10", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x10", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x10", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "0", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "1", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x05", "[", "1", "]"}], "+", 
     RowBox[{"x09", "[", "0", "]"}], "+", 
     RowBox[{"x12", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x03", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x18", "[", "1", "]"}], "+", 
     RowBox[{"x20", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x03", "[", "0", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}], "+", 
     RowBox[{"x20", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x10", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x10", "[", "0", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x10", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x10", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "0", "]"}], "+", 
     RowBox[{"x18", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x10", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x10", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}], "+", 
     RowBox[{"x18", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}], "+", 
     RowBox[{"x14", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x01", "[", "1", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}], "+", 
     RowBox[{"x14", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}], "+", 
     RowBox[{"x14", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "0", "]"}], "+", 
     RowBox[{"x14", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}], "+", 
     RowBox[{"x14", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x01", "[", "0", "]"}], "+", 
     RowBox[{"x11", "[", "1", "]"}], "+", 
     RowBox[{"x14", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x08", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x07", "[", "0", "]"}], "+", 
     RowBox[{"x08", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x08", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x08", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "1", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x07", "[", "1", "]"}], "+", 
     RowBox[{"x08", "[", "0", "]"}], "+", 
     RowBox[{"x15", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x10", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x08", "[", "0", "]"}], "+", 
     RowBox[{"x10", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x10", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x10", "[", "0", "]"}], "+", 
     RowBox[{"x16", "[", "0", "]"}]}]}], " ", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x10", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "0", "]"}]}], " ", 
    OverscriptBox["\[RightArrow]", 
     RowBox[{" ", "1", " "}]], " ", 
    RowBox[{
     RowBox[{"x08", "[", "1", "]"}], "+", 
     RowBox[{"x10", "[", "1", "]"}], "+", 
     RowBox[{"x16", "[", "1", "]"}]}]}]}], " ", "}"}]], "Output",
 CellChangeTimes->{{3.773347629741613*^9, 3.773347683122864*^9}},
 CellLabel->
  "Out[456]=",ExpressionUUID->"7d1584db-3ff7-44fe-8800-5734187a3612"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"assign", "=", 
  RowBox[{"RunFormulaSATCRN", "[", "AdlemanSAT", "]"}]}]], "Input",
 CellChangeTimes->{{3.773347818586851*^9, 3.773347852310367*^9}, {
  3.7733480107082043`*^9, 3.773348011179825*^9}, {3.773348342645481*^9, 
  3.7733483436702747`*^9}},
 CellLabel->
  "In[473]:=",ExpressionUUID->"8463ea4f-2f7b-44b0-a17b-b987730ead4b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x01", "\[Rule]", "False"}], ",", 
   RowBox[{"x02", "\[Rule]", "True"}], ",", 
   RowBox[{"x03", "\[Rule]", "False"}], ",", 
   RowBox[{"x04", "\[Rule]", "False"}], ",", 
   RowBox[{"x05", "\[Rule]", "False"}], ",", 
   RowBox[{"x06", "\[Rule]", "False"}], ",", 
   RowBox[{"x07", "\[Rule]", "True"}], ",", 
   RowBox[{"x08", "\[Rule]", "True"}], ",", 
   RowBox[{"x09", "\[Rule]", "False"}], ",", 
   RowBox[{"x10", "\[Rule]", "True"}], ",", 
   RowBox[{"x11", "\[Rule]", "True"}], ",", 
   RowBox[{"x12", "\[Rule]", "True"}], ",", 
   RowBox[{"x13", "\[Rule]", "False"}], ",", 
   RowBox[{"x14", "\[Rule]", "False"}], ",", 
   RowBox[{"x15", "\[Rule]", "True"}], ",", 
   RowBox[{"x16", "\[Rule]", "True"}], ",", 
   RowBox[{"x17", "\[Rule]", "True"}], ",", 
   RowBox[{"x18", "\[Rule]", "False"}], ",", 
   RowBox[{"x19", "\[Rule]", "False"}], ",", 
   RowBox[{"x20", "\[Rule]", "False"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773347854769895*^9, 3.7733478711071587`*^9}, 
   3.773347955510508*^9, 3.773348012121873*^9, 3.773348344942965*^9},
 CellLabel->
  "Out[473]=",ExpressionUUID->"5ecac96e-df53-407e-b0a4-8bc97196bd60"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdlemanSAT", "/.", "assign"}]], "Input",
 CellChangeTimes->{{3.773348015034793*^9, 3.773348020175734*^9}, {
  3.773348337168647*^9, 3.773348340051284*^9}},
 CellLabel->
  "In[474]:=",ExpressionUUID->"6dffd76c-4202-4b84-96a6-388c01dde44f"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.773348020805368*^9, 3.7733483480850697`*^9},
 CellLabel->
  "Out[474]=",ExpressionUUID->"a298596f-e0ab-491a-a945-fbe4dc63ff9c"]
}, Open  ]],

Cell["\<\
It\[CloseCurlyQuote]s nice to watch the CRN in action.  The image below \
represents a trace of the operation with the vertical axis indicating the \
species (in the same order as SpeciesInRxnsys[ ], from top to bottom) and the \
horizontal axis indicating time (increasing from left to right).  Time is \
measured in number of reaction events, and is subsampled as evenly as \
possible to a given maximum number of points (if there are more events than \
the maximum).  The color is white for a species that is present and the same \
as in the final state (i.e. correct, if the final state solves the \
satisfiability problem), is grey for a species that is present but not the \
same as in the final state, and black for a species that is absent.  \
Consequently, if the CRN simulation does not time out, the rightmost column \
will consist of just black and white pixels and will indicate a valid \
solution to the formula.\
\>", "Text",
 CellChangeTimes->{{3.7731345194022903`*^9, 3.7731346761403522`*^9}, {
   3.773134715066553*^9, 3.77313475194668*^9}, {3.773137458606723*^9, 
   3.773137486858985*^9}, {3.773139011708281*^9, 3.7731391622186317`*^9}, {
   3.773140039024252*^9, 3.773140082100349*^9}, {3.773196266803932*^9, 
   3.773196267304377*^9}, 3.7733290832963943`*^9, {3.773336599123534*^9, 
   3.773336628856786*^9}, {3.773340030748124*^9, 3.7733400560896873`*^9}, {
   3.7733415481305513`*^9, 3.7733417065521183`*^9}, {3.7733422950884953`*^9, 
   3.773342296503228*^9}, {3.773342748459626*^9, 3.773342768392971*^9}, {
   3.773343140295533*^9, 3.773343161161839*^9}, {3.773348316787459*^9, 
   3.77334837903338*^9}, {3.773348659401659*^9, 3.773348712501857*^9}, {
   3.7733489982510138`*^9, 3.7733490137616*^9}, {3.773349687160474*^9, 
   3.773349699401517*^9}, {3.773349787010092*^9, 3.7733498096778517`*^9}, {
   3.7733500890127563`*^9, 3.773350107619672*^9}, {3.773350362743279*^9, 
   3.7733504902085648`*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"38725cd3-3614-45e7-b58b-6acc27db4061"],

Cell[BoxData[
 RowBox[{
  RowBox[{"WatchFormulaSATCRN", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"maxpoints_:", "1000"}], ",", 
    RowBox[{"timeout_:", "Infinity"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "crn", ",", "rsys", ",", "times", ",", "data", ",", "points", ",", 
      "lessdata", ",", "finishconcs"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"crn", "=", 
      RowBox[{"FormulaSATCRN", "[", "expr", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rsys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"crn", ",", 
        RowBox[{"DualRailInitialState", "[", "crn", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"times", ",", "data"}], "}"}], "=", 
      RowBox[{"SimulateRxnsysSSA", "[", 
       RowBox[{"rsys", ",", "timeout"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"points", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "data", "]"}], ">", "maxpoints"}], ",", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", "1", "}"}], ",", 
          RowBox[{"Ceiling", "/@", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"maxpoints", "-", "1"}], "]"}], "*", 
             RowBox[{
              RowBox[{"Length", "[", "data", "]"}], "/", 
              RowBox[{"(", 
               RowBox[{"maxpoints", "-", "1"}], ")"}]}]}], ")"}]}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", "data", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"lessdata", "=", 
      RowBox[{"data", "[", 
       RowBox[{"[", "points", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"Image", "[", 
       RowBox[{"Transpose", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Last", "[", "lessdata", "]"}], "*", "#"}], "+", "#"}], 
            ")"}], "/", "2"}], "&"}], " ", "/@", " ", "lessdata"}], "]"}], 
       "]"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"finishconcs", "=", 
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}], ",", 
          RowBox[{"Last", "[", "data", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Cases", "[", 
       RowBox[{"finishconcs", ",", 
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{
           RowBox[{"s_", "[", "t_", "]"}], ",", 
           RowBox[{"_", "?", "Positive"}]}], "]"}], "\[RuleDelayed]", 
         RowBox[{"(", 
          RowBox[{"s", "\[Rule]", "t"}], ")"}]}]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0", "\[Rule]", "False"}], ",", 
        RowBox[{"1", "\[Rule]", "True"}]}], "}"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6803973434360723`*^9, 3.680397421797638*^9}, {
   3.6803975247123137`*^9, 3.6803975615801764`*^9}, {3.680398471315331*^9, 
   3.680398498077474*^9}, {3.680398559044063*^9, 3.68039857798982*^9}, {
   3.6803993556148853`*^9, 3.680399361294039*^9}, {3.6803996349269247`*^9, 
   3.6803996606914062`*^9}, 3.6803997017693*^9, {3.6803998127154408`*^9, 
   3.680399832954554*^9}, {3.680400011951935*^9, 3.680400022408893*^9}, {
   3.680400120742281*^9, 3.680400147115947*^9}, {3.680400196612588*^9, 
   3.680400201442669*^9}, {3.680400505028851*^9, 3.6804005354642277`*^9}, {
   3.6804006208005667`*^9, 3.6804006768463573`*^9}, {3.6836715597221317`*^9, 
   3.6836715619369373`*^9}, {3.68373743268504*^9, 3.683737434579191*^9}, {
   3.773348071110723*^9, 3.773348149948955*^9}, 3.773348260508574*^9, {
   3.7733484599229794`*^9, 3.7733484827009573`*^9}, {3.7733498168230963`*^9, 
   3.773349822510388*^9}, {3.773349861492824*^9, 3.773349966539503*^9}, {
   3.773350019973353*^9, 3.773350020507333*^9}, {3.773350052731489*^9, 
   3.773350066729409*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"77a91b69-50fd-427a-8f6c-c6630bb38c86"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"assign", " ", "=", " ", 
  RowBox[{"WatchFormulaSATCRN", "[", "AdlemanSAT", "]"}]}]], "Input",
 CellChangeTimes->{{3.680400230154809*^9, 3.680400230777896*^9}, {
  3.7733482134903393`*^9, 3.773348218802259*^9}},
 CellLabel->
  "In[493]:=",ExpressionUUID->"eef07376-415c-4f4d-8c5b-57f009fc7c85"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztW0uuJEkRTIGEuAY71swBUlxhOEEjwWqkkYYFYlfH5Rh0w9SQz8fNzTwy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    "], {{0, 40}, {1000, 0}}, {
    0., 1.},
    ColorFunction->GrayLevel],
   BoxForm`ImageTag["Real32", ColorSpace -> Automatic, Interleaving -> None],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->{3032.94140625, Automatic},
  ImageSizeRaw->{1000, 40},
  PlotRange->{{0, 1000}, {0, 40}}]], "Print",
 CellChangeTimes->{{3.773348221695159*^9, 3.7733482753991632`*^9}, 
   3.7733484999051933`*^9, 3.773349970326997*^9, 3.773350317637628*^9},
 CellLabel->
  "During evaluation of \
In[493]:=",ExpressionUUID->"7594539f-63c8-40b1-a68c-49726129f48c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x01", "\[Rule]", "False"}], ",", 
   RowBox[{"x02", "\[Rule]", "True"}], ",", 
   RowBox[{"x03", "\[Rule]", "False"}], ",", 
   RowBox[{"x04", "\[Rule]", "False"}], ",", 
   RowBox[{"x05", "\[Rule]", "False"}], ",", 
   RowBox[{"x06", "\[Rule]", "False"}], ",", 
   RowBox[{"x07", "\[Rule]", "True"}], ",", 
   RowBox[{"x08", "\[Rule]", "True"}], ",", 
   RowBox[{"x09", "\[Rule]", "False"}], ",", 
   RowBox[{"x10", "\[Rule]", "True"}], ",", 
   RowBox[{"x11", "\[Rule]", "True"}], ",", 
   RowBox[{"x12", "\[Rule]", "True"}], ",", 
   RowBox[{"x13", "\[Rule]", "False"}], ",", 
   RowBox[{"x14", "\[Rule]", "False"}], ",", 
   RowBox[{"x15", "\[Rule]", "True"}], ",", 
   RowBox[{"x16", "\[Rule]", "True"}], ",", 
   RowBox[{"x17", "\[Rule]", "True"}], ",", 
   RowBox[{"x18", "\[Rule]", "False"}], ",", 
   RowBox[{"x19", "\[Rule]", "False"}], ",", 
   RowBox[{"x20", "\[Rule]", "False"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773348221697515*^9, 3.773348275406501*^9}, 
   3.773348499916655*^9, 3.773349970330079*^9, 3.773350317641135*^9},
 CellLabel->
  "Out[493]=",ExpressionUUID->"15297e68-9371-4d6c-9017-5281f362b6d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdlemanSAT", "/.", "assign"}]], "Input",
 CellChangeTimes->{{3.773348328139873*^9, 3.77334833138282*^9}},
 CellLabel->
  "In[472]:=",ExpressionUUID->"d231b156-c319-4953-a48d-8f8cd53618bf"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7733483321226273`*^9},
 CellLabel->
  "Out[472]=",ExpressionUUID->"4a4ade92-f4c6-48b7-b763-87c4a8861718"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpeciesInRxnsys", "[", 
  RowBox[{"FormulaSATCRN", "[", "AdlemanSAT", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7733476138064938`*^9, 3.773347627053453*^9}, 
   3.773347983176874*^9, {3.773348600445217*^9, 3.773348606943149*^9}},
 CellLabel->
  "In[492]:=",ExpressionUUID->"25f5dd38-2759-4159-924a-67b4f49014c5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x01", "[", "0", "]"}], ",", 
   RowBox[{"x01", "[", "1", "]"}], ",", 
   RowBox[{"x02", "[", "0", "]"}], ",", 
   RowBox[{"x02", "[", "1", "]"}], ",", 
   RowBox[{"x03", "[", "0", "]"}], ",", 
   RowBox[{"x03", "[", "1", "]"}], ",", 
   RowBox[{"x04", "[", "0", "]"}], ",", 
   RowBox[{"x04", "[", "1", "]"}], ",", 
   RowBox[{"x05", "[", "0", "]"}], ",", 
   RowBox[{"x05", "[", "1", "]"}], ",", 
   RowBox[{"x06", "[", "0", "]"}], ",", 
   RowBox[{"x06", "[", "1", "]"}], ",", 
   RowBox[{"x07", "[", "0", "]"}], ",", 
   RowBox[{"x07", "[", "1", "]"}], ",", 
   RowBox[{"x08", "[", "0", "]"}], ",", 
   RowBox[{"x08", "[", "1", "]"}], ",", 
   RowBox[{"x09", "[", "0", "]"}], ",", 
   RowBox[{"x09", "[", "1", "]"}], ",", 
   RowBox[{"x10", "[", "0", "]"}], ",", 
   RowBox[{"x10", "[", "1", "]"}], ",", 
   RowBox[{"x11", "[", "0", "]"}], ",", 
   RowBox[{"x11", "[", "1", "]"}], ",", 
   RowBox[{"x12", "[", "0", "]"}], ",", 
   RowBox[{"x12", "[", "1", "]"}], ",", 
   RowBox[{"x13", "[", "0", "]"}], ",", 
   RowBox[{"x13", "[", "1", "]"}], ",", 
   RowBox[{"x14", "[", "0", "]"}], ",", 
   RowBox[{"x14", "[", "1", "]"}], ",", 
   RowBox[{"x15", "[", "0", "]"}], ",", 
   RowBox[{"x15", "[", "1", "]"}], ",", 
   RowBox[{"x16", "[", "0", "]"}], ",", 
   RowBox[{"x16", "[", "1", "]"}], ",", 
   RowBox[{"x17", "[", "0", "]"}], ",", 
   RowBox[{"x17", "[", "1", "]"}], ",", 
   RowBox[{"x18", "[", "0", "]"}], ",", 
   RowBox[{"x18", "[", "1", "]"}], ",", 
   RowBox[{"x19", "[", "0", "]"}], ",", 
   RowBox[{"x19", "[", "1", "]"}], ",", 
   RowBox[{"x20", "[", "0", "]"}], ",", 
   RowBox[{"x20", "[", "1", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7733486074777308`*^9, 3.773348611692428*^9}, 
   3.773350235715431*^9},
 CellLabel->
  "Out[492]=",ExpressionUUID->"36efa7a1-8238-481b-8cd2-a5fe20c9643e"]
}, Open  ]],

Cell["\<\
To compare FormulaSATCRN to CircuitSATCRN, we convert a circuit to a formal, \
incorporating new clauses for any constrained input, output, or intermediate \
gate values.  We use the Tseytin transformation.   There doesn\
\[CloseCurlyQuote]t seem to be a striking difference between what can be \
solved, e.g. we can still factor 143 but not 85 or 236.\
\>", "Text",
 CellChangeTimes->{{3.7731345194022903`*^9, 3.7731346761403522`*^9}, {
   3.773134715066553*^9, 3.77313475194668*^9}, {3.773137458606723*^9, 
   3.773137486858985*^9}, {3.773139011708281*^9, 3.7731391622186317`*^9}, {
   3.773140039024252*^9, 3.773140082100349*^9}, {3.773196266803932*^9, 
   3.773196267304377*^9}, 3.7733290832963943`*^9, {3.773336599123534*^9, 
   3.773336628856786*^9}, {3.773340030748124*^9, 3.7733400560896873`*^9}, {
   3.7733415481305513`*^9, 3.7733417065521183`*^9}, {3.7733422950884953`*^9, 
   3.773342296503228*^9}, {3.773342748459626*^9, 3.773342768392971*^9}, {
   3.773343140295533*^9, 3.773343161161839*^9}, {3.773348316787459*^9, 
   3.77334837903338*^9}, {3.773348659401659*^9, 3.773348712501857*^9}, {
   3.7733489982510138`*^9, 3.7733490137616*^9}, {3.773349687160474*^9, 
   3.773349699401517*^9}, {3.773349787010092*^9, 3.7733498096778517`*^9}, {
   3.7733500890127563`*^9, 3.773350107619672*^9}, {3.773350362743279*^9, 
   3.7733504902085648`*^9}, {3.773350864296248*^9, 3.773350903682831*^9}, {
   3.7733509621797113`*^9, 3.773350966836876*^9}, {3.773351004468815*^9, 
   3.773351021501116*^9}, {3.773351940845718*^9, 3.773351949953579*^9}, {
   3.773352781572257*^9, 3.773352799405654*^9}, {3.773352834110778*^9, 
   3.773352846249939*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"cd72aaf7-7365-4088-b52b-40d7ee21e695"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CircuitToFormula", "[", "circuit_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Length", "[", "#", "]"}], ">", "1"}], ",", 
      RowBox[{"And", "@@", "#"}], ",", "#"}], "]"}], "&"}], "@", 
   RowBox[{"(", 
    RowBox[{"circuit", "/.", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Rule", "[", 
         RowBox[{"gate_", ",", 
          RowBox[{"(", 
           RowBox[{"in1_", " ", "||", " ", "in2_"}], ")"}]}], "]"}], 
        "\[RuleDelayed]", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"in1", "||", "in2", "||", 
           RowBox[{"!", "gate"}]}], ")"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"!", "in1"}], "||", "gate"}], ")"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"!", "in2"}], "||", "gate"}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Rule", "[", 
         RowBox[{"gate_", ",", 
          RowBox[{"(", 
           RowBox[{"in1_", " ", "&&", " ", "in2_"}], ")"}]}], "]"}], 
        "\[RuleDelayed]", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"!", "in1"}], "||", 
           RowBox[{"!", "in2"}], "||", "gate"}], ")"}], "&&", 
         RowBox[{"(", 
          RowBox[{"in1", "||", 
           RowBox[{"!", "gate"}]}], ")"}], "&&", 
         RowBox[{"(", 
          RowBox[{"in2", "||", 
           RowBox[{"!", "gate"}]}], ")"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Rule", "[", 
         RowBox[{"gate_", ",", 
          RowBox[{"(", 
           RowBox[{"in1_", " ", "\[Xor]", " ", "in2_"}], ")"}]}], "]"}], 
        "\[RuleDelayed]", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"!", "in1"}], "||", 
           RowBox[{"!", "in2"}], "||", 
           RowBox[{"!", "gate"}]}], ")"}], "&&", 
         RowBox[{"(", 
          RowBox[{"in1", "||", "in2", "||", 
           RowBox[{"!", "gate"}]}], ")"}], "&&", 
         RowBox[{"(", 
          RowBox[{"in1", "||", 
           RowBox[{"!", "in2"}], "||", "gate"}], ")"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"!", "in1"}], "||", "in2", "||", "gate"}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Rule", "[", 
         RowBox[{"gate_", ",", 
          RowBox[{"(", 
           RowBox[{"!", "in_"}], ")"}]}], "]"}], "\[RuleDelayed]", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"!", "in"}], "||", 
           RowBox[{"!", "gate"}]}], ")"}], "&&", 
         RowBox[{"(", 
          RowBox[{"in", "||", "gate"}], ")"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Rule", "[", 
         RowBox[{"gate_", ",", "value_Integer"}], "]"}], "\[RuleDelayed]", 
        " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"value", "\[Equal]", "0"}], ",", 
          RowBox[{"!", "gate"}], ",", "gate"}], "]"}]}]}], 
      "\[IndentingNewLine]", "}"}]}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773351168491981*^9, 3.7733512268474092`*^9}, {
   3.77335140174795*^9, 3.7733517579466763`*^9}, 3.773351853101066*^9},
 CellLabel->"In[17]:=",ExpressionUUID->"a5b6a1a4-ad14-407d-86b5-a698baa6fa6e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sqrtformula", "=", 
  RowBox[{"CircuitToFormula", "[", "sqrtcircuit", "]"}]}]], "Input",
 CellChangeTimes->{{3.773351902052804*^9, 3.773351910950308*^9}, {
  3.773352012041801*^9, 3.7733520152676277`*^9}},
 CellLabel->
  "In[504]:=",ExpressionUUID->"ea14b13a-df06-4137-a911-affb1ac48c0c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"in1", "||", "in2", "||", 
    RowBox[{"!", "out1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "in1"}], "||", "out1"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "in2"}], "||", "out1"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"g1", "||", "g4", "||", 
    RowBox[{"!", "out2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "g1"}], "||", "out2"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "g4"}], "||", "out2"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "in1"}], "||", 
    RowBox[{"!", "in2"}], "||", "g1"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"in1", "||", 
    RowBox[{"!", "g1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"in2", "||", 
    RowBox[{"!", "g1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "in2"}], "||", 
    RowBox[{"!", "g2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"in2", "||", "g2"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"in3", "||", "in4", "||", 
    RowBox[{"!", "g3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "in3"}], "||", "g3"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "in4"}], "||", "g3"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "g2"}], "||", 
    RowBox[{"!", "g3"}], "||", "g4"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"g2", "||", 
    RowBox[{"!", "g4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"g3", "||", 
    RowBox[{"!", "g4"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.773351912992325*^9, 3.7733520173149*^9},
 CellLabel->
  "Out[504]=",ExpressionUUID->"7a0b9233-1827-4cdd-b84f-05396bd1a93d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Boole", "[", 
   RowBox[{"SatisfiabilityInstances", "[", 
    RowBox[{"sqrtformula", ",", 
     RowBox[{"{", 
      RowBox[{
      "in1", ",", "in2", ",", "in3", ",", "in4", ",", "out1", ",", "out2", 
       ",", "g1", ",", "g2", ",", "g3", ",", "g4"}], "}"}], ",", "10000"}], 
    "]"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773352019308247*^9, 3.773352108434002*^9}},
 CellLabel->
  "In[507]:=",ExpressionUUID->"59f09154-82d6-493d-80cd-a7f1631dad43"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", "1", "1", "1", "1", "1", "0", "1", "0"},
     {"1", "1", "1", "0", "1", "1", "1", "0", "1", "0"},
     {"1", "1", "0", "1", "1", "1", "1", "0", "1", "0"},
     {"1", "1", "0", "0", "1", "1", "1", "0", "0", "0"},
     {"1", "0", "1", "1", "1", "1", "0", "1", "1", "1"},
     {"1", "0", "1", "0", "1", "1", "0", "1", "1", "1"},
     {"1", "0", "0", "1", "1", "1", "0", "1", "1", "1"},
     {"1", "0", "0", "0", "1", "0", "0", "1", "0", "0"},
     {"0", "1", "1", "1", "1", "0", "0", "0", "1", "0"},
     {"0", "1", "1", "0", "1", "0", "0", "0", "1", "0"},
     {"0", "1", "0", "1", "1", "0", "0", "0", "1", "0"},
     {"0", "1", "0", "0", "1", "0", "0", "0", "0", "0"},
     {"0", "0", "1", "1", "0", "1", "0", "1", "1", "1"},
     {"0", "0", "1", "0", "0", "1", "0", "1", "1", "1"},
     {"0", "0", "0", "1", "0", "1", "0", "1", "1", "1"},
     {"0", "0", "0", "0", "0", "0", "0", "1", "0", "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.77335204995221*^9, {3.773352083507483*^9, 3.773352109475171*^9}},
 CellLabel->
  "Out[507]//MatrixForm=",ExpressionUUID->"41e74062-26fe-431e-9d9f-\
4ab073b11f28"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RunFormulaSATCRNonCircuit", "[", 
   RowBox[{"circuit_", ",", "known_", ",", "desired_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"expr", ",", "results"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"expr", "=", 
      RowBox[{"CircuitToFormula", "[", 
       RowBox[{"Join", "[", 
        RowBox[{"circuit", ",", "known"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"results", "=", 
      RowBox[{"RunFormulaSATCRN", "[", "expr", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Boole", "[", 
      RowBox[{"desired", "/.", "results"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.68021565999244*^9, 3.680215750241291*^9}, {
   3.6802158052863903`*^9, 3.6802158385740547`*^9}, {3.773136058908334*^9, 
   3.773136129428895*^9}, {3.773136200951747*^9, 3.773136220896125*^9}, {
   3.7731367033385553`*^9, 3.773136728021192*^9}, {3.773136827472237*^9, 
   3.773136847838519*^9}, {3.7731378382659616`*^9, 3.773137844146751*^9}, {
   3.7731378785932217`*^9, 3.773137886692079*^9}, {3.773137999129963*^9, 
   3.773138017053162*^9}, {3.773139783824836*^9, 3.7731397890753393`*^9}, {
   3.773139890729321*^9, 3.773139903448102*^9}, {3.773280197937496*^9, 
   3.773280211920089*^9}, {3.7733453849612217`*^9, 3.7733453892668533`*^9}, {
   3.77334751343707*^9, 3.773347545687004*^9}, {3.773347847280039*^9, 
   3.773347866100006*^9}, {3.773347945836709*^9, 3.773347952150361*^9}, 
   3.77334825368139*^9, {3.773351078254981*^9, 3.77335114338939*^9}, {
   3.77335219691759*^9, 3.773352276363826*^9}, {3.773352340452085*^9, 
   3.773352341979653*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"4661d0e3-1c30-40e3-bdc0-5bfe8e59a90e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunFormulaSATCRNonCircuit", "[", 
  RowBox[{"sqrtcircuit", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"out1", "\[Rule]", "1"}], ",", 
     RowBox[{"out2", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"in1", ",", "in2", ",", "in3", ",", "in4"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
  3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
  3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
  3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
  3.773166458472303*^9}, {3.773280234288148*^9, 3.773280252028183*^9}, {
  3.773280304844215*^9, 3.7732803306111727`*^9}, {3.773345412060792*^9, 
  3.773345412390747*^9}, {3.7733523201041718`*^9, 3.773352328805985*^9}},
 CellLabel->
  "In[512]:=",ExpressionUUID->"4b7399d0-58d0-45ba-a821-5bddd609ac30"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.773138049033792*^9, {3.7731382852593927`*^9, 3.773138291002398*^9}, 
   3.773138667428905*^9, {3.773139748572077*^9, 3.773139794982086*^9}, 
   3.773139854611534*^9, {3.773139907046414*^9, 3.7731399345977077`*^9}, {
   3.773139973510147*^9, 3.773139993703556*^9}, 3.773166459116466*^9, 
   3.773196452277845*^9, {3.773280255270053*^9, 3.773280271366089*^9}, {
   3.773280308901577*^9, 3.773280355577343*^9}, {3.7733454134745007`*^9, 
   3.773345429951271*^9}, {3.7733523324087343`*^9, 3.7733523445496883`*^9}},
 CellLabel->
  "Out[512]=",ExpressionUUID->"9a67242f-7d91-4b34-a2f2-e33a3a0f474a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunFormulaSATCRNonCircuit", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P7", "\[Rule]", "1"}], ",", 
     RowBox[{"P6", "\[Rule]", "0"}], ",", 
     RowBox[{"P5", "\[Rule]", "0"}], ",", 
     RowBox[{"P4", "\[Rule]", "0"}], ",", 
     RowBox[{"P3", "\[Rule]", "1"}], ",", 
     RowBox[{"P2", "\[Rule]", "1"}], ",", 
     RowBox[{"P1", "\[Rule]", "1"}], ",", 
     RowBox[{"P0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", "B1", 
     ",", "B0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
   3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
   3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
   3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
   3.773166458472303*^9}, {3.77327988361902*^9, 3.773279911979558*^9}, {
   3.773280057199664*^9, 3.773280128264084*^9}, {3.7733262156521378`*^9, 
   3.773326221916224*^9}, {3.773326916728631*^9, 3.773326934196891*^9}, 
   3.77332709817653*^9, 3.773327144762494*^9, {3.773345652241632*^9, 
   3.773345652423212*^9}, {3.773352394246258*^9, 3.7733523981484632`*^9}},
 CellLabel->
  "In[514]:=",ExpressionUUID->"6f1aaa88-7a1e-4e7d-8a80-bc317c7c5ed3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "0", ",", "1", ",", "1", ",", "0", ",", "1", ",", "1"}],
   "}"}]], "Output",
 CellChangeTimes->{3.773352401703767*^9},
 CellLabel->
  "Out[514]=",ExpressionUUID->"e5cd13c4-9b22-41b0-8718-600a55dae4bd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunFormulaSATCRNonCircuit", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P7", "\[Rule]", "0"}], ",", 
     RowBox[{"P6", "\[Rule]", "1"}], ",", 
     RowBox[{"P5", "\[Rule]", "0"}], ",", 
     RowBox[{"P4", "\[Rule]", "1"}], ",", 
     RowBox[{"P3", "\[Rule]", "0"}], ",", 
     RowBox[{"P2", "\[Rule]", "1"}], ",", 
     RowBox[{"P1", "\[Rule]", "0"}], ",", 
     RowBox[{"P0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", "B1", 
     ",", "B0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
   3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
   3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
   3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
   3.773166458472303*^9}, {3.77327988361902*^9, 3.773279911979558*^9}, {
   3.773280057199664*^9, 3.773280128264084*^9}, {3.7733262156521378`*^9, 
   3.773326221916224*^9}, {3.773326916728631*^9, 3.773326934196891*^9}, 
   3.77332709817653*^9, 3.773327144762494*^9, {3.77332738664828*^9, 
   3.77332740261819*^9}, {3.773345717121467*^9, 3.7733457227248583`*^9}, 
   3.773352463890972*^9},
 CellLabel->
  "In[515]:=",ExpressionUUID->"39b640df-ff0c-478e-b38e-c113d0dda5b3"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.773326235034787*^9, 3.773326951215279*^9, 
  3.773327161467757*^9, 3.773327683609096*^9, 3.7733285269073143`*^9, 
  3.773347326219266*^9, 3.773352757801076*^9},
 CellLabel->
  "Out[515]=",ExpressionUUID->"c50fb419-ba40-4776-9b40-a31c6b5218c9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunFormulaSATCRNonCircuit", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P7", "\[Rule]", "1"}], ",", 
     RowBox[{"P6", "\[Rule]", "1"}], ",", 
     RowBox[{"P5", "\[Rule]", "1"}], ",", 
     RowBox[{"P4", "\[Rule]", "0"}], ",", 
     RowBox[{"P3", "\[Rule]", "1"}], ",", 
     RowBox[{"P2", "\[Rule]", "1"}], ",", 
     RowBox[{"P1", "\[Rule]", "0"}], ",", 
     RowBox[{"P0", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", "B1", 
     ",", "B0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
   3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
   3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
   3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
   3.773166458472303*^9}, {3.77327988361902*^9, 3.773279911979558*^9}, {
   3.773280057199664*^9, 3.773280128264084*^9}, {3.773347344526004*^9, 
   3.773347347630453*^9}, 3.7733524664458723`*^9},
 CellLabel->
  "In[516]:=",ExpressionUUID->"d4da3d12-fbf6-4b1f-b8f5-5bbfdba31f66"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{
  3.773138049033792*^9, {3.7731382852593927`*^9, 3.773138291002398*^9}, 
   3.773138667428905*^9, {3.773139748572077*^9, 3.773139794982086*^9}, 
   3.773139854611534*^9, {3.773139907046414*^9, 3.7731399345977077`*^9}, {
   3.773139973510147*^9, 3.773139993703556*^9}, 3.773166459116466*^9, 
   3.773196452277845*^9, 3.773280874142686*^9, 3.773347563409141*^9, 
   3.773352865394864*^9},
 CellLabel->
  "Out[516]=",ExpressionUUID->"aaef234c-1caa-4800-b814-510dc342d154"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["WalkSAT-inspired Boolean Formula Satisfiability Solver", "Section",
 CellChangeTimes->{{3.7731353585432863`*^9, 3.773135367944931*^9}, {
  3.773137113731822*^9, 3.77313711827369*^9}, {3.773326022161957*^9, 
  3.773326022708658*^9}, {3.773329079022523*^9, 3.7733290797123623`*^9}, {
  3.773353056078246*^9, 
  3.773353061348796*^9}},ExpressionUUID->"beb17e0a-6e6d-4f97-8bbe-\
8deacf6a9af6"],

Cell["\<\
At long last, here is our improved construction.

To review, WalkSAT chooses an unsatisfied clause at random, then fixes it by \
flipping the variable that causes the fewest currently-satisfied clauses to \
become unsatisfied.  (GSAT also considers whether other currently-unsatisfied \
clauses will become satisfied, and chooses the variable that makes the \
largest net difference.)  With some probability, another variable in the \
unsatisfied clause is chosen.  With some probability, the whole variable \
assignment is reset.   

Our CRN has a similar flavor. If there is an unsatisfied clause, it will try \
to flip the associated variables (any or all of which would result in the \
clause becoming satisfied), but other clauses can reject the attempt if doing \
so would make that clause unsatisfied.  If an attempted flip is not rejected, \
then it will eventually solidify.   The similarity to WalkSAT resides in that \
variables that result in breaking a greater number of clauses are less likely \
to be flipped.  However, it is different in that all clauses try to fix \
themselves simultaneously, and can be in an intermediate stage of trying to \
flip while other clauses are also taking action.  

clause (X + !Y + Z)  ==>

X0 + Y1 + Z0 --> tryX1 + tryY0 + tryZ1
tryX0 + Y1 + Z0 --> X1 + Y1 + Z0
X0 + tryY1 + Z0 --> X0 + Y0 + Z0 
X0 + Y1 + tryZ1 --> X0 + Y1 + Z0

variable X ==>
tryX1 --> X1
tryX0 --> X0
\
\>", "Text",
 CellChangeTimes->{{3.7731345194022903`*^9, 3.7731346761403522`*^9}, {
   3.773134715066553*^9, 3.77313475194668*^9}, {3.773137458606723*^9, 
   3.773137486858985*^9}, {3.773139011708281*^9, 3.7731391622186317`*^9}, {
   3.773140039024252*^9, 3.773140082100349*^9}, {3.773196266803932*^9, 
   3.773196267304377*^9}, 3.7733290832963943`*^9, {3.773336599123534*^9, 
   3.773336628856786*^9}, {3.773340030748124*^9, 3.7733400560896873`*^9}, {
   3.7733415481305513`*^9, 3.7733417065521183`*^9}, {3.7733422950884953`*^9, 
   3.773342296503228*^9}, {3.773342748459626*^9, 3.773342768392971*^9}, {
   3.773343140295533*^9, 3.773343161161839*^9}, {3.773353066433485*^9, 
   3.773353169116274*^9}, {3.7733536263573112`*^9, 3.7733536274670362`*^9}, {
   3.773353657855805*^9, 3.773353765997407*^9}, {3.773354250981241*^9, 
   3.77335443900744*^9}, {3.773364593817204*^9, 3.773364595041761*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"98ba0c9b-fb80-4659-89a1-e3d681111cc9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"WalkClauseReactions", "[", "clause_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vars", ",", "n", ",", "unsat"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vars", "=", 
      RowBox[{"BooleanVariables", "[", "clause", "]"}]}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "vars", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"unsat", "=", 
      RowBox[{"Boole", "[", 
       RowBox[{"SatisfiabilityInstances", "[", 
        RowBox[{
         RowBox[{"!", "clause"}], ",", "vars", ",", 
         RowBox[{"2", "^", "n"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "watch", " ", "out", " ", "that", " ", "rxn", " ", "uses", " ", 
         "HoldAll"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"rxn", "@@", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Plus", "@@", 
               RowBox[{"MapThread", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#1", "[", "#2", "]"}], "&"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"vars", ",", "case"}], "}"}]}], "]"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Plus", "@@", 
               RowBox[{"MapThread", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#1", "[", 
                   RowBox[{"try", ",", "#2"}], "]"}], "&"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"vars", ",", 
                   RowBox[{"1", "-", "case"}]}], "}"}]}], "]"}]}], ",", 
              "\[IndentingNewLine]", "1"}], "}"}]}], "\[IndentingNewLine]", 
           "}"}], ",", 
          RowBox[{"Table", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rxn", "@@", 
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Plus", "@@", 
                  RowBox[{"MapThread", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"#1", "[", "#2", "]"}], "&"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"vars", ",", "case"}], "}"}]}], "]"}]}], ")"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"vars", "[", 
                    RowBox[{"[", "var", "]"}], "]"}], "[", "v_", "]"}], 
                  "\[RuleDelayed]", 
                  RowBox[{
                   RowBox[{"vars", "[", 
                    RowBox[{"[", "var", "]"}], "]"}], "[", 
                   RowBox[{"try", ",", "v"}], "]"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Plus", "@@", 
                  RowBox[{"MapThread", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"#1", "[", "#2", "]"}], "&"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"vars", ",", "case"}], "}"}]}], "]"}]}], ")"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"vars", "[", 
                    RowBox[{"[", "var", "]"}], "]"}], "[", "v_", "]"}], 
                  "\[RuleDelayed]", 
                  RowBox[{
                   RowBox[{"vars", "[", 
                    RowBox[{"[", "var", "]"}], "]"}], "[", 
                   RowBox[{"1", "-", "v"}], "]"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", "1"}], "}"}]}], "\[IndentingNewLine]", 
            ",", 
            RowBox[{"{", 
             RowBox[{"var", ",", "n"}], "}"}]}], "\[IndentingNewLine]", 
           "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"case", ",", "unsat"}], "}"}]}], "\[IndentingNewLine]", 
       "]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.77334261243182*^9, 3.773342728828231*^9}, {
   3.7733431055806026`*^9, 3.773343191889161*^9}, {3.773343236919108*^9, 
   3.773343401403895*^9}, {3.7733436082507887`*^9, 3.7733436790628033`*^9}, {
   3.7733437625699587`*^9, 3.773343787909876*^9}, {3.77334385756599*^9, 
   3.773343858701167*^9}, {3.7733441097439957`*^9, 3.773344145630681*^9}, {
   3.773344250074697*^9, 3.773344281477072*^9}, {3.773344477676824*^9, 
   3.77334449995581*^9}, {3.7733446198526917`*^9, 3.773344622665374*^9}, {
   3.773344715209586*^9, 3.773344724570692*^9}, 3.7733447606741257`*^9, {
   3.7733449095711737`*^9, 3.7733449568079243`*^9}, {3.773354476718292*^9, 
   3.7733544770944347`*^9}, {3.773359716958083*^9, 3.7733597258330107`*^9}, {
   3.773360780534959*^9, 3.773360794406698*^9}, {3.773360826630269*^9, 
   3.7733609034666233`*^9}, {3.773360965002714*^9, 3.7733611039006777`*^9}, {
   3.773361141948732*^9, 3.773361187210387*^9}, {3.773361291662678*^9, 
   3.773361336650243*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"5334a71f-b7a7-495d-a5fa-7f5785285f42"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"WalkClauseReactions", "[", 
   RowBox[{
    RowBox[{"X", "&&", "Y"}], "||", 
    RowBox[{"!", "Y"}], "||", 
    RowBox[{"Z", "&&", "X"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773361211922688*^9, 3.773361239522821*^9}, {
  3.773361753335257*^9, 3.773361769347041*^9}},
 CellLabel->
  "In[524]:=",ExpressionUUID->"07a539ea-6597-49b9-873e-cdfa4547ba8a"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"Y", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"Z", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "1", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "0", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"Y", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"Z", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "1", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "0", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " "}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.773361227506632*^9, 3.773361240050583*^9}, 
   3.7733613054142437`*^9, 3.773361339965754*^9, 3.773361770343644*^9},
 CellLabel->
  "Out[524]//MatrixForm=",ExpressionUUID->"8216c71f-9698-4185-9b96-\
dc9c13511d0d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"WalkVariableReactions", "[", "slow_", "]"}], "[", "variable_", 
   "]"}], ":=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rxn", "@@", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"variable", "[", 
        RowBox[{"try", ",", "0"}], "]"}], ",", " ", 
       RowBox[{"variable", "[", "0", "]"}], ",", "slow"}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"rxn", "@@", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"variable", "[", 
        RowBox[{"try", ",", "1"}], "]"}], ",", " ", 
       RowBox[{"variable", "[", "1", "]"}], ",", "slow"}], "}"}]}]}], 
   "\[IndentingNewLine]", "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773354520576117*^9, 3.773354531184923*^9}, {
  3.773362070040822*^9, 3.773362071081951*^9}, {3.773362101724264*^9, 
  3.77336218702419*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"3f40438d-4f8c-41d8-8bc9-c012c7facb27"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"WalkVariableReactions", "[", "0.1", "]"}], "[", "X", "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773361211922688*^9, 3.773361239522821*^9}, {
  3.773361753335257*^9, 3.773361769347041*^9}, {3.773362285263282*^9, 
  3.773362293210326*^9}},
 CellLabel->
  "In[526]:=",ExpressionUUID->"a2d9c8c8-b741-42f8-89e3-8ea047d3a049"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"X", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"X", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"X", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"X", "[", "1", "]"}], " "}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.773362294821561*^9},
 CellLabel->
  "Out[526]//MatrixForm=",ExpressionUUID->"dd090ea7-4a6c-4e2a-8a1f-\
66d1338ed984"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"WalkSATCRN", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"slow_:", "0.1"}]}], "]"}], ":=", 
  RowBox[{"Join", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"WalkClauseReactions", "/@", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "expr", "]"}], "===", "And"}], ",", 
        RowBox[{"List", "@@", "expr"}], ",", 
        RowBox[{"{", "expr", "}"}]}], "]"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"WalkVariableReactions", "[", "slow", "]"}], "/@", 
      RowBox[{"BooleanVariables", "[", "expr", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773362312228259*^9, 3.7733624536237783`*^9}, 
   3.77336248970185*^9, {3.773362581132801*^9, 3.773362630322885*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"04db65a5-f7c1-4d07-b8ae-a2a156d81201"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"WalkSATCRN", "[", "AdlemanSAT", "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773362686005267*^9, 3.7733626985606728`*^9}},
 CellLabel->
  "In[528]:=",ExpressionUUID->"26d998d8-1f52-400a-b594-5ef1b8ae043e"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x16", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x18", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x13", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x20", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x06", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x19", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x04", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x11", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x04", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x13", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x19", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x17", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x15", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x17", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x06", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x11", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x15", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x17", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x06", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x13", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x19", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x06", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x14", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x03", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x20", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x03", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x08", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x10", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x18", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x20", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x10", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x16", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x18", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x10", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x10", "[", "0", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x11", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x14", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x08", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x15", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x08", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x10", "[", 
          RowBox[{"try", ",", "0"}], "]"}], "+", 
         RowBox[{"x16", "[", 
          RowBox[{"try", ",", "1"}], "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x08", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", 
          RowBox[{"try", ",", "1"}], "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", 
          RowBox[{"try", ",", "0"}], "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{"x01", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x01", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x01", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x01", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x02", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x02", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x02", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x02", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x03", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x03", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x03", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x03", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x04", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x04", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x04", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x04", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x05", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x05", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x05", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x05", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x06", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x06", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x06", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x06", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x07", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x07", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x07", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x07", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x08", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x08", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x08", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x08", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x09", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x09", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x09", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x09", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x10", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x10", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x10", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x10", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x11", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x11", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x11", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x11", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x12", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x12", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x12", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x12", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x13", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x13", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x13", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x13", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x14", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x14", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x14", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x14", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x15", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x15", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x15", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x15", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x16", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x16", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x16", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x16", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x17", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x17", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x17", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x17", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x18", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x18", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x18", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x18", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x19", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x19", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x19", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x19", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x20", "[", 
         RowBox[{"try", ",", "0"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x20", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x20", "[", 
         RowBox[{"try", ",", "1"}], "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.1`", " "}]], " ", 
        RowBox[{"x20", "[", "1", "]"}], " "}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.773362699147488*^9},
 CellLabel->
  "Out[528]//MatrixForm=",ExpressionUUID->"c7ea05c9-bedd-4fb8-86c2-\
7f6faf004890"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RunWalkSATCRN", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"slow_:", "0.1"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "crn", ",", "rsys", ",", "times", ",", "data", ",", "finishconcs", ",", 
      "results"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"crn", "=", 
      RowBox[{"WalkSATCRN", "[", 
       RowBox[{"expr", ",", "slow"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rsys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"crn", ",", 
        RowBox[{"DualRailInitialState", "[", "crn", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"times", ",", "data"}], "}"}], "=", 
      RowBox[{"SimulateRxnsysSSA", "[", 
       RowBox[{"rsys", ",", "Infinity", ",", 
        RowBox[{"Output", "\[Rule]", "\"\<State\>\""}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"finishconcs", "=", 
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}], ",", 
          RowBox[{"Last", "[", "data", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"results", "=", 
      RowBox[{
       RowBox[{"Cases", "[", 
        RowBox[{"finishconcs", ",", 
         RowBox[{
          RowBox[{"conc", "[", 
           RowBox[{
            RowBox[{"s_", "[", "t_", "]"}], ",", 
            RowBox[{"_", "?", "Positive"}]}], "]"}], "\[RuleDelayed]", 
          RowBox[{"(", 
           RowBox[{"s", "\[Rule]", "t"}], ")"}]}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0", "\[Rule]", "False"}], ",", 
         RowBox[{"1", "\[Rule]", "True"}]}], "}"}]}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.68021565999244*^9, 3.680215750241291*^9}, {
   3.6802158052863903`*^9, 3.6802158385740547`*^9}, {3.773136058908334*^9, 
   3.773136129428895*^9}, {3.773136200951747*^9, 3.773136220896125*^9}, {
   3.7731367033385553`*^9, 3.773136728021192*^9}, {3.773136827472237*^9, 
   3.773136847838519*^9}, {3.7731378382659616`*^9, 3.773137844146751*^9}, {
   3.7731378785932217`*^9, 3.773137886692079*^9}, {3.773137999129963*^9, 
   3.773138017053162*^9}, {3.773139783824836*^9, 3.7731397890753393`*^9}, {
   3.773139890729321*^9, 3.773139903448102*^9}, {3.773280197937496*^9, 
   3.773280211920089*^9}, {3.7733453849612217`*^9, 3.7733453892668533`*^9}, {
   3.77334751343707*^9, 3.773347545687004*^9}, {3.773347847280039*^9, 
   3.773347866100006*^9}, {3.773347945836709*^9, 3.773347952150361*^9}, 
   3.77334825368139*^9, {3.773362734420347*^9, 3.773362753224311*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"7f417511-41fd-4819-b492-dfee9f1c564a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"assign", "=", 
  RowBox[{"RunWalkSATCRN", "[", "AdlemanSAT", "]"}]}]], "Input",
 CellChangeTimes->{{3.773347818586851*^9, 3.773347852310367*^9}, {
  3.7733480107082043`*^9, 3.773348011179825*^9}, {3.773348342645481*^9, 
  3.7733483436702747`*^9}, {3.7733627927173357`*^9, 3.7733628055822678`*^9}, {
  3.7733628624199333`*^9, 3.773362863835215*^9}, {3.773362914605308*^9, 
  3.773362934119389*^9}},
 CellLabel->
  "In[534]:=",ExpressionUUID->"805c94f9-8c8f-4a04-ab8b-d2c4d2d28472"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x01", "\[Rule]", "False"}], ",", 
   RowBox[{"x02", "\[Rule]", "True"}], ",", 
   RowBox[{"x03", "\[Rule]", "False"}], ",", 
   RowBox[{"x04", "\[Rule]", "False"}], ",", 
   RowBox[{"x05", "\[Rule]", "False"}], ",", 
   RowBox[{"x06", "\[Rule]", "False"}], ",", 
   RowBox[{"x07", "\[Rule]", "True"}], ",", 
   RowBox[{"x08", "\[Rule]", "True"}], ",", 
   RowBox[{"x09", "\[Rule]", "False"}], ",", 
   RowBox[{"x10", "\[Rule]", "True"}], ",", 
   RowBox[{"x11", "\[Rule]", "True"}], ",", 
   RowBox[{"x12", "\[Rule]", "True"}], ",", 
   RowBox[{"x13", "\[Rule]", "False"}], ",", 
   RowBox[{"x14", "\[Rule]", "False"}], ",", 
   RowBox[{"x15", "\[Rule]", "True"}], ",", 
   RowBox[{"x16", "\[Rule]", "True"}], ",", 
   RowBox[{"x17", "\[Rule]", "True"}], ",", 
   RowBox[{"x18", "\[Rule]", "False"}], ",", 
   RowBox[{"x19", "\[Rule]", "False"}], ",", 
   RowBox[{"x20", "\[Rule]", "False"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773362796894875*^9, 3.773362860468576*^9, {3.7733629131608963`*^9, 
   3.773362935954893*^9}},
 CellLabel->
  "Out[534]=",ExpressionUUID->"2dbd3790-bd30-4ad9-b441-670660a0538b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdlemanSAT", "/.", "assign"}]], "Input",
 CellChangeTimes->{{3.7733630223180447`*^9, 3.773363026782319*^9}},
 CellLabel->
  "In[535]:=",ExpressionUUID->"591aaabc-3fb1-472a-9f6e-7d97bdc9b5c0"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7733630275211763`*^9},
 CellLabel->
  "Out[535]=",ExpressionUUID->"9cb992ad-1dd2-4edc-9e14-0e12caa87c72"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"WatchWalkSATCRN", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"maxpoints_:", "1000"}], ",", 
    RowBox[{"timeout_:", "Infinity"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "crn", ",", "rsys", ",", "times", ",", "data", ",", "points", ",", 
      "lessdata", ",", "finishconcs"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"crn", "=", 
      RowBox[{"WalkSATCRN", "[", "expr", "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"rsys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"crn", ",", 
        RowBox[{"DualRailInitialState", "[", "crn", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"times", ",", "data"}], "}"}], "=", 
      RowBox[{"SimulateRxnsysSSA", "[", 
       RowBox[{"rsys", ",", "timeout"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"points", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "data", "]"}], ">", "maxpoints"}], ",", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", "1", "}"}], ",", 
          RowBox[{"Ceiling", "/@", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"maxpoints", "-", "1"}], "]"}], "*", 
             RowBox[{
              RowBox[{"Length", "[", "data", "]"}], "/", 
              RowBox[{"(", 
               RowBox[{"maxpoints", "-", "1"}], ")"}]}]}], ")"}]}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", "data", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"lessdata", "=", 
      RowBox[{"data", "[", 
       RowBox[{"[", "points", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"Image", "[", 
       RowBox[{"Transpose", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Last", "[", "lessdata", "]"}], "*", "#"}], "+", "#"}], 
            ")"}], "/", "2"}], "&"}], " ", "/@", " ", "lessdata"}], "]"}], 
       "]"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"finishconcs", "=", 
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}], ",", 
          RowBox[{"Last", "[", "data", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Cases", "[", 
       RowBox[{"finishconcs", ",", 
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{
           RowBox[{"s_", "[", "t_", "]"}], ",", 
           RowBox[{"_", "?", "Positive"}]}], "]"}], "\[RuleDelayed]", 
         RowBox[{"(", 
          RowBox[{"s", "\[Rule]", "t"}], ")"}]}]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0", "\[Rule]", "False"}], ",", 
        RowBox[{"1", "\[Rule]", "True"}]}], "}"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6803973434360723`*^9, 3.680397421797638*^9}, {
   3.6803975247123137`*^9, 3.6803975615801764`*^9}, {3.680398471315331*^9, 
   3.680398498077474*^9}, {3.680398559044063*^9, 3.68039857798982*^9}, {
   3.6803993556148853`*^9, 3.680399361294039*^9}, {3.6803996349269247`*^9, 
   3.6803996606914062`*^9}, 3.6803997017693*^9, {3.6803998127154408`*^9, 
   3.680399832954554*^9}, {3.680400011951935*^9, 3.680400022408893*^9}, {
   3.680400120742281*^9, 3.680400147115947*^9}, {3.680400196612588*^9, 
   3.680400201442669*^9}, {3.680400505028851*^9, 3.6804005354642277`*^9}, {
   3.6804006208005667`*^9, 3.6804006768463573`*^9}, {3.6836715597221317`*^9, 
   3.6836715619369373`*^9}, {3.68373743268504*^9, 3.683737434579191*^9}, {
   3.773348071110723*^9, 3.773348149948955*^9}, 3.773348260508574*^9, {
   3.7733484599229794`*^9, 3.7733484827009573`*^9}, {3.7733498168230963`*^9, 
   3.773349822510388*^9}, {3.773349861492824*^9, 3.773349966539503*^9}, {
   3.773350019973353*^9, 3.773350020507333*^9}, {3.773350052731489*^9, 
   3.773350066729409*^9}, {3.77336303107001*^9, 3.773363039952565*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"99cbf48d-e540-4e21-906d-c537ea2ed12b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"assign", " ", "=", " ", 
  RowBox[{"WatchWalkSATCRN", "[", "AdlemanSAT", "]"}]}]], "Input",
 CellChangeTimes->{{3.680400230154809*^9, 3.680400230777896*^9}, {
  3.7733482134903393`*^9, 3.773348218802259*^9}, {3.773363054327042*^9, 
  3.773363060024683*^9}},
 CellLabel->
  "In[537]:=",ExpressionUUID->"7b2fef39-64ab-41f7-9594-c7ae8336a1d1"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnV2uLLltgBsxYGQb2YK9gIJ3EDgrmADJkwED9oORt15ulpE5Dg6mri7/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    "], {{0, 80}, {1000, 
    0}}, {0., 1.},
    ColorFunction->GrayLevel],
   BoxForm`ImageTag["Real32", ColorSpace -> Automatic, Interleaving -> None],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->{3032.94140625, Automatic},
  ImageSizeRaw->{1000, 80},
  PlotRange->{{0, 1000}, {0, 80}}]], "Print",
 CellChangeTimes->{{3.773348221695159*^9, 3.7733482753991632`*^9}, 
   3.7733484999051933`*^9, 3.773349970326997*^9, 3.773350317637628*^9, 
   3.773363063550962*^9},
 CellLabel->
  "During evaluation of \
In[537]:=",ExpressionUUID->"0d85fa39-fa59-4205-94ee-4fa90efda3e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x01", "\[Rule]", "False"}], ",", 
   RowBox[{"x02", "\[Rule]", "True"}], ",", 
   RowBox[{"x03", "\[Rule]", "False"}], ",", 
   RowBox[{"x04", "\[Rule]", "False"}], ",", 
   RowBox[{"x05", "\[Rule]", "False"}], ",", 
   RowBox[{"x06", "\[Rule]", "False"}], ",", 
   RowBox[{"x07", "\[Rule]", "True"}], ",", 
   RowBox[{"x08", "\[Rule]", "True"}], ",", 
   RowBox[{"x09", "\[Rule]", "False"}], ",", 
   RowBox[{"x10", "\[Rule]", "True"}], ",", 
   RowBox[{"x11", "\[Rule]", "True"}], ",", 
   RowBox[{"x12", "\[Rule]", "True"}], ",", 
   RowBox[{"x13", "\[Rule]", "False"}], ",", 
   RowBox[{"x14", "\[Rule]", "False"}], ",", 
   RowBox[{"x15", "\[Rule]", "True"}], ",", 
   RowBox[{"x16", "\[Rule]", "True"}], ",", 
   RowBox[{"x17", "\[Rule]", "True"}], ",", 
   RowBox[{"x18", "\[Rule]", "False"}], ",", 
   RowBox[{"x19", "\[Rule]", "False"}], ",", 
   RowBox[{"x20", "\[Rule]", "False"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773348221697515*^9, 3.773348275406501*^9}, 
   3.773348499916655*^9, 3.773349970330079*^9, 3.773350317641135*^9, 
   3.7733630635559807`*^9},
 CellLabel->
  "Out[537]=",ExpressionUUID->"0f57bc42-c605-4833-a421-c06dbb612b6f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdlemanSAT", "/.", "assign"}]], "Input",
 CellChangeTimes->{{3.773348328139873*^9, 3.77334833138282*^9}},
 CellLabel->
  "In[538]:=",ExpressionUUID->"0785eeac-b144-4632-aa13-0eff7bb3ab4c"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7733483321226273`*^9, 3.773363080392412*^9},
 CellLabel->
  "Out[538]=",ExpressionUUID->"5fb8ce8b-1389-42ed-b30e-56561502e56a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpeciesInRxnsys", "[", 
  RowBox[{"WalkSATCRN", "[", "AdlemanSAT", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7733476138064938`*^9, 3.773347627053453*^9}, 
   3.773347983176874*^9, {3.773348600445217*^9, 3.773348606943149*^9}, {
   3.7733630874882917`*^9, 3.773363089424032*^9}},
 CellLabel->
  "In[540]:=",ExpressionUUID->"7e641a55-2df2-4127-b88d-cda0936db802"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x01", "[", "0", "]"}], ",", 
   RowBox[{"x01", "[", "1", "]"}], ",", 
   RowBox[{"x01", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x01", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x02", "[", "0", "]"}], ",", 
   RowBox[{"x02", "[", "1", "]"}], ",", 
   RowBox[{"x02", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x02", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x03", "[", "0", "]"}], ",", 
   RowBox[{"x03", "[", "1", "]"}], ",", 
   RowBox[{"x03", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x03", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x04", "[", "0", "]"}], ",", 
   RowBox[{"x04", "[", "1", "]"}], ",", 
   RowBox[{"x04", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x04", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x05", "[", "0", "]"}], ",", 
   RowBox[{"x05", "[", "1", "]"}], ",", 
   RowBox[{"x05", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x05", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x06", "[", "0", "]"}], ",", 
   RowBox[{"x06", "[", "1", "]"}], ",", 
   RowBox[{"x06", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x06", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x07", "[", "0", "]"}], ",", 
   RowBox[{"x07", "[", "1", "]"}], ",", 
   RowBox[{"x07", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x07", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x08", "[", "0", "]"}], ",", 
   RowBox[{"x08", "[", "1", "]"}], ",", 
   RowBox[{"x08", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x08", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x09", "[", "0", "]"}], ",", 
   RowBox[{"x09", "[", "1", "]"}], ",", 
   RowBox[{"x09", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x09", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x10", "[", "0", "]"}], ",", 
   RowBox[{"x10", "[", "1", "]"}], ",", 
   RowBox[{"x10", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x10", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x11", "[", "0", "]"}], ",", 
   RowBox[{"x11", "[", "1", "]"}], ",", 
   RowBox[{"x11", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x11", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x12", "[", "0", "]"}], ",", 
   RowBox[{"x12", "[", "1", "]"}], ",", 
   RowBox[{"x12", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x12", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x13", "[", "0", "]"}], ",", 
   RowBox[{"x13", "[", "1", "]"}], ",", 
   RowBox[{"x13", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x13", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x14", "[", "0", "]"}], ",", 
   RowBox[{"x14", "[", "1", "]"}], ",", 
   RowBox[{"x14", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x14", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x15", "[", "0", "]"}], ",", 
   RowBox[{"x15", "[", "1", "]"}], ",", 
   RowBox[{"x15", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x15", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x16", "[", "0", "]"}], ",", 
   RowBox[{"x16", "[", "1", "]"}], ",", 
   RowBox[{"x16", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x16", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x17", "[", "0", "]"}], ",", 
   RowBox[{"x17", "[", "1", "]"}], ",", 
   RowBox[{"x17", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x17", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x18", "[", "0", "]"}], ",", 
   RowBox[{"x18", "[", "1", "]"}], ",", 
   RowBox[{"x18", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x18", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x19", "[", "0", "]"}], ",", 
   RowBox[{"x19", "[", "1", "]"}], ",", 
   RowBox[{"x19", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x19", "[", 
    RowBox[{"try", ",", "1"}], "]"}], ",", 
   RowBox[{"x20", "[", "0", "]"}], ",", 
   RowBox[{"x20", "[", "1", "]"}], ",", 
   RowBox[{"x20", "[", 
    RowBox[{"try", ",", "0"}], "]"}], ",", 
   RowBox[{"x20", "[", 
    RowBox[{"try", ",", "1"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7733486074777308`*^9, 3.773348611692428*^9}, 
   3.773350235715431*^9, {3.7733630834590797`*^9, 3.7733630902204733`*^9}},
 CellLabel->
  "Out[540]=",ExpressionUUID->"f5057879-59c8-4866-9218-47824b4446e8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RunWalkSATCRNonCircuit", "[", 
   RowBox[{"circuit_", ",", "known_", ",", "desired_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"expr", ",", "results"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"expr", "=", 
      RowBox[{"CircuitToFormula", "[", 
       RowBox[{"Join", "[", 
        RowBox[{"circuit", ",", "known"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"results", "=", 
      RowBox[{"RunWalkSATCRN", "[", "expr", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Boole", "[", 
      RowBox[{"desired", "/.", "results"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.68021565999244*^9, 3.680215750241291*^9}, {
   3.6802158052863903`*^9, 3.6802158385740547`*^9}, {3.773136058908334*^9, 
   3.773136129428895*^9}, {3.773136200951747*^9, 3.773136220896125*^9}, {
   3.7731367033385553`*^9, 3.773136728021192*^9}, {3.773136827472237*^9, 
   3.773136847838519*^9}, {3.7731378382659616`*^9, 3.773137844146751*^9}, {
   3.7731378785932217`*^9, 3.773137886692079*^9}, {3.773137999129963*^9, 
   3.773138017053162*^9}, {3.773139783824836*^9, 3.7731397890753393`*^9}, {
   3.773139890729321*^9, 3.773139903448102*^9}, {3.773280197937496*^9, 
   3.773280211920089*^9}, {3.7733453849612217`*^9, 3.7733453892668533`*^9}, {
   3.77334751343707*^9, 3.773347545687004*^9}, {3.773347847280039*^9, 
   3.773347866100006*^9}, {3.773347945836709*^9, 3.773347952150361*^9}, 
   3.77334825368139*^9, {3.773351078254981*^9, 3.77335114338939*^9}, {
   3.77335219691759*^9, 3.773352276363826*^9}, {3.773352340452085*^9, 
   3.773352341979653*^9}, {3.773363136518976*^9, 3.7733631448631487`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"8303592c-3f36-4608-b088-10d90f14dbb5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunWalkSATCRNonCircuit", "[", 
  RowBox[{"sqrtcircuit", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"out1", "\[Rule]", "1"}], ",", 
     RowBox[{"out2", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"in1", ",", "in2", ",", "in3", ",", "in4"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
  3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
  3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
  3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
  3.773166458472303*^9}, {3.773280234288148*^9, 3.773280252028183*^9}, {
  3.773280304844215*^9, 3.7732803306111727`*^9}, {3.773345412060792*^9, 
  3.773345412390747*^9}, {3.7733523201041718`*^9, 3.773352328805985*^9}, {
  3.7733631589936247`*^9, 3.773363159382866*^9}},
 CellLabel->
  "In[542]:=",ExpressionUUID->"340b7b1c-b362-40fb-8a00-4f70900874f9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1", ",", "1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.773138049033792*^9, {3.7731382852593927`*^9, 3.773138291002398*^9}, 
   3.773138667428905*^9, {3.773139748572077*^9, 3.773139794982086*^9}, 
   3.773139854611534*^9, {3.773139907046414*^9, 3.7731399345977077`*^9}, {
   3.773139973510147*^9, 3.773139993703556*^9}, 3.773166459116466*^9, 
   3.773196452277845*^9, {3.773280255270053*^9, 3.773280271366089*^9}, {
   3.773280308901577*^9, 3.773280355577343*^9}, {3.7733454134745007`*^9, 
   3.773345429951271*^9}, {3.7733523324087343`*^9, 3.7733523445496883`*^9}, 
   3.773363162657509*^9},
 CellLabel->
  "Out[542]=",ExpressionUUID->"fdd47a49-7cfc-4fd2-8d02-eca353723333"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunWalkSATCRNonCircuit", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P7", "\[Rule]", "1"}], ",", 
     RowBox[{"P6", "\[Rule]", "0"}], ",", 
     RowBox[{"P5", "\[Rule]", "0"}], ",", 
     RowBox[{"P4", "\[Rule]", "0"}], ",", 
     RowBox[{"P3", "\[Rule]", "1"}], ",", 
     RowBox[{"P2", "\[Rule]", "1"}], ",", 
     RowBox[{"P1", "\[Rule]", "1"}], ",", 
     RowBox[{"P0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", "B1", 
     ",", "B0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
   3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
   3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
   3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
   3.773166458472303*^9}, {3.77327988361902*^9, 3.773279911979558*^9}, {
   3.773280057199664*^9, 3.773280128264084*^9}, {3.7733262156521378`*^9, 
   3.773326221916224*^9}, {3.773326916728631*^9, 3.773326934196891*^9}, 
   3.77332709817653*^9, 3.773327144762494*^9, {3.773345652241632*^9, 
   3.773345652423212*^9}, {3.773352394246258*^9, 3.7733523981484632`*^9}, {
   3.773363166011685*^9, 3.7733631663332167`*^9}},
 CellLabel->
  "In[543]:=",ExpressionUUID->"7075bd83-8aa7-4ec1-9da1-8cbd364be334"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "0", ",", "1", ",", "1", ",", "1", ",", "1", ",", "0", ",", "1"}],
   "}"}]], "Output",
 CellChangeTimes->{3.773352401703767*^9, 3.773363169622856*^9},
 CellLabel->
  "Out[543]=",ExpressionUUID->"5a41471e-9afc-4ddd-9f77-2135b0240f46"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunWalkSATCRNonCircuit", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P7", "\[Rule]", "0"}], ",", 
     RowBox[{"P6", "\[Rule]", "1"}], ",", 
     RowBox[{"P5", "\[Rule]", "0"}], ",", 
     RowBox[{"P4", "\[Rule]", "1"}], ",", 
     RowBox[{"P3", "\[Rule]", "0"}], ",", 
     RowBox[{"P2", "\[Rule]", "1"}], ",", 
     RowBox[{"P1", "\[Rule]", "0"}], ",", 
     RowBox[{"P0", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", "B1", 
     ",", "B0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
   3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
   3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
   3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
   3.773166458472303*^9}, {3.77327988361902*^9, 3.773279911979558*^9}, {
   3.773280057199664*^9, 3.773280128264084*^9}, {3.7733262156521378`*^9, 
   3.773326221916224*^9}, {3.773326916728631*^9, 3.773326934196891*^9}, 
   3.77332709817653*^9, 3.773327144762494*^9, {3.77332738664828*^9, 
   3.77332740261819*^9}, {3.773345717121467*^9, 3.7733457227248583`*^9}, 
   3.773352463890972*^9, {3.773363174547442*^9, 3.773363174900547*^9}},
 CellLabel->
  "In[544]:=",ExpressionUUID->"fccf75f1-590c-4884-b2da-7cf90d6f9ab6"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.773326235034787*^9, 3.773326951215279*^9, 
  3.773327161467757*^9, 3.773327683609096*^9, 3.7733285269073143`*^9, 
  3.773347326219266*^9, 3.773352757801076*^9, 3.773363716393908*^9},
 CellLabel->
  "Out[544]=",ExpressionUUID->"224341ea-cdf9-4d60-bd97-3dcc589b1f90"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RunWalkSATCRNonCircuit", "[", 
  RowBox[{"mult4", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P7", "\[Rule]", "1"}], ",", 
     RowBox[{"P6", "\[Rule]", "1"}], ",", 
     RowBox[{"P5", "\[Rule]", "1"}], ",", 
     RowBox[{"P4", "\[Rule]", "0"}], ",", 
     RowBox[{"P3", "\[Rule]", "1"}], ",", 
     RowBox[{"P2", "\[Rule]", "1"}], ",", 
     RowBox[{"P1", "\[Rule]", "0"}], ",", 
     RowBox[{"P0", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "A3", ",", "A2", ",", "A1", ",", "A0", ",", "B3", ",", "B2", ",", "B1", 
     ",", "B0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773138028484976*^9, 3.773138048008445*^9}, {
   3.773138627353924*^9, 3.77313862982815*^9}, {3.77313974788748*^9, 
   3.773139748019202*^9}, {3.773139921436125*^9, 3.773139930069871*^9}, {
   3.773139972880645*^9, 3.773139972971477*^9}, {3.773166458413117*^9, 
   3.773166458472303*^9}, {3.77327988361902*^9, 3.773279911979558*^9}, {
   3.773280057199664*^9, 3.773280128264084*^9}, {3.773347344526004*^9, 
   3.773347347630453*^9}, 3.7733524664458723`*^9, {3.773364199584198*^9, 
   3.773364199947332*^9}},
 CellLabel->
  "In[546]:=",ExpressionUUID->"febe96bb-0306-4134-9ab7-34ae5bd5a49e"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.773364195088607*^9, 3.773364574286209*^9},
 CellLabel->
  "Out[546]=",ExpressionUUID->"c1b93d77-c2f7-424f-a069-74a67f86a38e"]
}, Open  ]],

Cell["\<\
To be honest, it is disappointing that the \[OpenCurlyDoubleQuote]improved\
\[CloseCurlyDoubleQuote] WalkSATCRN also cannot solve the hard instances of \
inverting the multiplication circuit.  So be it.   However, as we will see, \
the WalkSATCRN perform admirably on randomly-generated hard satisfiability \
problems.   (Don\[CloseCurlyQuote]t bother trying FormulaSATCRN on the \
problems in the next section.)\
\>", "Text",
 CellChangeTimes->{{3.7731345194022903`*^9, 3.7731346761403522`*^9}, {
   3.773134715066553*^9, 3.77313475194668*^9}, {3.773137458606723*^9, 
   3.773137486858985*^9}, {3.773139011708281*^9, 3.7731391622186317`*^9}, {
   3.773140039024252*^9, 3.773140082100349*^9}, {3.773196266803932*^9, 
   3.773196267304377*^9}, 3.7733290832963943`*^9, {3.773336599123534*^9, 
   3.773336628856786*^9}, {3.773340030748124*^9, 3.7733400560896873`*^9}, {
   3.7733415481305513`*^9, 3.7733417065521183`*^9}, {3.7733422950884953`*^9, 
   3.773342296503228*^9}, {3.773342748459626*^9, 3.773342768392971*^9}, {
   3.773343140295533*^9, 3.773343161161839*^9}, {3.773353066433485*^9, 
   3.773353169116274*^9}, {3.7733536263573112`*^9, 3.7733536274670362`*^9}, {
   3.773353657855805*^9, 3.773353765997407*^9}, {3.773354250981241*^9, 
   3.77335443900744*^9}, {3.773364593817204*^9, 3.7733647456627617`*^9}, {
   3.773364836904587*^9, 3.773364842447727*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"61e4cf0f-0de9-46e2-b7a0-855129fd4da5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Performance on random k-SAT problems ", "Section",
 CellChangeTimes->{{3.7733648487105093`*^9, 3.7733648626020947`*^9}, {
  3.773364933314846*^9, 
  3.773364933551106*^9}},ExpressionUUID->"40c59b8a-c187-474d-a831-\
c334fc7554ba"],

Cell["\<\
Here we use Selman\[CloseCurlyQuote]s notion of random k-SAT formulas (Selman \
et al, Generating Hard Random Satisfiability Problems, 1996).   Each clause \
has exactly k literals, and they are guaranteed to involve k distinct \
variables. (Although a full clause may be exactly repeated in the formula, it \
is rare.)  We will use N for the number of variables and M for the number of \
clauses;  for the random k-SAT formulas, hardness peaks near M/N=4.26.   We \
will use M/N=4.2, which is hard enough.\
\>", "Text",
 CellChangeTimes->{{3.680820680163741*^9, 3.680820784067107*^9}, {
  3.766078040347226*^9, 3.7660780988811283`*^9}, {3.7660790669476423`*^9, 
  3.766079098754188*^9}, {3.766079137719144*^9, 3.766079212305265*^9}, {
  3.766079474534441*^9, 3.7660795533011637`*^9}, {3.766079591790983*^9, 
  3.766079621365512*^9}, {3.766079705294653*^9, 3.766079723595962*^9}, {
  3.766079777206427*^9, 3.766079827922763*^9}, {3.7660798625820017`*^9, 
  3.766079986092773*^9}, {3.766080163887148*^9, 3.766080265115068*^9}, {
  3.76608031696035*^9, 3.7660803203759813`*^9}, {3.766080413154846*^9, 
  3.7660804159297867`*^9}, {3.7660804494746017`*^9, 3.76608053852421*^9}, {
  3.77336492170162*^9, 3.773365086262064*^9}, {3.7733651275692883`*^9, 
  3.773365215038601*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"77edbc7e-5c65-450a-884d-6a7a95a37844"],

Cell[BoxData[
 RowBox[{
  RowBox[{"StandardVariables", "[", 
   RowBox[{"Nvars_", ",", 
    RowBox[{"prefix_:", "\"\<x\>\""}]}], "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", "=", 
      RowBox[{"Ceiling", "[", 
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", 
         RowBox[{"Nvars", "+", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ToExpression", "/@", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"prefix", "<>", 
        RowBox[{"(", 
         RowBox[{"StringJoin", "@@", 
          RowBox[{"ToString", "/@", 
           RowBox[{"IntegerDigits", "[", 
            RowBox[{"i", ",", "10", ",", "k"}], "]"}]}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "Nvars"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.680533768802321*^9, 3.680533787538021*^9}, {
  3.68366648307806*^9, 3.683666504212413*^9}, {3.683666547959938*^9, 
  3.6836666071692657`*^9}, {3.773341135099516*^9, 3.77334113701339*^9}, {
  3.773341174898814*^9, 3.773341194217887*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"584507ff-c08d-4c98-99d1-2a3249c960fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomKSAT", "[", 
   RowBox[{"k_", ",", "Nvars_", ",", "Mclauses_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vars", ",", "Flip"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vars", "=", 
      RowBox[{"StandardVariables", "[", "Nvars", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Flip", "[", "var_", "]"}], ":=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"RandomChoice", "[", 
         RowBox[{"{", 
          RowBox[{"True", ",", "False"}], "}"}], "]"}], ",", "var", ",", 
        RowBox[{"Not", "[", "var", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"And", " ", "@@", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Or", "@@", 
         RowBox[{"(", 
          RowBox[{"Flip", "/@", " ", 
           RowBox[{"RandomSample", "[", 
            RowBox[{"vars", ",", "k"}], "]"}]}], ")"}]}], ",", 
        RowBox[{"{", "Mclauses", "}"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.680533794409507*^9, 3.680533798560493*^9}, {
  3.766079834166976*^9, 3.7660798588140783`*^9}, {3.766080013680538*^9, 
  3.766080102131113*^9}, {3.766080549257215*^9, 3.766080550768347*^9}, {
  3.773365235020603*^9, 3.7733652744597273`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"a2747571-2ed4-4475-9648-971a4bfe6c4b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomKSAT", "[", 
  RowBox[{"3", ",", "10", ",", "20"}], "]"}]], "Input",
 CellLabel->
  "In[548]:=",ExpressionUUID->"b50b5c1d-f6bc-4ab1-bdb2-94f741859237"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x04"}], "||", 
    RowBox[{"!", "x08"}], "||", 
    RowBox[{"!", "x10"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x01"}], "||", "x02", "||", 
    RowBox[{"!", "x08"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"x05", "||", 
    RowBox[{"!", "x03"}], "||", 
    RowBox[{"!", "x07"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x10"}], "||", 
    RowBox[{"!", "x03"}], "||", 
    RowBox[{"!", "x06"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x02"}], "||", "x05", "||", "x04"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x08"}], "||", 
    RowBox[{"!", "x05"}], "||", 
    RowBox[{"!", "x10"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"x08", "||", "x07", "||", "x06"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x09"}], "||", 
    RowBox[{"!", "x08"}], "||", 
    RowBox[{"!", "x01"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x03"}], "||", "x07", "||", 
    RowBox[{"!", "x08"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"x03", "||", "x09", "||", "x10"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"x01", "||", 
    RowBox[{"!", "x09"}], "||", "x06"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x10"}], "||", "x07", "||", 
    RowBox[{"!", "x09"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x06"}], "||", 
    RowBox[{"!", "x07"}], "||", 
    RowBox[{"!", "x08"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x01"}], "||", "x07", "||", 
    RowBox[{"!", "x10"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"x03", "||", 
    RowBox[{"!", "x09"}], "||", 
    RowBox[{"!", "x05"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"x04", "||", 
    RowBox[{"!", "x07"}], "||", "x01"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"x09", "||", 
    RowBox[{"!", "x05"}], "||", "x06"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"x01", "||", "x05", "||", "x06"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"x02", "||", "x07", "||", "x03"}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x04"}], "||", 
    RowBox[{"!", "x06"}], "||", 
    RowBox[{"!", "x01"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.773365299722972*^9},
 CellLabel->
  "Out[548]=",ExpressionUUID->"772ad7b3-bf01-4e9c-b6ac-aafbf60713eb"]
}, Open  ]],

Cell["\<\
Because like WalkSAT, the WalkSATCRN will not halt if the the formula is not \
satisfiable, we test it only on verified satisfiable random formulas.   Since \
we may want to test different CRNs and different rate constants on the same \
problems, we first generate a set of \[OpenCurlyDoubleQuote]safe\
\[CloseCurlyDoubleQuote] test expressions, make a note of how long \
Mathematica took to solve them, and save them to a file.   Mathematica may \
take days to solve hard 500-variable problems, during which time your laptop \
might crash, so we incrementally write the test cases as soon as they are \
solved.  The timing is wall-clock time, so be sure there are no competing \
processes that will slow down the code.\
\>", "Text",
 CellChangeTimes->{{3.680820680163741*^9, 3.680820784067107*^9}, {
   3.766078040347226*^9, 3.7660780988811283`*^9}, {3.7660790669476423`*^9, 
   3.766079098754188*^9}, {3.766079137719144*^9, 3.766079212305265*^9}, {
   3.766079474534441*^9, 3.7660795533011637`*^9}, {3.766079591790983*^9, 
   3.766079621365512*^9}, {3.766079705294653*^9, 3.766079723595962*^9}, {
   3.766079777206427*^9, 3.766079827922763*^9}, {3.7660798625820017`*^9, 
   3.766079986092773*^9}, {3.766080163887148*^9, 3.766080265115068*^9}, {
   3.76608031696035*^9, 3.7660803203759813`*^9}, {3.766080413154846*^9, 
   3.7660804159297867`*^9}, {3.7660804494746017`*^9, 3.76608053852421*^9}, {
   3.77336492170162*^9, 3.773365086262064*^9}, {3.7733651275692883`*^9, 
   3.773365215038601*^9}, {3.7733653604790154`*^9, 3.773365410155324*^9}, {
   3.773366186314693*^9, 3.773366276569304*^9}, 3.773366476605577*^9, {
   3.77336650808703*^9, 3.7733666098903437`*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"d8320302-cb5c-4991-8e97-44d0446f4fb0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindSATProblems", "[", 
   RowBox[{
   "k_", ",", "Nvars_", ",", "Mclauses_", ",", "iters_", ",", "filename_"}], 
   "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"expr", ",", "satq", ",", "tMma", ",", 
      RowBox[{"numfound", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"numfound", "<", "iters"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"expr", "=", 
        RowBox[{"RandomKSAT", "[", 
         RowBox[{"k", ",", "Nvars", ",", "Mclauses"}], "]"}]}], " ", ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"tMma", ",", "satq"}], "}"}], "=", 
        RowBox[{"Timing", "[", 
         RowBox[{"SatisfiableQ", "[", 
          RowBox[{"expr", ",", 
           RowBox[{"BooleanVariables", "[", "expr", "]"}]}], "]"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{"satq", ",", 
         RowBox[{
          RowBox[{"Save", "[", 
           RowBox[{"filename", ",", 
            RowBox[{"{", 
             RowBox[{"tMma", ",", "expr"}], "}"}]}], "]"}], ";", " ", 
          RowBox[{"PrintTemporary", "[", 
           RowBox[{"DateString", "[", "]"}], "]"}], ";", 
          RowBox[{"numfound", "++"}]}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.682604104077248*^9, 3.6826041409107*^9}, {
  3.682604173924263*^9, 3.6826042379652443`*^9}, {3.682604535680069*^9, 
  3.682604548887187*^9}, {3.682604579194419*^9, 3.6826046268455*^9}, {
  3.682604708928042*^9, 3.682604805559499*^9}, {3.682604848468966*^9, 
  3.682605069692271*^9}, {3.683246516628952*^9, 3.683246593296185*^9}, {
  3.683246627107395*^9, 3.683246681213175*^9}, {3.683246981910981*^9, 
  3.68324700909265*^9}, {3.6832470525425463`*^9, 3.683247079341708*^9}, {
  3.683247465707466*^9, 3.683247482324741*^9}, {3.683247555248176*^9, 
  3.683247557646367*^9}, {3.683247864724969*^9, 3.683247867899873*^9}, {
  3.771962545887137*^9, 3.771962555743325*^9}, {3.773366288601128*^9, 
  3.773366305701185*^9}, {3.7733666699409847`*^9, 3.7733667660785627`*^9}, {
  3.7733668345028276`*^9, 3.773366836854804*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"e23bf3df-62f9-414b-bd7c-71c81cd77ce9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ReadSATData", "[", "filename_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"filein", ",", "fileout", ",", "line", ",", "tests", ",", 
      RowBox[{"n", "=", "1"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"tMmaTEMP", ",", "exprTEMP"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"filein", "=", 
      RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"fileout", "=", 
      RowBox[{"OpenWrite", "[", 
       RowBox[{"filename", "<>", "\"\<_TEMP\>\""}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{"True", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"line", "=", 
         RowBox[{"Read", "[", 
          RowBox[{"filein", ",", "String"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"line", "===", "EndOfFile"}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"StringMatchQ", "[", 
           RowBox[{"line", ",", "\"\<tMma*\>\""}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"line", "=", 
           RowBox[{"StringReplace", "[", 
            RowBox[{"line", ",", 
             RowBox[{
              RowBox[{
              "\"\<tMma$\>\"", " ", "~~", "NumberString", "~~", " ", 
               "\"\< =\>\""}], " ", "\[Rule]", " ", 
              RowBox[{"\"\<tMmaTEMP[\>\"", "<>", 
               RowBox[{"ToString", "[", "n", "]"}], "<>", "\"\<] =\>\""}]}]}],
             "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"StringMatchQ", "[", 
           RowBox[{"line", ",", "\"\<expr*\>\""}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"line", "=", 
            RowBox[{"StringReplace", "[", 
             RowBox[{"line", ",", 
              RowBox[{
               RowBox[{
               "\"\<expr$\>\"", " ", "~~", "NumberString", "~~", " ", 
                "\"\< =\>\""}], " ", "\[Rule]", " ", 
               RowBox[{"\"\<exprTEMP[\>\"", "<>", 
                RowBox[{"ToString", "[", "n", "]"}], "<>", 
                "\"\<] =\>\""}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"n", "=", 
            RowBox[{"n", "+", "1"}]}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"WriteLine", "[", 
         RowBox[{"fileout", ",", "line"}], "]"}]}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Close", "[", "filein", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Close", "[", "fileout", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"n", "=", 
      RowBox[{"n", "-", "1"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Get", "[", 
      RowBox[{"filename", "<>", "\"\<_TEMP\>\""}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tests", " ", "=", " ", 
      RowBox[{"MapThread", "[", 
       RowBox[{"List", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tMmaTEMP", "/@", 
           RowBox[{"Range", "[", 
            RowBox[{"1", ",", "n"}], "]"}]}], ",", 
          RowBox[{"exprTEMP", "/@", 
           RowBox[{"Range", "[", 
            RowBox[{"1", ",", "n"}], "]"}]}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"DeleteFile", "[", 
      RowBox[{"filename", "<>", "\"\<_TEMP\>\""}], "]"}], ";", 
     "\[IndentingNewLine]", "tests"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.68326098230669*^9, 3.683261055023877*^9}, {
  3.6832611392774563`*^9, 3.683261153677475*^9}, {3.6832612817184973`*^9, 
  3.6832613137257967`*^9}, {3.6832614307714043`*^9, 3.6832615197132883`*^9}, {
  3.683261571583208*^9, 3.683261588070763*^9}, {3.683261620532275*^9, 
  3.683261633258789*^9}, {3.683261818586093*^9, 3.683261836295718*^9}, {
  3.6832619714331417`*^9, 3.6832620207947073`*^9}, {3.683262079610721*^9, 
  3.68326219922616*^9}, {3.683262292818307*^9, 3.683262351461492*^9}, {
  3.683262437794849*^9, 3.6832624501301823`*^9}, {3.6832625567848883`*^9, 
  3.6832626018200693`*^9}, {3.683262632268635*^9, 3.683262776516027*^9}, {
  3.683263085828115*^9, 3.683263090747484*^9}, {3.6832633911570797`*^9, 
  3.683263394005226*^9}, {3.683263710763249*^9, 3.68326371180168*^9}, {
  3.6832637622964*^9, 3.683263765454905*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"9d7be80d-de35-4dfb-96f8-d404381a67a2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindSATProblems", "[", 
   RowBox[{
   "3", ",", "50", ",", "210", ",", "100", ",", 
    "\"\<findSATdata50_test\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.7733669620495853`*^9, 3.773366978346509*^9}},
 CellLabel->
  "In[558]:=",ExpressionUUID->"417e2b52-294b-4496-b5b4-448089c4ff78"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindSATProblems", "[", 
   RowBox[{
   "3", ",", "100", ",", "420", ",", "100", ",", 
    "\"\<findSATdata100_test\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.7733669974509068`*^9, 3.773367005528079*^9}},
 CellLabel->
  "In[559]:=",ExpressionUUID->"c58b9bd7-1fd4-44dd-a634-ca612d8708e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindSATProblems", "[", 
   RowBox[{
   "3", ",", "200", ",", "840", ",", "100", ",", 
    "\"\<findSATdata200_test\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.773367022867634*^9, 3.773367029991683*^9}},
 CellLabel->
  "In[560]:=",ExpressionUUID->"5ed1c86b-2f44-428a-aa61-1c30f945f7bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindSATProblems", "[", 
   RowBox[{
   "3", ",", "300", ",", "1260", ",", "100", ",", 
    "\"\<findSATdata300_test\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.7733670684840603`*^9, 
  3.773367093700571*^9}},ExpressionUUID->"7f1b6e0b-c99d-4122-9c6e-\
c0d91b46326c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindSATProblems", "[", 
   RowBox[{
   "3", ",", "400", ",", "1680", ",", "100", ",", 
    "\"\<findSATdata400_test\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.7733670707230988`*^9, 
  3.773367095673514*^9}},ExpressionUUID->"377c020c-0bfa-42e7-8b1f-\
530bc86e760b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindSATProblems", "[", 
   RowBox[{
   "3", ",", "500", ",", "2100", ",", "100", ",", 
    "\"\<findSATdata500_test\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.7733671010190363`*^9, 
  3.773367107115197*^9}},ExpressionUUID->"5a5caf80-a65f-4eaa-b7e6-\
9456da15b77a"],

Cell["\<\
You might not want to run the above code to find satisfiable 3SAT instances.  \
We\[CloseCurlyQuote]ve run it, so you can just load the included files in \
this directory.  (Note that for large N, it can be VERY slow, so I ran it in \
parallel on multiple machines over many days and collected results from those \
that happened to finish... this introduces the possibility that the problems \
we found were biased toward those that are easier for Mathematica to solve.  \
That\[CloseCurlyQuote]s OK by me.)\
\>", "Text",
 CellChangeTimes->{{3.7734544945047283`*^9, 3.773454523012648*^9}, {
  3.7734546353100863`*^9, 3.773454641026163*^9}, {3.773495359839964*^9, 
  3.773495415721994*^9}, {3.773496376174018*^9, 3.773496450348591*^9}, {
  3.77367487034376*^9, 3.773674874373747*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"d7c95c24-0236-474e-b7c4-5d04ef4df6e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"safetests50", "=", 
   RowBox[{"ReadSATData", "[", "\"\<findSATdata50_test\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.773367112014225*^9, 3.773367130855165*^9}, {
  3.7733671640716248`*^9, 3.773367185573641*^9}, {3.773367328747211*^9, 
  3.773367329444357*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"8760279b-62f3-41e8-a83c-4b9f63be7283"],

Cell[BoxData[
 RowBox[{
  RowBox[{"safetests100", "=", 
   RowBox[{"ReadSATData", "[", "\"\<findSATdata100_test\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.773367112014225*^9, 3.773367130855165*^9}, {
  3.7733671640716248`*^9, 3.773367185573641*^9}, {3.773367332971377*^9, 
  3.773367335679192*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"33ef9358-1cf9-41d4-ae75-c40a67a58d42"],

Cell[BoxData[
 RowBox[{
  RowBox[{"safetests200", "=", 
   RowBox[{"ReadSATData", "[", "\"\<findSATdata200_test\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.773367112014225*^9, 3.773367130855165*^9}, {
  3.7733671640716248`*^9, 3.773367185573641*^9}, {3.773367340542495*^9, 
  3.773367344862096*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"4ffb4414-c3e5-4f35-b2cc-7dc03733d22d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"safetests300", "=", 
   RowBox[{"ReadSATData", "[", "\"\<findSATdata300_test\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.773367112014225*^9, 3.773367130855165*^9}, {
  3.7733671640716248`*^9, 3.773367185573641*^9}, {3.773367349618084*^9, 
  3.773367352700921*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"3c26f50d-4664-4ac7-b271-d3ea25e9a7bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"safetests400", "=", 
   RowBox[{"ReadSATData", "[", "\"\<findSATdata400_test\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.773367112014225*^9, 3.773367130855165*^9}, {
  3.7733671640716248`*^9, 3.773367185573641*^9}, {3.7733673560577393`*^9, 
  3.773367363842046*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"1ae9f80f-179b-43c0-a3fc-9419e368c7c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"safetests500", "=", 
   RowBox[{"ReadSATData", "[", "\"\<findSATdata500_test\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.773367112014225*^9, 3.773367130855165*^9}, {
  3.7733671640716248`*^9, 3.773367185573641*^9}, {3.7733673560577393`*^9, 
  3.773367366334367*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"877c4669-132f-4a0e-b893-588152062e1a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "/@", 
  RowBox[{"{", 
   RowBox[{
   "safetests50", ",", "safetests100", ",", "safetests200", ",", 
    "safetests300", ",", "safetests400", ",", "safetests500"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.773454285950274*^9, 3.7734543088821507`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"b2403e53-80ff-451c-b25b-cc8476f72f66"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"100", ",", "100", ",", "100", ",", "100", ",", "100", ",", "100"}],
   "}"}]], "Output",
 CellChangeTimes->{3.7734543096544228`*^9, 3.773454364684824*^9, 
  3.773454440931424*^9, 3.773499115822939*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"4b817a55-91c9-4379-98ba-d47deacd2eb7"]
}, Open  ]],

Cell["\<\
To collect the timing for simulating the SAT-solving CRN, we don\
\[CloseCurlyQuote]t want to include the time the SSA simulator takes to \
pre-process the CRN into a convenient format -- this can take a several \
seconds because it uses non-optimized symbolic code.  We time only the part \
that actually involves running the SSA algorithm to simulate reaction events \
in the CRN.\
\>", "Text",
 CellChangeTimes->{{3.680820680163741*^9, 3.680820784067107*^9}, {
   3.766078040347226*^9, 3.7660780988811283`*^9}, {3.7660790669476423`*^9, 
   3.766079098754188*^9}, {3.766079137719144*^9, 3.766079212305265*^9}, {
   3.766079474534441*^9, 3.7660795533011637`*^9}, {3.766079591790983*^9, 
   3.766079621365512*^9}, {3.766079705294653*^9, 3.766079723595962*^9}, {
   3.766079777206427*^9, 3.766079827922763*^9}, {3.7660798625820017`*^9, 
   3.766079986092773*^9}, {3.766080163887148*^9, 3.766080265115068*^9}, {
   3.76608031696035*^9, 3.7660803203759813`*^9}, {3.766080413154846*^9, 
   3.7660804159297867`*^9}, {3.7660804494746017`*^9, 3.76608053852421*^9}, {
   3.77336492170162*^9, 3.773365086262064*^9}, {3.7733651275692883`*^9, 
   3.773365215038601*^9}, {3.7733653604790154`*^9, 3.773365410155324*^9}, {
   3.773366186314693*^9, 3.773366276569304*^9}, 3.773366476605577*^9, {
   3.77336650808703*^9, 3.7733666098903437`*^9}, {3.773367501724395*^9, 
   3.7733675073851433`*^9}, {3.7733680209195004`*^9, 3.773368183207665*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"677a1458-55ec-4598-b274-255938c5a5a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TimeWalkSATCRN", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"slow_:", "0.1"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "crn", ",", "rsys", ",", "realtime", ",", "times", ",", "data", ",", 
      "finishconcs", ",", "results"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"crn", "=", 
      RowBox[{"WalkSATCRN", "[", 
       RowBox[{"expr", ",", "slow"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rsys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"crn", ",", 
        RowBox[{"DualRailInitialState", "[", "crn", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rsys", "=", 
      RowBox[{"CompiledRxnsysSSA", "[", "rsys", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"realtime", ",", 
        RowBox[{"{", 
         RowBox[{"times", ",", "data"}], "}"}]}], "}"}], "=", 
      RowBox[{"Timing", "[", 
       RowBox[{"SimulateRxnsysSSA", "[", 
        RowBox[{"rsys", ",", "Infinity", ",", 
         RowBox[{"Output", "\[Rule]", "\"\<State\>\""}]}], "]"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"finishconcs", "=", 
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}], ",", 
          RowBox[{"Last", "[", "data", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"results", "=", " ", 
      RowBox[{
       RowBox[{"Cases", "[", 
        RowBox[{"finishconcs", ",", 
         RowBox[{
          RowBox[{"conc", "[", 
           RowBox[{
            RowBox[{"s_", "[", "t_", "]"}], ",", 
            RowBox[{"_", "?", "Positive"}]}], "]"}], "\[RuleDelayed]", 
          RowBox[{"(", 
           RowBox[{"s", "\[Rule]", "t"}], ")"}]}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0", "\[Rule]", "False"}], ",", 
         RowBox[{"1", "\[Rule]", "True"}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"realtime", ",", "results"}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.68021565999244*^9, 3.680215750241291*^9}, {
   3.6802158052863903`*^9, 3.6802158385740547`*^9}, {3.773136058908334*^9, 
   3.773136129428895*^9}, {3.773136200951747*^9, 3.773136220896125*^9}, {
   3.7731367033385553`*^9, 3.773136728021192*^9}, {3.773136827472237*^9, 
   3.773136847838519*^9}, {3.7731378382659616`*^9, 3.773137844146751*^9}, {
   3.7731378785932217`*^9, 3.773137886692079*^9}, {3.773137999129963*^9, 
   3.773138017053162*^9}, {3.773139783824836*^9, 3.7731397890753393`*^9}, {
   3.773139890729321*^9, 3.773139903448102*^9}, {3.773280197937496*^9, 
   3.773280211920089*^9}, {3.7733453849612217`*^9, 3.7733453892668533`*^9}, {
   3.77334751343707*^9, 3.773347545687004*^9}, {3.773347847280039*^9, 
   3.773347866100006*^9}, {3.773347945836709*^9, 3.773347952150361*^9}, 
   3.77334825368139*^9, {3.773362734420347*^9, 3.773362753224311*^9}, {
   3.773367483122933*^9, 3.7733674839454393`*^9}, {3.773367552213456*^9, 
   3.773367682201851*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"f65b9b59-e440-45b6-8697-53c43c71575f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FoundWalkSATCRN", "[", 
   RowBox[{"testinfo_", ",", 
    RowBox[{"slow_:", "0.1"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"expr", ",", "assign", ",", "tMma", ",", "tCRN", ",", "times"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"times", "=", 
      RowBox[{"Table", "[", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"the", " ", "CRN", " ", "simulator", " ", 
          RowBox[{"can", "'"}], "t", " ", "be", " ", "run", " ", "on", " ", 
          "parallel", " ", "kernels"}], ",", " ", 
         RowBox[{"not", " ", "sure", " ", "why"}]}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"tMma", ",", "expr"}], "}"}], " ", "=", " ", "exprdata"}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"tCRN", ",", "assign"}], "}"}], " ", "=", " ", 
          RowBox[{"TimeWalkSATCRN", "[", 
           RowBox[{"expr", ",", "slow"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", " ", 
          RowBox[{
           RowBox[{"expr", " ", "/.", " ", "assign"}], ",", " ", 
           "\[IndentingNewLine]", 
           RowBox[{"PrintTemporary", "[", 
            RowBox[{
            "\"\<Solved! \>\"", ",", " ", "tCRN", ",", " ", 
             "\"\< (CRN) vs \>\"", ",", "tMma", ",", " ", 
             "\"\< (Mathematica)\>\""}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{
           "Print", "[", "\"\<WARNING: CRN SAT solver failed!\>\"", "]"}]}], 
          " ", "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"tMma", ",", "tCRN"}], "}"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"exprdata", ",", "testinfo"}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
     "times"}]}], "\[IndentingNewLine]", "]"}], " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->CompressedData["
1:eJwdyjlIwnEAxXFpig6Dlk4hoRoqHBoaXPTfIU3RKWFDUdhhQYiaZhaBUmQH
VDQoBhWWRYcgaWhSYBcFlZRIQYfaYaURSEST9XsOj8/wvszW3lphHI1GyyaD
NnPKmLI7RL2svmmh3s3ehB4qYoYZp0d2+GXIP4d3zNcrmLUrDkBBV3XZAHpT
gQBuy11CaDkc7IB0TRrHTaxnM7iwaN7K8hM/JJxiuGMTJQaI300zMRX2oPOJ
SHOY9uDxSPrJvThE3WwtvMLc9RW+JDNMdbrWY26UB12wpfDyAD6qnI1SYp6Z
J4DRyG8zTAoLhNAnrxLB6sr3EaibV+nh+1rdEvxs45sg669mDe43eI5kRK2a
54PcaUNyHzFdeUuHw+qoQU6cCo8aoXFSfgZfdG4/LC2pjUDvkDTmxOx1goK4
bO5Phrao88KE38Hwwp/Eqgcok/Y8Q7qmdTyHEaYUcxVTsD1+0QJT9zxW+A+l
C+g9
  "],
 CellLabel->"In[30]:=",ExpressionUUID->"26d926c8-9d35-4bbb-ae5d-c709a8011f8f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"timing50", "=", 
   RowBox[{"FoundWalkSATCRN", "[", "safetests50", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Save", "[", 
   RowBox[{"\"\<WalkSATCRNtiming\>\"", ",", "timing50"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.773367799500793*^9, 3.773367821990096*^9}, {
  3.773454737077519*^9, 
  3.773454737290598*^9}},ExpressionUUID->"6be57fbc-d6d9-4a2b-a1a8-\
a4389773ab7d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"timing100", "=", 
   RowBox[{"FoundWalkSATCRN", "[", "safetests100", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Save", "[", 
   RowBox[{"\"\<WalkSATCRNtiming\>\"", ",", "timing100"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.773406705812481*^9, 3.773406709242016*^9}, {
  3.77345475856236*^9, 
  3.773454758774876*^9}},ExpressionUUID->"686c4a7d-5b00-4be3-96cd-\
b83f76b0900a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"timing200", "=", 
   RowBox[{"FoundWalkSATCRN", "[", "safetests200", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Save", "[", 
   RowBox[{"\"\<WalkSATCRNtiming\>\"", ",", "timing200"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.773406705812481*^9, 3.773406709242016*^9}, {
  3.773454763520028*^9, 3.773454770586289*^9}},
 CellLabel->
  "In[580]:=",ExpressionUUID->"bdaf8477-30b1-4e2f-b4d0-98ffdd72fde4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"timing300", "=", 
   RowBox[{"FoundWalkSATCRN", "[", "safetests300", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Save", "[", 
   RowBox[{"\"\<WalkSATCRNtiming\>\"", ",", "timing300"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.773454720515787*^9, 3.7734547564756727`*^9}, {
  3.773455359705789*^9, 3.773455368350114*^9}},
 CellLabel->
  "In[582]:=",ExpressionUUID->"82f1cf82-a8c6-4d5e-ba91-2462f442c65e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"timing400", "=", 
   RowBox[{"FoundWalkSATCRN", "[", "safetests400", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Save", "[", 
   RowBox[{"\"\<WalkSATCRNtiming\>\"", ",", "timing400"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.773406705812481*^9, 3.773406709242016*^9}, {
  3.773454763520028*^9, 3.773454770586289*^9}, {3.773455370557043*^9, 
  3.773455381708206*^9}},
 CellLabel->
  "In[584]:=",ExpressionUUID->"c1297778-580a-40a1-b165-417d9f75940c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"timing500", "=", 
   RowBox[{"FoundWalkSATCRN", "[", "safetests500", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Save", "[", 
   RowBox[{"\"\<WalkSATCRNtiming\>\"", ",", "timing500"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.773406705812481*^9, 3.773406709242016*^9}, {
  3.773454763520028*^9, 3.773454770586289*^9}, {3.773455375034639*^9, 
  3.77345537944322*^9}},
 CellLabel->
  "In[586]:=",ExpressionUUID->"1b702f6b-faf9-4c26-9705-ca7ca3d42377"],

Cell["\<\
It\[CloseCurlyQuote]ll take about half a day to run the above, so just load \
the saved values.\
\>", "Text",
 CellChangeTimes->{{3.7734544945047283`*^9, 3.773454523012648*^9}, {
  3.7734546353100863`*^9, 3.773454641026163*^9}, {3.773495359839964*^9, 
  3.773495415721994*^9}, {3.773496376174018*^9, 3.773496450348591*^9}, {
  3.773498470465448*^9, 3.773498498374516*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"0f8e94f1-5e27-4d5c-91a6-2f8a47ed30c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Get", "[", "\"\<WalkSATCRNtiming\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.771985960653356*^9, 3.771985972664722*^9}, {
  3.7734066611223*^9, 3.773406668914671*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"4e72bcf3-5937-44ff-9ff4-2333abb4d999"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "/@", 
  RowBox[{"{", 
   RowBox[{
   "timing50", ",", "timing100", ",", "timing200", ",", "timing300", ",", 
    "timing400", ",", "timing500"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7734554146471453`*^9, 3.773455416437297*^9}, {
  3.773498406092526*^9, 3.773498423215047*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"c8d57421-97b8-4d82-8472-5f30e6baaa44"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"100", ",", "100", ",", "100", ",", "100", ",", "100", ",", "100"}],
   "}"}]], "Output",
 CellChangeTimes->{3.773498424314514*^9, 3.773499129480445*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"bfe4cc13-b50d-490b-baaf-d2ae9156df55"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fulldata", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Min", "[", 
            RowBox[{
             RowBox[{"Length", "[", "#", "]"}], ",", "100"}], "]"}]}], "]"}], 
         "&"}], "/@", 
        RowBox[{"{", 
         RowBox[{
         "timing50", ",", "timing100", ",", "timing200", ",", "timing300", 
          ",", "timing400", ",", "timing500"}], "}"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"fullnames", "=", 
       RowBox[{"{", 
        RowBox[{
        "\"\<50\>\"", ",", "\"\<100\>\"", ",", "\"\<200\>\"", ",", 
         "\"\<300\>\"", ",", "\"\<400\>\"", ",", "\"\<500\>\""}], "}"}]}]}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"data", "=", 
         RowBox[{"Mean", " ", "/@", " ", 
          RowBox[{"Log10", "[", "fulldata", "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"errors", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"StandardDeviation", " ", "/@", " ", 
            RowBox[{"Log10", "[", "fulldata", "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"Sqrt", "/@", 
            RowBox[{"Length", "/@", "fulldata"}]}], ")"}]}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"labels", "=", 
           RowBox[{"MapThread", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Text", "[", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{"#1", ",", "20", ",", "Bold"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"#2", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], ",", 
                  RowBox[{
                   RowBox[{"#2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "+", "0.25"}]}], "}"}]}], 
               "]"}], "&"}], ",", 
             RowBox[{"{", 
              RowBox[{"fullnames", ",", "data"}], "}"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"errordata", "=", 
           RowBox[{"MapThread", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"#2", ",", 
                RowBox[{"ErrorBar", "@@", "#1"}]}], "}"}], "&"}], ",", 
             RowBox[{"{", 
              RowBox[{"errors", ",", "data"}], "}"}]}], "]"}]}]}], 
         "\[IndentingNewLine]", "}"}], ",", 
        RowBox[{"Show", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<Averages of log-times: \>\"", ",", "data"}], "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<Averages of times: \>\"", ",", 
             RowBox[{"Mean", "/@", "fulldata"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"Log10", " ", "/@", " ", "fulldata"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "3.5"}], ",", "5.5"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1.5"}], ",", "3.5"}], "}"}]}], "}"}]}], ",", 
             RowBox[{"Frame", "\[Rule]", "True"}], ",", 
             RowBox[{"FrameTicksStyle", "\[Rule]", "20"}], ",", 
             RowBox[{"FrameLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                   "\"\<CRN time (log seconds)\>\"", ",", "20", ",", "Bold"}],
                    "]"}], ",", "\"\<\>\""}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                   "\"\<Mathematica time (log seconds)\>\"", ",", "20", ",", 
                    "Bold"}], "]"}], ",", 
                  RowBox[{"Style", "[", 
                   RowBox[{
                   "\"\<Solving 3SAT on random N-variable problems (100 for \
each N)\>\"", ",", "20", ",", "Bold"}], "]"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"ErrorListPlot", "[", 
           RowBox[{"errordata", ",", 
            RowBox[{"Joined", "\[Rule]", "True"}], ",", 
            RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
            RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Thick"}], "}"}]}], ",", 
            RowBox[{"PlotRangeClipping", "\[Rule]", "False"}], ",", " ", 
            RowBox[{"PlotRange", "\[Rule]", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "3.5"}], ",", "5.5"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1.5"}], ",", "3.5"}], "}"}]}], "}"}]}]}], 
           "]"}], ",", " ", "\[IndentingNewLine]", 
          RowBox[{"ListLinePlot", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1.5"}], ",", 
                RowBox[{"-", "1.5"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"3.5", ",", "3.5"}], "}"}]}], "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", "Dashed"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Graphics", "[", "labels", "]"}]}], "\[IndentingNewLine]", 
         "]"}]}], "]"}]}], "]"}]}], "]"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.68056710630836*^9, 3.680567107453302*^9}, {
   3.680567595574855*^9, 3.6805676064575157`*^9}, {3.680568811192284*^9, 
   3.6805688497550592`*^9}, {3.682881633911653*^9, 3.682881646894114*^9}, {
   3.683591494487957*^9, 3.683591629311653*^9}, {3.683591666774778*^9, 
   3.683591703082757*^9}, {3.6835918472165203`*^9, 3.683591850693227*^9}, {
   3.683591899889123*^9, 3.683591937330978*^9}, {3.683591974091873*^9, 
   3.683592066806638*^9}, {3.683592104842822*^9, 3.683592112778263*^9}, {
   3.683601356814857*^9, 3.683601370359737*^9}, {3.683601415570168*^9, 
   3.683601456385277*^9}, {3.771987468484762*^9, 3.7719874696280193`*^9}, {
   3.771987500382358*^9, 3.771987514614719*^9}, {3.7719876638915873`*^9, 
   3.771987683305272*^9}, {3.771987763396648*^9, 3.771987770754487*^9}, {
   3.7720741189192533`*^9, 3.77207412978272*^9}, {3.7720742204026833`*^9, 
   3.772074223249403*^9}, {3.772074407568828*^9, 3.772074454548636*^9}, {
   3.772074509759321*^9, 3.77207451834414*^9}, {3.772074728902235*^9, 
   3.772074747394944*^9}, {3.772074791629877*^9, 3.772074804545965*^9}, {
   3.772074834688435*^9, 3.7720748367003317`*^9}, 3.772074884210944*^9, {
   3.772081742875765*^9, 3.7720817458192987`*^9}, {3.772106795753067*^9, 
   3.77210683743261*^9}, {3.772106882481295*^9, 3.772106891560787*^9}, {
   3.77212655001964*^9, 3.772126555035597*^9}, {3.772129137530509*^9, 
   3.7721291412012453`*^9}, {3.7734973377878923`*^9, 3.773497400929796*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"093c1b16-59fd-4cc2-8e59-9ad350b21714"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Averages of log-times: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3.291802530762224`"}], ",", 
       RowBox[{"-", "0.908673474427846`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2.7720013300229622`"}], ",", 
       RowBox[{"-", "0.3040720281624273`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1.5478448224949155`"}], ",", "0.49605268863561136`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.22579613200853457`", ",", "1.1000047036054326`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"1.7615612374698841`", ",", "1.2642006617484092`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.174705414069584`", ",", "1.5712222666847953`"}], "}"}]}], 
    "}"}]}],
  SequenceForm[
  "Averages of log-times: ", {{-3.291802530762224, -0.908673474427846}, \
{-2.7720013300229622`, -0.3040720281624273}, {-1.5478448224949155`, 
   0.49605268863561136`}, {0.22579613200853457`, 1.1000047036054326`}, {
   1.7615612374698841`, 1.2642006617484092`}, {3.174705414069584, 
   1.5712222666847953`}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.773498506220503*^9, 3.7734985726313972`*^9, 
  3.773499134653819*^9},
 CellLabel->
  "During evaluation of \
In[44]:=",ExpressionUUID->"4ef890c1-bd82-4032-a83c-6b0a15b02010"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Averages of times: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.0005275199999999997`", ",", "0.19378921999999998`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.001839849999999999`", ",", "1.1017502400000005`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.04809466999999997`", ",", "9.49641866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.128226679999998`", ",", "46.92864876000002`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200.48527520999997`", ",", "87.62002580000001`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"8663.266689170001`", ",", "235.74257339000005`"}], "}"}]}], 
    "}"}]}],
  SequenceForm[
  "Averages of times: ", {{0.0005275199999999997, 0.19378921999999998`}, {
   0.001839849999999999, 1.1017502400000005`}, {0.04809466999999997, 
   9.49641866}, {4.128226679999998, 46.92864876000002}, {200.48527520999997`, 
   87.62002580000001}, {8663.266689170001, 235.74257339000005`}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.773498506220503*^9, 3.7734985726313972`*^9, 
  3.7734991346600037`*^9},
 CellLabel->
  "During evaluation of \
In[44]:=",ExpressionUUID->"b860e44b-cd77-482e-82dd-83131b766112"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{}, {{
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6], 
       PointBox[CompressedData["
1:eJxFlHs8lFkYx0m18553VSOyEUW1Ra6ly6oxpBSKSSkhm0JbKlm3lFRKqUhE
CFF0QReKXJLnSbooKZdiigzjtiQzY0bRxdp/3v3jfM5f55zv8/y+z9Ha5uPg
OUZOTs5jdP238wkKeZUUTnLV1gt6LAKTtMgv9x0p9C4NSvGOG4TKQ7woUsjC
XHZBk1qOGMYIQlfr1hPccj+sm6MrAyphU/3fvgRfmLGDm1ZIgEoNGHv2DIU6
4hit8+YisF63+YR8IsFiT+cd6/2quJxL88wrD1HoV1Eco6CNcHGBQ0mdKQvZ
X7MG9WdLgcS+zJRfQFBfqUvH8kE3TA9QS5nzjaBy3bO4ciMxFGnnr7AVEAxX
S3I+Ht8G1B6PL5HTaQxHm7hhOyFMzREU9i1hoXPekfCM+mZQ4egkbjehcChG
L7qpqQ0Ged8jk/MJuqycrnSl4TNYjP106fNMGh1aHeLclWVwO9af/1OfYNCL
GRHBdr0gSLI8cOAAwRkfnjipmvXCi4eeitavKeQfc3siUpBBwf4NJm4aNAaE
HM7NThFD6OXpGGZGYYQO3XFSIIJaYUFFrjKN5/pbmp1eSsC84p1mLk3Q1F2+
IzxZzPCYKez1+FLUBxs741uTHWmcbFn4bqG9ANKX+7w2UqexsntLtDdXAgla
a9Jc5hBc+MNCOHukAXzfUiVWJwmW6jodIVZSmMplWQZmUDiGU7LPP7aE2yls
jop/xkLDw9PU2/XFwLq3KdyjlKDPtpkpDyvFcPTVk5L6X2iMSX30fNhfDHxt
r1kbMwjObX/baMmth+DNil+GeDT+9cagu8r1Myh/V9Qviabw8N2oYo3WcuBG
Z978NYCgKEnPpSi2Aw7tVPGTeRCM09iyj/3hI8N/MK3BRjv6PXDyTxu6jhD8
qTLpA7dVDL7G2WjwYpTHKrSgfe0A2C7arHnHjEaD0nPtu6bJYLwkythtDY26
Ooa+ZVP64OTaSGvncSxUFG6NuNrTD1/NJKZtUoKWRdZy2qJWJh+viaH5P3ld
sPJE/37ueBZy5qruVAsTg3uS4dISEcHTbhv7mhf2Q7VvWcy8KoK9nG8WxxLb
II9ymLrbffQ+d7uyGssBKJPwds9xJPjj1IO8ueV9zHlve8GNKYvEMP9W/3KL
HwQneS2K2+E5CBaKBi4P/iCY6h5frX5NwtRzqyz4n9ZTUqheuq52+UeC645b
qUhnSRk/Eo+2z7ArloK88qVxN++O+v/Ulv1xfQ9kjVy4lqNLMNqkiMue08rk
betTOKy6VcL0m7J7/DF6khS+/tDJ0rowytPp7x2R1QL8ZP7bpGMEl1V2sBtG
JFCnlV21bAKNEzSHprH8GuE+xZcMDrHQPCCqXP12Dzxbln6vaQ/BPjNH9eia
VxCc8tBOdJvCJ7yc7dxVnUy9lrsWO7q2iMDeKNk6PYDCvOYep/23+MBP1ztF
WCxM3L1hZoRtL3QW6F5e009h7rpDfoNP26BBpHRg9zIaK5ISpgRMbmfmx8Aq
pDYwRAaBPQaBR3kUsgPvOmmGSSBqluDI81U0hi6+0liuJQL3zDtxRo0EZ7bN
q5n45wA4Tnz0zKqcYD9/h0awjxAeKXFGVtdSeFaRvfH6jR64On/JvZMyCo3b
guIdiwfg/p6oEzrVBNkxmXszJ8ugW/E7x9GYYPJSLznZsBRsKtUv9C6msbqz
T++3fBmkWvv7CTMpfPO7atxW6wGGP6M2snKlvQRiKqgM25DR9yPIdonyIMO/
qpNUzVLth/qhn0/HTqVxr7FqlJbR//lr1FQrVJemc4dD8ng5djTWv4y9aCMv
gdDlQdv3y9No4XI239RfBCq7IhMeiVm4wvzyvYrHYrjbHd8ivEnw2vwE2eX1
daBzPn1rbBeF2WHzX8m/l4J2tnrN4ggWSq9vUhuY0MX8140Th99nu0gYP6iD
xxSqNVsY30zPZCnK3/7EzGfqJ+McQZqY4XnXGGj6wVnG+NQcpr5zbXsj/AvN
CD/t
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6], 
       PointBox[CompressedData["
1:eJw9lHs4lAkbxu2Y931nItWKhMjG55BtjAgT+9o2RQ5bDFYuJmdtDVtra3ej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        "]]}, 
      {RGBColor[0.560181, 0.691569, 0.194885], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6], 
       PointBox[CompressedData["
1:eJwV0vk/1IkfwPFxhb61yawtbX1VLGkytWYTkXeH9CWECovUKqlUPGixjiJy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        "]]}, 
      {RGBColor[0.922526, 0.385626, 0.209179], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6], 
       PointBox[CompressedData["
1:eJwVk308FHgCh8frLVtWJWRLm47CrTqVUHzHex8sbec2NiJ0llFpT+J6U0be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        "]]}, 
      {RGBColor[0.528488, 0.470624, 0.701351], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6], 
       PointBox[CompressedData["
1:eJwV0fdf03cewPGMbxJWkZVWEe6EMOq5oFKoCLw/QqCOoqJwUEVRA5UoEKUY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        "]]}, 
      {RGBColor[0.772079, 0.431554, 0.102387], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6], 
       PointBox[CompressedData["
1:eJwV0vs71IkewPExN4yZ+Y5LxZZyW0JIYqLs51OW6Koh6aAml0RntRRnW7k8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        "]]}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6]}, 
      {RGBColor[0.560181, 0.691569, 0.194885], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6]}, 
      {RGBColor[0.922526, 0.385626, 0.209179], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6]}, 
      {RGBColor[0.528488, 0.470624, 0.701351], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6]}, 
      {RGBColor[0.772079, 0.431554, 0.102387], PointSize[
       0.0055000000000000005`], AbsoluteThickness[
       1.6]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6]}, 
      {RGBColor[0.560181, 0.691569, 0.194885], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6]}, 
      {RGBColor[0.922526, 0.385626, 0.209179], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6]}, 
      {RGBColor[0.528488, 0.470624, 0.701351], PointSize[
       0.0055000000000000005`], AbsoluteThickness[1.6]}, 
      {RGBColor[0.772079, 0.431554, 0.102387], PointSize[
       0.0055000000000000005`], AbsoluteThickness[
       1.6]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}, {{}, {}}}, {{}, \
{{{}, {}, 
      {GrayLevel[0], PointSize[0.012833333333333334`], Thickness[Large], 
       LineBox[{{-3.291802530762224, -0.908673474427846}, \
{-2.7720013300229622`, -0.3040720281624273}, {-1.5478448224949155`, 
        0.49605268863561136`}, {0.22579613200853457`, 1.1000047036054326`}, {
        1.7615612374698841`, 1.2642006617484092`}, {3.174705414069584, 
        1.5712222666847953`}}], {{
         LineBox[{{-3.281178123198563, -0.908673474427846}, \
{-3.302426938325885, -0.908673474427846}}], 
         LineBox[{
          Offset[{0, 1.5}, {-3.281178123198563, -0.908673474427846}], 
           Offset[{0, -1.5}, {-3.281178123198563, -0.908673474427846}]}], 
         LineBox[{
          Offset[{0, 1.5}, {-3.302426938325885, -0.908673474427846}], 
           Offset[{0, -1.5}, {-3.302426938325885, -0.908673474427846}]}], 
         LineBox[{{-3.291802530762224, -0.8712130555888585}, \
{-3.291802530762224, -0.9461338932668334}}], 
         LineBox[{
          Offset[{1.5, 0}, {-3.291802530762224, -0.8712130555888585}], 
           Offset[{-1.5, 0}, {-3.291802530762224, -0.8712130555888585}]}], 
         LineBox[{
          Offset[{1.5, 0}, {-3.291802530762224, -0.9461338932668334}], 
           Offset[{-1.5, 0}, {-3.291802530762224, -0.9461338932668334}]}]}, {
         LineBox[{{-2.754092708203082, -0.3040720281624273}, \
{-2.7899099518428425`, -0.3040720281624273}}], 
         LineBox[{
          Offset[{0, 1.5}, {-2.754092708203082, -0.3040720281624273}], 
           Offset[{0, -1.5}, {-2.754092708203082, -0.3040720281624273}]}], 
         LineBox[{
          Offset[{0, 1.5}, {-2.7899099518428425`, -0.3040720281624273}], 
           Offset[{0, -1.5}, {-2.7899099518428425`, -0.3040720281624273}]}], 
         LineBox[{{-2.7720013300229622`, -0.25505679974102935`}, \
{-2.7720013300229622`, -0.3530872565838252}}], 
         LineBox[{
          Offset[{1.5, 0}, {-2.7720013300229622`, -0.25505679974102935`}], 
           Offset[{-1.5, 0}, {-2.7720013300229622`, -0.25505679974102935`}]}],
          LineBox[{
          Offset[{1.5, 0}, {-2.7720013300229622`, -0.3530872565838252}], 
           Offset[{-1.5, 
             0}, {-2.7720013300229622`, -0.3530872565838252}]}]}, {
         LineBox[{{-1.4978159069195163`, 
          0.49605268863561136`}, {-1.5978737380703147`, 
          0.49605268863561136`}}], 
         LineBox[{
          Offset[{0, 1.5}, {-1.4978159069195163`, 0.49605268863561136`}], 
           Offset[{0, -1.5}, {-1.4978159069195163`, 0.49605268863561136`}]}], 
         LineBox[{
          Offset[{0, 1.5}, {-1.5978737380703147`, 0.49605268863561136`}], 
           Offset[{0, -1.5}, {-1.5978737380703147`, 0.49605268863561136`}]}], 
         LineBox[{{-1.5478448224949155`, 
          0.5508548444107547}, {-1.5478448224949155`, 0.441250532860468}}], 
         LineBox[{
          Offset[{1.5, 0}, {-1.5478448224949155`, 0.5508548444107547}], 
           Offset[{-1.5, 0}, {-1.5478448224949155`, 0.5508548444107547}]}], 
         LineBox[{
          Offset[{1.5, 0}, {-1.5478448224949155`, 0.441250532860468}], 
           Offset[{-1.5, 0}, {-1.5478448224949155`, 0.441250532860468}]}]}, {
         LineBox[{{0.2947416843335046, 1.1000047036054326`}, {
          0.15685057968356453`, 1.1000047036054326`}}], 
         LineBox[{
          Offset[{0, 1.5}, {0.2947416843335046, 1.1000047036054326`}], 
           Offset[{0, -1.5}, {0.2947416843335046, 1.1000047036054326`}]}], 
         LineBox[{
          Offset[{0, 1.5}, {0.15685057968356453`, 1.1000047036054326`}], 
           Offset[{0, -1.5}, {0.15685057968356453`, 1.1000047036054326`}]}], 
         LineBox[{{0.22579613200853457`, 1.173835274289405}, {
          0.22579613200853457`, 1.0261741329214602`}}], 
         LineBox[{
          Offset[{1.5, 0}, {0.22579613200853457`, 1.173835274289405}], 
           Offset[{-1.5, 0}, {0.22579613200853457`, 1.173835274289405}]}], 
         LineBox[{
          Offset[{1.5, 0}, {0.22579613200853457`, 1.0261741329214602`}], 
           Offset[{-1.5, 0}, {0.22579613200853457`, 
            1.0261741329214602`}]}]}, {
         LineBox[{{1.8414697151234567`, 1.2642006617484092`}, {
          1.6816527598163116`, 1.2642006617484092`}}], 
         LineBox[{
          Offset[{0, 1.5}, {1.8414697151234567`, 1.2642006617484092`}], 
           Offset[{0, -1.5}, {1.8414697151234567`, 1.2642006617484092`}]}], 
         LineBox[{
          Offset[{0, 1.5}, {1.6816527598163116`, 1.2642006617484092`}], 
           Offset[{0, -1.5}, {1.6816527598163116`, 1.2642006617484092`}]}], 
         LineBox[{{1.7615612374698841`, 1.333360190094975}, {
          1.7615612374698841`, 1.1950411334018434`}}], 
         LineBox[{
          Offset[{1.5, 0}, {1.7615612374698841`, 1.333360190094975}], 
           Offset[{-1.5, 0}, {1.7615612374698841`, 1.333360190094975}]}], 
         LineBox[{
          Offset[{1.5, 0}, {1.7615612374698841`, 1.1950411334018434`}], 
           Offset[{-1.5, 0}, {1.7615612374698841`, 1.1950411334018434`}]}]}, {
         LineBox[{{3.2691973719751277`, 1.5712222666847953`}, {
          3.08021345616404, 1.5712222666847953`}}], 
         LineBox[{
          Offset[{0, 1.5}, {3.2691973719751277`, 1.5712222666847953`}], 
           Offset[{0, -1.5}, {3.2691973719751277`, 1.5712222666847953`}]}], 
         LineBox[{
          Offset[{0, 1.5}, {3.08021345616404, 1.5712222666847953`}], 
           Offset[{0, -1.5}, {3.08021345616404, 1.5712222666847953`}]}], 
         LineBox[{{3.174705414069584, 1.640084140413724}, {3.174705414069584, 
          1.5023603929558664`}}], 
         LineBox[{
          Offset[{1.5, 0}, {3.174705414069584, 1.640084140413724}], 
           Offset[{-1.5, 0}, {3.174705414069584, 1.640084140413724}]}], 
         LineBox[{
          Offset[{1.5, 0}, {3.174705414069584, 1.5023603929558664`}], 
           Offset[{-1.5, 0}, {3.174705414069584, 
            1.5023603929558664`}]}]}}}}, 
     {GrayLevel[0], PointSize[0.012833333333333334`], Thickness[
      Large], {InsetBox[
        FormBox[
         StyleBox[
          GraphicsBox[
           {EdgeForm[None], DiskBox[{0, 0}]}],
          StripOnInput->False,
          GraphicsBoxOptions->{DefaultBaseStyle->Directive[
            PointSize[0.012833333333333334`], 
            AbsoluteThickness[1.6], 
            GrayLevel[0], 
            Thickness[Large]]}],
         TraditionalForm], {-3.291802530762224, -0.908673474427846}, 
        Automatic, Offset[6.272]], {
        LineBox[{{-3.281178123198563, -0.908673474427846}, \
{-3.302426938325885, -0.908673474427846}}], 
        LineBox[{
         Offset[{0, 1.5}, {-3.281178123198563, -0.908673474427846}], 
          Offset[{0, -1.5}, {-3.281178123198563, -0.908673474427846}]}], 
        LineBox[{
         Offset[{0, 1.5}, {-3.302426938325885, -0.908673474427846}], 
          Offset[{0, -1.5}, {-3.302426938325885, -0.908673474427846}]}], 
        LineBox[{{-3.291802530762224, -0.8712130555888585}, \
{-3.291802530762224, -0.9461338932668334}}], 
        LineBox[{
         Offset[{1.5, 0}, {-3.291802530762224, -0.8712130555888585}], 
          Offset[{-1.5, 0}, {-3.291802530762224, -0.8712130555888585}]}], 
        LineBox[{
         Offset[{1.5, 0}, {-3.291802530762224, -0.9461338932668334}], 
          Offset[{-1.5, 0}, {-3.291802530762224, -0.9461338932668334}]}]}}, {
       InsetBox[
        FormBox[
         StyleBox[
          GraphicsBox[
           {EdgeForm[None], DiskBox[{0, 0}]}],
          StripOnInput->False,
          GraphicsBoxOptions->{DefaultBaseStyle->Directive[
            PointSize[0.012833333333333334`], 
            AbsoluteThickness[1.6], 
            GrayLevel[0], 
            Thickness[Large]]}],
         TraditionalForm], {-2.7720013300229622, -0.3040720281624273}, 
        Automatic, Offset[6.272]], {
        LineBox[{{-2.754092708203082, -0.3040720281624273}, \
{-2.7899099518428425`, -0.3040720281624273}}], 
        LineBox[{
         Offset[{0, 1.5}, {-2.754092708203082, -0.3040720281624273}], 
          Offset[{0, -1.5}, {-2.754092708203082, -0.3040720281624273}]}], 
        LineBox[{
         Offset[{0, 1.5}, {-2.7899099518428425`, -0.3040720281624273}], 
          Offset[{0, -1.5}, {-2.7899099518428425`, -0.3040720281624273}]}], 
        LineBox[{{-2.7720013300229622`, -0.25505679974102935`}, \
{-2.7720013300229622`, -0.3530872565838252}}], 
        LineBox[{
         Offset[{1.5, 0}, {-2.7720013300229622`, -0.25505679974102935`}], 
          Offset[{-1.5, 0}, {-2.7720013300229622`, -0.25505679974102935`}]}], 
        LineBox[{
         Offset[{1.5, 0}, {-2.7720013300229622`, -0.3530872565838252}], 
          Offset[{-1.5, 
            0}, {-2.7720013300229622`, -0.3530872565838252}]}]}}, {InsetBox[
        FormBox[
         StyleBox[
          GraphicsBox[
           {EdgeForm[None], DiskBox[{0, 0}]}],
          StripOnInput->False,
          GraphicsBoxOptions->{DefaultBaseStyle->Directive[
            PointSize[0.012833333333333334`], 
            AbsoluteThickness[1.6], 
            GrayLevel[0], 
            Thickness[Large]]}],
         TraditionalForm], {-1.5478448224949155, 0.49605268863561136}, 
        Automatic, Offset[6.272]], {
        LineBox[{{-1.4978159069195163`, 
         0.49605268863561136`}, {-1.5978737380703147`, 
         0.49605268863561136`}}], 
        LineBox[{
         Offset[{0, 1.5}, {-1.4978159069195163`, 0.49605268863561136`}], 
          Offset[{0, -1.5}, {-1.4978159069195163`, 0.49605268863561136`}]}], 
        LineBox[{
         Offset[{0, 1.5}, {-1.5978737380703147`, 0.49605268863561136`}], 
          Offset[{0, -1.5}, {-1.5978737380703147`, 0.49605268863561136`}]}], 
        LineBox[{{-1.5478448224949155`, 
         0.5508548444107547}, {-1.5478448224949155`, 0.441250532860468}}], 
        LineBox[{
         Offset[{1.5, 0}, {-1.5478448224949155`, 0.5508548444107547}], 
          Offset[{-1.5, 0}, {-1.5478448224949155`, 0.5508548444107547}]}], 
        LineBox[{
         Offset[{1.5, 0}, {-1.5478448224949155`, 0.441250532860468}], 
          Offset[{-1.5, 0}, {-1.5478448224949155`, 0.441250532860468}]}]}}, {
       InsetBox[
        FormBox[
         StyleBox[
          GraphicsBox[
           {EdgeForm[None], DiskBox[{0, 0}]}],
          StripOnInput->False,
          GraphicsBoxOptions->{DefaultBaseStyle->Directive[
            PointSize[0.012833333333333334`], 
            AbsoluteThickness[1.6], 
            GrayLevel[0], 
            Thickness[Large]]}],
         TraditionalForm], {0.22579613200853457, 1.1000047036054326}, 
        Automatic, Offset[6.272]], {
        LineBox[{{0.2947416843335046, 1.1000047036054326`}, {
         0.15685057968356453`, 1.1000047036054326`}}], 
        LineBox[{
         Offset[{0, 1.5}, {0.2947416843335046, 1.1000047036054326`}], 
          Offset[{0, -1.5}, {0.2947416843335046, 1.1000047036054326`}]}], 
        LineBox[{
         Offset[{0, 1.5}, {0.15685057968356453`, 1.1000047036054326`}], 
          Offset[{0, -1.5}, {0.15685057968356453`, 1.1000047036054326`}]}], 
        LineBox[{{0.22579613200853457`, 1.173835274289405}, {
         0.22579613200853457`, 1.0261741329214602`}}], 
        LineBox[{
         Offset[{1.5, 0}, {0.22579613200853457`, 1.173835274289405}], 
          Offset[{-1.5, 0}, {0.22579613200853457`, 1.173835274289405}]}], 
        LineBox[{
         Offset[{1.5, 0}, {0.22579613200853457`, 1.0261741329214602`}], 
          Offset[{-1.5, 0}, {0.22579613200853457`, 
           1.0261741329214602`}]}]}}, {InsetBox[
        FormBox[
         StyleBox[
          GraphicsBox[
           {EdgeForm[None], DiskBox[{0, 0}]}],
          StripOnInput->False,
          GraphicsBoxOptions->{DefaultBaseStyle->Directive[
            PointSize[0.012833333333333334`], 
            AbsoluteThickness[1.6], 
            GrayLevel[0], 
            Thickness[Large]]}],
         TraditionalForm], {1.7615612374698841, 1.2642006617484092}, 
        Automatic, Offset[6.272]], {
        LineBox[{{1.8414697151234567`, 1.2642006617484092`}, {
         1.6816527598163116`, 1.2642006617484092`}}], 
        LineBox[{
         Offset[{0, 1.5}, {1.8414697151234567`, 1.2642006617484092`}], 
          Offset[{0, -1.5}, {1.8414697151234567`, 1.2642006617484092`}]}], 
        LineBox[{
         Offset[{0, 1.5}, {1.6816527598163116`, 1.2642006617484092`}], 
          Offset[{0, -1.5}, {1.6816527598163116`, 1.2642006617484092`}]}], 
        LineBox[{{1.7615612374698841`, 1.333360190094975}, {
         1.7615612374698841`, 1.1950411334018434`}}], 
        LineBox[{
         Offset[{1.5, 0}, {1.7615612374698841`, 1.333360190094975}], 
          Offset[{-1.5, 0}, {1.7615612374698841`, 1.333360190094975}]}], 
        LineBox[{
         Offset[{1.5, 0}, {1.7615612374698841`, 1.1950411334018434`}], 
          Offset[{-1.5, 0}, {1.7615612374698841`, 1.1950411334018434`}]}]}}, {
       InsetBox[
        FormBox[
         StyleBox[
          GraphicsBox[
           {EdgeForm[None], DiskBox[{0, 0}]}],
          StripOnInput->False,
          GraphicsBoxOptions->{DefaultBaseStyle->Directive[
            PointSize[0.012833333333333334`], 
            AbsoluteThickness[1.6], 
            GrayLevel[0], 
            Thickness[Large]]}],
         TraditionalForm], {3.174705414069584, 1.5712222666847953}, Automatic,
         Offset[6.272]], {
        LineBox[{{3.2691973719751277`, 1.5712222666847953`}, {
         3.08021345616404, 1.5712222666847953`}}], 
        LineBox[{
         Offset[{0, 1.5}, {3.2691973719751277`, 1.5712222666847953`}], 
          Offset[{0, -1.5}, {3.2691973719751277`, 1.5712222666847953`}]}], 
        LineBox[{
         Offset[{0, 1.5}, {3.08021345616404, 1.5712222666847953`}], 
          Offset[{0, -1.5}, {3.08021345616404, 1.5712222666847953`}]}], 
        LineBox[{{3.174705414069584, 1.640084140413724}, {3.174705414069584, 
         1.5023603929558664`}}], 
        LineBox[{
         Offset[{1.5, 0}, {3.174705414069584, 1.640084140413724}], 
          Offset[{-1.5, 0}, {3.174705414069584, 1.640084140413724}]}], 
        LineBox[{
         Offset[{1.5, 0}, {3.174705414069584, 1.5023603929558664`}], 
          Offset[{-1.5, 0}, {3.174705414069584, 1.5023603929558664`}]}]}}}, {
      {GrayLevel[0], PointSize[0.012833333333333334`], Thickness[
       Large]}, {}}, {
      {GrayLevel[0], PointSize[0.012833333333333334`], Thickness[
       Large]}, {}}}, {{}, {}}}, {{}, {{{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[1.6], 
       Dashing[{Small, Small}], LineBox[{{-1.5, -1.5}, {3.5, 3.5}}]}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[1.6], 
      Dashing[{Small, Small}]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[1.6], 
       Dashing[{Small, Small}]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[1.6], 
       Dashing[{Small, Small}]}, {}}}, {{}, {}}}, {InsetBox[
     StyleBox["\<\"50\"\>",
      StripOnInput->False,
      FontSize->20,
      FontWeight->Bold], {-3.291802530762224, -0.658673474427846}], InsetBox[
     StyleBox["\<\"100\"\>",
      StripOnInput->False,
      FontSize->20,
      FontWeight->Bold], {-2.7720013300229622, -0.05407202816242729}], 
    InsetBox[
     StyleBox["\<\"200\"\>",
      StripOnInput->False,
      FontSize->20,
      FontWeight->Bold], {-1.5478448224949155, 0.7460526886356114}], 
    InsetBox[
     StyleBox["\<\"300\"\>",
      StripOnInput->False,
      FontSize->20,
      FontWeight->Bold], {0.22579613200853457, 1.3500047036054326}], 
    InsetBox[
     StyleBox["\<\"400\"\>",
      StripOnInput->False,
      FontSize->20,
      FontWeight->Bold], {1.7615612374698841, 1.5142006617484092}], InsetBox[
     StyleBox["\<\"500\"\>",
      StripOnInput->False,
      FontSize->20,
      FontWeight->Bold], {3.174705414069584, 1.8212222666847953}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox["\"CRN time (log seconds)\"", 20, Bold, StripOnInput -> False],
       TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox[
      StyleBox[
      "\"Mathematica time (log seconds)\"", 20, Bold, StripOnInput -> False], 
      TraditionalForm], 
     FormBox[
      StyleBox[
      "\"Solving 3SAT on random N-variable problems (100 for each N)\"", 20, 
       Bold, StripOnInput -> False], TraditionalForm]}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  FrameTicksStyle->20,
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{909.85546875, Automatic},
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-3.5, 5.5}, {-1.5, 3.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.773498506476418*^9, 3.7734985727732773`*^9, 
  3.773499134890892*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"d34fb675-a178-483e-90fb-dce5c7a26fdd"]
}, Open  ]],

Cell["\<\
The above plot involved different problem instances, different computers, and \
different extents of multiprocessing than Figure 3 from the paper.  You\
\[CloseCurlyQuote]ll note that the results are a little different, but \
qualitatively and quantitatively similar.\
\>", "Text",
 CellChangeTimes->{{3.7734544945047283`*^9, 3.773454523012648*^9}, {
   3.7734546353100863`*^9, 3.773454641026163*^9}, {3.773495359839964*^9, 
   3.773495415721994*^9}, {3.773496376174018*^9, 3.773496450348591*^9}, {
   3.773498470465448*^9, 3.773498498374516*^9}, {3.77349922646054*^9, 
   3.7734993250252657`*^9}, 3.773499582424449*^9},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"5423a493-f869-4b25-8df6-b3cea0392145"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loose Ends", "Section",
 CellChangeTimes->{{3.773497470890245*^9, 
  3.7734974762250147`*^9}},ExpressionUUID->"4a5f0e73-b277-47e5-9242-\
cb22d629f011"],

Cell["\<\
The solidification slow rate constant of 0.1 was chosen because the simpler \
value of 1.0 did not work well for AdlemanSAT.  It takes a very long time!\
\>", "Text",
 CellChangeTimes->{{3.7734544945047283`*^9, 3.773454523012648*^9}, {
  3.7734546353100863`*^9, 3.773454641026163*^9}, {3.773495359839964*^9, 
  3.773495415721994*^9}, {3.773496376174018*^9, 3.773496450348591*^9}, {
  3.7734974553475313`*^9, 3.7734974570331087`*^9}, {3.773497492844253*^9, 
  3.773497530447557*^9}, {3.773497577793417*^9, 3.773497584811298*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"e972fe3f-ff7b-4a10-b851-3876116e09a3"],

Cell[BoxData[
 RowBox[{"assign", "=", 
  RowBox[{"RunWalkSATCRN", "[", 
   RowBox[{"AdlemanSAT", ",", "1.0"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.773347818586851*^9, 3.773347852310367*^9}, {
  3.7733480107082043`*^9, 3.773348011179825*^9}, {3.773348342645481*^9, 
  3.7733483436702747`*^9}, {3.7733627927173357`*^9, 3.7733628055822678`*^9}, {
  3.7733628624199333`*^9, 3.773362863835215*^9}, {3.773362914605308*^9, 
  3.773362934119389*^9}, {3.773497570271636*^9, 3.773497570981447*^9}, {
  3.7736749387771673`*^9, 
  3.773674940522972*^9}},ExpressionUUID->"76beb90e-ed3a-4b27-ae6a-\
28adad8300ea"],

Cell[BoxData[
 RowBox[{"AdlemanSAT", "/.", "assign"}]], "Input",
 CellChangeTimes->{{3.773499617973*^9, 
  3.7734996225221977`*^9}},ExpressionUUID->"fb85f81b-de06-478f-b14f-\
ff26a660ba8a"],

Cell["\<\
But to our surprise, when testing on the randomly-generated hard problems, \
rate constants between 0.3 and 1.2 worked about equally well, and all worked \
2x to 3x better than rate constant 0.1, with the optimum being close to 1.0, \
maybe a little above.\
\>", "Text",
 CellChangeTimes->{{3.7734544945047283`*^9, 3.773454523012648*^9}, {
  3.7734546353100863`*^9, 3.773454641026163*^9}, {3.773495359839964*^9, 
  3.773495415721994*^9}, {3.773496376174018*^9, 3.773496450348591*^9}, {
  3.7734974553475313`*^9, 3.7734974570331087`*^9}, {3.773497492844253*^9, 
  3.773497530447557*^9}, {3.773497577793417*^9, 3.773497648955943*^9}, {
  3.773497858769063*^9, 3.773497877110938*^9}, {3.7734979164827023`*^9, 
  3.773497945169029*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"b8eebe28-e5ad-47fb-86f5-1a0ddd8fbc18"],

Cell["\<\
While writing up the DNA25 paper, I was forced to acknowledge that I don\
\[CloseCurlyQuote]t know how to prove that WalkSATCRN can always reach a \
solution if a solution exists.  So in footnote 2, I propose a related CRN for \
which the proof is straightforward.   The basic idea is that a clause (A+B+C) \
results in the reactions

A0+B0+C0 ==> tryA+tryB+tryC
tryA+B0+C0 ==> A1+B0+C0
A0+tryB+C0 ==> A0+B1+C0
A0+B0+tryC ==> A0+B0+C1
tryA --> A0
tryA --> A1
tryB --> B0
tryB --> B1
tryC --> C0
tryC --> C1

For formula with M clauses and N variables, we have still 4M+2N reactions.  \
But there are fewer species: only 3N instead of 4N.  Again, the unimolecular \
reactions are slow and the trimolecular reactions are fast.

I call it \[OpenCurlyDoubleQuote]StumbleSAT\[CloseCurlyDoubleQuote] because \
sometimes the attempts to flip a variable work, sometimes they just go back, \
unlike the more directed \[OpenCurlyDoubleQuote]WalkSAT\
\[CloseCurlyDoubleQuote] CRN where a trial to flip a variable will definitely \
result in the clause becoming satisfied, unless the trial is rejected for a \
reason.

Is it equally effective? Yes, pretty close, for random hard problem \
instances, and with the slow rate constant around 0.75.\
\>", "Text",
 CellChangeTimes->{{3.68366070573755*^9, 3.683660863775231*^9}, {
  3.683661054059445*^9, 3.6836610580739727`*^9}, {3.6836653640589113`*^9, 
  3.6836653856151342`*^9}, {3.683665689025714*^9, 3.683665710248249*^9}, {
  3.683671669164979*^9, 3.683671693490624*^9}, {3.684003335582779*^9, 
  3.684003364766593*^9}, {3.772156053882072*^9, 3.772156061464719*^9}, {
  3.772156396540753*^9, 3.7721567518761473`*^9}, {3.772156808473497*^9, 
  3.772156893931569*^9}, {3.773547126112564*^9, 3.773547193250325*^9}, {
  3.7735476135010157`*^9, 3.773547642207872*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"32f77d05-a26c-47ed-8269-32b32e024eba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"StumbleClauseReactions", "[", "clause_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vars", ",", "n", ",", "unsat"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vars", "=", 
      RowBox[{"BooleanVariables", "[", "clause", "]"}]}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "vars", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"unsat", "=", 
      RowBox[{"Boole", "[", 
       RowBox[{"SatisfiabilityInstances", "[", 
        RowBox[{
         RowBox[{"!", "clause"}], ",", "vars", ",", 
         RowBox[{"2", "^", "n"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "watch", " ", "out", " ", "that", " ", "rxn", " ", "uses", " ", 
         "HoldAll"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"rxn", "@@", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Plus", "@@", 
               RowBox[{"MapThread", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#1", "[", "#2", "]"}], "&"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"vars", ",", "case"}], "}"}]}], "]"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Plus", "@@", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#1", "[", "try", "]"}], "&"}], " ", "/@", "vars"}],
                 ")"}]}], ",", "\[IndentingNewLine]", "1"}], "}"}]}], 
           "\[IndentingNewLine]", "}"}], ",", 
          RowBox[{"Table", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rxn", "@@", 
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Plus", "@@", 
                  RowBox[{"MapThread", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"#1", "[", "#2", "]"}], "&"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"vars", ",", "case"}], "}"}]}], "]"}]}], ")"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"vars", "[", 
                    RowBox[{"[", "var", "]"}], "]"}], "[", "v_", "]"}], 
                  "\[RuleDelayed]", 
                  RowBox[{
                   RowBox[{"vars", "[", 
                    RowBox[{"[", "var", "]"}], "]"}], "[", "try", "]"}]}], 
                 "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Plus", "@@", 
                  RowBox[{"MapThread", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"#1", "[", "#2", "]"}], "&"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"vars", ",", "case"}], "}"}]}], "]"}]}], ")"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"vars", "[", 
                    RowBox[{"[", "var", "]"}], "]"}], "[", "v_", "]"}], 
                  "\[RuleDelayed]", 
                  RowBox[{
                   RowBox[{"vars", "[", 
                    RowBox[{"[", "var", "]"}], "]"}], "[", 
                   RowBox[{"1", "-", "v"}], "]"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", "1"}], "}"}]}], "\[IndentingNewLine]", 
            ",", 
            RowBox[{"{", 
             RowBox[{"var", ",", "n"}], "}"}]}], "\[IndentingNewLine]", 
           "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"case", ",", "unsat"}], "}"}]}], "\[IndentingNewLine]", 
       "]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.77334261243182*^9, 3.773342728828231*^9}, {
   3.7733431055806026`*^9, 3.773343191889161*^9}, {3.773343236919108*^9, 
   3.773343401403895*^9}, {3.7733436082507887`*^9, 3.7733436790628033`*^9}, {
   3.7733437625699587`*^9, 3.773343787909876*^9}, {3.77334385756599*^9, 
   3.773343858701167*^9}, {3.7733441097439957`*^9, 3.773344145630681*^9}, {
   3.773344250074697*^9, 3.773344281477072*^9}, {3.773344477676824*^9, 
   3.77334449995581*^9}, {3.7733446198526917`*^9, 3.773344622665374*^9}, {
   3.773344715209586*^9, 3.773344724570692*^9}, 3.7733447606741257`*^9, {
   3.7733449095711737`*^9, 3.7733449568079243`*^9}, {3.773354476718292*^9, 
   3.7733544770944347`*^9}, {3.773359716958083*^9, 3.7733597258330107`*^9}, {
   3.773360780534959*^9, 3.773360794406698*^9}, {3.773360826630269*^9, 
   3.7733609034666233`*^9}, {3.773360965002714*^9, 3.7733611039006777`*^9}, {
   3.773361141948732*^9, 3.773361187210387*^9}, {3.773361291662678*^9, 
   3.773361336650243*^9}, {3.7735472532343807`*^9, 3.7735473147399683`*^9}, {
   3.773547405012062*^9, 3.7735474055391617`*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"9e101ded-c667-46e0-9fed-07a48a234e32"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StumbleClauseReactions", "[", 
   RowBox[{
    RowBox[{"X", "&&", "Y"}], "||", 
    RowBox[{"!", "Y"}], "||", 
    RowBox[{"Z", "&&", "X"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773361211922688*^9, 3.773361239522821*^9}, {
  3.773361753335257*^9, 3.773361769347041*^9}, {3.773547431053329*^9, 
  3.7735474331845827`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"364b4e2e-bda9-49d7-ad60-fd61a35b3e80"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "try", "]"}], "+", 
         RowBox[{"Y", "[", "try", "]"}], "+", 
         RowBox[{"Z", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "try", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "1", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "try", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "0", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "try", "]"}], "+", 
         RowBox[{"Y", "[", "try", "]"}], "+", 
         RowBox[{"Z", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "try", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "1", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "try", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "0", "]"}], "+", 
         RowBox[{"Z", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"X", "[", "0", "]"}], "+", 
         RowBox[{"Y", "[", "1", "]"}], "+", 
         RowBox[{"Z", "[", "1", "]"}]}], " "}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.773361227506632*^9, 3.773361240050583*^9}, 
   3.7733613054142437`*^9, 3.773361339965754*^9, 3.773361770343644*^9, 
   3.773547434804557*^9},
 CellLabel->
  "Out[47]//MatrixForm=",ExpressionUUID->"3ec44952-70b1-41f8-98e1-\
e03bd91b1616"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"StumbleVariableReactions", "[", "slow_", "]"}], "[", "variable_", 
   "]"}], ":=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rxn", "@@", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"variable", "[", "try", "]"}], ",", " ", 
       RowBox[{"variable", "[", "0", "]"}], ",", "slow"}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"rxn", "@@", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"variable", "[", "try", "]"}], ",", " ", 
       RowBox[{"variable", "[", "1", "]"}], ",", "slow"}], "}"}]}]}], 
   "\[IndentingNewLine]", "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773354520576117*^9, 3.773354531184923*^9}, {
  3.773362070040822*^9, 3.773362071081951*^9}, {3.773362101724264*^9, 
  3.77336218702419*^9}, {3.773547479433708*^9, 3.77354749108631*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"77d75d75-f59d-472e-975f-0a900fcb7cc4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"StumbleVariableReactions", "[", "0.75", "]"}], "[", "X", "]"}], "//",
   "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773361211922688*^9, 3.773361239522821*^9}, {
  3.773361753335257*^9, 3.773361769347041*^9}, {3.773362285263282*^9, 
  3.773362293210326*^9}, {3.7735474959581823`*^9, 3.773547496873002*^9}, {
  3.773547595234351*^9, 3.77354759570317*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"6fc5d25b-4b0d-48b3-b2c9-88500b9dcfee"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"X", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"X", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"X", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"X", "[", "1", "]"}], " "}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.773362294821561*^9, 3.7735474984811983`*^9, 
  3.7735475963647842`*^9},
 CellLabel->
  "Out[54]//MatrixForm=",ExpressionUUID->"02c36396-093e-4591-a7cd-\
5fb6b461f676"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"StumbleSATCRN", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"slow_:", "0.75"}]}], "]"}], ":=", 
  RowBox[{"Join", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"StumbleClauseReactions", "/@", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "expr", "]"}], "===", "And"}], ",", 
        RowBox[{"List", "@@", "expr"}], ",", 
        RowBox[{"{", "expr", "}"}]}], "]"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"StumbleVariableReactions", "[", "slow", "]"}], "/@", 
      RowBox[{"BooleanVariables", "[", "expr", "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773362312228259*^9, 3.7733624536237783`*^9}, 
   3.77336248970185*^9, {3.773362581132801*^9, 3.773362630322885*^9}, {
   3.7735475043196363`*^9, 3.773547515364677*^9}, {3.773547606621066*^9, 
   3.773547607078445*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"8802f731-d8c0-4787-8fac-c99e88b3c781"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StumbleSATCRN", "[", "AdlemanSAT", "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.773362686005267*^9, 3.7733626985606728`*^9}, {
  3.773547520333527*^9, 3.773547524731724*^9}},
 CellLabel->"In[57]:=",ExpressionUUID->"e6a69207-2ddf-4946-aa03-fdf2acf14a91"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "try", "]"}], "+", 
         RowBox[{"x16", "[", "try", "]"}], "+", 
         RowBox[{"x18", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "try", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "try", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "try", "]"}], "+", 
         RowBox[{"x13", "[", "try", "]"}], "+", 
         RowBox[{"x20", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "try", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "try", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "try", "]"}], "+", 
         RowBox[{"x06", "[", "try", "]"}], "+", 
         RowBox[{"x19", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "try", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "try", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "try", "]"}], "+", 
         RowBox[{"x04", "[", "try", "]"}], "+", 
         RowBox[{"x11", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "try", "]"}], "+", 
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x04", "[", "try", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "try", "]"}], "+", 
         RowBox[{"x13", "[", "try", "]"}], "+", 
         RowBox[{"x19", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "try", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "try", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x17", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x15", "[", "try", "]"}], "+", 
         RowBox[{"x17", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "try", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "try", "]"}], "+", 
         RowBox[{"x06", "[", "try", "]"}], "+", 
         RowBox[{"x11", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "try", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "1", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "try", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x04", "[", "0", "]"}], "+", 
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "try", "]"}], "+", 
         RowBox[{"x15", "[", "try", "]"}], "+", 
         RowBox[{"x17", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "try", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "try", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}], "+", 
         RowBox[{"x17", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}], "+", 
         RowBox[{"x17", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x06", "[", "try", "]"}], "+", 
         RowBox[{"x13", "[", "try", "]"}], "+", 
         RowBox[{"x19", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x06", "[", "try", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x06", "[", "0", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "try", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "1", "]"}], "+", 
         RowBox[{"x19", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x06", "[", "1", "]"}], "+", 
         RowBox[{"x13", "[", "0", "]"}], "+", 
         RowBox[{"x19", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}], "+", 
         RowBox[{"x14", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "try", "]"}], "+", 
         RowBox[{"x03", "[", "try", "]"}], "+", 
         RowBox[{"x20", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "try", "]"}], "+", 
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "1", "]"}], "+", 
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x03", "[", "try", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x02", "[", "0", "]"}], "+", 
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "try", "]"}], "+", 
         RowBox[{"x08", "[", "try", "]"}], "+", 
         RowBox[{"x10", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "try", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "try", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "try", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "0", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "try", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "1", "]"}], "+", 
         RowBox[{"x12", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x05", "[", "1", "]"}], "+", 
         RowBox[{"x09", "[", "0", "]"}], "+", 
         RowBox[{"x12", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "try", "]"}], "+", 
         RowBox[{"x18", "[", "try", "]"}], "+", 
         RowBox[{"x20", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "try", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "try", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}], "+", 
         RowBox[{"x20", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x03", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}], "+", 
         RowBox[{"x20", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x10", "[", "try", "]"}], "+", 
         RowBox[{"x16", "[", "try", "]"}], "+", 
         RowBox[{"x18", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x10", "[", "try", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x10", "[", "0", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "try", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}], "+", 
         RowBox[{"x18", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}], "+", 
         RowBox[{"x18", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "try", "]"}], "+", 
         RowBox[{"x11", "[", "try", "]"}], "+", 
         RowBox[{"x14", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "try", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "1", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "try", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "0", "]"}], "+", 
         RowBox[{"x14", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x01", "[", "0", "]"}], "+", 
         RowBox[{"x11", "[", "1", "]"}], "+", 
         RowBox[{"x14", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "try", "]"}], "+", 
         RowBox[{"x08", "[", "try", "]"}], "+", 
         RowBox[{"x15", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "try", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "0", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "try", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x15", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x07", "[", "1", "]"}], "+", 
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x15", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x08", "[", "try", "]"}], "+", 
         RowBox[{"x10", "[", "try", "]"}], "+", 
         RowBox[{"x16", "[", "try", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x08", "[", "try", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x08", "[", "0", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "try", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "0", "]"}], "+", 
         RowBox[{"x16", "[", "0", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "try", "]"}]}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "1", " "}]], " ", 
        RowBox[{
         RowBox[{"x08", "[", "1", "]"}], "+", 
         RowBox[{"x10", "[", "1", "]"}], "+", 
         RowBox[{"x16", "[", "1", "]"}]}], " "}]},
      {
       RowBox[{
        RowBox[{"x01", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x01", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x01", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x01", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x02", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x02", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x02", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x02", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x03", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x03", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x03", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x03", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x04", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x04", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x04", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x04", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x05", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x05", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x05", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x05", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x06", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x06", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x06", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x06", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x07", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x07", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x07", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x07", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x08", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x08", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x08", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x08", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x09", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x09", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x09", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x09", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x10", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x10", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x10", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x10", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x11", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x11", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x11", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x11", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x12", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x12", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x12", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x12", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x13", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x13", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x13", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x13", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x14", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x14", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x14", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x14", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x15", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x15", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x15", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x15", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x16", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x16", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x16", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x16", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x17", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x17", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x17", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x17", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x18", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x18", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x18", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x18", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x19", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x19", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x19", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x19", "[", "1", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x20", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x20", "[", "0", "]"}], " "}]},
      {
       RowBox[{
        RowBox[{"x20", "[", "try", "]"}], " ", 
        OverscriptBox["\[RightArrow]", 
         RowBox[{" ", "0.75`", " "}]], " ", 
        RowBox[{"x20", "[", "1", "]"}], " "}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.773362699147488*^9, 3.77354752756529*^9, 
  3.7735476488238363`*^9},
 CellLabel->
  "Out[57]//MatrixForm=",ExpressionUUID->"3c0987d8-88dc-4ba0-8fa2-\
905b41ca9c42"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"RunStumbleSATCRN", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"slow_:", "0.75"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "crn", ",", "rsys", ",", "times", ",", "data", ",", "finishconcs", ",", 
      "results"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"crn", "=", 
      RowBox[{"StumbleSATCRN", "[", 
       RowBox[{"expr", ",", "slow"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rsys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"crn", ",", 
        RowBox[{"DualRailInitialState", "[", "crn", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"times", ",", "data"}], "}"}], "=", 
      RowBox[{"SimulateRxnsysSSA", "[", 
       RowBox[{"rsys", ",", "Infinity", ",", 
        RowBox[{"Output", "\[Rule]", "\"\<State\>\""}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"finishconcs", "=", 
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"conc", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}], ",", 
          RowBox[{"Last", "[", "data", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"results", "=", 
      RowBox[{
       RowBox[{"Cases", "[", 
        RowBox[{"finishconcs", ",", 
         RowBox[{
          RowBox[{"conc", "[", 
           RowBox[{
            RowBox[{"s_", "[", "t_", "]"}], ",", 
            RowBox[{"_", "?", "Positive"}]}], "]"}], "\[RuleDelayed]", 
          RowBox[{"(", 
           RowBox[{"s", "\[Rule]", "t"}], ")"}]}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0", "\[Rule]", "False"}], ",", 
         RowBox[{"1", "\[Rule]", "True"}]}], "}"}]}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.68021565999244*^9, 3.680215750241291*^9}, {
   3.6802158052863903`*^9, 3.6802158385740547`*^9}, {3.773136058908334*^9, 
   3.773136129428895*^9}, {3.773136200951747*^9, 3.773136220896125*^9}, {
   3.7731367033385553`*^9, 3.773136728021192*^9}, {3.773136827472237*^9, 
   3.773136847838519*^9}, {3.7731378382659616`*^9, 3.773137844146751*^9}, {
   3.7731378785932217`*^9, 3.773137886692079*^9}, {3.773137999129963*^9, 
   3.773138017053162*^9}, {3.773139783824836*^9, 3.7731397890753393`*^9}, {
   3.773139890729321*^9, 3.773139903448102*^9}, {3.773280197937496*^9, 
   3.773280211920089*^9}, {3.7733453849612217`*^9, 3.7733453892668533`*^9}, {
   3.77334751343707*^9, 3.773347545687004*^9}, {3.773347847280039*^9, 
   3.773347866100006*^9}, {3.773347945836709*^9, 3.773347952150361*^9}, 
   3.77334825368139*^9, {3.773362734420347*^9, 3.773362753224311*^9}, {
   3.77354755063125*^9, 3.77354755642218*^9}, {3.773547659385*^9, 
   3.773547668434321*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"56e87709-3dad-474e-9d52-9335372449c4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"assign", "=", 
  RowBox[{"RunStumbleSATCRN", "[", "AdlemanSAT", "]"}]}]], "Input",
 CellChangeTimes->{{3.773347818586851*^9, 3.773347852310367*^9}, {
  3.7733480107082043`*^9, 3.773348011179825*^9}, {3.773348342645481*^9, 
  3.7733483436702747`*^9}, {3.7733627927173357`*^9, 3.7733628055822678`*^9}, {
  3.7733628624199333`*^9, 3.773362863835215*^9}, {3.773362914605308*^9, 
  3.773362934119389*^9}, {3.773547675838622*^9, 3.773547679075305*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"b834fc04-640b-4ce2-ba00-86224a5dd1aa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x01", "\[Rule]", "False"}], ",", 
   RowBox[{"x02", "\[Rule]", "True"}], ",", 
   RowBox[{"x03", "\[Rule]", "False"}], ",", 
   RowBox[{"x04", "\[Rule]", "False"}], ",", 
   RowBox[{"x05", "\[Rule]", "False"}], ",", 
   RowBox[{"x06", "\[Rule]", "False"}], ",", 
   RowBox[{"x07", "\[Rule]", "True"}], ",", 
   RowBox[{"x08", "\[Rule]", "True"}], ",", 
   RowBox[{"x09", "\[Rule]", "False"}], ",", 
   RowBox[{"x10", "\[Rule]", "True"}], ",", 
   RowBox[{"x11", "\[Rule]", "True"}], ",", 
   RowBox[{"x12", "\[Rule]", "True"}], ",", 
   RowBox[{"x13", "\[Rule]", "False"}], ",", 
   RowBox[{"x14", "\[Rule]", "False"}], ",", 
   RowBox[{"x15", "\[Rule]", "True"}], ",", 
   RowBox[{"x16", "\[Rule]", "True"}], ",", 
   RowBox[{"x17", "\[Rule]", "True"}], ",", 
   RowBox[{"x18", "\[Rule]", "False"}], ",", 
   RowBox[{"x19", "\[Rule]", "False"}], ",", 
   RowBox[{"x20", "\[Rule]", "False"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773362796894875*^9, 3.773362860468576*^9, {3.7733629131608963`*^9, 
   3.773362935954893*^9}, 3.773547720679611*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"a0b60f59-5abc-48b9-9d51-735765f3bd05"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdlemanSAT", "/.", "assign"}]], "Input",
 CellChangeTimes->{{3.7733630223180447`*^9, 3.773363026782319*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"b21367c6-f14e-4fb5-975c-f8df949c24dc"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7733630275211763`*^9, 3.773547727028393*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"fa37003a-0acb-4cab-956a-790dbfe4dc7e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"assign", "=", 
   RowBox[{"RunStumbleSATCRN", "[", 
    RowBox[{"safetests500", "[", 
     RowBox[{"[", 
      RowBox[{"50", ",", "2"}], "]"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.773547751066682*^9, 3.773547769025107*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"8d2b4bc2-f06d-44a5-a917-52dcf13815f0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"safetests500", "[", 
   RowBox[{"[", 
    RowBox[{"50", ",", "2"}], "]"}], "]"}], "/.", "assign"}]], "Input",
 CellChangeTimes->{{3.773547814864472*^9, 3.773547827353402*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"53f48fb4-9896-4871-95fa-8162bb57b6da"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.773547806386091*^9, 3.773547828241482*^9}},
 CellLabel->"Out[64]=",ExpressionUUID->"185be999-e732-4d93-9135-1a962fe34e8f"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1041, 905},
WindowMargins->{{Automatic, 14}, {Automatic, 0}},
InputAliases->{"intt" -> RowBox[{"\[Integral]", 
     RowBox[{"\[SelectionPlaceholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "dintt" -> 
  RowBox[{
     SubsuperscriptBox[
     "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
     RowBox[{"\[Placeholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "rintt" -> 
  RowBox[{
     UnderscriptBox["\[Integral]", 
      RowBox[{"\[SelectionPlaceholder]", "\[Element]", "\[Placeholder]"}]], 
     "\[Placeholder]"}], "sumt" -> RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "prodt" -> RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "dt" -> RowBox[{
     SubscriptBox["\[PartialD]", "\[Placeholder]"], " ", 
     "\[SelectionPlaceholder]"}], "cbrt" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "3", SurdForm -> True, MultilineFunction -> 
    None], "surd" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "\[Placeholder]", SurdForm -> True, 
    MultilineFunction -> None], "ket" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Ket"], "bra" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Bra"], "braket" -> 
  TemplateBox[{"\[SelectionPlaceholder]", "\[Placeholder]"}, "BraKet"], 
  "delay" -> TemplateBox[{"\[SelectionPlaceholder]"}, "SystemsModelDelay"], 
  "grad" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Placeholder]"}], 
  "del." -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], ".", 
     "\[Placeholder]"}], "delx" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Cross]", 
     "\[Placeholder]"}], "del2" -> RowBox[{
     SubsuperscriptBox["\[Del]", "\[SelectionPlaceholder]", 2], 
     "\[Placeholder]"}], "kd" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "KroneckerDeltaSeq"], "algs" -> 
  TemplateBox[{}, "Algebraics"], "bools" -> TemplateBox[{}, "Booleans"], 
  "comps" -> TemplateBox[{}, "Complexes"], "ints" -> 
  TemplateBox[{}, "Integers"], "pris" -> TemplateBox[{}, "Primes"], "rats" -> 
  TemplateBox[{}, "Rationals"], "reals" -> TemplateBox[{}, "Reals"], "pints" -> 
  TemplateBox[{}, "PositiveIntegers"], "npints" -> 
  TemplateBox[{}, "NonPositiveIntegers"], "nnints" -> 
  TemplateBox[{}, "NonNegativeIntegers"], "nints" -> 
  TemplateBox[{}, "NegativeIntegers"], "prats" -> 
  TemplateBox[{}, "PositiveRationals"], "nprats" -> 
  TemplateBox[{}, "NonPositiveRationals"], "nnrats" -> 
  TemplateBox[{}, "NonNegativeRationals"], "nrats" -> 
  TemplateBox[{}, "NegativeRationals"], "preals" -> 
  TemplateBox[{}, "PositiveReals"], "npreals" -> 
  TemplateBox[{}, "NonPositiveReals"], "nnreals" -> 
  TemplateBox[{}, "NonNegativeReals"], "nreals" -> 
  TemplateBox[{}, "NegativeReals"], "dlim" -> RowBox[{
     UnderscriptBox["\[Limit]", 
      RowBox[{"\[SelectionPlaceholder]", 
        UnderscriptBox["\[Rule]", 
         TemplateBox[{}, "Integers"]], "\[Infinity]"}]], "\[Placeholder]"}], 
  "dMlim" -> RowBox[{
     UnderscriptBox["\[MaxLimit]", 
      RowBox[{"\[SelectionPlaceholder]", 
        UnderscriptBox["\[Rule]", 
         TemplateBox[{}, "Integers"]], "\[Infinity]"}]], "\[Placeholder]"}], 
  "dmlim" -> RowBox[{
     UnderscriptBox["\[MinLimit]", 
      RowBox[{"\[SelectionPlaceholder]", 
        UnderscriptBox["\[Rule]", 
         TemplateBox[{}, "Integers"]], "\[Infinity]"}]], "\[Placeholder]"}], 
  "notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation>" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation<" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "symb" -> RowBox[{"Symbolize", "[", 
     TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], "]"}], 
  "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], ",", 
       "\[Placeholder]"}], "]"}], "addia" -> RowBox[{"AddInputAlias", "[", 
     RowBox[{"\"\[SelectionPlaceholder]\"", "\[Rule]", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "pattwraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationPatternTag"], 
  "madeboxeswraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationMadeBoxesTag"], "rxn" -> 
  RowBox[{"\[Placeholder]", " ", 
     OverscriptBox["\[RightArrow]", 
      RowBox[{" ", "\[Placeholder]", " "}]], " ", "\[Placeholder]", " "}], 
  "revrxn" -> RowBox[{"\[Placeholder]", " ", 
     UnderoverscriptBox[
     "\[RightArrowLeftArrow]", "\[Placeholder]", "\[Placeholder]"], " ", 
     "\[Placeholder]", " "}]},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1754, 29, 258, "Text",ExpressionUUID->"51a0b4e7-203e-4187-a88e-2aad3c6dffb7"],
Cell[2315, 51, 684, 16, 110, "Input",ExpressionUUID->"b171f188-5f30-4a33-9b94-e0e5eec7e0de",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3024, 71, 173, 3, 67, "Section",ExpressionUUID->"f77d9965-b86d-43af-9533-588f8d769478"],
Cell[3200, 76, 693, 12, 97, "Text",ExpressionUUID->"e0695cca-c69a-4341-8581-b1c5e8e8e655"],
Cell[3896, 90, 1237, 32, 194, "Input",ExpressionUUID->"489e8fe5-19e0-4fbb-9cab-ba96949bbccd",
 InitializationCell->True],
Cell[5136, 124, 471, 11, 30, "Input",ExpressionUUID->"1f1bf884-ae4e-48aa-a6cf-8f0ca074fdd3"],
Cell[CellGroupData[{
Cell[5632, 139, 538, 14, 30, "Input",ExpressionUUID->"51f4137a-49a2-4cbb-a2b7-0018cc62720d"],
Cell[6173, 155, 248, 5, 34, "Output",ExpressionUUID->"70e76aa0-761a-4f8f-8583-d9ee0ce19d1c"]
}, Open  ]],
Cell[6436, 163, 708, 18, 46, "Input",ExpressionUUID->"8e33f8b3-9525-424d-bea9-5ed4b855ba37",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[7169, 185, 1636, 40, 115, "Input",ExpressionUUID->"29165b4f-e020-4278-a21a-697bc063ce45"],
Cell[8808, 227, 1603, 36, 298, "Output",ExpressionUUID->"6ccd3d6c-d813-46d2-9530-12ce51101e5b"]
}, Open  ]],
Cell[10426, 266, 606, 10, 97, "Text",ExpressionUUID->"88051b51-c25d-4abb-8d1f-136195ec2549"],
Cell[CellGroupData[{
Cell[11057, 280, 224, 4, 30, "Input",ExpressionUUID->"7cc25c2f-90d1-4fac-9932-72bbd3f0f473"],
Cell[11284, 286, 178, 3, 34, "Output",ExpressionUUID->"c29b2730-3ae2-4392-9927-6aa7461d8d78"]
}, Open  ]],
Cell[11477, 292, 8437, 207, 593, "Input",ExpressionUUID->"549d7aec-4465-4ec9-a82e-0ee873e30bf0",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[19939, 503, 311, 6, 30, "Input",ExpressionUUID->"b23b9c00-2efa-440a-9609-1d5b3d1fd613"],
Cell[20253, 511, 9892, 280, 554, "Output",ExpressionUUID->"dcf68cda-6ecd-4866-84b7-8fc87bc9aedc"]
}, Open  ]],
Cell[30160, 794, 776, 18, 89, "Input",ExpressionUUID->"64d51fbe-72a9-4523-90f9-531f92a0c487",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[30961, 816, 319, 7, 30, "Input",ExpressionUUID->"c041d904-78b5-4744-abbb-bda3d8f2708a"],
Cell[31283, 825, 550, 14, 44, "Output",ExpressionUUID->"48c68c4f-a2d3-44d8-8ec7-afd25f0ca096"]
}, Open  ]],
Cell[31848, 842, 656, 18, 46, "Input",ExpressionUUID->"acd7cd05-7a7c-48bf-b8dd-da707616f7d7",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[32529, 864, 421, 6, 30, "Input",ExpressionUUID->"66081b91-0e37-4b88-93b4-fe193a976dc4"],
Cell[32953, 872, 1319, 37, 56, "Output",ExpressionUUID->"eceef750-f502-42e1-9684-c6b86f6bc73e"]
}, Open  ]],
Cell[34287, 912, 2302, 57, 194, "Input",ExpressionUUID->"e61078bd-1a8c-4fd7-b73c-7c4139fe05b4",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[36614, 973, 623, 14, 30, "Input",ExpressionUUID->"c65795a7-f48b-4604-abfa-d0bfe5fdebb9"],
Cell[37240, 989, 342, 7, 34, "Output",ExpressionUUID->"3190fdf5-d498-4fbb-b8c7-288fcb58eeb8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37619, 1001, 1682, 39, 115, "Input",ExpressionUUID->"44abeccf-05d9-4ae8-9200-74a881209702"],
Cell[39304, 1042, 1508, 35, 298, "Output",ExpressionUUID->"89a850a9-a8f9-444c-8fff-5924992c8ab7"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[40861, 1083, 284, 4, 67, "Section",ExpressionUUID->"a56e8c6f-c790-458b-b497-e1b6581a3113"],
Cell[41148, 1089, 950, 15, 120, "Text",ExpressionUUID->"0714e2bd-0b23-4ac7-907f-d46fca36bf7b"],
Cell[42101, 1106, 20961, 512, 1139, "Input",ExpressionUUID->"0099d88b-d5a3-4220-973c-0ad5a499b6ce",
 InitializationCell->True],
Cell[63065, 1620, 2630, 61, 194, "Input",ExpressionUUID->"c2e3fc8a-a646-46ab-88d7-f7295c0d01f0",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[65720, 1685, 846, 18, 30, "Input",ExpressionUUID->"a9eebed0-2ea2-42a0-bcb6-b0ac09750617"],
Cell[66569, 1705, 661, 12, 34, "Output",ExpressionUUID->"5120d0a3-8481-4d4f-9523-5acded815a45"]
}, Open  ]],
Cell[67245, 1720, 1284, 20, 166, "Text",ExpressionUUID->"a111e14a-9836-4143-99f5-531e7e36ae24"],
Cell[68532, 1742, 1124, 28, 52, "Input",ExpressionUUID->"25cd4c20-b6de-47fa-ac02-4350e5f9d404"],
Cell[CellGroupData[{
Cell[69681, 1774, 332, 7, 30, "Input",ExpressionUUID->"91035f16-3e19-4e12-9bbf-3ceded792160"],
Cell[70016, 1783, 691, 16, 56, "Output",ExpressionUUID->"0865c0b5-e765-4dd0-a214-fe77c669e42f"]
}, Closed]],
Cell[70722, 1802, 2713, 62, 153, "Input",ExpressionUUID->"cb97aa93-1087-4b40-9bc9-73b95ad97fcf"],
Cell[CellGroupData[{
Cell[73460, 1868, 617, 15, 30, "Input",ExpressionUUID->"69d6064b-fea9-4c1e-a19d-913eb6815b23"],
Cell[74080, 1885, 2137, 48, 161, "Output",ExpressionUUID->"80f56fd2-98fd-42ab-a4ec-9a7f38e08686"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76254, 1938, 771, 19, 30, "Input",ExpressionUUID->"403e1937-7d4e-436d-b7cf-442e6cf8d56b"],
Cell[77028, 1959, 275, 6, 34, "Output",ExpressionUUID->"a69dcbb3-bc75-4f82-b6fe-b0ae1f72ee0b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77340, 1970, 3393, 86, 220, "Input",ExpressionUUID->"475f4beb-a00c-4a43-bc8a-a9293776ca19"],
Cell[80736, 2058, 24232, 530, 4378, "Output",ExpressionUUID->"a51c8d87-f760-4173-b3b6-cb5eb594a8f2"]
}, Closed]],
Cell[104983, 2591, 6888, 167, 342, "Input",ExpressionUUID->"17785053-f44a-4eeb-bdec-bfa49b744892"],
Cell[CellGroupData[{
Cell[111896, 2762, 681, 16, 30, "Input",ExpressionUUID->"d1bed4a5-79d9-43ac-aa5e-f376332a48c8"],
Cell[112580, 2780, 7834, 162, 749, "Output",ExpressionUUID->"23995361-1b42-4a50-afc4-bb5c089e3017"]
}, Closed]],
Cell[CellGroupData[{
Cell[120451, 2947, 1002, 23, 26, "Input",ExpressionUUID->"932cdb9f-3605-463f-8ab4-292cb0905446"],
Cell[121456, 2972, 500, 10, 34, "Output",ExpressionUUID->"a331f6ee-bef9-4db6-a2e1-f45ff85f0767"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121993, 2987, 3542, 88, 220, "Input",ExpressionUUID->"2652cdb2-b366-4846-92f2-99adc4a12feb"],
Cell[125538, 3077, 32353, 529, 4378, "Output",ExpressionUUID->"3df92b44-b39f-41b7-b01c-4f67370b2191"]
}, Closed]],
Cell[CellGroupData[{
Cell[157928, 3611, 908, 21, 48, "Input",ExpressionUUID->"db194095-ce19-420b-b2b8-a4218a3e2efa"],
Cell[158839, 3634, 392, 9, 34, "Output",ExpressionUUID->"f3c170ff-e34f-4f1f-98a2-33d52c958edc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159268, 3648, 210, 4, 30, "Input",ExpressionUUID->"712a2506-bf0e-43b6-a778-88cf838f687c"],
Cell[159481, 3654, 154, 3, 34, "Output",ExpressionUUID->"a76f1a9b-62f8-4a49-b76b-8f9477e95b0b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159672, 3662, 301, 7, 30, "Input",ExpressionUUID->"fde378a9-0931-49b0-aedf-0de713138c23"],
Cell[159976, 3671, 453, 10, 34, "Output",ExpressionUUID->"a915b64e-dda8-4db1-8623-0a7734840cd0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[160466, 3686, 259, 5, 30, "Input",ExpressionUUID->"46aa7a3f-1b13-4f94-a3bf-256125506ba8"],
Cell[160728, 3693, 176, 3, 34, "Output",ExpressionUUID->"3b7625e0-90cd-42f6-8e73-2b11e9fab780"]
}, Open  ]],
Cell[CellGroupData[{
Cell[160941, 3701, 351, 7, 30, "Input",ExpressionUUID->"ef574283-f484-450b-8c63-a75242c9b5f4"],
Cell[161295, 3710, 223, 4, 34, "Output",ExpressionUUID->"f28564e7-db34-4697-8b45-caf7efaf55fe"]
}, Open  ]],
Cell[161533, 3717, 704, 13, 120, "Text",ExpressionUUID->"ca27e3e7-2597-4442-88b2-63103944f43a"],
Cell[CellGroupData[{
Cell[162262, 3734, 905, 22, 30, "Input",ExpressionUUID->"047236e6-efa1-40f9-949f-704946100446"],
Cell[163170, 3758, 313, 8, 34, "Output",ExpressionUUID->"a8380801-aa18-43eb-8cff-4d3bec878d55"]
}, Open  ]],
Cell[163498, 3769, 471, 8, 51, "Text",ExpressionUUID->"1729763d-471c-438d-9079-4c9b1a8a51cc"],
Cell[CellGroupData[{
Cell[163994, 3781, 1030, 25, 52, "Input",ExpressionUUID->"1a3cf362-cd72-400c-80ee-7714857645d0"],
Cell[165027, 3808, 265, 6, 34, "Output",ExpressionUUID->"7d3e06df-6423-47af-ae59-e4831a6f1f00"]
}, Open  ]],
Cell[165307, 3817, 578, 10, 51, "Text",ExpressionUUID->"6402d316-4f4f-4abb-a04a-c22231d6d7a8"],
Cell[CellGroupData[{
Cell[165910, 3831, 1290, 27, 30, "Input",ExpressionUUID->"335f3aef-2f8a-41e1-b211-84449664db25"],
Cell[167203, 3860, 332, 8, 34, "Output",ExpressionUUID->"133bbb51-1c1c-4e66-be4b-62d2a8c0c3d2"]
}, Open  ]],
Cell[167550, 3871, 1498, 24, 189, "Text",ExpressionUUID->"853b8345-5510-4b61-97ee-15305c5f6e9c"],
Cell[CellGroupData[{
Cell[169073, 3899, 473, 11, 30, "Input",ExpressionUUID->"9a14e253-7325-4049-b35e-132cdd433d23"],
Cell[169549, 3912, 317, 6, 34, "Output",ExpressionUUID->"48c04e27-162c-4536-8b3f-54c6abe1aad4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169903, 3923, 472, 11, 30, "Input",ExpressionUUID->"236fe45a-0d21-4af5-9c29-348670e46ea9"],
Cell[170378, 3936, 216, 4, 34, "Output",ExpressionUUID->"9a2ca045-13e5-4f9b-84b1-8163316a3cb4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170631, 3945, 1194, 27, 52, "Input",ExpressionUUID->"cba80840-8cb7-44ae-915e-004902eb6120"],
Cell[171828, 3974, 432, 10, 34, "Output",ExpressionUUID->"450d3285-8132-4197-89f6-010cda1c33ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172297, 3989, 1577, 35, 52, "Input",ExpressionUUID->"044e269b-47bd-4d5e-a6fc-ce4ca6274f0f"],
Cell[173877, 4026, 495, 10, 34, "Output",ExpressionUUID->"d5f5366d-3526-4b32-a43d-4fd5466a9750"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174409, 4041, 1162, 26, 52, "Input",ExpressionUUID->"088735be-5039-4d98-9660-079b4648cce3"],
Cell[175574, 4069, 288, 7, 34, "Output",ExpressionUUID->"a9078277-d364-4b17-97d4-968e41e47ec9"]
}, Open  ]],
Cell[175877, 4079, 685, 11, 74, "Text",ExpressionUUID->"7e7743bf-6e0f-4d77-b860-6885af8aa1ce"],
Cell[CellGroupData[{
Cell[176587, 4094, 324, 7, 30, "Input",ExpressionUUID->"0bac5d1a-13af-4419-8e69-bad74c3a0477"],
Cell[176914, 4103, 264, 7, 34, "Output",ExpressionUUID->"0020dac4-aa74-4124-82fc-fc9817867207"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177215, 4115, 1336, 27, 30, "Input",ExpressionUUID->"d6977147-1323-4c65-8487-7484c353a85b"],
Cell[178554, 4144, 278, 5, 34, "Output",ExpressionUUID->"eacdb752-195f-4fd7-a057-d0b0295707a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[178869, 4154, 252, 5, 30, "Input",ExpressionUUID->"71bb9780-5c63-45eb-ab16-37bbb497dce3"],
Cell[179124, 4161, 290, 7, 34, "Output",ExpressionUUID->"399b11c4-4423-4f78-9850-ba36baf54881"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179451, 4173, 1139, 25, 30, "Input",ExpressionUUID->"74e92b25-5712-4b17-8445-fc19bdf2d0bf"],
Cell[180593, 4200, 499, 8, 34, "Output",ExpressionUUID->"bbd08b6b-a505-4c62-9d7a-6c380e7ddd73"]
}, Open  ]],
Cell[181107, 4211, 369, 7, 51, "Text",ExpressionUUID->"893e883c-7bde-4ffb-90dd-874dcab9a5e3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181513, 4223, 335, 5, 67, "Section",ExpressionUUID->"62e41cfb-bf1e-4528-8dff-d7cf41579d46"],
Cell[181851, 4230, 1563, 23, 143, "Text",ExpressionUUID->"2288d7c7-daec-4289-befc-122a82a2b65f"],
Cell[183417, 4255, 3564, 98, 131, "Input",ExpressionUUID->"7c9289ec-ab0e-4bcf-b6de-efed6f5a86ed",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[187006, 4357, 229, 4, 30, "Input",ExpressionUUID->"b4126a2c-5a89-49bd-843b-9737653fc2b9"],
Cell[187238, 4363, 457, 9, 34, "Output",ExpressionUUID->"c3a81515-7976-46c2-b342-7cf59f4e8495"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187732, 4377, 369, 7, 30, "Input",ExpressionUUID->"57665152-9652-4aa0-a6f9-6dae687939bc"],
Cell[188104, 4386, 563, 12, 56, "Output",ExpressionUUID->"46b1cc4f-9654-4389-bc77-779d1808e749"]
}, Open  ]],
Cell[188682, 4401, 2924, 67, 257, "Input",ExpressionUUID->"8639ca1b-0889-4de5-ba6e-50cfb1b27856",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[191631, 4472, 454, 10, 30, "Input",ExpressionUUID->"57105204-eeea-4bbe-a786-961d65fca50d"],
Cell[192088, 4484, 4645, 130, 242, "Output",ExpressionUUID->"5c314db2-247b-4e34-919f-49334102e6f4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[196770, 4619, 420, 9, 30, "Input",ExpressionUUID->"7a815e52-6622-4979-8871-acb23154fae2"],
Cell[197193, 4630, 2137, 59, 98, "Output",ExpressionUUID->"2cd20336-52a4-4789-8ebd-22a1cc6767ed"]
}, Open  ]],
Cell[199345, 4692, 698, 17, 89, "Input",ExpressionUUID->"8bf513d9-c4b4-4fb7-9d6b-48b22ec3156e",
 InitializationCell->True],
Cell[200046, 4711, 2796, 65, 173, "Input",ExpressionUUID->"490bc627-b582-4087-af95-de5220a5f6fd",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[202867, 4780, 226, 4, 30, "Input",ExpressionUUID->"1fd8813c-c36f-4da7-95bc-3053fe5dd21e"],
Cell[203096, 4786, 27562, 797, 925, "Output",ExpressionUUID->"7d1584db-3ff7-44fe-8800-5734187a3612"]
}, Closed]],
Cell[CellGroupData[{
Cell[230695, 5588, 357, 7, 26, "Input",ExpressionUUID->"8463ea4f-2f7b-44b0-a17b-b987730ead4b"],
Cell[231055, 5597, 1185, 26, 56, "Output",ExpressionUUID->"5ecac96e-df53-407e-b0a4-8bc97196bd60"]
}, Open  ]],
Cell[CellGroupData[{
Cell[232277, 5628, 262, 5, 30, "Input",ExpressionUUID->"6dffd76c-4202-4b84-96a6-388c01dde44f"],
Cell[232542, 5635, 180, 3, 34, "Output",ExpressionUUID->"a298596f-e0ab-491a-a945-fbe4dc63ff9c"]
}, Open  ]],
Cell[232737, 5641, 2032, 30, 166, "Text",ExpressionUUID->"38725cd3-3614-45e7-b58b-6acc27db4061"],
Cell[234772, 5673, 4372, 105, 278, "Input",ExpressionUUID->"77a91b69-50fd-427a-8f6c-c6630bb38c86",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[239169, 5782, 318, 6, 30, "Input",ExpressionUUID->"eef07376-415c-4f4d-8c5b-57f009fc7c85"],
Cell[239490, 5790, 5382, 94, 129, "Print",ExpressionUUID->"7594539f-63c8-40b1-a68c-49726129f48c"],
Cell[244875, 5886, 1183, 26, 56, "Output",ExpressionUUID->"15297e68-9371-4d6c-9017-5281f362b6d5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[246095, 5917, 212, 4, 30, "Input",ExpressionUUID->"d231b156-c319-4953-a48d-8f8cd53618bf"],
Cell[246310, 5923, 158, 3, 34, "Output",ExpressionUUID->"4a4ade92-f4c6-48b7-b763-87c4a8861718"]
}, Open  ]],
Cell[CellGroupData[{
Cell[246505, 5931, 340, 6, 30, "Input",ExpressionUUID->"25f5dd38-2759-4159-924a-67b4f49014c5"],
Cell[246848, 5939, 1870, 46, 77, "Output",ExpressionUUID->"36efa7a1-8238-481b-8cd2-a5fe20c9643e"]
}, Open  ]],
Cell[248733, 5988, 1752, 26, 97, "Text",ExpressionUUID->"cd72aaf7-7365-4088-b52b-40d7ee21e695"],
Cell[250488, 6016, 3391, 94, 194, "Input",ExpressionUUID->"a5b6a1a4-ad14-407d-86b5-a698baa6fa6e",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[253904, 6114, 312, 6, 30, "Input",ExpressionUUID->"ea14b13a-df06-4137-a911-affb1ac48c0c"],
Cell[254219, 6122, 1677, 57, 77, "Output",ExpressionUUID->"7a0b9233-1827-4cdd-b84f-05396bd1a93d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255933, 6184, 511, 12, 52, "Input",ExpressionUUID->"59f09154-82d6-493d-80cd-a7f1631dad43"],
Cell[256447, 6198, 1547, 34, 298, "Output",ExpressionUUID->"41e74062-26fe-431e-9d9f-4ab073b11f28"]
}, Closed]],
Cell[258009, 6235, 1808, 35, 127, "Input",ExpressionUUID->"4661d0e3-1c30-40e3-bdc0-5bfe8e59a90e",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[259842, 6274, 903, 18, 30, "Input",ExpressionUUID->"4b7399d0-58d0-45ba-a821-5bddd609ac30"],
Cell[260748, 6294, 711, 12, 34, "Output",ExpressionUUID->"9a67242f-7d91-4b34-a2f2-e33a3a0f474a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[261496, 6311, 1347, 27, 52, "Input",ExpressionUUID->"6f1aaa88-7a1e-4e7d-8a80-bc317c7c5ed3"],
Cell[262846, 6340, 264, 7, 34, "Output",ExpressionUUID->"e5cd13c4-9b22-41b0-8718-600a55dae4bd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[263147, 6352, 1371, 28, 52, "Input",ExpressionUUID->"39b640df-ff0c-478e-b38e-c113d0dda5b3"],
Cell[264521, 6382, 300, 5, 34, "Output",ExpressionUUID->"c50fb419-ba40-4776-9b40-a31c6b5218c9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[264858, 6392, 1178, 25, 52, "Input",ExpressionUUID->"d4da3d12-fbf6-4b1f-b8f5-5bbfdba31f66"],
Cell[266039, 6419, 525, 9, 34, "Output",ExpressionUUID->"aaef234c-1caa-4800-b814-510dc342d154"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[266613, 6434, 395, 6, 67, "Section",ExpressionUUID->"beb17e0a-6e6d-4f97-8bbe-8deacf6a9af6"],
Cell[267011, 6442, 2425, 46, 580, "Text",ExpressionUUID->"98ba0c9b-fb80-4659-89a1-e3d681111cc9"],
Cell[269439, 6490, 5316, 119, 425, "Input",ExpressionUUID->"5334a71f-b7a7-495d-a5fa-7f5785285f42",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[274780, 6613, 411, 10, 30, "Input",ExpressionUUID->"07a539ea-6597-49b9-873e-cdfa4547ba8a"],
Cell[275194, 6625, 4447, 128, 218, "Output",ExpressionUUID->"8216c71f-9698-4185-9b96-dc9c13511d0d"]
}, Open  ]],
Cell[279656, 6756, 967, 25, 110, "Input",ExpressionUUID->"3f40438d-4f8c-41d8-8bc9-c012c7facb27",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[280648, 6785, 388, 9, 30, "Input",ExpressionUUID->"a2d9c8c8-b741-42f8-89e3-8ea047d3a049"],
Cell[281039, 6796, 1095, 33, 74, "Output",ExpressionUUID->"dd090ea7-4a6c-4e2a-8a1f-66d1338ed984"]
}, Open  ]],
Cell[282149, 6832, 982, 24, 110, "Input",ExpressionUUID->"04db65a5-f7c1-4d07-b8ae-a2a156d81201",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[283156, 6860, 259, 6, 30, "Input",ExpressionUUID->"26d998d8-1f52-400a-b594-5ef1b8ae043e"],
Cell[283418, 6868, 55739, 1595, 3290, "Output",ExpressionUUID->"c7ea05c9-bedd-4fb8-86c2-7f6faf004890"]
}, Closed]],
Cell[339172, 8466, 2912, 67, 169, "Input",ExpressionUUID->"7f417511-41fd-4819-b492-dfee9f1c564a",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[342109, 8537, 504, 9, 30, "Input",ExpressionUUID->"805c94f9-8c8f-4a04-ab8b-d2c4d2d28472"],
Cell[342616, 8548, 1166, 27, 56, "Output",ExpressionUUID->"2dbd3790-bd30-4ad9-b441-670660a0538b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343819, 8580, 215, 4, 30, "Input",ExpressionUUID->"591aaabc-3fb1-472a-9f6e-7d97bdc9b5c0"],
Cell[344037, 8586, 158, 3, 34, "Output",ExpressionUUID->"9cb992ad-1dd2-4edc-9e14-0e12caa87c72"]
}, Open  ]],
Cell[344210, 8592, 4411, 105, 278, "Input",ExpressionUUID->"99cbf48d-e540-4e21-906d-c537ea2ed12b",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[348646, 8701, 364, 7, 30, "Input",ExpressionUUID->"7b2fef39-64ab-41f7-9594-c7ae8336a1d1"],
Cell[349013, 8710, 7612, 131, 251, "Print",ExpressionUUID->"0d85fa39-fa59-4205-94ee-4fa90efda3e1"],
Cell[356628, 8843, 1211, 27, 56, "Output",ExpressionUUID->"0f57bc42-c605-4833-a421-c06dbb612b6f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[357876, 8875, 212, 4, 30, "Input",ExpressionUUID->"0785eeac-b144-4632-aa13-0eff7bb3ab4c"],
Cell[358091, 8881, 180, 3, 34, "Output",ExpressionUUID->"5fb8ce8b-1389-42ed-b30e-56561502e56a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[358308, 8889, 389, 7, 30, "Input",ExpressionUUID->"7e641a55-2df2-4127-b88d-cda0936db802"],
Cell[358700, 8898, 4640, 126, 182, "Output",ExpressionUUID->"f5057879-59c8-4866-9218-47824b4446e8"]
}, Open  ]],
Cell[363355, 9027, 1850, 35, 131, "Input",ExpressionUUID->"8303592c-3f36-4608-b088-10d90f14dbb5",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[365230, 9066, 951, 19, 30, "Input",ExpressionUUID->"340b7b1c-b362-40fb-8a00-4f70900874f9"],
Cell[366184, 9087, 737, 13, 34, "Output",ExpressionUUID->"fdd47a49-7cfc-4fd2-8d02-eca353723333"]
}, Open  ]],
Cell[CellGroupData[{
Cell[366958, 9105, 1396, 28, 52, "Input",ExpressionUUID->"7075bd83-8aa7-4ec1-9da1-8cbd364be334"],
Cell[368357, 9135, 286, 7, 34, "Output",ExpressionUUID->"5a41471e-9afc-4ddd-9f77-2135b0240f46"]
}, Open  ]],
Cell[CellGroupData[{
Cell[368680, 9147, 1414, 28, 52, "Input",ExpressionUUID->"fccf75f1-590c-4884-b2da-7cf90d6f9ab6"],
Cell[370097, 9177, 322, 5, 34, "Output",ExpressionUUID->"224341ea-cdf9-4d60-bd97-3dcc589b1f90"]
}, Open  ]],
Cell[CellGroupData[{
Cell[370456, 9187, 1225, 26, 52, "Input",ExpressionUUID->"febe96bb-0306-4134-9ab7-34ae5bd5a49e"],
Cell[371684, 9215, 182, 3, 34, "Output",ExpressionUUID->"c1b93d77-c2f7-424f-a069-74a67f86a38e"]
}, Open  ]],
Cell[371881, 9221, 1468, 22, 97, "Text",ExpressionUUID->"61e4cf0f-0de9-46e2-b7a0-855129fd4da5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[373386, 9248, 235, 4, 67, "Section",ExpressionUUID->"40c59b8a-c187-474d-a831-c334fc7554ba"],
Cell[373624, 9254, 1377, 21, 120, "Text",ExpressionUUID->"77edbc7e-5c65-450a-884d-6a7a95a37844"],
Cell[375004, 9277, 1216, 31, 89, "Input",ExpressionUUID->"584507ff-c08d-4c98-99d1-2a3249c960fa",
 InitializationCell->True],
Cell[376223, 9310, 1455, 36, 131, "Input",ExpressionUUID->"a2747571-2ed4-4475-9648-971a4bfe6c4b",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[377703, 9350, 181, 4, 30, "Input",ExpressionUUID->"b50b5c1d-f6bc-4ab1-bdb2-94f741859237"],
Cell[377887, 9356, 2354, 78, 98, "Output",ExpressionUUID->"772ad7b3-bf01-4e9c-b6ac-aafbf60713eb"]
}, Open  ]],
Cell[380256, 9437, 1771, 26, 143, "Text",ExpressionUUID->"d8320302-cb5c-4991-8e97-44d0446f4fb0"],
Cell[382030, 9465, 2363, 51, 152, "Input",ExpressionUUID->"e23bf3df-62f9-414b-bd7c-71c81cd77ce9",
 InitializationCell->True],
Cell[384396, 9518, 4628, 103, 488, "Input",ExpressionUUID->"9d7be80d-de35-4dfb-96f8-d404381a67a2",
 InitializationCell->True],
Cell[389027, 9623, 330, 8, 30, "Input",ExpressionUUID->"417e2b52-294b-4496-b5b4-448089c4ff78"],
Cell[389360, 9633, 332, 8, 30, "Input",ExpressionUUID->"c58b9bd7-1fd4-44dd-a634-ca612d8708e5"],
Cell[389695, 9643, 330, 8, 30, "Input",ExpressionUUID->"5ed1c86b-2f44-428a-aa61-1c30f945f7bd"],
Cell[390028, 9653, 310, 8, 30, "Input",ExpressionUUID->"7f1b6e0b-c99d-4122-9c6e-c0d91b46326c"],
Cell[390341, 9663, 310, 8, 30, "Input",ExpressionUUID->"377c020c-0bfa-42e7-8b1f-530bc86e760b"],
Cell[390654, 9673, 310, 8, 30, "Input",ExpressionUUID->"5a5caf80-a65f-4eaa-b7e6-9456da15b77a"],
Cell[390967, 9683, 887, 14, 120, "Text",ExpressionUUID->"d7c95c24-0236-474e-b7c4-5d04ef4df6e2"],
Cell[391857, 9699, 389, 8, 30, "Input",ExpressionUUID->"8760279b-62f3-41e8-a83c-4b9f63be7283"],
Cell[392249, 9709, 391, 8, 30, "Input",ExpressionUUID->"33ef9358-1cf9-41d4-ae75-c40a67a58d42"],
Cell[392643, 9719, 391, 8, 30, "Input",ExpressionUUID->"4ffb4414-c3e5-4f35-b2cc-7dc03733d22d"],
Cell[393037, 9729, 391, 8, 30, "Input",ExpressionUUID->"3c26f50d-4664-4ac7-b271-d3ea25e9a7bd"],
Cell[393431, 9739, 393, 8, 30, "Input",ExpressionUUID->"1ae9f80f-179b-43c0-a3fc-9419e368c7c5"],
Cell[393827, 9749, 393, 8, 30, "Input",ExpressionUUID->"877c4669-132f-4a0e-b893-588152062e1a"],
Cell[CellGroupData[{
Cell[394245, 9761, 367, 8, 30, "Input",ExpressionUUID->"b2403e53-80ff-451c-b25b-cc8476f72f66"],
Cell[394615, 9771, 320, 6, 34, "Output",ExpressionUUID->"4b817a55-91c9-4379-98ba-d47deacd2eb7"]
}, Open  ]],
Cell[394950, 9780, 1534, 23, 97, "Text",ExpressionUUID->"677a1458-55ec-4598-b274-255938c5a5a3"],
Cell[396487, 9805, 3367, 78, 215, "Input",ExpressionUUID->"f65b9b59-e440-45b6-8697-53c43c71575f",
 InitializationCell->True],
Cell[399857, 9885, 2670, 61, 278, "Input",ExpressionUUID->"26d926c8-9d35-4bbb-ae5d-c709a8011f8f",
 InitializationCell->True],
Cell[402530, 9948, 440, 12, 52, "Input",ExpressionUUID->"6be57fbc-d6d9-4a2b-a1a8-a4389773ab7d"],
Cell[402973, 9962, 442, 12, 52, "Input",ExpressionUUID->"686c4a7d-5b00-4be3-96cd-b83f76b0900a"],
Cell[403418, 9976, 466, 12, 52, "Input",ExpressionUUID->"bdaf8477-30b1-4e2f-b4d0-98ffdd72fde4"],
Cell[403887, 9990, 468, 12, 52, "Input",ExpressionUUID->"82f1cf82-a8c6-4d5e-ba91-2462f442c65e"],
Cell[404358, 10004, 515, 13, 52, "Input",ExpressionUUID->"c1297778-580a-40a1-b165-417d9f75940c"],
Cell[404876, 10019, 514, 13, 52, "Input",ExpressionUUID->"1b702f6b-faf9-4c26-9705-ca7ca3d42377"],
Cell[405393, 10034, 476, 9, 51, "Text",ExpressionUUID->"0f8e94f1-5e27-4d5c-91a6-2f8a47ed30c7"],
Cell[405872, 10045, 289, 5, 30, "Input",ExpressionUUID->"4e72bcf3-5937-44ff-9ff4-2333abb4d999"],
Cell[CellGroupData[{
Cell[406186, 10054, 394, 8, 30, "Input",ExpressionUUID->"c8d57421-97b8-4d82-8472-5f30e6baaa44"],
Cell[406583, 10064, 271, 5, 34, "Output",ExpressionUUID->"bfe4cc13-b50d-490b-baaf-d2ae9156df55"]
}, Open  ]],
Cell[CellGroupData[{
Cell[406891, 10074, 7671, 174, 451, "Input",ExpressionUUID->"093c1b16-59fd-4cc2-8e59-9ad350b21714"],
Cell[CellGroupData[{
Cell[414587, 10252, 1413, 36, 44, "Print",ExpressionUUID->"4ef890c1-bd82-4032-a83c-6b0a15b02010"],
Cell[416003, 10290, 1278, 31, 44, "Print",ExpressionUUID->"b860e44b-cd77-482e-82dd-83131b766112"]
}, Open  ]],
Cell[417296, 10324, 33216, 640, 621, "Output",ExpressionUUID->"d34fb675-a178-483e-90fb-dce5c7a26fdd"]
}, Open  ]],
Cell[450527, 10967, 724, 12, 74, "Text",ExpressionUUID->"5423a493-f869-4b25-8df6-b3cea0392145"]
}, Open  ]],
Cell[CellGroupData[{
Cell[451288, 10984, 157, 3, 67, "Section",ExpressionUUID->"4a5f0e73-b277-47e5-9242-cb22d629f011"],
Cell[451448, 10989, 632, 10, 74, "Text",ExpressionUUID->"e972fe3f-ff7b-4a10-b851-3876116e09a3"],
Cell[452083, 11001, 604, 11, 30, "Input",ExpressionUUID->"76beb90e-ed3a-4b27-ae6a-28adad8300ea"],
Cell[452690, 11014, 189, 4, 30, "Input",ExpressionUUID->"fb85f81b-de06-478f-b14f-ff26a660ba8a"],
Cell[452882, 11020, 836, 14, 74, "Text",ExpressionUUID->"b8eebe28-e5ad-47fb-86f5-1a0ddd8fbc18"],
Cell[453721, 11036, 1906, 41, 534, "Text",ExpressionUUID->"32f77d05-a26c-47ed-8269-32b32e024eba"],
Cell[455630, 11079, 5217, 115, 425, "Input",ExpressionUUID->"9e101ded-c667-46e0-9fed-07a48a234e32",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[460872, 11198, 461, 10, 30, "Input",ExpressionUUID->"364b4e2e-bda9-49d7-ad60-fd61a35b3e80"],
Cell[461336, 11210, 4100, 117, 218, "Output",ExpressionUUID->"3ec44952-70b1-41f8-98e1-e03bd91b1616"]
}, Open  ]],
Cell[465451, 11330, 957, 23, 110, "Input",ExpressionUUID->"77d75d75-f59d-472e-975f-0a900fcb7cc4",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[466433, 11357, 484, 9, 30, "Input",ExpressionUUID->"6fc5d25b-4b0d-48b3-b2c9-88500b9dcfee"],
Cell[466920, 11368, 1087, 32, 74, "Output",ExpressionUUID->"02c36396-093e-4591-a7cd-5fb6b461f676"]
}, Open  ]],
Cell[468022, 11403, 1094, 26, 110, "Input",ExpressionUUID->"8802f731-d8c0-4787-8fac-c99e88b3c781",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[469141, 11433, 307, 6, 30, "Input",ExpressionUUID->"e6a69207-2ddf-4946-aa03-fdf2acf14a91"],
Cell[469451, 11441, 50162, 1412, 3290, "Output",ExpressionUUID->"3c0987d8-88dc-4ba0-8fa2-905b41ca9c42"]
}, Closed]],
Cell[519628, 12856, 3014, 69, 169, "Input",ExpressionUUID->"56e87709-3dad-474e-9d52-9335372449c4",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[522667, 12929, 549, 8, 30, "Input",ExpressionUUID->"b834fc04-640b-4ce2-ba00-86224a5dd1aa"],
Cell[523219, 12939, 1184, 26, 56, "Output",ExpressionUUID->"a0b60f59-5abc-48b9-9d51-735765f3bd05"]
}, Open  ]],
Cell[CellGroupData[{
Cell[524440, 12970, 211, 3, 30, "Input",ExpressionUUID->"b21367c6-f14e-4fb5-975c-f8df949c24dc"],
Cell[524654, 12975, 176, 2, 34, "Output",ExpressionUUID->"fa37003a-0acb-4cab-956a-790dbfe4dc7e"]
}, Open  ]],
Cell[524845, 12980, 356, 8, 30, "Input",ExpressionUUID->"8d2b4bc2-f06d-44a5-a917-52dcf13815f0"],
Cell[CellGroupData[{
Cell[525226, 12992, 289, 6, 30, "Input",ExpressionUUID->"53f48fb4-9896-4871-95fa-8162bb57b6da"],
Cell[525518, 13000, 176, 2, 34, "Output",ExpressionUUID->"185be999-e732-4d93-9135-1a962fe34e8f"]
}, Open  ]]
}, Open  ]]
}
]
*)

