(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    437458,       7621]
NotebookOptionsPosition[    433063,       7490]
NotebookOutlinePosition[    434154,       7522]
CellTagsIndexPosition[    433924,       7515]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Note: requires CRNSimulator.m to be loaded.", "Text",
 CellChangeTimes->{{3.521032815786957*^9, 3.521032822918911*^9}}],

Cell["See basic documentation for the key functions:", "Text",
 CellChangeTimes->{{3.656291888224341*^9, 3.656291897098534*^9}, {
  3.665621499107088*^9, 3.665621507327568*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SimulateRxnsys"}]], "Input",
 CellChangeTimes->{{3.665621087307007*^9, 3.665621094031432*^9}}],

Cell[BoxData[
 StyleBox["\<\"SimulateRxnsys[rxnsys,endtime] simulates the reaction system \
rxnsys for time 0 to endtime. In rxnsys, initial concentrations are specified \
by conc statements. If no initial condition is set for a species, its initial \
concentration is set to 0. Rxnsys can include term[] statements (eg. term[x, \
-2 x[t]]) which are additively combined together with term[]s derived from \
rxn[] statements. Rxnsys can also include ODEs directly for some species (Eg \
x'[t]==...) that are passed on to NDSolve without modification.\\nAny options \
specified (eg WorkingPrecision->30) are passed to NDSolve.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.665623548791313*^9},
 CellTags->"Info-c53a0585-9331-41fd-a5bf-e9baef649dbe"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "RxnsysToOdesys"}]], "Input",
 CellChangeTimes->{{3.665621532095591*^9, 3.66562153489965*^9}}],

Cell[BoxData[
 StyleBox["\<\"RxnsysToOdesys[rxnsys,t] returns the ODEs corresponding to \
reaction system rxnsys, with initial conditions. If no initial condition is \
set for a species, its initial concentration is set to 0. The time variable \
is given as the second argument; if omitted it is set to Global`t.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6656235490728283`*^9},
 CellTags->"Info-48f1dae4-c3c0-4ae4-969b-bad5886db60f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SpeciesInRxnsys"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"SpeciesInRxnsys[rxnsys] returns the species in reaction system \
rxnsys. SpeciesInRxnsys[rxnsys,pttrn] returns the species in reaction system \
rxnsys matching Mathematica pattern pttrn (eg x[1,_]).\"\>", "MSG"]], "Print",\
 "PrintUsage",
 CellChangeTimes->{3.665623549181398*^9},
 CellTags->"Info-884ad53b-0653-463f-b05a-cbeb768e1d34"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Predator-Prey", "Subsection",
 CellChangeTimes->{{3.506895078210659*^9, 3.506895081203388*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsys", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rxn", "[", 
      RowBox[{
       RowBox[{"x1", "+", "x2"}], ",", 
       RowBox[{"2", "x2"}], ",", "1.5"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"rxn", "[", 
      RowBox[{"x1", ",", 
       RowBox[{"2", "x1"}], ",", "1"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"rxn", "[", 
      RowBox[{"x2", ",", "1", ",", "1"}], "]"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"conc", "[", 
      RowBox[{"x1", ",", "2"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"conc", "[", 
      RowBox[{"x2", ",", "1"}], "]"}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4687025505360613`*^9, 3.468702614243576*^9}, {
  3.468702684046033*^9, 3.468702797275187*^9}, {3.4687029541813297`*^9, 
  3.46870296099183*^9}, {3.469219349717853*^9, 3.4692193497885027`*^9}, {
  3.46921938334344*^9, 3.469219394567686*^9}, {3.469227269508279*^9, 
  3.469227271243472*^9}, {3.471011641403061*^9, 3.47101164496911*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmax", "=", "45"}], ";"}]], "Input",
 CellChangeTimes->{{3.468702590790525*^9, 3.46870259330956*^9}, {
  3.469219715993766*^9, 3.4692197162713614`*^9}, {3.469223306116238*^9, 
  3.469223306180459*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"SimulateRxnsys", "[", 
    RowBox[{"rsys", ",", "tmax"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.468702595192546*^9, 3.468702633689616*^9}, 
   3.470085615769067*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotter", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x1", "[", "t", "]"}], ",", 
      RowBox[{"x2", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.46826276617019*^9, 3.468262777359262*^9}, {
  3.468262836992633*^9, 3.468262958884576*^9}, {3.468263018256619*^9, 
  3.468263075130353*^9}, {3.468263285918445*^9, 3.468263381543727*^9}, {
  3.468263413380739*^9, 3.468263429243466*^9}, {3.468365679383275*^9, 
  3.468365778320983*^9}, {3.4683668032722387`*^9, 3.468366847508575*^9}, {
  3.46836804449853*^9, 3.468368052412436*^9}, {3.4683705728813553`*^9, 
  3.46837057352957*^9}, {3.468435768604846*^9, 3.468435774568234*^9}, {
  3.468702655162812*^9, 3.468702655310307*^9}, {3.506895021805895*^9, 
  3.506895031204191*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"plotter", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "All"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "Red", "}"}], ",", 
      RowBox[{"{", "Green", "}"}], ",", 
      RowBox[{"{", "Blue", "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.4682630393343*^9, {3.46826314956773*^9, 3.4682632247667227`*^9}, 
   3.4682633965844316`*^9, 3.468365788765299*^9, 3.468368200449752*^9, {
   3.4683705819263353`*^9, 3.4683705828664303`*^9}, {3.468370815007806*^9, 
   3.4683708177190523`*^9}, {3.468702659743595*^9, 3.4687026735143642`*^9}, {
   3.468703124142672*^9, 3.468703126418498*^9}, {3.50689505627216*^9, 
   3.506895056701329*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwUWHc81e8Xv4SUXcjee6/LNc8hJMooIUollSZKKiOjIspqCEmpr5IGIeRe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     "]]}, 
   {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwUmnc81d8fx2+FiOy9996uefF+J7uloiQaNtlFElIpUaRFA/k2JZGGcK89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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0., 44.99999908163265}, {0, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.506895035337945*^9, 3.506895059875478*^9}, {
   3.5738441290709133`*^9, 3.573844155121922*^9}, 3.6433215937878036`*^9, 
   3.6433216489018297`*^9, 3.643322075954582*^9, 3.6656210981400023`*^9, 
   3.665621562385086*^9, 3.665621655582651*^9, {3.6656235320866127`*^9, 
   3.6656235493490887`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Showing: reversible reactions, nanomolar concentrations", "Subsection",
 CellChangeTimes->{{3.506895103099546*^9, 3.506895220085722*^9}, {
  3.6433217229489517`*^9, 3.643321727196405*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsys", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"revrxn", "[", 
      RowBox[{
       RowBox[{"a", "+", "b"}], ",", "c", ",", 
       RowBox[{"1.5", " ", 
        RowBox[{"10", "^", "6"}]}], ",", "10"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"rxn", "[", 
      RowBox[{
       RowBox[{"2", "a"}], ",", "b", ",", 
       RowBox[{"10", "^", "5"}]}], "]"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"conc", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
       RowBox[{"10", "^", 
        RowBox[{"-", "9"}]}]}], "]"}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4687025505360613`*^9, 3.468702614243576*^9}, {
  3.468702684046033*^9, 3.468702797275187*^9}, {3.4687029541813297`*^9, 
  3.46870296099183*^9}, {3.469219349717853*^9, 3.4692193497885027`*^9}, {
  3.46921938334344*^9, 3.469219394567686*^9}, {3.469227269508279*^9, 
  3.469227271243472*^9}, {3.471011641403061*^9, 3.47101164496911*^9}, {
  3.5068952342322187`*^9, 3.506895331541938*^9}, {3.5068954289150667`*^9, 
  3.506895500571403*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{"10", "*", "60", "*", "60"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.468702590790525*^9, 3.46870259330956*^9}, {
  3.469219715993766*^9, 3.4692197162713614`*^9}, {3.469223306116238*^9, 
  3.469223306180459*^9}, {3.506895371257526*^9, 3.5068953737726603`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"SimulateRxnsys", "[", 
    RowBox[{"rsys", ",", "tmax"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.468702595192546*^9, 3.468702633689616*^9}, 
   3.470085615769067*^9, {3.506895354661997*^9, 3.506895354885285*^9}, {
   3.64332169336204*^9, 3.643321693536879*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotter", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], ",", 
      RowBox[{"b", "[", "t", "]"}], ",", 
      RowBox[{"c", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.46826276617019*^9, 3.468262777359262*^9}, {
  3.468262836992633*^9, 3.468262958884576*^9}, {3.468263018256619*^9, 
  3.468263075130353*^9}, {3.468263285918445*^9, 3.468263381543727*^9}, {
  3.468263413380739*^9, 3.468263429243466*^9}, {3.468365679383275*^9, 
  3.468365778320983*^9}, {3.4683668032722387`*^9, 3.468366847508575*^9}, {
  3.46836804449853*^9, 3.468368052412436*^9}, {3.4683705728813553`*^9, 
  3.46837057352957*^9}, {3.468435768604846*^9, 3.468435774568234*^9}, {
  3.468702655162812*^9, 3.468702655310307*^9}, {3.506895021805895*^9, 
  3.506895031204191*^9}, {3.506895362169972*^9, 3.506895364885762*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"plotter", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "All"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "Red", "}"}], ",", 
      RowBox[{"{", "Green", "}"}], ",", 
      RowBox[{"{", "Blue", "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.4682630393343*^9, {3.46826314956773*^9, 3.4682632247667227`*^9}, 
   3.4682633965844316`*^9, 3.468365788765299*^9, 3.468368200449752*^9, {
   3.4683705819263353`*^9, 3.4683705828664303`*^9}, {3.468370815007806*^9, 
   3.4683708177190523`*^9}, {3.468702659743595*^9, 3.4687026735143642`*^9}, {
   3.468703124142672*^9, 3.468703126418498*^9}, {3.50689505627216*^9, 
   3.506895056701329*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwVyns01Pkfx3Ejt0LDjCFTmiHXTURTLvX59F61I9XKhrJqd12SqZ3Erku5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     "]]}, 
   {RGBColor[0, 1, 0], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwVx3k4lQkbgHFUtGGkU0J0lvf1nrJkp8zTQxKFJBJSyliarH2oQSl7ESVl
iYpjy1BOOEX4RFTSsYRkjW+G7CJSc9T0/XFf9/Wjn/SxdhUREhIK/9n/b3o9
fYOktOmuCYslysBSCnKfvirwpJEoOBF57aAOHbzi/4wwoOng6x3BRcO76BCu
+NV+MAHxeyTX3c2MDi1n0/1YNBNcenNJtNWaDptbdl12T9uPPTWK7eRROmgn
+Vl1JFjhx/VTNA9XOoRNrPeQoR1G38oUoQdn6ZCfMjxX/u4Ick4JlEsu0qHZ
+EmoY5ojLlXvbc++TId4ftH+5gRnzOvOire8TYce8qDLOpobEjRlh9oqOkwJ
9Nkuge5YoG2zWqOBDiJvGdMl7zzQ/kyh1DU+HajQz0G2aafxZZKusMwAHSrG
95s1JfgiY5+OvtMPOogZTztL0gJRwahh8aMBA355+L+6x/WByFd5r3zYmAGy
sl2kc+BZbDnS31i6nwGqMzUTxe/OoaGzwoiJAwNs0hPPWacFY4S5jn5dIAOs
vsm+bEy4iCtkLM5CEQMyrKsHxGlR6PO+Zqe2FBNExihai38UrrMV5dzcyAS3
Szf2JbZHoYXWo9nRzUzYXuxRtiEpGg2F/+rw3sqEWnHpWEXpy7hoOWQ+acSE
4ZfuOupScRidW+Tb5ceE5LsxJgWi1/FGksxelZdM2Df+64lYnesoMW+YZPyG
CQKduWBPt+uYudHY8FAbE5z5TlzVhutYtjQtYdfLhK1LGvIlkYm4kDDZ+G2a
CZUOfZ+eLk/Clb5GYc9pLPhA08h4I5KMChHNaYOOLOhS+xoQppaMc55zzXXH
WdBsVmOpezQZhWwFAfdcWFB93lIosywZaT1Be8xOsyDj799d/D1S8NbOfFWH
IBY4lHHYcvxU1KtZmgxLZkGHDY3nkZqO5d0Fcnp8FjR598ZvbkhHk+gPrPOt
LHgew3Fvm03HGd2Zwap2FpRWqm8yMM/A+YuZqRo9LEhkWYZI/shAJY+V46Mj
LLD6HGXE++0uNuRv/3ZLiIC/zUJGhGUysfrZnngFNQIamQnSEyqZyB2amO9W
J6B4KXNX5+5MtFDwk0vSIiCE+yK5wCcT7fk5jwX6BKzbJG166EUm8ojwrjxj
AuDj/fzswCx8K2sS8rs9ASlR707t7eDgWwPjPfUXCbjgPHZTfZyDZlGqFcxw
Alx2LD2TE87Gqd964kMjCVCdYsjOKGfjxvgJD7UrBNTbejemRGRj4545e98b
BMyyVmwb08zB1IHjrUE5BJjXaUzEJebiHSeu9psXBBSUGaZaF+Si/ncx47WN
BIjlW5nI1Oai5KR3k2kTAbVx3vc4n3Jx9kWJY0ULAXqHC2wqrPJwuW7ScOh7
AohRetWIRD4a2PnvTBkj4LuEVLxR7H0U+o/dAZk1JDx0mFZbDC/EEatmZykT
ErZriVUqpRWiy7dOXtFeEorFFU3tiguRLx5y3dTsp2ssnXm9hbj1UlnvH+Y/
TT645q9dhKuFo5e9tibh0aznp5nhIgyyFTnIPk4C78rYo1Gzh2jf3ts5FEjC
8b7ZtEkxLjZWHXPLyyLhaGcIfU6ai/yVV1Mlskk40iyav6jIxdmBklj/HBKs
nsmWLdPjolVNW4lBPgmYY9S8yYOLUk1SRtVFJGzxSlxm8pKLFht5pdFPSBgS
qHveiXmEWqXCT+ANCa7yfr8eWFWKW55r9V+ZI6HzaRtHnlaKZTNFEvmfSTBx
1Fo9tqUUVa8wjj2fJ4FK+9IZoVeKclkax759IWFi4wXfCvdStF1x8rujgAR/
6VgO0VCKYSYP0xeWK0HE6pxVgrAy5BwXl7pGUwLOYldHvoCHPndNJyK0lEC3
3OkAVJVjygaZSFd3JXgV4/pxd3klhh2V9zhySwkeGVw5GRn2X9wS+fzM2kol
GDUxPzWg8AyX2Y3HOPcqweLCenWttFq8pZLO0/xHCTQ2eY6Sgjr0OrH5Y+56
CsZrI7itwfU4b9yXrK9CgeHORP9znxvwiZFsUIMRBbWEKlV16CXaeh3rHLP5
6eTY8fKWV1iZ7dxf60bBZPDZuzZar9Gi2GH/RAAFySMsl7yyJiz7PNs0HUFB
H/0FfUGNj0ZrVLw8Eymw5H9pGbrWjLHn3oquuEOBovD8i7roFhQvJUY49ylQ
sSlTdN3Rig3j9W7cEgouS8z4R4y2Is8wVm6wkoLsuDVtoXltuDzLemxbAwUd
u72VGo+8RY2FmPt7+BTUV3MjZmTaccUFjUPnOylYnukzkNTRjnl7V95Z3U/B
kUp/jZjIDvTzWllc8BcFnrcdrtoZd2L4oyEnn3EKbpZEfwhY6MSA4WWSrp8o
WKuppr4u5x1ulN/8eHKBgt2Bjy9fOdmFLkE83wwBBQmzUd0Hpd+jjOX2tTnC
bLitoas53/YenyhbtbeKsqHyT9WIkchunBJRlTy1hg3Kcffa7LR7UOW5c2CJ
JBsct89R2XM9WBq6c4Sxng33xK+e3ZXTizIHKrJoMmzIfiDG57n24fm6Hq1t
8mxY4AnohYx+DArYX/9dkQ3HFvW8Z9r6Uad9yuEUkw2RS7a1vyQOYLqXbME8
yYbBzU5iyPiA6cFxLoytbMjzNS/k/fEBNyx9l9qiwgYLQtn2dtcHjFKOWQPb
2XAhUC1ISX0Qda2ePVilyYZJd0Zan9kgumhevdf000ftaRU3Tg4i583puKta
bHi9b2W3WfAg3v3qFmSuzYYdBv98/XFjEIUSY86s0mHDv8lktgY=
     "]]}, 
   {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwVxXs8EwgcAPBRd/RYL9bR46SQK8nGZj1+/DTvR17zCL1m60YT3YlYndKQ
t6jPyiMtj5Ve6OgI1VQIw/Kollf3KS3UUrpVU3f3x/fzNWRF+nA0CQRCwH/+
3/lU4dKFOs62nsllDXLiYpvy220VPJIJVkcQw3YSORCRdUWwlUTD3rg8h981
OHDC4POO0WzEtBCjrtRpNnTHFh40IjlilrRzl0jBBurpg1592V7YP/RDU28P
GxIndLl6JH90SsyTLKxnQ5b0mltX9h48RZnkl6WxQW7iHbqEtA+/xthn/RbM
BtOEj/F++ftxmV6VTGDGhvpxN5eO7ChsSd5h/nomFLTs3+1ZSIrBGBvj4jZR
KJgr705UDhxG3UoRKyA6FJiFuYd98vk4WhB2z98pFLy+LGt9lH0Mi8odCu++
ZUGRT9MwkZSMl1U/TwgZLLCo5NYsPZ2CH1c8MCtZygIJUSfdQCcVB1Jmjru/
2QuvWn+lkRdnoK2dR2hy3l4QFp90rPjxFLpvnx/Dm9wDIyRKUaemEDXK5w6+
4u+GpqPbCaIaIZrFVzzt2LQbil6Gh0Zzz2KSqTKxRLULgmpKflkuPYeUAgmP
FLcL+pikWu65QpxL8/1aLtgJL12OjGnoidCVmjrh3RwMR6pahBWRIkxm5EwW
ZQfDEn0dZ98WEWo4GknzQ4LB5vXlS6UxF3HuuMP9YlUQnE0eCHPqK0HNxvYo
Nj0I3JspExm55bil56b8UW8gSDIOXCh5X47jd3yPRYgDge5fwaz3EmPi2VUh
mfGBYKwwbBxbcAlvserosasD4duCxVnb0i8j9fv7+LS4ALgR9G6j6sRVnBsf
5fkC/aHS5HpONPUamnCNRPvUflA9xXuvfHUN+an9m47W+UFt2ptqhcsN1KcR
r1DpfrB7cCp/UqsKc9bPnsVzZAKWbevS51ahiaPLfSttJqyKyJ3l2FqFFG2x
4V/tvvBCTeadP1mNy+8eVS0L8AXOioPgOedPFNPGDuIRHyhRPem7pK5Fe/qa
jvMa3mBdt9PTprEO5e+0BQ5lntB2kvOaUdeAvCEP/th+D6jemsZKSryD145q
Wd7PdwOFo3vY8M/38OH7iyOd2q6g+qRLtsqX4HpXp3DCCWeg6PMUJupm9OfT
N/FsnWBcIqjq4T/AgSvqiJWajmC3JTf68MeH+PnbgPW8CXuQGJubNvq24hxx
nHn4dwZIhOnjdd1tSEBRHYHEgEl+bDHTqh15h7SnXrlvA+GYUai4pgOLn9sX
NCXZwaBhi+GnjVIcnOlcoe5B2C79p/tFThdG3uz4/pCGYKAx3dKc0o1bEvJl
TlRb2MCsMeBs7kHCqb2KdSY2kLpAGS1Q9GAmZ/yxaANAacY8WYJYhl87xtNj
yVuhj3Fg7aPAx6hrIfug6bcFHjRVCZR6vZiVxp3TEr0ZZosih0/39aKOXMkz
K98EgQ3RlJNJfThxkziaoKQDryAoM8C+H0uY7j8l0uhw5mbKyKFP/Wg3lSLe
nWsN8y03kpeUDeDfR+S+ks80YMTcSk1jPUF1QYJrZggNsqeSn3nrPMVOzjyh
fQ8VCijWltOyp6jJJLG77KjQcMVcMJb0DJ0jq6vtJFZglnFBFkCV41pZUPhb
VysItvhgWvpBjq8dVnexuizhAjEz1rbsOTb3VCoYey2h9LqWtJYziF+OfZix
fEeBT7Vqw6urh3Ba+qbfSkCBXSr6AaVsCGevc1LmGFEgacZPsih3GA+7+Tet
ukeG0ZU7tXD1CG63Y85ZyCWDOMr9am3cCK45dNtokS4ZPIzN/AqejOD+QF5p
VIMF/BGzMX4teRQFvdNtrREWELKDVJ/HGsUz7aZfDBgWsHnr18/f80bxuDyd
66NvAf8CwzyLvw==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0., 35999.99926530612}, {0, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.506895035337945*^9, 3.506895059875478*^9}, {
   3.506895368447427*^9, 3.506895376930566*^9}, {3.506895431481127*^9, 
   3.5068955028835573`*^9}, {3.573844129451272*^9, 3.5738441552566957`*^9}, 
   3.643321594450219*^9, 3.6433216491536093`*^9, 3.643321696763873*^9, 
   3.643322076149508*^9, 3.665621098222734*^9, 3.665621562462653*^9, 
   3.665621655661641*^9, {3.665623532303203*^9, 3.665623549453471*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Showing: defining modules", "Subsection",
 CellChangeTimes->{{3.506895515713764*^9, 3.506895521199378*^9}}],

Cell["\<\
In the module definition, Seq[] is used to wrap the reactions and \
concentrations (rather than { }). This is so that when multiple modules are \
combined in rsys we won\[CloseCurlyQuote]t get a nested list. Alternatively, \
Flatten[] could be used to flatten the resulting nested list.\
\>", "Text",
 CellChangeTimes->{{3.6447619149419928`*^9, 3.6447621386684237`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"keff", "=", "300000"}], ";"}]], "Input",
 CellChangeTimes->{{3.5001571770103817`*^9, 3.500157194851631*^9}, {
  3.50015722781374*^9, 3.500157229193832*^9}, {3.506895595731769*^9, 
  3.506895619958795*^9}, {3.506895811366178*^9, 3.506895811966848*^9}, {
  3.5068959559391413`*^9, 3.506895957435261*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{"5", "*", "24", "*", "60", "*", "60"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.473025099126486*^9, 3.4730251345423737`*^9}, 
   3.473025323398469*^9, {3.474149890727325*^9, 3.4741498921748037`*^9}, {
   3.4777728493720818`*^9, 3.477772849943151*^9}, {3.478036267955059*^9, 
   3.47803626930268*^9}, {3.495335420114262*^9, 3.495335421916986*^9}, {
   3.4953360364343853`*^9, 3.495336052975268*^9}, {3.495336468901352*^9, 
   3.495336469293128*^9}, 3.4954747737719584`*^9, 3.495479305781823*^9, 
   3.495479355970359*^9, {3.4954798102051992`*^9, 3.495479810761504*^9}, {
   3.49547987110651*^9, 3.4954798711837606`*^9}, {3.495480168179775*^9, 
   3.495480168792857*^9}, 3.4954807022870626`*^9, {3.495482184791265*^9, 
   3.495482185099202*^9}, {3.495482241573255*^9, 3.495482241860682*^9}, {
   3.495482314942142*^9, 3.495482323542026*^9}, {3.496440129242626*^9, 
   3.496440130390419*^9}, {3.4965127043945713`*^9, 3.496512706321731*^9}, {
   3.496512788119561*^9, 3.4965127886785107`*^9}, {3.496515841281218*^9, 
   3.496515842680663*^9}, {3.4965174324553833`*^9, 3.496517433143094*^9}, {
   3.496518630277019*^9, 3.4965186307275667`*^9}, {3.5001530348578167`*^9, 
   3.5001530350014677`*^9}, {3.5001554578791237`*^9, 
   3.5001554582518263`*^9}, {3.500155728550169*^9, 3.500155728787991*^9}, {
   3.5068959704688473`*^9, 3.506895970756318*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bibi", "[", 
   RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "gate", ",", "backward", ",", "agate", ",", "out", ",", "atrans", ",", 
      "helper"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Seq", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"revrxn", "[", 
       RowBox[{
        RowBox[{"a", "+", "gate"}], ",", 
        RowBox[{"backward", "+", "agate"}], ",", 
        RowBox[{"keff", "/", "10"}], ",", "keff"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"rxn", "[", 
       RowBox[{
        RowBox[{"b", "+", "agate"}], ",", "out", ",", "keff"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"revrxn", "[", 
       RowBox[{
        RowBox[{"out", "+", 
         RowBox[{"trans", "[", "c", "]"}]}], ",", " ", 
        RowBox[{"c", "+", "atrans"}], ",", 
        RowBox[{"keff", "/", "10"}], ",", "keff"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"rxn", "[", 
       RowBox[{
        RowBox[{"helper", "+", "atrans"}], ",", "d", ",", "keff"}], "]"}], 
      ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"conc", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"gate", ",", 
          RowBox[{"trans", "[", "c", "]"}]}], "}"}], ",", " ", 
        RowBox[{"200", " ", 
         RowBox[{"10", "^", 
          RowBox[{"-", "9"}]}]}]}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"conc", "[", 
       RowBox[{"backward", ",", 
        RowBox[{"100", " ", 
         RowBox[{"10", "^", 
          RowBox[{"-", "9"}]}]}]}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"conc", "[", 
       RowBox[{"helper", ",", " ", 
        RowBox[{"200", " ", 
         RowBox[{"10", "^", 
          RowBox[{"-", "9"}]}]}]}], "]"}]}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4730241355776873`*^9, 3.4730243511011553`*^9}, {
   3.473024395760973*^9, 3.473024539973936*^9}, {3.473024602202878*^9, 
   3.473024764293219*^9}, {3.47302569819724*^9, 3.473025700128611*^9}, {
   3.473026733004072*^9, 3.473026804571171*^9}, {3.4730268412828407`*^9, 
   3.473026848163783*^9}, {3.473026931181736*^9, 3.473026949105652*^9}, {
   3.473027002415721*^9, 3.4730270291045732`*^9}, {3.473027098440976*^9, 
   3.473027137903564*^9}, {3.473027199419702*^9, 3.473027199499372*^9}, {
   3.473027239560822*^9, 3.473027240037799*^9}, 3.474145160993017*^9, {
   3.474145879236278*^9, 3.474145905375366*^9}, {3.474147107746396*^9, 
   3.474147111273484*^9}, {3.474147153438128*^9, 3.47414720141616*^9}, {
   3.474147232966687*^9, 3.4741473052409773`*^9}, {3.474147949626482*^9, 
   3.4741479497736483`*^9}, {3.474148472254405*^9, 3.474148477785726*^9}, {
   3.474148546534618*^9, 3.474148564117902*^9}, {3.474148603936727*^9, 
   3.474148725893361*^9}, {3.474148775825819*^9, 3.474148964892948*^9}, {
   3.474149762661139*^9, 3.474149823945552*^9}, {3.477514674463427*^9, 
   3.477514689178421*^9}, {3.477516082581923*^9, 3.477516253551909*^9}, {
   3.4775162911027946`*^9, 3.477516294449031*^9}, {3.477516350567032*^9, 
   3.477516354473338*^9}, {3.477516539605242*^9, 3.4775165851549587`*^9}, {
   3.477518151393301*^9, 3.47751819288721*^9}, {3.477518233687029*^9, 
   3.477518235227306*^9}, {3.477520010855514*^9, 3.477520012505554*^9}, {
   3.478036323250589*^9, 3.4780363406276293`*^9}, {3.478037010652096*^9, 
   3.4780370346670094`*^9}, {3.478097682650037*^9, 3.478097725780785*^9}, {
   3.4780977654232616`*^9, 3.478097808703863*^9}, {3.478098132321031*^9, 
   3.4780981325714493`*^9}, {3.478098285858284*^9, 3.478098323366996*^9}, {
   3.4780989872372007`*^9, 3.4780990126635523`*^9}, {3.478099088321566*^9, 
   3.4780991250621243`*^9}, {3.4780991678628817`*^9, 3.478099183648547*^9}, {
   3.47809937606532*^9, 3.478099377326922*^9}, {3.478099817548584*^9, 
   3.478099825333776*^9}, {3.484318819500697*^9, 3.4843188312504997`*^9}, {
   3.484319067405736*^9, 3.48431909724247*^9}, {3.484319140441484*^9, 
   3.4843191405687637`*^9}, {3.48431918467448*^9, 3.48431921179912*^9}, {
   3.4843192811361227`*^9, 3.484319312525083*^9}, {3.4843193633676233`*^9, 
   3.4843193765670424`*^9}, {3.4843491844084177`*^9, 3.4843492043142*^9}, {
   3.484349495386361*^9, 3.48434953567808*^9}, {3.4843496528030252`*^9, 
   3.484349692486661*^9}, 3.484349753111311*^9, {3.484354051025976*^9, 
   3.484354080362171*^9}, {3.4845882608731613`*^9, 3.4845882716971903`*^9}, {
   3.500153079990951*^9, 3.5001532592618437`*^9}, {3.5001533135291967`*^9, 
   3.500153342300384*^9}, {3.500153373025238*^9, 3.50015346272331*^9}, {
   3.500154166933819*^9, 3.500154167077725*^9}, {3.5001545014994287`*^9, 
   3.500154519814241*^9}, {3.5001545635920763`*^9, 3.5001545704917593`*^9}, {
   3.500154858390953*^9, 3.500154983713294*^9}, {3.5001550757252502`*^9, 
   3.5001551402472763`*^9}, {3.500155177468998*^9, 3.500155179100305*^9}, {
   3.5001705433291388`*^9, 3.500170613559849*^9}, {3.5001708562112293`*^9, 
   3.500170867385868*^9}, {3.50017092323543*^9, 3.500170939616446*^9}, {
   3.500171065407159*^9, 3.500171216819582*^9}, {3.504386307471003*^9, 
   3.504386352283587*^9}, {3.506895652016272*^9, 3.506895656061592*^9}, {
   3.506895724966591*^9, 3.5068957500535107`*^9}, {3.50689583957082*^9, 
   3.5068958783384047`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsys", "=", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"bibi", "[", 
      RowBox[{"b", ",", "a", ",", "b", ",", "b"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"bibi", "[", 
      RowBox[{"c", ",", "b", ",", "c", ",", "c"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"bibi", "[", 
      RowBox[{"a", ",", "c", ",", "a", ",", "a"}], "]"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"conc", "[", 
      RowBox[{"b", ",", 
       RowBox[{"20", " ", 
        RowBox[{"10", "^", 
         RowBox[{"-", "9"}]}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"conc", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "c"}], "}"}], ",", 
       RowBox[{"5", " ", 
        RowBox[{"10", "^", 
         RowBox[{"-", "9"}]}]}]}], "]"}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.500153467195532*^9, 3.500153531593285*^9}, {
   3.50015500927135*^9, 3.500155055921892*^9}, {3.500155180848091*^9, 
   3.500155200136628*^9}, 3.500155259815858*^9, {3.500155312870574*^9, 
   3.500155329517668*^9}, {3.500170831188334*^9, 3.500170839471385*^9}, {
   3.5001709529719887`*^9, 3.5001709555521393`*^9}, {3.5001710068534203`*^9, 
   3.5001710527506313`*^9}, {3.500171225865508*^9, 3.500171305257475*^9}, {
   3.500171341706686*^9, 3.500171389132668*^9}, {3.500171581576837*^9, 
   3.500171605604063*^9}, {3.500171652532816*^9, 3.500171656844335*^9}, {
   3.500171970019595*^9, 3.5001720280995207`*^9}, {3.500172058685905*^9, 
   3.500172075032852*^9}, {3.500172220938572*^9, 3.5001722243233023`*^9}, {
   3.500172366527205*^9, 3.500172378074729*^9}, {3.500303789046337*^9, 
   3.50030390246778*^9}, {3.500304028749173*^9, 3.5003040289250593`*^9}, {
   3.500477675937549*^9, 3.500477677671008*^9}, {3.506895663328968*^9, 
   3.5068956718542356`*^9}, {3.5068959404718637`*^9, 3.5068959431875772`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"SimulateRxnsys", "[", 
    RowBox[{"rsys", ",", "tmax"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4965193451408243`*^9, 3.49651934534831*^9}, {
  3.496519553787393*^9, 3.496519554688005*^9}, {3.5003039751337957`*^9, 
  3.5003039759710407`*^9}, {3.643322073576069*^9, 3.643322073833188*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotSpecies", "=", "\[IndentingNewLine]", 
   RowBox[{"Join", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"trans", "[", "a", "]"}], ",", 
       RowBox[{"trans", "[", "b", "]"}], ",", 
       RowBox[{"trans", "[", "c", "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"SpeciesInRxnsysStringPattern", "[", 
      RowBox[{"rsys", ",", "\"\<gate$*\>\""}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4965130062402153`*^9, 3.496513018727889*^9}, {
  3.496515691965541*^9, 3.496515695724505*^9}, {3.496517486930285*^9, 
  3.496517501430243*^9}, {3.496518709295514*^9, 3.496518719074196*^9}, {
  3.4965192525176077`*^9, 3.496519254250886*^9}, {3.500153583303584*^9, 
  3.500153591395639*^9}, {3.5001720922271147`*^9, 3.500172128257573*^9}, {
  3.500172190394642*^9, 3.500172204491126*^9}, {3.504386365990152*^9, 
  3.5043863796860943`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"plotter", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", "t", "]"}], "/.", "sol"}], "&"}], "/@", 
    "plotSpecies"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"plotter", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"100", " ", 
       RowBox[{"10", "^", 
        RowBox[{"-", "9"}]}]}]}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Red", ",", "Thick"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Green", ",", "Thick"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Thick"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Thick", ",", "Dashed"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Green", ",", "Thick", ",", "Dashed"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Thick", ",", "Dashed"}], "}"}]}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQ/e3D+6Ni3K8c13LwHgfRSjV/z4DoAgWliyB6TWe1
sSSQ/lIbYQaipQXi7ED0mT9pYDpnG2cjiL7/LrcJRB9O1uoA0SJKV8D086Ms
/SB639LpE0C0YuTafyC6rWg7mE6r2VsoBaSdFFYUgWjzf5JHBHlfOe5hMwPT
OyynnAbR7x7OAtOfNutfANHeLM5gOubHpmsg2uiU13UQnSlrJyAMpA/8dgPT
Uck8r0G0TOAEMP2j4U6XCEj8xhMwzSJ1OZlZ5JVjxUfHFBA9y17IkQVIz70W
4wyiH52dz8YDpF91S7KDaG6nKbkgetfBt2D63uQiLTGZV46peW+0QTQA35uO
UQ==
  "]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwUmXc8V/8Xx/n42EKy905WRAj39L5kVvb6UIgiMzIKKfsrGZX2lIwSGUlE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     "]]}, 
   {RGBColor[0, 1, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwUV3c8l98X52PvUfaWTSGU9ZzupazK3kqSr0ISRREhI8mKEEVGZURSKIUU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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwUV3c81t8XNx88tmTLzCZCVs9xbzIie3uUkYiMUlRoC02jpSWUkpHIyCgU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     "]]}, 
   {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], Dashing[{Small, Small}],
     LineBox[CompressedData["
1:eJwV13c8Vf8fB/B7bS5yLy6ukgZKVCokenfeTSMjK6ko3Guve65NyyhpKC0z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     "]]}, 
   {RGBColor[0, 1, 0], Thickness[Large], Opacity[1.], Dashing[{Small, Small}],
     LineBox[CompressedData["
1:eJwV13lYjN8XAPBp32vaV9lKIaGQqOM9VCpabYXSzLQvNNM6o40I0SJESSRJ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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], Dashing[{Small, Small}],
     LineBox[CompressedData["
1:eJwVl3c8lf/7x885xrH3Vr4pokhFJetyXyWOCqGs7IxzjBL3saJUkmwNpUGl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     "]]}, 
   {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwV1nc81d8bAHDutffeVGbJCGXm9HkipbJLSMa99urea96LZCSjpDQkKS2R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     "]]}, 
   {RGBColor[0, 1, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwV13dczd8bAPDube+pXUSlpNBAyePzEA3aQ0uRxr0NrduUihKShhSlbxkR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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwV1nk4lF8bB/CZsY8lBmOt7EqWilLibu60IUuWJFuWGWthBlmTyJItJUWi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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->NCache[{{0., 431999.9911836735}, {0, 
      Rational[1, 10000000]}}, {{0., 431999.9911836735}, {0, 1.*^-7}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.5001535987881727`*^9, 3.5001536347989883`*^9}, 
   3.50015417606115*^9, {3.500154224761079*^9, 3.500154246026197*^9}, {
   3.500154547045635*^9, 3.500154575606289*^9}, {3.5001549020656*^9, 
   3.50015498831011*^9}, 3.500155022432151*^9, {3.5001550614917297`*^9, 
   3.500155078603674*^9}, {3.5001551156601048`*^9, 3.500155142935364*^9}, {
   3.500155191386937*^9, 3.5001552024762163`*^9}, 3.500155262817114*^9, {
   3.500155377060029*^9, 3.500155419660091*^9}, {3.500155461085226*^9, 
   3.5001555914203167`*^9}, {3.500155695261869*^9, 3.5001557314191713`*^9}, 
   3.5001706373065166`*^9, 3.50017087287999*^9, 3.500170958200131*^9, {
   3.500171012169272*^9, 3.500171055087805*^9}, {3.500171177068985*^9, 
   3.500171202059989*^9}, {3.500171240973934*^9, 3.500171390764971*^9}, {
   3.5001715833217697`*^9, 3.500171607887773*^9}, 3.500171660629569*^9, {
   3.50017200140077*^9, 3.500172030467207*^9}, {3.5001720635467377`*^9, 
   3.5001720775068693`*^9}, 3.5001721305259237`*^9, {3.500172206736722*^9, 
   3.500172227120986*^9}, {3.500172265990355*^9, 3.5001722915620937`*^9}, {
   3.500172371697898*^9, 3.500172385896603*^9}, {3.500303818651279*^9, 
   3.500303930631812*^9}, 3.5003039801029167`*^9, 3.50030403276901*^9, 
   3.500477693432124*^9, 3.504386411922708*^9, 3.5068957776629257`*^9, 
   3.506895816111165*^9, 3.506895896475507*^9, {3.506895947966112*^9, 
   3.506895979150277*^9}, {3.573844130473147*^9, 3.573844157999195*^9}, 
   3.643321595537487*^9, 3.6433216528701677`*^9, 3.64332207658657*^9, 
   3.665621098512807*^9, 3.665621562688074*^9, 3.665621656101194*^9, {
   3.6656235327001038`*^9, 3.665623549703353*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example of adding/removing species during experiment", "Subsection",
 CellChangeTimes->{{3.506990906717347*^9, 3.5069909078193007`*^9}, {
  3.521032741023697*^9, 3.521032783431868*^9}, {3.5210328332469597`*^9, 
  3.521032834067655*^9}}],

Cell["Note: Also requires CRNSimulatorExtensions.m to be loaded", "Text",
 CellChangeTimes->{{3.521032838338593*^9, 3.5210328415518827`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsys", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"revrxn", "[", 
      RowBox[{
       RowBox[{"a", "+", "b"}], ",", "c", ",", "0.1", ",", "30"}], "]"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"rxn", "[", 
      RowBox[{
       RowBox[{"2", "a"}], ",", "b", ",", "0.01"}], "]"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"conc", "[", 
      RowBox[{"c", ",", "1"}], "]"}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4687025505360613`*^9, 3.468702614243576*^9}, {
  3.468702684046033*^9, 3.468702797275187*^9}, {3.4687029541813297`*^9, 
  3.46870296099183*^9}, {3.469219349717853*^9, 3.4692193497885027`*^9}, {
  3.46921938334344*^9, 3.469219394567686*^9}, {3.469227269508279*^9, 
  3.469227271243472*^9}, {3.471011641403061*^9, 3.47101164496911*^9}, {
  3.5068952342322187`*^9, 3.506895331541938*^9}, {3.5068954289150667`*^9, 
  3.506895500571403*^9}, {3.5069911777669983`*^9, 3.506991203767332*^9}, {
  3.506991522232835*^9, 3.506991580259471*^9}, {3.506991631263843*^9, 
  3.506991642568962*^9}}],

Cell["\<\
Don\[CloseCurlyQuote]t specify the initial concentrations of a, b because \
these are controlled by a schedule. Positive numbers means add this amount, \
negative numbers means remove this amount. The first column is the time to \
wait until next addition.\
\>", "Text",
 CellChangeTimes->{{3.506991984949119*^9, 3.506992103346533*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"schedule", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"50", ",", "4", ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"20", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"20", ",", "10", ",", "0"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{"20", ",", "0", ",", 
       RowBox[{"-", "9"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"20", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}]}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQfcy7rP/Gl5eONq+DJoPotuMCs0D0movu80B0zHXn
UyBazWLJWRD9aVHJKxDNuDH5NYi2LViucxNIuz3w1gXR14puuIDoDP0HPiD6
U3ReCIj+Nu1JBIhmkhHrBdGXZCTB9Lb61xNBdIGY3lwQrbw+ZzdY/PqEvSDa
50PGQRC95c62wyDa4Oi3EyD6fofKeRB95eTL03xfXzpGXf9wBkRnvS+9BqKT
tI8+ANEvjJd8Cfz20vFHn/lXED3pxU8FPsVXjhvk4tVB9Pu5ftogOqAqUxdE
XwpkNgbR57hYwfRfn7cWIJrr4BcwnXNvpQOI1udk9gHRAD8KuIY=
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmax", "=", 
  RowBox[{"Total", "[", 
   RowBox[{"schedule", "\[LeftDoubleBracket]", 
    RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "]"}]}]], "Input"],

Cell[BoxData["130"], "Output",
 CellChangeTimes->{
  3.4838133290501347`*^9, {3.4838134264854593`*^9, 3.483813486001301*^9}, {
   3.483813693479989*^9, 3.483813724201437*^9}, {3.48381377198628*^9, 
   3.4838137855094357`*^9}, {3.48381423359627*^9, 3.48381429727982*^9}, {
   3.483814328910357*^9, 3.483814372940669*^9}, 3.483814405934033*^9, {
   3.483814457866613*^9, 3.483814471443852*^9}, {3.483814503906988*^9, 
   3.483814600120685*^9}, 3.4838146457406883`*^9, 3.483815017872567*^9, {
   3.483815057164777*^9, 3.483815146482864*^9}, {3.483815388512534*^9, 
   3.4838154055220003`*^9}, {3.4838154361601048`*^9, 3.483815454609132*^9}, 
   3.4838155126033*^9, 3.483815546069852*^9, 3.483815680439131*^9, {
   3.483923696405531*^9, 3.483923722362948*^9}, 3.4839238620725*^9, {
   3.483923897680529*^9, 3.483923945260257*^9}, 3.483924076799097*^9, {
   3.483924210197606*^9, 3.483924233284614*^9}, 3.48458500262707*^9, 
   3.484585095503088*^9, {3.4845858820774612`*^9, 3.4845859011980257`*^9}, 
   3.484585948305567*^9, 3.4845871901112432`*^9, 3.484587237889332*^9, 
   3.4845878043231707`*^9, 3.484587844220903*^9, {3.4845878876453867`*^9, 
   3.484587937570612*^9}, {3.485460387765849*^9, 3.4854604168217278`*^9}, 
   3.485460457935102*^9, 3.485460531817997*^9, {3.50699144672797*^9, 
   3.506991469823143*^9}, {3.5069915033304977`*^9, 3.5069915830244513`*^9}, {
   3.506991624495914*^9, 3.506991673868088*^9}, {3.506991705210598*^9, 
   3.5069917145208197`*^9}, 3.521032703948675*^9, {3.573844130846094*^9, 
   3.573844158092926*^9}, 3.64332159580893*^9, 3.64332165293281*^9, 
   3.643322076681122*^9, 3.6656210985500813`*^9, 3.665621562752636*^9, 
   3.6656216563313913`*^9, 3.665623549751606*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"SimulateRxnsysWithSchedule", "[", 
    RowBox[{"rsys", ",", "schedule", ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4838125861423397`*^9, 3.4838125917095623`*^9}, {
  3.4838126258362093`*^9, 3.483812627451624*^9}, {3.4838126853028183`*^9, 
  3.483812696886086*^9}, {3.483812776228284*^9, 3.483812795373386*^9}, {
  3.483813243700042*^9, 3.483813261380825*^9}, {3.506991434588904*^9, 
  3.506991435893285*^9}, {3.521032694298553*^9, 3.5210326946803827`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plotter", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], ",", 
      RowBox[{"b", "[", "t", "]"}], ",", 
      RowBox[{"c", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.46826276617019*^9, 3.468262777359262*^9}, {
  3.468262836992633*^9, 3.468262958884576*^9}, {3.468263018256619*^9, 
  3.468263075130353*^9}, {3.468263285918445*^9, 3.468263381543727*^9}, {
  3.468263413380739*^9, 3.468263429243466*^9}, {3.468365679383275*^9, 
  3.468365778320983*^9}, {3.4683668032722387`*^9, 3.468366847508575*^9}, {
  3.46836804449853*^9, 3.468368052412436*^9}, {3.4683705728813553`*^9, 
  3.46837057352957*^9}, {3.468435768604846*^9, 3.468435774568234*^9}, {
  3.468702655162812*^9, 3.468702655310307*^9}, {3.506895021805895*^9, 
  3.506895031204191*^9}, {3.506895362169972*^9, 3.506895364885762*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"SimulateRxnsysWithSchedule\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{RowBox[{\\\"a\\\", \\\"+\\\", \
\\\"b\\\"}], \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", RowBox[{\\\" \
\\\", \\\"0.1`\\\", \\\" \\\"}]], \\\" \\\", \\\"c\\\", \\\" \\\"}], \
\\\",\\\", RowBox[{\\\"c\\\", \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", \
RowBox[{\\\" \\\", \\\"30\\\", \\\" \\\"}]], \\\" \\\", RowBox[{\\\"a\\\", \\\
\"+\\\", \\\"b\\\"}], \\\" \\\"}], \\\",\\\", RowBox[{RowBox[{\\\"2\\\", \\\" \
\\\", \\\"a\\\"}], \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", RowBox[{\\\
\" \\\", \\\"0.01`\\\", \\\" \\\"}]], \\\" \\\", \\\"b\\\", \\\" \\\"}], \
\\\",\\\", RowBox[{\\\"conc\\\", \\\"[\\\", RowBox[{\\\"c\\\", \\\",\\\", \
\\\"1\\\"}], \\\"]\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"50\\\", \\\",\\\", \\\"4\\\", \
\\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\
\"20\\\", \\\",\\\", \\\"0\\\", \\\",\\\", \\\"10\\\"}], \\\"}\\\"}], \\\",\\\
\", RowBox[{\\\"{\\\", RowBox[{\\\"20\\\", \\\",\\\", \\\"10\\\", \\\",\\\", \
\\\"0\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"20\\\", \
\\\",\\\", \\\"0\\\", \\\",\\\", RowBox[{\\\"-\\\", \\\"9\\\"}]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"20\\\", \\\",\\\", \
RowBox[{\\\"-\\\", \\\"2\\\"}], \\\",\\\", \\\"0\\\"}], \\\"}\\\"}]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"a\\\", \\\",\\\", \
\\\"b\\\"}], \\\"}\\\"}]}], \\\"]\\\"}], \\\"}\\\"}]\\)\[NoBreak] is neither \
a list of replacement rules nor a valid dispatch table, and so cannot be used \
for replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", ButtonNote -> \
\\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6656235498217*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"plotter", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "All"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "Red", "}"}], ",", 
      RowBox[{"{", "Green", "}"}], ",", 
      RowBox[{"{", "Blue", "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.4682630393343*^9, {3.46826314956773*^9, 3.4682632247667227`*^9}, 
   3.4682633965844316`*^9, 3.468365788765299*^9, 3.468368200449752*^9, {
   3.4683705819263353`*^9, 3.4683705828664303`*^9}, {3.468370815007806*^9, 
   3.4683708177190523`*^9}, {3.468702659743595*^9, 3.4687026735143642`*^9}, {
   3.468703124142672*^9, 3.468703126418498*^9}, {3.50689505627216*^9, 
   3.506895056701329*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"SimulateRxnsysWithSchedule\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{RowBox[{\\\"a\\\", \\\"+\\\", \
\\\"b\\\"}], \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", RowBox[{\\\" \
\\\", \\\"0.1`\\\", \\\" \\\"}]], \\\" \\\", \\\"c\\\", \\\" \\\"}], \
\\\",\\\", RowBox[{\\\"c\\\", \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", \
RowBox[{\\\" \\\", \\\"30\\\", \\\" \\\"}]], \\\" \\\", RowBox[{\\\"a\\\", \\\
\"+\\\", \\\"b\\\"}], \\\" \\\"}], \\\",\\\", RowBox[{RowBox[{\\\"2\\\", \\\" \
\\\", \\\"a\\\"}], \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", RowBox[{\\\
\" \\\", \\\"0.01`\\\", \\\" \\\"}]], \\\" \\\", \\\"b\\\", \\\" \\\"}], \
\\\",\\\", RowBox[{\\\"conc\\\", \\\"[\\\", RowBox[{\\\"c\\\", \\\",\\\", \
\\\"1\\\"}], \\\"]\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"50\\\", \\\",\\\", \\\"4\\\", \
\\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\
\"20\\\", \\\",\\\", \\\"0\\\", \\\",\\\", \\\"10\\\"}], \\\"}\\\"}], \\\",\\\
\", RowBox[{\\\"{\\\", RowBox[{\\\"20\\\", \\\",\\\", \\\"10\\\", \\\",\\\", \
\\\"0\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"20\\\", \
\\\",\\\", \\\"0\\\", \\\",\\\", RowBox[{\\\"-\\\", \\\"9\\\"}]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"20\\\", \\\",\\\", \
RowBox[{\\\"-\\\", \\\"2\\\"}], \\\",\\\", \\\"0\\\"}], \\\"}\\\"}]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"a\\\", \\\",\\\", \
\\\"b\\\"}], \\\"}\\\"}]}], \\\"]\\\"}], \\\"}\\\"}]\\)\[NoBreak] is neither \
a list of replacement rules nor a valid dispatch table, and so cannot be used \
for replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", ButtonNote -> \
\\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6656235500309258`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"SimulateRxnsysWithSchedule\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{RowBox[{\\\"a\\\", \\\"+\\\", \
\\\"b\\\"}], \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", RowBox[{\\\" \
\\\", \\\"0.1`\\\", \\\" \\\"}]], \\\" \\\", \\\"c\\\", \\\" \\\"}], \
\\\",\\\", RowBox[{\\\"c\\\", \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", \
RowBox[{\\\" \\\", \\\"30.`\\\", \\\" \\\"}]], \\\" \\\", RowBox[{\\\"a\\\", \
\\\"+\\\", \\\"b\\\"}], \\\" \\\"}], \\\",\\\", RowBox[{RowBox[{\\\"2.`\\\", \
\\\" \\\", \\\"a\\\"}], \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", \
RowBox[{\\\" \\\", \\\"0.01`\\\", \\\" \\\"}]], \\\" \\\", \\\"b\\\", \\\" \\\
\"}], \\\",\\\", RowBox[{\\\"conc\\\", \\\"[\\\", RowBox[{\\\"c\\\", \
\\\",\\\", \\\"1.`\\\"}], \\\"]\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"50.`\\\", \
\\\",\\\", \\\"4.`\\\", \\\",\\\", \\\"0.`\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"20.`\\\", \\\",\\\", \\\"0.`\\\", \\\",\\\", \
\\\"10.`\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"20.`\\\
\", \\\",\\\", \\\"10.`\\\", \\\",\\\", \\\"0.`\\\"}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"20.`\\\", \\\",\\\", \\\"0.`\\\", \
\\\",\\\", RowBox[{\\\"-\\\", \\\"9.`\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"20.`\\\", \\\",\\\", RowBox[{\\\"-\\\", \
\\\"2.`\\\"}], \\\",\\\", \\\"0.`\\\"}], \\\"}\\\"}]}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"a\\\", \\\",\\\", \\\"b\\\"}], \
\\\"}\\\"}]}], \\\"]\\\"}], \\\"}\\\"}]\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.665623550069902*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"SimulateRxnsysWithSchedule\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{RowBox[{\\\"a\\\", \\\"+\\\", \
\\\"b\\\"}], \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", RowBox[{\\\" \
\\\", \\\"0.1`\\\", \\\" \\\"}]], \\\" \\\", \\\"c\\\", \\\" \\\"}], \
\\\",\\\", RowBox[{\\\"c\\\", \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", \
RowBox[{\\\" \\\", \\\"30\\\", \\\" \\\"}]], \\\" \\\", RowBox[{\\\"a\\\", \\\
\"+\\\", \\\"b\\\"}], \\\" \\\"}], \\\",\\\", RowBox[{RowBox[{\\\"2\\\", \\\" \
\\\", \\\"a\\\"}], \\\" \\\", OverscriptBox[\\\"\[RightArrow]\\\", RowBox[{\\\
\" \\\", \\\"0.01`\\\", \\\" \\\"}]], \\\" \\\", \\\"b\\\", \\\" \\\"}], \
\\\",\\\", RowBox[{\\\"conc\\\", \\\"[\\\", RowBox[{\\\"c\\\", \\\",\\\", \
\\\"1\\\"}], \\\"]\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"50\\\", \\\",\\\", \\\"4\\\", \
\\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\
\"20\\\", \\\",\\\", \\\"0\\\", \\\",\\\", \\\"10\\\"}], \\\"}\\\"}], \\\",\\\
\", RowBox[{\\\"{\\\", RowBox[{\\\"20\\\", \\\",\\\", \\\"10\\\", \\\",\\\", \
\\\"0\\\"}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"20\\\", \
\\\",\\\", \\\"0\\\", \\\",\\\", RowBox[{\\\"-\\\", \\\"9\\\"}]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"20\\\", \\\",\\\", \
RowBox[{\\\"-\\\", \\\"2\\\"}], \\\",\\\", \\\"0\\\"}], \\\"}\\\"}]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"a\\\", \\\",\\\", \
\\\"b\\\"}], \\\"}\\\"}]}], \\\"]\\\"}], \\\"}\\\"}]\\)\[NoBreak] is neither \
a list of replacement rules nor a valid dispatch table, and so cannot be used \
for replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", ButtonNote -> \
\\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6656235500763397`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"ReplaceAll\\\", \\\"::\\\", \
\\\"reps\\\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during \
this calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6656235501036053`*^9}],

Cell[BoxData[
 GraphicsBox[{},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0., 0.}, {0, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.506991447695178*^9, 3.506991470675802*^9}, {
   3.506991503545532*^9, 3.506991583174409*^9}, {3.506991624651187*^9, 
   3.506991674039695*^9}, {3.506991705394966*^9, 3.50699171467554*^9}, 
   3.5210327047150917`*^9, {3.573844131640976*^9, 3.573844158469639*^9}, 
   3.643321597695361*^9, 3.643321654787751*^9, 3.6433220770633993`*^9, 
   3.665621098774787*^9, 3.665621562950892*^9, 3.665621656576087*^9, 
   3.665623550109433*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example of non-mass action kinetics: Repressilator", "Subsection",
 CellChangeTimes->{{3.506990906717347*^9, 3.5069909078193007`*^9}, {
  3.521032741023697*^9, 3.521032783431868*^9}, {3.5210328332469597`*^9, 
  3.521032834067655*^9}, {3.573842620940196*^9, 3.5738426327121897`*^9}, {
  3.5738429513535624`*^9, 3.573842956086698*^9}}],

Cell["\<\
A reaction system can include term[] statements (eg. [x, y[t]/(1+y[t])]), \
which are additively combined
together to generate the ODEs. You can intermix rxn[] and term[] statements. \
\
\>", "Text",
 CellChangeTimes->{{3.506991984949119*^9, 3.506992103346533*^9}, {
  3.5738427714493523`*^9, 3.573842897955778*^9}, {3.573842994670869*^9, 
  3.57384303313078*^9}, {3.573843825724351*^9, 3.5738438293159637`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmax", "=", "20"}], ";"}]], "Input",
 CellChangeTimes->{{3.5630436161556053`*^9, 3.563043618257226*^9}, {
   3.563043686325157*^9, 3.563043686388475*^9}, {3.563043759254019*^9, 
   3.563043895036664*^9}, {3.563043937211443*^9, 3.563043953876205*^9}, 
   3.563044000951704*^9, 3.5630440352422657`*^9, {3.5630447087509604`*^9, 
   3.563044756673802*^9}, {3.563044884316877*^9, 3.5630448868602333`*^9}, 
   3.563045769786368*^9, 3.563045800011384*^9, 3.5630458439373703`*^9, {
   3.563046043168994*^9, 3.5630460736644487`*^9}, 3.573843037197281*^9, 
   3.57384315433589*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "=", "4"}], ";", 
  RowBox[{"\[Gamma]", "=", "1"}], ";", 
  RowBox[{"\[Beta]", "=", "10"}], ";", 
  RowBox[{"k", "=", "5"}], ";"}]], "Input",
 CellChangeTimes->{{3.563043501463831*^9, 3.5630435027859077`*^9}, {
   3.563043565879706*^9, 3.5630435690374203`*^9}, {3.563043613218141*^9, 
   3.563043613786482*^9}, {3.563043703333742*^9, 3.563043755487255*^9}, {
   3.5630437863900347`*^9, 3.563043787521508*^9}, {3.563043824123231*^9, 
   3.5630438435041027`*^9}, {3.5630439051208553`*^9, 3.5630439081112413`*^9}, 
   3.56304394254532*^9, {3.5630439856306353`*^9, 3.5630440488680067`*^9}, {
   3.563044111865796*^9, 3.563044120986339*^9}, {3.56304469800799*^9, 
   3.5630447351541767`*^9}, {3.563044801287835*^9, 3.56304482598629*^9}, {
   3.56304486315767*^9, 3.563044891641693*^9}, {3.563045835381095*^9, 
   3.56304586344095*^9}, {3.563046067451621*^9, 3.5630460675387907`*^9}, {
   3.5630461182372427`*^9, 3.563046158093318*^9}, {3.5630462190121193`*^9, 
   3.563046227277103*^9}, {3.563046268143425*^9, 3.563046273993959*^9}, {
   3.563046319001565*^9, 3.563046383574595*^9}, {3.5738430493573008`*^9, 
   3.573843054363976*^9}, {3.573843143591267*^9, 3.573843238563612*^9}, {
   3.5738434203603563`*^9, 3.573843430494856*^9}, {3.573843652047056*^9, 
   3.5738436543180437`*^9}, {3.573843686958056*^9, 3.5738437049755898`*^9}, {
   3.573843746988553*^9, 3.5738437474278107`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsys", "=", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"term", "[", 
      RowBox[{"x2", ",", 
       FractionBox[
        RowBox[{"\[Beta]", " ", 
         SuperscriptBox["k", "n"]}], 
        RowBox[{
         SuperscriptBox["k", "n"], "+", 
         SuperscriptBox[
          RowBox[{"x1", "[", "t", "]"}], "n"]}]]}], "]"}], ",", 
     RowBox[{"term", "[", 
      RowBox[{"x3", ",", 
       FractionBox[
        RowBox[{"\[Beta]", " ", 
         SuperscriptBox["k", "n"]}], 
        RowBox[{
         SuperscriptBox["k", "n"], "+", 
         SuperscriptBox[
          RowBox[{"x2", "[", "t", "]"}], "n"]}]]}], "]"}], ",", 
     RowBox[{"term", "[", 
      RowBox[{"x1", ",", 
       FractionBox[
        RowBox[{"\[Beta]", " ", 
         SuperscriptBox["k", "n"]}], 
        RowBox[{
         SuperscriptBox["k", "n"], "+", 
         SuperscriptBox[
          RowBox[{"x3", "[", "t", "]"}], "n"]}]]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"term", "[", 
      RowBox[{"x1", ",", 
       RowBox[{
        RowBox[{"-", "\[Gamma]"}], " ", 
        RowBox[{"x1", "[", "t", "]"}]}]}], "]"}], ",", 
     RowBox[{"term", "[", 
      RowBox[{"x2", ",", 
       RowBox[{
        RowBox[{"-", "\[Gamma]"}], " ", 
        RowBox[{"x2", "[", "t", "]"}]}]}], "]"}], ",", 
     RowBox[{"term", "[", 
      RowBox[{"x3", ",", 
       RowBox[{
        RowBox[{"-", "\[Gamma]"}], " ", 
        RowBox[{"x3", "[", "t", "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"conc", "[", 
      RowBox[{"x1", ",", "1"}], "]"}], ",", 
     RowBox[{"conc", "[", 
      RowBox[{"x2", ",", "0.9"}], "]"}], ",", 
     RowBox[{"conc", "[", 
      RowBox[{"x3", ",", "0.1"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.563043448627839*^9, 3.563043602060258*^9}, {
  3.563043634831092*^9, 3.563043656394458*^9}, {3.5630437973495092`*^9, 
  3.5630438106314163`*^9}, {3.5630438636297903`*^9, 3.5630439022138863`*^9}, {
  3.563043964900153*^9, 3.563043974520196*^9}, {3.563045085844963*^9, 
  3.563045090139509*^9}, {3.563045255921225*^9, 3.563045259750983*^9}, {
  3.56304574780858*^9, 3.56304579453188*^9}, {3.563045825990694*^9, 
  3.563045832334564*^9}, {3.573843059126924*^9, 3.5738431188983297`*^9}, {
  3.5738436329230757`*^9, 3.573843677552498*^9}, {3.573843722318182*^9, 
  3.573843753584358*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"SimulateRxnsys", "[", 
    RowBox[{"rsys", ",", "tmax"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.563043604869884*^9, 3.563043624758172*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotter", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x1", "[", "t", "]"}], ",", 
      RowBox[{"x2", "[", "t", "]"}], ",", 
      RowBox[{"x3", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.563043658666382*^9, 3.5630436690599213`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"plotter", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.563043670604801*^9, 3.56304367916113*^9}, {
  3.5630437097472467`*^9, 3.563043715377193*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUm3c4lW8Yx+2VeYaVcTg4OByOREOdGyGyV1ZkJoRQkpEtshKSIomUiGwq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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUm3c81d8fx42y1112crm4uNx7S2i5769oEGkoO5vITCF7S1ZmWVlFEUUJ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     "]]}, 
   {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUm3c8lV8cx42yV3cg28U1L9cIRe43RSWKpKjsvfcMkV2JRBrIKqKQKCsr
UcpIIpKZkZWd7Xd+f/V6v67nec75nu85z+ftRtjK/bwtDRUV1ad9VFT//5se
akUnb/NY41O6xflfDyspGZdnj1wSCqRQ/TUWu3izidKnd9NLSCiOolYm50it
9oXif9KEbb/QQ4o3vmGGqvo7RbsJrv4TfE7pE/Jk070wSnl5QyliQbCSEkoY
2M9isECppevl//uqilL01rdAUHaR0nkzsGLueA3FPEHouwPjEmUpqXZu2r6O
ItbczRVTtUxJMxB9sdTbSPmpFHzFjO4fZcSyiHNO8BPF4RKLTj9lhzKds2c9
O/WJ8pvjxuT3nR3K0rj+q5lXrRTVBY3Jt5W7lH1Oy2emj3+hrNDY7yTiqYDo
pRo+ad9BOZhtIy8cRA3Kx0ZWF3q7KHKc7T667PvgyGhcmof6N8r2ykE6vOk+
0IhQOL6Q+Y3S4nci5vPzfXDyQ0TiX8duCusuKDDAfjA+TZSe3/pO8ZIZNvtr
TgfXDJwtZgT7KN+3Bpnd3BlgN0L54NDtPoouS/9BuVIGCHtD3dW10UeZVDDQ
+7nMAJG8D45XfeunPJl8cHu/DyPcGW8ixsUMUB7TxadwOzABB3fiUPDKAIV7
lm0kP5sJknSuPPCw/EVpV34RpT3ABKnFi4zGaoMUfcbbV6p1mSEzUGCO+HeI
ItiZgN8vwgIHelbOs8oOU1xGK/cCL7LAeffLcjE2wxTTdx0tAnEs8D1LbCro
6zAFFp1qGGZZoJ+uxsSqcIQiwNP/oSOfFcY6p9TlzccoUefrDt6kZgdRp7MH
C1PGKB0vn6h2S7KDHW3ZquiXMYrlqTsaNw3YYerQ9SLuw78ph0f3rWo/YYfZ
R3ghKuw4xfpTp7EMDwes2WjSdjRPUAzXXA4V5nCAym7e0KmdCUpSp0Hs4GsO
CEhlrWlUnKQMTp1/9es9B2x9+uHzJnOSEijxGnNijAOo5Nwn0oOmKD8meSXa
BQ8A48bjTy6y0xT+n4Z8RYkHQDWmL0jHcppyk46rUzH9ADjguWQkkqcpCnZH
Rx88PwDN8kl3xjamKfmLtvdoGw9ApFOs4eUPM5RtI+wTp8UDQDXg8+vk1TkK
nR8D75IOBshOpXfEEuYos5XfnF8aYcB8/S+FtnGOMpxQunHOAgO1OOfsWvF5
SsALooWuLwau6VnaH1qepwxxyrTKZCAeehZwQGuBkvfA/FH3DAaSnmkZhJkt
UEqKnOdlVjFQ4Ppb8q//AkV36tMdz10M9G8J//xSsEDhESkorufAgip3+tFY
jkWKx0dZt2AlLKzp36PZ+7lI6d6hD70fgAXPxuu3Z72WKTefiCXYrWBh/UDy
y5+3limyT89JX9vCQqhlfntr7jLFSTPoXDgNDm5TfeV43rNM8XZ55G3FgYN8
DUKK7ZEVytXqqNFAaRwMVzWlD1KvUgbKO+fpzHFgz9RX28azSvE0JogcscXB
vMncUI3iKiWCPeCOuTMOttfxhMe2qxSxruaD4f444Faxf3bp0yrFVwfrIZiA
A/3XjMWdiWuUoldfWz9X46CXRqCz7vkaZU9734BIAw7MzissFjWuUU7ykDXd
mnHgsnhZMX5ljZLSd5m5vxMHsXIv3p42/kehe2/iyjqOg7rCs/WNguuUsyn2
xcNMeNDeshp5pbpO4Sk5SWXKjocvOv40WQbrlE6+Jb/PWDz0/3ly4nrEOiUt
irMxlA8Pa+KLH9Um1ynbLa+0NUh4kM2997WsaINCu/agkE8XD7gH5H/1nzYo
AmOuZXT6eNi61cbX9nuDwqN1gGPYEA8fvekdxnk2KS2GY7kWV/BgdfzaLj5m
k1Lw9W7sA0c8nFLhFiVkb1K6//S4brvgQU66/LTsu00KKznc65wHHrYxf5O1
lzcpvpGqjY1+eEgZtZL2N9+i1Mzf7/51Aw/BPXv6EUFblHbH1+xVUej+rWl+
CSlbFImmt0ejYtF4S3sa8j5vUYRM1y2n4tF4wnWMf6hsU9ZZfl4aScVDke9k
yO/z2xTy3ts3So/Q/R0jcxZctymskQ8m/dLQ/Qxq5xlytyl/OHrftmSi8Qgp
RB3m2KE4WlfMPsrHwyiuo0BLeodSq0L/yqYAD58YXDoNtHco+ppjavwv8HB/
4SmvU/AOJenk/JPLxWi8vzWP+aXuUISnhAOGSvBg/WPI7kbpDiVZsZbTsBQP
5PqDpY+mdig6kpoldOV44Cx70/uMdpeScaO0WPsNHnbyDHdKBXYpW7/TQn3f
4uH34wVC3eFdynSeluC9Cjy0JsSf+nxhl7JEWLz3pBIPJRFSbr3uu5QnL8cG
H1Wh8fi33Bu7uUtpMLOkiapG43G2qfz7dJeiRG1PbVaDxmNOPbRVv0vpmWgY
EXuHBx3DjH0MA7sUGvqJ5wOIySfVpHD/dilcJictbtSi8an9OCeE2aN4dJsw
c9Wh+sj6+sqQ9ihOHndfPUI8SsA8Vj21R7EUtTJhrUf14SyuP2G9RymdpDC6
Iy5h0p3QD92jVL3KaKlDfH93itn04R6lO3Dp0R7i4KUoeceyPYrPw6442QY0
vgnCJd+OPQpNqGq6LmKd/rrg8Ok9iqnewWETxNz2sl+baajg2uFA04uImUe2
x3Q5qOC8z1UhTcS7lz+vdfFTwQ+5FkV+xEvdDxlNpKmAOuNd9iR63vhZB74h
VSp4v3A8IAsxrtlFNFSLChpc3rIYINY86inDf54KvE/GaCyh+XmW+SrVmFHB
0EweZxTiTOkg9SvO6H6bcRmMiDuyQ09s+lPBdr3E6HVUr92DEboPI6mANc9w
fhLVk3Q35oLqXSpole3vOIb4KsPtq73pVPCh/9a9eLQet64n2vgVUEEKSVX7
M1qvqrVkF/xbKmh7XrSyidaTazw92LCTCj5JqAaQ0XprX82OXBqggrfkaTtl
1A8+357dvvuHCsxdciNlUb90NRSnddBQwx3JJxGrZXigPlyW68ZODWqD3yOb
XqP1Lal4wcpHDd2dNUtRqB/jMxpqzhyihpepRy8No/6twTc3TR+jhv7rEu6B
RXiYvt36Je4sNXS12Srvf4n287VvAy321LDbGIhffY4H/6Xe33Y+1CAcmnXW
BO2XZ44Ds/vDqYGG72tgyTM80BqPbx9/RA0P1vFLKjl4qFX6x1f/hRpYC6Nz
Xj7Gw1zhlqh5HzWsdAU8LHyIBz4RKtLuODW8lr1KSEf7N/AA41H1PWogzllo
XLmHB6V5HtMKeRrYt5g3p3UT9YutoO0lDRrY22prG43BQ9KAiOuaDg286nJY
8kbnxd9WmRAlGxqIB6yDdxgeCvI00kvu08Dpwt6MP7546BM4/vRcDg1cMQ5S
l/bGA8P9ky/ni2mgUfLKkCU6n2wj9d/JfKKBySWqrCInPAhZWv3K36IB1nhq
xk9meEjliebPsqAFvb+vCAe10Hk61p531o0WQojfV92O4eHCSy6F7Wu08ONN
/0LlUTxg4Ln2pVRa+PwP809OGQ+3bb+4s7bTQv2tUfdMIh7CSjCNgWr7gMrT
haZ8Px4ctJ/YnefcDw3Tbb9a3+HgsFdFMe0XOiC0208yCuKgc0/NzLOPDo6m
HKuh58GBXXwdy9AEHZS95zTaj8dBUn6zYxU1PcgMGPpTMeNgerBbxFOFHjw1
j+1urmEh7cxi6mA2PXz5lHdDtAMLu6JSYZWBDCCwrIE3D8dCculLWfEYBkiu
32TKCcaCFMj/Sk5mgL6NquIZfyxcvKJ6xKOYAZbH/96/5YaF4rvaK8RxBogW
rO1kvIoFi10rh2R9RhD0cfcWVMXC+97H+u7iTCAbmsWZgd73yVZGK6uKTCDI
njq7s4gBuzm2B8HABNd75wJt5zHARHtjKM6ECZacEvh0JzGgL+vglnuLCcYT
pGWD+jAwGKl0u+8vE7Q9WH7kWoeBEvZ5OYttJqC6fGTAsAYDNx7lfZtgYAZ2
1jsaxysxIFbCw7sizAwtKhvVR19jwOUnVQHbBWZ48dtgNicPA5vybS3HK5iB
PvtRnVYSBr7URDu3NjGD9fy1qy0JGMg4CewGX5nhkqX6GcN4DBwzfX3RbJoZ
1qIu2d2MxUBs7MPxAD6UGzMDvPyvY+Ay1jBuT4IF6LXTA/VCMCCTwUKKPsQC
iVjO87LXMNDx+rrPvbMsMGiyWszhjwHOIVvaojAWuLZEU2TijoEpR8E8pXgW
SDts2R7jioGqlR861Q9ZwIF1Tb7BGQOmTLpJH0tZ4Iy955aRAwZkU/Yrn6tj
Abu3LUGv7DBAJVTX9/0zC1wXF3XntsVA7iEF4bHfLHA6yXuIwQoDfvUzTY6L
iLPz3ZNQfjt55qnDwg4LTG7bp4ubY2Dagrtkh5MVUmsYN32uYkD+9q4G92lW
kEj0+5Z2CQMKjts2Ly+ygkpgwjnXixhQ0t68qWnDChP2ht1nUD5UplrrcbmO
fr7moLCiIQZUfy1vU8ezgq0V+7raeQwcrlokpD5iBbMero3zBhhQ95lzayhn
Bb8HPvcLz2FAw2Am+eJ7VsA8OX9s7iwGKLJ/qmY6WcHi90XFo4iBeXI4bJAV
npxo9n6shwHNqd90nLOswJw2zsiA+MSHUZnCDZTbmze2b+hiQCt7+DzQs4Ft
1skLLIi1rw8GfMexQQc9jiv3DAZOXR3IcCKwwfS547o6iHUO9zftybFB0gme
f7so/57h/DGdfJQNGDV/czci1l3+ziF1hg1OsU6V3kN8tvObcp0xG+g4uzR7
I9Z/+fXqBTv088IVF6wQG9zsuPHHmw3Clg+YmyM+b9+WHxrOBvl59RNOiC+c
+NyOTWCDEBrmuUjEF4U/reSnscH6RxXvl4gv7TbzaBSwAa4+Pug3YuOfTfDt
LRt8fmG4TwqN93JFo53DBzbgvtB5IBTx1ZT62ztdbODecDJ3GLGpV21p0jAb
FHwUqjZA8zc7V/NDfJ4NEjiHDb4itpCp2q3ZYoOx9ARrc1Q/K8YK0fOM7OBs
cHhmC7H1RLnOJCfyGJHJsWeo/jbvX3sEi7KDDEPOKQu0XnaZr+4fUGCHvwt+
OAl9DDiEFNc8o7DDVqeL5i5ix8svR9X02AH/+E7bKFpvF9xzWTsHdoiuCJns
Qf3htvjswpYvOzgsmrlMXMCAe3tuUGIEO7gO3TuyD/WXV2xmc1UGO4iEFjx0
MsaAt23G7LkX7GDlfYDztQkGfDTTMOOV7OC+lvuG8QoG/LdTzdi/s4NfCY/K
iCkGAvpSInNH2eGNiyWVFervoDf3Cg4vsINuQ3r9Aup/jYqTW6/2c8A+jfp1
FRu0v72OnxwQ4gCKsgSzC9pvjRaa/c/EOYDjSbbeFbQfNc8dc/WU5QDG4GFR
Y7RfT8hQ7tGpc8DqhvGZIG+0nyaODJEvccDBfv7bZsGoPt+6Z2NMOYBwllk4
MRQDkfVum4PWHDCgGYNpC8NAw6NsfLwHBywm//vqEIUBtXNMun/iOEBK47I4
EZ0/chV9FVk1HOh8YrPPz0X99tS7eb2RAwwkov/GoPPLJYm1+9wnDmA9IV7h
WYDeNi7H/u58R/dfkHhnXYIBEeHnYpf/csDmv42zdeh85LoZkIQhHADOW+vM
0Iv2qz8m01HiAHQ486pX9qN+tHnxsl72ADjtylLUBjFwV2P4o5vaARC4TTQ1
GccA8/LJvdYLB+D9HhfN1jIG9q5wuUTEHADmd+z11RgsTJLeaK3MHgDyFk7C
yQgLhBBXW+nlA+C70wSvTLBw9YtolNXGAdBndjbYMcVCp9O9ps79qA+GHw/k
2GGhKs/j+EsBDFTeyZYQR353W1j6mB3qo3H98/tnHmNBHp+p/gOd4w8+XtaI
GseCi82lq+xV6NyKazpEmsbCs9dswdr1GGjL08P2zGOB53xIddkXdO7QZ21I
rmNhX8LlI3fRPGzfhDf0MOGghwGvqsOFhdft+jlEMg6ubccp1gRhYb9D0L/S
QBy0+1gnB6H3om5119kHoTgQmlNfVY3FwuWditrACBw0/fr7pjwFCyssihRy
PA5Y6oyOFJdgQejTazH7TBxkhAsfy55Antr74fmPDzhY2NjMsphD4zoTJuDS
igNNr24aQeSt7ByPeTfacTBpFdP0mBoHbrk/Wfd6cUA+MXcyhQ8H775GZr75
g4MGusqzsedx8OrKPp/XzCjPXk8q1jZB47whE9CG/M/unzPHfgscfOQdzx9E
/sc0JdAV7oo8lZ2TfoIXD+c/RRpdi8XBv42f/yKlkW/c0r/qVouDOZL5j/FT
eFDeJ/VOBo0zeVOt1gr5YGwwrcDMZxzQ1k7Ud59D+db1zZB9Hw5+/9zLTb2I
B7+zfNaWKziQuliWnWKNB/oDU44XpFCOxkWcN7mG8lHMVa0nZDyYHE6sngnB
w8Rup9A0ykFmNuqk//NZ82xl7/XjeJBmqe+zQPkt+uMtrcKreLjW6C5Wfgfd
n0IlvGaFh+rIpPy5RDS/Nz7bgDzTQHUwgwflQ+1c09c9KNeZdm8+M0D5kS5M
TpgmAQ8LUXe9FZ6g56/lbOum4GEs4MQgSxZ6viv3j1SUQ8cEDsHPbPT8K9QJ
JJRjJ373FRqi/Pqmy9cpAOXgn4K793fyUL49Pa31HuXqKftoymOUf6NVvm0b
I894pW3/5BXyQb+ikz9yWvDA8hSrKYWusxOreT3fhgeBkNaA+yhfa2OfOkX2
o/tI7gWcRvlb+eZB7Y5hPFR+6CQlonxOpL4jzDOJh3qnC3qt6Dl0f/1+FC8j
bzE7mMON8v2a7czrzQ3kIb5FTTIo/08MmCdoUXHC+EKauBLyg+bWU9o/WTgh
9AJTIh/yiTfH3gkTsZxwZhR/awfxswr5HY+DnPD+x2TRV+Qf0c94yuiInPA8
PNbUEPmLH39CgoEMJ+BXCwepkN/YJdM6pylwgpghxTcL8UXmAO1JVU4w3nbh
O4R8SfvGrLAChRNIBuYd1YiVNyx2grU4QbgU4g6huhA9vv9oOcMJ5dfVtLIR
c06eLsOc5wQ7nqBd6kY0P7PaBFNjTth0IpVcQLzWreCcb8YJ3h8jLz1CPHEm
T3vZhhNeGjGtdiHuaeQlaDhzgvnSw7hdxM2HE3diPTlBI5Sdk/89mm/Jvr5v
/pxA06f9WBbxM/HAMoFQTrAc5eVRRHw/Yy7BMZITMEFO96QQR+OtnMtucsLn
62wMeMR+t3u09xI54fi3sYAldH872jMEnVROkL/QPNGI+GJQ3U5yOifojt49
H41Ye1GxbyiHE06bEt6pI1Z2yC+TKuCEoVxD8Yn/5z/El+hbwgnN4zJJN/6f
/8W7zvVvUP2G8qgxiPe37T/J/I4TFNgpwcmofiyuada/3qP1LGfv2kH1xrEq
hhW3csKprfzdS4j5Xn5KC/+K6sNty5SD1ktUz6LS8AcnXNfO2BlEfikzt/Zd
bIgTomuLhpkRK8XHL/0b54SMyoVqSbTeJ9qqpNOWOcGB3ytYFfmlrqvBKbdN
1B/rtl6SqH8usE7ZADUXZB9ZCWdG/WWth8/4zcYFVUuLuJxyPDjNFVa9wXNB
hf/dMmPUn17xmr2xfFygqYjP3kP9fKPNnYMkxQUnfqjnCpfg4aYrHWmPzAWj
0Y9609B+SGJNP/1VhQsurZ27z4h8Mluv9YavFhewZx9afov2U0Ob6Oo7Cy6I
Yjja74j240fX6gOJ9lxgvWwi4J2Jh07W87JWblywtjXl65aBh2G96/Z0wVyQ
xjnwRu0RHqja+/rOpnJB5on43wp3kc+5eawJZXBBz99XEh3o/OBgo8cu53JB
9EFtObPbyOfOKummlqLx6574eQH5I6X9Tu1QGxcovRuzygvGQ2j78RyPfdxQ
YOCgtWGD+sWtv06TmRuCDut9bbPEwx02zwEchhs+Ojq330c+mH42A18pyA1F
xOcZdMbIp9vXY6jVuMFQQE3cUgcPW+0vXZI8ueEeudZJgITOha+Wj08EcMNQ
eZLrFUk8aH7Dt66FcgN/ZqpBghiqX2+I+JXb3KDsdejkAD8euIf1RkXyuEG7
rLuIjQ312+LcpfIBboC/NEwrszjwwMoe/3HyIExMHXz4/ikOxi8VHRQQ4IG6
yk3JOeR/z4x3Gq+K8gBc/2NvSo8DBxNdl8dSPLChmEXfToP88PJ0LbcKD3Rv
XJgu2cDCginRBqvPAw6D5KKwSSxsW2cUMdzggcJD0yXW77GA9bhzfHmcB7o6
BZTYQrDQ7fFrVn6WB0YK+R40o/f1fU+Z+x5LPDBzvFsywgcL3N6tU3O7PMC4
pHWa0QULAn50d6a4eGE0gDFN9wryy+DQH79O8wKXttVWyxEsHIt1c/34khdS
o/9EntnFAE/p0KU7Zbwgsfes0XMTAys/9TUvVPOi91n458w1DDyTU+Qa/sgL
ShNFVQf/YoCl91/9vzFeGDBxUQ8axkCPWDhOnIcP0jSmGNg+YKD43NLurBAf
fBmjt2hvQP4WaP2nVBx9zuZ47GEtyl9tWrUah/jgI4cszbkKDGT6MDlc1OeD
hm+unEdfYMD5/b3qqGg++Puy4IzqfZT/5vY9OxPPB7M9GUYv7mFAgMsv8UAy
H9yKqjOSuYtB+cbYNj2LD1p/fY3Wv43yFoafvbyGD7gtdTqlIzDArn5nI+g9
H8yklxZThyP/s90bg1Y+6CT/Ev6N8uLjypGKL718kDx5Y19HEPI7y2dWv5f4
gLIY6aCB8mbfTS69gg0+sBJtehjkiYHSslgVDyp+2DlD1fce5VNbBmeWbVZ+
SDii8i7EBeVdhYG1Bhw/hI/iw+adMMB9VW8khpcfRqDytosjBlqL5d5gJfnB
WvV7TSLyydy+zMw+OX7QydX8p4x8MoQWc+uJMj+IXjxWOG2NAfKlFXPpE/zQ
sL8qL8gSA4zhtjqLOvwQX8+17xLK16MFPUpvDfjBTK2d+hjK3ym7FYzHzfmB
f4aFUQPlcxbxD24ptvygoCsUboF8M/Lc12+TzvxgviG5dQfl+S3/X6pHvPjB
nx+uf7qMfCDzT/rtADR+sheeA/Gfj6s0Q6H8oCdParJCPmCxSO0gH8UP/fU2
CQ3IF3oPsrVF3OIHllN9QTKIz2ryKPTc5YcPcmdu5iCf/eBETJV4wA8zw0EN
RMTq9xS2gzL4wbJJQvQN8o/X1RqWbbno+uP4NwaIpX7rNAsW8kPHB6prG8h3
s1guSXu9QvUtL/T7//sR7kPWiU1v+UHuWs8LV8QJpu6rnLX8cO/6MeEjiOmi
r112bOKHTOmXvRjEIUUxddWt/HB4qu/bP+Q/Kz33RNm+8sNdxssH/yB23nsS
Z9HLD05Z6s//96NR8Rfzpb/4Qdyx7sYCYhP9CsP9v/nhoTDnUzp0v86ApopL
0+j6Wz7skohPZXXyFyzww7A9W8MlxHWfBm5sr/HDJX+uyqT/fX1pavLsDj+0
BL1f60NcxLOqm0UrANSK2oEkNF+x49Sly4wC0GPxjRKPOM2ZlUubQwC4P2Sc
3kCMTT4Y/IBTAFKFBlI8Uf1u1oiNTPMJgKhSncgaYupxee2jIgJwt/7aUjSq
fwCrRmGCpABghkuoRNF6/T2kwzEqJwATTJOn2xDbmV30VVIWAJaS7I830Ppe
KHaj9GkKQNezan0M6o/PvUG50qcFQClV+NwsYk2qGMbQcwLgQhFw7UL9JG/w
5BvhqgD8XpldbET9lh9YqOprJQDjmS16bagfhbLfprc4CABo6rweQ/3Kttxh
7+IrADezjaOUkP9NJ1Ntl98RAG2CQ5It2g+W71gsGVIEIHbxTngH2i8/xrmb
Lz8WAEmt10e00H5qVpZP3MsTANKe6Kgh2m/ZPyxFTzcIQK0t1dS2LwYOUrvF
PW4RgMA9O8YmfwwkSgbNz7UJwC8JmZz7gRgIDUqqSOoXgGl3P5xZCAau8L3X
HVgWgPjpG1Y+yAenXReXyjfReDc+z7yPQfWrE3yYQC0Ii6YkB6GbGLhvFTyu
yS4IP59Vzu/dwUBX/qHQ51KCMGPiRLj0EAM6h/KL/SwF4f7HFk9D5IN90T1G
+g6C4Cw+5+2APMrhx75tSXdBmOU8QRf3BgPR1yxP/QoWhG/piYGzyBcbG3hG
jj8QhIuFF2oPt2LgyNl4zIEOQRDMXObqnsDApyfVFdPfBUHkrwlfyjQGjBf/
mDUNCCJfnBk3n8eAb7J2of+0ILx4tQ4YdF4bz+0J/6URgn/h5cYT+7GQrFhZ
ZSQgBF5G53Cy4lhgqZeeJRgJQYDZ5zPq7lgYfWjw8bqxEHz2tW3r98bCW2//
3IErQpBOWaOEoveNlfj7q/ethECDqfrqN+Rpb+9cbmP0EAL/W52HSpPR56Zx
RQs3hSDn9sNwwWosVGxOeNTWC8EdpIuPGHFwp5tFj7dJCD4dedUay4YD6yIF
yYAWIdh/u0/DH4sDNqvQEfl2ITilOUNtyI8+/4Q///SnEOy7tm1KLY8+f3BC
8faaECy2/P6OM8aB7aHsVRMZYcBfuO6zkoODm3fw7CFywhB2k/2GRj4OiiZj
JTIVhGH6dd5KxAscrD10vzKhKgwPxgbjqMpxELur3uClJQyHvy5u1iAPK2jp
vX3LTBj4Xtu6iU8gzxM686zIUhieYvQwB6dxsBRYW/fVRhjW7VJI++ZxoCbz
dInLWRjcclYMm1dx8CXRyzjXXxjuWj4R+bcPD/MmrKLvEoUheOdVw6IwHjCv
w44O3xMG3S4FU1eUP5RZVi7SpgqDjEhm8bAEHq7X9sedThcGUowrW5EcylMi
+X+/PxeGbgfl1mF1PCjMalbPNwqD47E/HYlGKC9rvek+0CwMBLjHEIzyUFCG
5LzSJ2HYqlL1Mr2Ch/f6HMLXOtD9r3y6RoPy1IXyX9H0A8KQ1Na91eWMB//Q
gPNCq8JQ2HXzdfB1PEjMBrPErAtDLKG6cDEcDz9MwpvntoRBZdA2xyQSD6qH
bh6ppiGADN2GIk0cHtZnHhMuchCA2nqm6TXKg/kmmQM1WAIISZaE1SJfNG7J
vS/CRQADgk1WNfLCyuyXTIv8BLhYnfvx9kM0XpO6pVvSBBA8RF0Si/KnVMv7
F0uyBGi76vJAFOXTfqWPdiYKBHj4ksWsNAcPahxf+4mHCfBKS+t8DvLH2ZDv
yfHqBEhujXOkQ16ZNtN3doVCgLrlK3JXUN7dbh5tbNAmwMEi6gd9hXh4oTQZ
LKFDgF/B4SK0KB9fzZ5RTtAjAN55UlYA5WcWjoWFVX0C3E6NK5JCPvkuZKXg
6gUCsAjX3pdAedttZt3m/SUC4MIZBrheoXxpsiMgdYUAo9e9/NYRhyrR3ftn
SYCujLTUeOSbstlMema2BHDzosFrojw/yM5O/8GBAD7wtnsS8Z0QbIO0CwGy
R1m7QlH+p8xwXUtyJ0C5ggkD/Rvk1cZ8hza8CODENOsVhjizWeivuR8Brh8/
yDqDWF9J7HlzIKrHW8UubeSvVNmS1qQQAtTCnXf3EJewy/InhxHAuuJa61fE
FiEKvZsRBNiWDlmhQv7BMaN81zKGABZChUeEETcYq535eJMAxmyOTxQQezVT
9svdIYCHxWGxQ4gJSifqUu4S4FB4RrsE4q6sU4HbyQSQ/8mTwYr4BrueovUD
Aiz+IN8fQ89TCDGY+/SYAHu/rSoLEI9OG+WRnxBgylGRyRpxkvFly9RsAih3
id5iQXy82Yx39ykB/GIrNfLQ/FYUrb/bPCeAwj9vcUXEuVn2CZ9fEOBfbM/J
ElSvC+wupxVKCNB09W62AOJ9IR60D18TwOX92NFQVN+yaZ93e2/Q89kuiHSg
9bAxDvS3qyLAQkfM1QOv//9+MkS+7R0B3twXXT6B/KpJ8caMYgMBPix3LDii
9fTJin76qAntLn858zC0/qLst8ypPyIunToZi/ojavret/Z21P+Ju0UuqJ8i
e8dbt74SYCKvmd70BeImlUaJ7wSoOfTzB6D+u5Hxs+TGT9SfPy/SjqF+Db9F
yi8eJKC8ZemWlYeHsIDrTwZGCMC5cDrg/9+PhJ4XuaM8RQD2AJOMJNT/IRTf
KOsZND8tg++CaH8Ey7QEJ84ToOzbp+FMtH+C6Jydp1cIwGo9VBCajny7qvRU
BrUI7KQxRxTcx4Nv3j74vE8EfjQEfO9NRvNLvqiyTi8Cfq1v7DeS0Hq7bYqd
ZxMBF+PB2wcT8OBO0KSl4xWBhr6SXx3ReHC4+fWdq5IIYPuE60V98GDvL1L+
SEUEen3p7mR4Ip+38X3RckQE5IkDLazuqN4aBx8LHxMBq7s1/V8c8WC5ZBHw
XU8EWim72x3I5y5fXlA4ai8CR81JJ3a18WByUlPKyUkEfs5aPek7js4PpWTh
VFcReHP48lghoPOOTZVj0VsEmldTEg4dwYNh4/W53DAReKsSaD4sg3xbij2f
5ZEIFD5usCzkQPf76J4vmY7my61nh2NF47PrzNfOFIHnXMaX/BhRvbPvPg97
JgLjbE9cxWhQv/DgCldKRcAe1+WpuIwDPuaDRQOfReBx+tcX4t04mJ0hlL3Y
EYFbVfnqkISD+JfK9bqWorDdKPF3fD8OiBYSli9tROGiK84eR42DWgwPDZuD
KAhpXg8+vo18z3/neIebKBz59pwndwkLFzSbWgyCRaEsrtvcewgLfL0GHRdT
ReHzhti4cyUWXlC5Dlq0iQKxpYm5Db2ftV6bXW/oFIWp3FMTxs5YGLTVFyJ0
i8LyEIF+2g4LHJ8Vrcb6ReGvS2AenxkWfFI2x22nRKHjJ71Siy4W1KRi55xo
xSCdSZ14ThoLrYY52z6HxSDBWz2NEeWH0qjR/sfqYnA77pFKFcoXj94KVzZS
xCDy/dNer0kMOPFm+nJoi4FqXPaNbeR7jGNp84XnxUDZY3HHuxvlX6/7w6PO
YvCS77Db/nfIV3K/1zK6i8GLDLIZVKG83oNLJ3uh+0/GP4l8i4HJw/dMQgPE
gEo/yU6yFOUh6sSug1FiMLPkemAiD/lCYlyTfoYYzF/9bnMkBQMvGj9m+2eJ
gcLC3bcY5H/JK/ThGblicONGmutqIgbt7+ijswViYNXHrtWP/G+fUMSbmLdo
PIYt4iIo380aNCYXVYlBPW23pD7ywe4Iau/v78SA179pKwb5YM7kdTmRJjHo
qFQ4xo18ULM4OL+2Uwy0ZL2La1CelBqpjh7/JgaF/l/ij/lhAIPdsmHpFYO8
/LYnX32QL/gFCl/+JQYHHtXHY72Q3+VX7IUNI84buvbBA9W3/9+vvDExOLSl
23QD5ddwDb9Hq3/QeH3yIgVdUT70KA/gmxMDCa4hlj1nDOhnr1w8viAG8dsb
7NMoDwvReWPvrqH53HTLG3XAAINq6eLbDTEgvsLoLthjYMFxsWNwWwwq8HK3
GRHXt7nflqElQk6y7Z4Z8kklHDCn0hFB2+CM9S2Uv/Mvc9ykZiJCeP/FxA/I
L/myhhlcWIkgq7t9mxVxwmRJTA8HEfLd/5laW2GARjac7hiOCJ1v6BhaUJ73
8zGIKuQiQvS9qQRVxNNVwvs4eYnwwv/K5luU/82ol26ECRBB5Du/rhbirpON
1DPCRPjCPx83jHxB+05SmJEYEeLe36yIQ1zVbbVXJ0GEI6qlA4CYxKsYKiVD
hIY5wtZ+xJmWtDvJckTYM3rM3WeGAVz+t2t7CkToHu07XIU4dj5n01GZCAaf
2K2fI95W8gnsPkwE8qm25GeIPa6dWNc4SoRLauT2V4h/N+D8nwMRfr4wYvuM
2JhhfBV7ggjfnl2+sIT489lyn9CTRLigePXJ/9/XaqRELU/pEMHvqv+8E+LS
n0ZehmeJoCfzCWoQEwnExXcGRFh64ZbCi+b7yGHNXcKICAFTkTOxiNmKm+eT
jImwPiWhuQ/V68bqfdedK0SIqfB/EI94Tc1+1t6cCOar8XOiqN5ON1Scu6yI
QBUjSWlFPPiRflrdjghY7WMxIWh9zrP/cMhzRD//UrxOA63n4bQAu2APVF/z
grFptN4vRk+NT3gTISxzpvG7HeofyYM2Bv5EuOej5d+O+oPhTaUlMZQI1I23
T/xB/hW8HTecGE6EebKgPjPqvwXNy+ZbkUSwFMBxqiH/+tGxebXzFhHWREzf
vHfDgC7n559HEohgElgWxof6u/7q48tPk4gQ+dBr9IYnBvL+qBkHPSTCyc2D
RwLQ/vCjDTEUzSPCRkj3T9prqF9O63XdKSACv5Mw7cdg1C+J/AYbL4lAymo0
fYj2nxZ/7dn2MiIIl6wHWd9A662ydzqgEa0nHa75HvKx2JCOj6MfiCCkVLZW
h/b79vsnJ/U+EcE36vHPdeRnY/qgRehE9WI5H5iIzotSp3D48osIJTtD+43S
0X6wsvhIHCFCkZ7hhx9PMPDGhKIf/psIdu9OKztkY6Dy1I658gxaf7XS78/R
eVRPDLyeuY7qa/vvfjk6r9pGPWp9sOJQXH4r7CfytbP957Q7OMWBv5qrm70d
A51fZdslecTBETNmc/YrOm/qZ38NColDk8/9r396MdCf4bBzSlYcCtXoh+6P
Y2DqsoU6/2lxcHV5kveKBgtO5ylN/rri8GVW9WswHRZmTwvodp0Th3f3Wpz1
mbDwV3XgSsxFcehONffjwGBhjdP42qK1OJxgrvReEMYC7bdzVR9CxaFWdckE
exwLAmcoqm5l4iCMPUH+G4eF+QbnnTtvxaHg0mSiyh0s1Kk+aCyuEoevkqkB
EUlYsCAu6i7Wi0P7YLm52GMsZFPnWPq0iQNU2DDfeYEF8Qq6W0ET6P7HBrt6
OrBAFmv/Fc0tgfIar6k1Fw6o0jaz83gl4JLZNGmQFwdfMeIOHwUk4PMfQT9j
IRx4UYUtMYpJwN/+fX90JHFQ/lOePl5eAnJEUmpF1HBwJCmFfE9HAgRm+k1i
zXBwfO9qxJNgCWgqNW84jHwv8ybPH9owCVD/sF+4Ng8H2/gfZx0iJOCL1EHB
o8j33sgY8sjflAAKo4mxFPI9icunXzWmSkCorZLLu2YcsJQfGhovlYDivOOF
uVM4cIDlEzpvJKC7Wb+vfhYHHz6XFBRVSoDXLTXt7ws4CB2V9vOvlwD6kKRT
E+s4WGAnsDK2S8CqSwPrUwY8dDuxqcn8kQCzuky2ACIeyGufMxNnJeBylc8I
vRQe4sPj6Fb/SkByZvzXeBIetB/s63q3JgGkar1715TwUPFh0+HcPkmgG3Ww
+nkM5VODivbX9JJw5pzNb24tPHgO+CpxM0tCcrBj6plTyJeWF/aGD0hCY1AQ
T+JZ5D9Ck/e9BCUhxsXUOeky8rPC3O0egiTcUTc38jPFg5GKlZUaURKuhhfc
P2uBB7azv0j7SJIwM3y75qctykPXvjWlHJEE8tH4MVsPPAzQ3ZXaPCoJH9cn
vv/xwsPhpLOJZsckIdXd4bKlLx6W8j9dET8lCemBw7VSQSjv9dQtVRhJQoSy
+g/RCOQXI60pY8aScFT9ra9gFB6qZ76rsl2VBD699nK2GOTD1LOh1laSsMlZ
MtR6Ew910tzMbO6SkBBSJ16BfNJJWaRI1UsS2LUDpS8in+Q8Jmtg7SsJjKx2
ZlMov7pcPJFacU0ShIYeiP9JxQNPuIeIdawk0N99KngF5d/mW9ea429JgpvO
Yd+HGah+96MdK+5Iwod7YU8/P8HDx8K0YtYUSdgVmHZmRnna503eedUHkpDt
PzvLjfK2YEPpqtVjSVDe/0CQJxfl6Z6PahVZksDhgov49xT50Mi3wdFcSbjk
a/P8G8rrbTOD4az5kvCzt845B+X5gLU/oqqFqD7SE012KO+LUq+2WBVJwhOG
1GJ+5KcdzFTO8a8kYZguifgRcRAnM1tFmSRY194XtSvAA1GY89XoW0mQaLHJ
/Yf4q7TwBdZqtD6V1ZnByCeClWX+qdRKwjWZK7hVxBLHVB5ZNUgCSyXNpgXy
j29nNI/GN6F6dUbr1iMOvag3/LZFEqgE5BmxyFekLI0jRlslwUeBl2yC+Luz
NZG1XRJEMqMakhCH+bl9UvkqCS0bJe/qEMuEB7pYdUuCQNcv0WHEP25Fssf3
SsJIte6/ZcQR9xNK3/ZLQvtpjUNbiGWzHhmN/pKELLblwVXE/YVP11lGJAGX
Xrgyhjj6Tcljld+SMB6T7/cBsXxDtYbVpCR0WErZPkI88Ll55Pa0JMS/86y3
Qhzb8zXy7ZwkDJDqYgUQK40MiI8uSIK+7KPaNjS/oZnJVpYVSWggDdp6IL65
tuSq8g+NR8Ulkg6xMvUuh9Umeh6LtFAiqtcIM2PZ7R1J8HalprAivs2Ju/SW
Sgr+HOyZCEH1HpOWSmehlwIwxv85jNbnjvIhUGGSgl0nvXNRaD2PHIMxS1Yp
uPpZ4GITWu/Eixcl32KloNhPwpQf9YO6peWXEU4pCNeUdVRB/TLp7OLOwiMF
L0wdSFqonzTCb5RbCknBmOapDTXUf//U0yyDRaTgx1uRV1JZyN/Xy1lTiVKg
7FNXx4r8TsTjj+0XGSn4ahvK8gr194A0LWZSTgquzJ6w8EzDw/1JvlpqRSmU
lzHKxMd4YDDX51Q5LAWfMxjuuT7AQyOPU6OBuhTYNHTLUaH9cq0nws2FIgU5
HvOBMSl4mNd725ylJQWvuQyO+SAf/KYu4M9yXgrsH5uPtNxC9VlXERE3koJG
GqtD1Gi/apcZdBwzloKMzPJMuVh0fklHifubScEoi8C2cyQeMnhme0ecpKD7
RlKITTDyx/VK1bcRUuCrMvzMygkPwmXffn+NloL7XctUq/aoP9znEmfjpACj
zRkVgs4jvUmhP8KJUlBvlH3FE51XCj0xD2+nSYGn712vCSM87Lw22rQslwK3
Uy2nuSl4eOPu/iy4QgrozwYtcarjwUM67nxqtRT4QLUA62E8jGbXFHxpkIII
p1iLYQW0/++KXFFplwJtnSpBMXReJ7kvVrNMSsFpzMCuOjMeeilpDM7TqD6/
wxa86PHAx3HS6NOcFHwQr6/PpMVDXknafNSKFFDexEX+3sJBzeJJ4T1qaThh
/PksB3p/THhnRC/ySUOmcfM612f0Pgs4Y9BzXhpy98vnT0XiYDTs6cSTWmm4
9PD71uhfLPh1pns0NUhDZc5xXOQMFpiE7m9ONSG+W3+COIkFhbpoNoXP0kD/
PMfebRALETv2yk290sBUocx4oA0LokFS0VML0iDAn6RdVYAFO+9iMXkRGdAZ
NTR0csDCZmNesRFRBiiJcWwONli4g8k8HCQpA8W5tlFOFlh48ypR772cDJD+
qGFDjbFAv+Dpa6QuA9s78YWjp7CQ76L0IdBIBiRECUsVUliYsa20aYyRgX3J
KymnljHA0qqZIHVLBgR8DsW2/sWAjOyXyqQ7MsBof+ml0SwGXNYG2axTZODC
ZCtNLMo7s9H7KmlzZKD3UfiQ+Q90/Uz8mPMzGTgTI+Is+x1df46Lrfu5DBwp
Ct+h60LXc0lZ55bIgGzo0sOez+j6vHOsWrUyMD0l6rRUh65n6VN52SADZc7i
v7HIP2U8rKzwH2TgrsaA9P/+6aLq+3b8swwonB8IrSzDwNzHR5bRfTJgErsV
KF+Agfk/4+UtKzIQNV0+dyoV5fWz7sNy6zKQz8vCJ4z8U7Z0nenBlgxE7hZd
2Y/ypFsQs4UDDQluc2jpL6G8Oc8kz8TIQYKZyYc/zGPQ9e5VSp5YEoxIHL3y
CPmn7Lfj5n2cJBiMo/YaQf7p9vhi2XN+Ejz5OJeWEoaBv9LBZjrS6PPt4Kup
QRjgSNwfVypLAmZ6HzrVQOTTK3de8yiQgJc6tXAc+ahHTRbDjCoJ4uE53sEX
A4lC0oqG6iRoel+zqI7ydklkmWk1hQSxpSf+CXijPK/bUnpLmwSn/TZfMKF8
zvFK/9fyaRJk82p641B+J+P76a/qkcA44vMtaeSn+oHWCk36JNg9w7xzDuV9
j1+zV2UukEAC59cWjnw18ZhfTPIlEjgHhdE2ID8oebr3avsyCa7wP3nKiriT
MW7AxgzV57F2lf3/PuGKoW+zJEHSvZmT/3+/Y27wx23LBs2npJlfD3G7Un2P
pAOqH0P7ux7kI0e5UzWMnUkwJXGc9P/3pS+2XJ9Fu5Fg+5G9Jyti3qETbOWe
JLD6F5xQhXz4ZiOv35gPCbjj6G97I954uvTrQAAJts6kOagidoj7pAXXSPA4
9SCREXGvS+ZLt1AS3Hxv+mEc+ZC2vj8+PZwEJuInT/7vR+WKZ0M+R5LgIU/Z
i0bEolxi4xsxJPi5cmPtf763uaUrcYsEr1iTxDoQ0wx2lV28Q4KCmrojk4g9
G57zRd1F9zOZVmZGzxvODYt8nUyCc2oLPGqIz8Vemh1JJQFfVfGkH+JaZ9kL
HI9JcJ5En1GLmHRuf41GBgn44bMGBs03TWFAxDWLBGuO+z55ImbmfH3rcS4J
btApH/6FOGgjbvlTHgl8i1/fuoDq+WfA4sp6AQlidjtrehEb16u8JxaRwC1+
5KMdWo+WHDZpo1ckGFpVfUGN1ks5ZjwpoowE975KWecjxp29ZzVcRYIHp2WO
HkTrHyHv1MpWS4KLB8eMxxAv4Y4pHG0ggdz7G4crUb90/JynftRCQvvw85FY
1F8adR8cP7aifuH7bBjuhdYvO+3rWhsJgkZSBKNRP9501Mky7CbBgd6AolLU
vxu6wow3eknw7B6NZb8fWi/yukdJPwl0I48+ZQ1A6/PvKbCOkMCVp6DhPtof
5f3B+Wq/SaCqqxc3i3xStNaQw2mSBOWtkQ3//39wmijq4eY5Ejg037NSQPur
FmN6PWyTBOM7KgER0ai+a4qTRTskCHGZ+6IYi+rbx3TuF5UsJKW3Hvsbh+qZ
WSFwhF4W1ipzjGPiUX1kcbXLWFng3LP59v/vo4pOf962I8mi88nues4zDEgP
lrhGkWWBjy+4YDkfA/le9wdzFGXhcsfvAr1CDGQ/tqwfPiwLVvGN0wIlGEiZ
+xdxWVsWenjlM5XQ+RR8V5T5rLksxGBp5vg7UT3EmIJdrGTBcjPIlfYb8ueq
v7M3bWWhmnc8axGdjx5jVe0tzrKgPqvYM/kTA9aHDJKOBcjCxT/yRw5PYUCn
L+TgobuyQP4+M3gV+WSLq/VNw2RZiFhUyXi/HwsnaE5veabKwvFR7ZcoEYKG
NO5XUTq6v0rbFREOLMiHFGRKFMiCOaHR4rIAFriFe8X53svCN63VeCp1LEw4
kJVpV2Wh0Www0v0a8tEDeSdt12WBVz1keeI6Ftar+E1atmQhVr77n1UkFuV2
5uBbNHIwcjlK2iEeCzKvxhuwHHLgGs3AnfMEC94bj/REpeWAkSktoqIJC1Q3
99tqWcqB3GzrKR0OHDAqBvvl2chBwWgdngGPA8zAUgyjgxxM6D699uEgDkRk
hwva3OSAVfabi4YIDrS7qhaMguUgiGHOXVQZB/E8HsF2qXKQVFVhm34FBzyF
/fdi2tDzKjn/SeQiH/2WMVrcKQc5O8+/QT4OPm1Zyf/4Jge1aTO7hsgnA3Rn
2iX65WDhR06LcxkOeue2GFsn5MChnbXNtAkHOg/YgI6KDIe3czjlx3Dg98LD
/hE1GSzPdr34O4GD7PquO7K0ZKhQ9ynPm8bB5tT9XxfpyDDAYP6SdgkHzw8L
XstjIcNN3nGCAxXKbz/l3pw6SIahwp35Vl6Ud//e/TXAQ4bZCZ0KrCAeLGhX
9nnyoesz5bUvEP7PXxWGDwXJQGvcplMjgQf7YFj8I0YGIyF9JbFDyIf4DWRu
KZAhbzP5q5Yu8jf514aCSmSIPTjyeA/5o4A2/trrQ2RYkpOtKDbAg69b36ef
qmRQEl9LWLqI/KXO0l6GQgaad5GOVJYo71t4ZbedIUP6X95CGW88rOzyPYrQ
I8MfhkP33JAf2qW33D18jgzV5f+qc/z//3szvvCn58lw4q6l/+Q15H8XWsxD
TNDzt45ndCFfjFzyvKR4hQzPmSL9XiBfXEvkO/fnKhmSszSpApEv9rV5ahhZ
oPno7o3/Qfkz8yQfP8meDF935qQkkS9iJppxYw5kqJz73Hgf5dfISE+Wh05k
EDjOfXcN+aN9Q/PWPjcyeEWK59++j/zF3HO5yp0MdiJhA40oD+vs8s54eJJh
Kt5LYAblZVk1z/4BHzQ/af3sAyhPZ/bxdiX5keHHga8d7ChvYwKaP50KIMNL
Sa7RPcSRnJ4Nu4FkyNSdax9B+XytjLey7Bqq3wWB2+XIPx0Mm0ucQsjw4iUN
xzXkn/2LHvlC18nwSU/KSAHle91E3syeMDI8sGY3/on4nWxz6u0baPyGsng/
5AOybR4JmpGon8Jo42iQL2Q688asR5HB/hxzSRhiDFNzaFEMGRRFG6MXEEfm
e/jZxJHhi1Uu43nks2vavG48t8ig4i576Clih/EPtp23yRD4cmD/NOL+CA/T
6DtkSA2XDhBCfqJL4DVST0R8LjX2FOLa+g+6S3fJIN2TpmiFmGzucSL/Hhmq
3LT8XRFn7/Com6WQYf8M/qITYmzaB0VcKhmYaS2/GSOOPOIh3foAzdctcEkV
8doPHpGwR2SAiVdvmBA7+H/gUU4jg4uwqUj7/+PBe2Bm08lw9kebWgRi3TIe
puwnZBhtvEgr9f/fu53/QG2cRQaJhzohjWi+5EX3DdYcMghit1/oIs5K4Fl8
n0uGD1PvUj6i+mFkP0wFPiMDd9foEWXEkV9Qvssnw12J7icpqN4OjB86HheS
Qaeaqlny//XJc28xeEmGGmG5x2Zo/XS1eeroi8lg/SX2QhRaX3KEe5F3KRne
hLGn5aP+yBbmeSZZRoZHhrYaTx/hAVfflD5UjtZvR2Xu3kPkd9sH489UksHX
7umDk6jfFpbPxG1UkcFx3Scag/pxajokKq+GDNMcnhKdyej5P0ZCaOvJ8N1e
qUzkfx/rwAa9aiCD7KRYdWUiHr40a/mZvyfDSsPaC80EVI+y527VzWQI3atM
IN3Gw9vCn06OH1E9+OefJKD9UpLNas/VSoYJ5qi+38jXshI9zb3byJDdZUbv
iPZbpMthfeluMjxcHKHtD8FDiLWzbt93MuA+bh7sRfvV73L6qZheMmy61A+3
BKL9dIr62Fg/Gbb3iN8j0X7XEf0k/3iEDJ5XFQvdXPDAMWCMZf5Lhiyl+Tac
MR4Yv91kr1wgQ4rFFscl5G80rTXM9ktkKBZ39LhzHg/Lb4X2vV9F56PY99kB
dD713JtaCdomQ/uh1TdbgIe0MwE904zyQB2xZGosjgeJ6tSHraLy8HPtrKTl
HA4+enqUXSHKo/f7zfqGPzhwkDjdMSsuD1G15yT40Pn7PGVzH7u0POTL2vbU
DuJAysPUw1BeHvrdLNtqO3AgLSZycuCoPJjsmw9pLMGBbELRytxFeXhRFOj5
zB0Hh6w/nDsQJw8JXNkeIcjH+HInjjTdlAfRwHN5Q6NYoBmnJ/rflocayT6b
48jP2u10tgcS5GFSLoaZ4zvyMaeO/Pz78iD8I1CisRELDzz7qCFXHrxpJcQL
MpCfXZ977VYnD0p2BLUoEywM17M9EW6Qh3dh8xhzIyw0U5NvdjfKQ5mj+R8N
Ayzci/CyONIsD8N9IdgDp9H7NOYfC12bPBg9vd5JcxgLpneo7dL75cHhzNVY
FR70vu8gGOgPyEMuYYMvjBMLUhwn1GkH5eHylcdZnf///vhuNMZxRB6uHhuZ
jWNGfpjCXKc0hcbPwfLcYgcD9Wl47i+r8kBg1nB6O4qBs+m/hK3+ycOtW9h3
DUMY+Jn+VHp9XR7UzM75dg9gYC3jEEV0G82XQm+P7UV5K8vILphGAUQ6u6M3
kL9VZfF7YPYpwOf3h9VPf8LAqezxwPz9CqB/cGk9qxkDNjm+8d0MCvD8bkuH
WwMGHj1NKZNhV4BCqX0d/m8xIPHMtLaRQwEqT/7LPlCO8uAzsY/GGAX44WVK
///v5zvzyn9G4hVALOT6B+4iDNAXfKf5xasA6c4rS0ZPMZBckM7iza8ACYdT
RTVyMEAotOVkFFSAv0NmjuQslF9frEoeIijAIOWvpWI6BnyK8AbxEgqQcoAz
ugzlP5riX5dFpBRA0GGkZR75YELxU5tKafT8grUYxSQMFJQcChiXVYCy0LsV
A8gPVV/thF8jK8CHC8PHj6E82fzqw60DCgrw6xpTRMktDIyUGj05ekgBTD4a
nylGedTtNf/zb8oKUHG9clID+eT26/FSR1UFUI4asehDPsld7tucoqYALzSd
2OWQT559mzI3d0wBgCrJziwUAwNvTf9FHFeAK1kWS1ooDztWiFHzaCnAF6Ga
Z6rBGIisLMdpn1IAvQfbRRSUpzFVIQIDp9F4w4n4C8g3M6u0JLzOKMCTr8kf
vFH+rq7+rpZxVgGc1M7yfEf5/FRNupaSvgKECwl/4kTcU2N7rtVAAaJoTvVa
ozxv845kYmGoANgWOp0a5KNL71at1i6g+RtmEYUQh9W+c/mv4nKPx/IM4/gq
rSaxvQcrRiXZKOG+2zSJX7aGhGgdRCJ6X6emqGwdCLFK3l6j5NAcaojU5tCw
5jAKoTIMqZXUlM3hLUIZu/bn94/ncz/39fyu67m+pzbTfWSuQafJB+ZWRB3Q
2cowze0bpkycXGF/tMSFoTLTIkBO/vBRpfikgyuDqs2grg6x+fxd5+67UV5c
fD6pIt9wCirK8nNnsEu3dPcnljTMKB7bwTCxZmnGQuKDuhuroz3pvvke07rJ
d2VHMptFXgwOz3LDLhNf+EPxMNOb4W+j5g8iiUuM1gwYSxjeq0ru9CZuPC6f
KJdSvTtuX3MiftT9UNnelyG7cEWxLfGImdH8Lj+GIVl823pi5YTQD30DGIKy
C+a5Emv3N308uptBw8wlbB8x/0Lr86hAhpZIB+UkYpu0AGfhXoaYKpeyOmK3
sV88MoIYlhtbyWfQ++91mhNotI/OU7lzypY4OnfbkV/3U94OVv+YTJw8IzfG
LoQhpXn3m1fEV93Gkzq/ZjhcmuDrTvWqKbbJkR5k6FVUjN4l7lA9d23kEIOt
WUimA9W7X9pbE3mEQc3ZStJOrK4R3Z12lOGbfrZUmb6nQXDboGEEw+igdEkR
sWWj7uQvkQyxFXcMfP/3tdBqjY5oyk/1ZtvhEPKZdoG+5DiDVkiU6y3KT5zx
TtPhEwzOIzP98yhfZY/f+vLdWMrjWH2QjPzt9qoNO7+XUX0r+tzllM+ehLQ9
y+QM5ndVTc5TflWsLWJt4hmu3UzxaQ8TYFF6bMofCQzVH2WWK4WTn43fv+R9
lqG+8a8u8wgBduQdunk0iWF6yy77pmPUv0oNraopDNt+Wv3dEvK/49s1elJT
GRT1srDj1F8FaqVTJWk0LzLbV3x1UgClfa9WKn5gyK311yiRU781rbUOy2Yw
XdmX7039bah3ZtPcSwwvcmKSNRME2NzBg/QvM7SFVTnmJJL/me/N8yyg+VVc
/mBVmgD2M//R+r2coas/4DeQ/+U8i5wIr2RQj6oNraB5Nb1Rs8vkN+rXNRl+
tjTPSr6zOxd3gyFV51pYKPmhzsI8gVMjwxzXDKn/DZqvZn6z7nYy2CR+3Wb+
QIAN2tP/Cuti+MFjYJv3IwHypiXXGD1gGHjinX6mRwCPuvrw048YPPUXzxL3
CXBrk/6EQy/DgReKwGOjAny/59lQ0zDDF/7zIlRE5G8bj9458orh8czretXv
C7HRdN4VwzGGpT5JN8M1hZg9ae0f+4Zh/7DZIfXFQgTFZD9dP52j9dMF2slM
COssyb0GNU7/1Zl7+p2FGOp6Ul1vwJH2t7lRS6IQL0IXV7kt4xifI3B8kyLE
8KKd5YOGHI09/KxeOp0vfVgiNuHYYH9MOzqHfHC4M9/TlGNSTVK0q1SId1Xu
JI5/xlFnlvhTTJcQxual/vrbOQYCApvjF4rAHo76XHfnsNnqeqNHV4QVEZ9I
HD04BhdZ9jJ9EVbWFXrs9+LoEAhW3DYRAV9e2VTly9G9KsN/xEqEDQEXLF0O
cETUaFv1eYsQmBorPHGaY33nBVt5lgiN03QH18VxRC2asp3MpX1CWnZLJZ7D
Y/7PbpKrIjwx6Q2Xn+VI3PtcTbdEhK21GEo8zxH07yVDp3oRrF68bMzK4xC1
7jjnSD6YtuVkjk8+nVe5oNZuQISJ6wuPGVzleGIafMKS/PDnb+1XXSng2HNR
9dO5r0VYppV9qbiUY2fe4S2r3xFD3WZbdE0th8vzP9G8RIzg/CHP6HqOzSVv
FB/ri3FX8O1qmwaOdVEhyvJlYsQ8KBxuuE3PX299uZiL8VbwXK+WNo756jor
ay3F2N5xweJMO8ePdryoxUqMstVmGls6OYrjilNb15IfzpY237vPYfH0zNpC
OzH6zldaPu7hSLqnLuwmX7SesUXz4lMOxyV6b8tcxLjo0/9qVy/H5UMqccvd
xNjBNa487+MwjilUWkc+2VoX/IFCwWEQH5fe6yeGyXLlsYKXHGutnM8u3y2G
LD69Zd8IR5fWuNQnUAxb96aTY2McJr1T64rIP7OqvSRlr+k8TS92k/ZRJf3X
aw5PcFycXZhxi/zTUybXspjk2O6siKyi/bX8pd741BRHbsqCmlzab/8DhIay
bA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.563043680392749*^9, 3.56304403586178*^9}, {
   3.563044112844111*^9, 3.56304412210821*^9}, {3.563044183803214*^9, 
   3.5630441983003683`*^9}, {3.563044711284185*^9, 3.5630447597803392`*^9}, {
   3.56304480214662*^9, 3.5630448271839943`*^9}, {3.563044864882463*^9, 
   3.563044893496107*^9}, {3.563045766773737*^9, 3.563045803538086*^9}, {
   3.563045839496114*^9, 3.563045857135682*^9}, {3.563046051239579*^9, 
   3.5630460773413153`*^9}, {3.563046125092463*^9, 3.563046155482294*^9}, {
   3.563046223829384*^9, 3.563046230573269*^9}, {3.563046271030015*^9, 
   3.5630462783595057`*^9}, {3.563046337800371*^9, 3.5630463883975058`*^9}, {
   3.5738431357927303`*^9, 3.5738432408013372`*^9}, {3.573843422436076*^9, 
   3.5738434326201897`*^9}, {3.573843681562263*^9, 3.5738437608894157`*^9}, {
   3.573844131893845*^9, 3.573844158768499*^9}, 3.6433215981501713`*^9, 
   3.643321655092658*^9, 3.643322077242013*^9, 3.6656210988983793`*^9, 
   3.66562156310452*^9, 3.6656216568876467`*^9, 3.665623550279649*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example of providing an external input", "Subsection",
 CellChangeTimes->{{3.506990906717347*^9, 3.5069909078193007`*^9}, {
  3.521032741023697*^9, 3.521032783431868*^9}, {3.5210328332469597`*^9, 
  3.521032834067655*^9}, {3.573842620940196*^9, 3.5738426327121897`*^9}, {
  3.5738429513535624`*^9, 3.573842956086698*^9}, {3.573843811422264*^9, 
  3.573843815516943*^9}}],

Cell["\<\
You can intermix definitions of the form x[t]==..., \
x\[CloseCurlyQuote][t]==..., with rxn, term, and conc statements.\
\>", "Text",
 CellChangeTimes->{{3.506991984949119*^9, 3.506992103346533*^9}, {
   3.5738427714493523`*^9, 3.573842897955778*^9}, {3.573842994670869*^9, 
   3.57384303313078*^9}, 3.573843969081559*^9, {3.573844074060257*^9, 
   3.5738441067369413`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmax", "=", "20"}], ";"}]], "Input",
 CellChangeTimes->{{3.5630436161556053`*^9, 3.563043618257226*^9}, {
   3.563043686325157*^9, 3.563043686388475*^9}, {3.563043759254019*^9, 
   3.563043895036664*^9}, {3.563043937211443*^9, 3.563043953876205*^9}, 
   3.563044000951704*^9, 3.5630440352422657`*^9, {3.5630447087509604`*^9, 
   3.563044756673802*^9}, {3.563044884316877*^9, 3.5630448868602333`*^9}, 
   3.563045769786368*^9, 3.563045800011384*^9, 3.5630458439373703`*^9, {
   3.563046043168994*^9, 3.5630460736644487`*^9}, 3.573843037197281*^9, 
   3.57384315433589*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsys", "=", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"u", "[", "t", "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"0.1", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "+", "1"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"revrxn", "[", 
      RowBox[{
       RowBox[{"x1", "+", "u"}], ",", "x2", ",", "1", ",", "1"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"conc", "[", 
      RowBox[{"x1", ",", "1"}], "]"}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.563043448627839*^9, 3.563043602060258*^9}, {
  3.563043634831092*^9, 3.563043656394458*^9}, {3.5630437973495092`*^9, 
  3.5630438106314163`*^9}, {3.5630438636297903`*^9, 3.5630439022138863`*^9}, {
  3.563043964900153*^9, 3.563043974520196*^9}, {3.563045085844963*^9, 
  3.563045090139509*^9}, {3.563045255921225*^9, 3.563045259750983*^9}, {
  3.56304574780858*^9, 3.56304579453188*^9}, {3.563045825990694*^9, 
  3.563045832334564*^9}, {3.573843059126924*^9, 3.5738431188983297`*^9}, {
  3.5738436329230757`*^9, 3.573843677552498*^9}, {3.573843722318182*^9, 
  3.573843753584358*^9}, {3.573843856216565*^9, 3.5738439541722507`*^9}, {
  3.573843992236495*^9, 3.573843992577783*^9}, {3.5738440258224993`*^9, 
  3.573844056699739*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"SimulateRxnsys", "[", 
    RowBox[{"rsys", ",", "tmax"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.563043604869884*^9, 3.563043624758172*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotter", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x1", "[", "t", "]"}], ",", 
      RowBox[{"x2", "[", "t", "]"}], ",", 
      RowBox[{"u", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.563043658666382*^9, 3.5630436690599213`*^9}, {
  3.573843958227273*^9, 3.57384396223566*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"plotter", ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.563043670604801*^9, 3.56304367916113*^9}, {
  3.5630437097472467`*^9, 3.563043715377193*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV2nc8lV8YAHC7hAgXmZe41r24VNrnSZmpNEQhm5ZVVkUZ2bOkiZRkZRTJ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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV2nk4lF0YB2A7iWxDZR1iRsxgxprKeZIlJaG0ICF8IqGkEiKKJEQSUbZs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     "]]}, 
   {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwdmnc81d8fx0nJ3pS9r3CNazbkvFOUESENKzuRkQhRJDIy+opCNFA0UKJQ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.563043680392749*^9, 3.56304403586178*^9}, {
   3.563044112844111*^9, 3.56304412210821*^9}, {3.563044183803214*^9, 
   3.5630441983003683`*^9}, {3.563044711284185*^9, 3.5630447597803392`*^9}, {
   3.56304480214662*^9, 3.5630448271839943`*^9}, {3.563044864882463*^9, 
   3.563044893496107*^9}, {3.563045766773737*^9, 3.563045803538086*^9}, {
   3.563045839496114*^9, 3.563045857135682*^9}, {3.563046051239579*^9, 
   3.5630460773413153`*^9}, {3.563046125092463*^9, 3.563046155482294*^9}, {
   3.563046223829384*^9, 3.563046230573269*^9}, {3.563046271030015*^9, 
   3.5630462783595057`*^9}, {3.563046337800371*^9, 3.5630463883975058`*^9}, {
   3.5738431357927303`*^9, 3.5738432408013372`*^9}, {3.573843422436076*^9, 
   3.5738434326201897`*^9}, {3.573843681562263*^9, 3.5738437608894157`*^9}, {
   3.573843971137948*^9, 3.57384399462306*^9}, {3.573844028013495*^9, 
   3.5738440584790792`*^9}, {3.5738441320760603`*^9, 3.573844158941675*^9}, 
   3.6433215988271713`*^9, 3.643321655385705*^9, 3.6433220774408417`*^9, 
   3.665621099009594*^9, 3.6656215632438593`*^9, 3.665621656986082*^9, 
   3.665623550403854*^9}]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{740, 756},
WindowMargins->{{Automatic, 148}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"10.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 10, \
2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info-c53a0585-9331-41fd-a5bf-e9baef649dbe"->{
  Cell[1013, 33, 764, 11, 131, "Print",
   CellTags->"Info-c53a0585-9331-41fd-a5bf-e9baef649dbe"]},
 "Info-48f1dae4-c3c0-4ae4-969b-bad5886db60f"->{
  Cell[1939, 53, 453, 7, 77, "Print",
   CellTags->"Info-48f1dae4-c3c0-4ae4-969b-bad5886db60f"]},
 "Info-884ad53b-0653-463f-b05a-cbeb768e1d34"->{
  Cell[2490, 68, 365, 6, 60, "Print",
   CellTags->"Info-884ad53b-0653-463f-b05a-cbeb768e1d34"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info-c53a0585-9331-41fd-a5bf-e9baef649dbe", 433509, 7503},
 {"Info-48f1dae4-c3c0-4ae4-969b-bad5886db60f", 433657, 7506},
 {"Info-884ad53b-0653-463f-b05a-cbeb768e1d34", 433803, 7509}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 125, 1, 30, "Text"],
Cell[685, 23, 177, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[887, 29, 123, 2, 28, "Input"],
Cell[1013, 33, 764, 11, 131, "Print",
 CellTags->"Info-c53a0585-9331-41fd-a5bf-e9baef649dbe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1814, 49, 122, 2, 28, "Input"],
Cell[1939, 53, 453, 7, 77, "Print",
 CellTags->"Info-48f1dae4-c3c0-4ae4-969b-bad5886db60f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2429, 65, 58, 1, 28, "Input"],
Cell[2490, 68, 365, 6, 60, "Print",
 CellTags->"Info-884ad53b-0653-463f-b05a-cbeb768e1d34"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2892, 79, 101, 1, 44, "Subsection"],
Cell[2996, 82, 1092, 24, 148, "Input"],
Cell[4091, 108, 236, 5, 28, "Input"],
Cell[4330, 115, 234, 6, 28, "Input"],
Cell[4567, 123, 816, 17, 28, "Input"],
Cell[CellGroupData[{
Cell[5408, 144, 863, 20, 46, "Input"],
Cell[6274, 166, 67386, 1118, 248, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[73709, 1290, 194, 2, 44, "Subsection"],
Cell[73906, 1294, 1193, 29, 114, "Input"],
Cell[75102, 1325, 320, 6, 28, "Input"],
Cell[75425, 1333, 329, 7, 28, "Input"],
Cell[75757, 1342, 902, 18, 28, "Input"],
Cell[CellGroupData[{
Cell[76684, 1364, 863, 20, 46, "Input"],
Cell[77550, 1386, 9322, 166, 231, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[86921, 1558, 113, 1, 44, "Subsection"],
Cell[87037, 1561, 380, 6, 68, "Text"],
Cell[87420, 1569, 337, 6, 28, "Input"],
Cell[87760, 1577, 1405, 21, 28, "Input"],
Cell[89168, 1600, 5396, 99, 233, "Input"],
Cell[94567, 1701, 1952, 40, 148, "Input"],
Cell[96522, 1743, 357, 7, 28, "Input"],
Cell[96882, 1752, 1043, 22, 97, "Input"],
Cell[CellGroupData[{
Cell[97950, 1778, 1599, 45, 80, "Input"],
Cell[99552, 1825, 169873, 2805, 240, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[269474, 4636, 242, 3, 44, "Subsection"],
Cell[269719, 4641, 141, 1, 30, "Text"],
Cell[269863, 4644, 1135, 24, 114, "Input"],
Cell[271001, 4670, 346, 6, 68, "Text"],
Cell[271350, 4678, 1077, 27, 131, "Input"],
Cell[CellGroupData[{
Cell[272452, 4709, 186, 4, 28, "Input"],
Cell[272641, 4715, 1702, 24, 28, "Output"]
}, Open  ]],
Cell[274358, 4742, 585, 11, 28, "Input"],
Cell[CellGroupData[{
Cell[274968, 4757, 902, 18, 28, "Input"],
Cell[275873, 4777, 2100, 32, 83, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[278010, 4814, 863, 20, 46, "Input"],
Cell[278876, 4836, 2104, 32, 83, "Message"],
Cell[280983, 4870, 2138, 32, 83, "Message"],
Cell[283124, 4904, 2104, 32, 83, "Message"],
Cell[285231, 4938, 567, 12, 24, "Message"],
Cell[285801, 4952, 1203, 29, 243, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[287053, 4987, 339, 4, 44, "Subsection"],
Cell[287395, 4993, 422, 8, 49, "Text"],
Cell[287820, 5003, 606, 10, 28, "Input"],
Cell[288429, 5015, 1419, 22, 28, "Input"],
Cell[289851, 5039, 2403, 63, 133, "Input"],
Cell[292257, 5104, 208, 5, 28, "Input"],
Cell[292468, 5111, 330, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[292823, 5125, 314, 7, 28, "Input"],
Cell[293140, 5134, 77834, 1288, 242, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[371023, 6428, 376, 5, 44, "Subsection"],
Cell[371402, 6435, 384, 7, 30, "Text"],
Cell[371789, 6444, 606, 10, 28, "Input"],
Cell[372398, 6456, 1323, 28, 97, "Input"],
Cell[373724, 6486, 208, 5, 28, "Input"],
Cell[373935, 6493, 377, 11, 28, "Input"],
Cell[CellGroupData[{
Cell[374337, 6508, 314, 7, 28, "Input"],
Cell[374654, 6517, 58381, 969, 237, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
